import{_ as e,a as t,g as n,h as r,l as i,n as a,v as o,y as s}from"./chunk-NNHCCRGN.BGI6DATj.js";var c,l=(c=class extends a{runCustomConverter(e,t,n){switch(e.name.toUpperCase()){case`LINK_LABEL`:return t.substring(1).trim();default:return}}},n(c,`WardleyValueConverter`),c),u={parser:{ValueConverter:n(()=>new l,`ValueConverter`)}};function d(n=t){let a=s(o(n),i),c=s(e({shared:a}),r,u);return a.ServiceRegistry.register(c),{shared:a,Wardley:c}}n(d,`createWardleyServices`);export{d as n,u as t};
//# sourceMappingURL=chunk-PUPMXCY4.BYFAhBNn.js.map