import{_ as e,a as t,g as n,l as r,n as i,r as a,t as o,v as s,y as c}from"./chunk-NNHCCRGN.BGI6DATj.js";var l,u,d=(l=class extends o{constructor(){super([`architecture`])}},n(l,`ArchitectureTokenBuilder`),l),f=(u=class extends i{runCustomConverter(e,t,n){if(e.name===`ARCH_ICON`)return t.replace(/[()]/g,``).trim();if(e.name===`ARCH_TEXT_ICON`)return t.replace(/["()]/g,``);if(e.name===`ARCH_TITLE`){let e=t.replace(/^\[|]$/g,``).trim();return(e.startsWith(`"`)&&e.endsWith(`"`)||e.startsWith(`'`)&&e.endsWith(`'`))&&(e=e.slice(1,-1),e=e.replace(/\\"/g,`"`).replace(/\\'/g,`'`)),e.trim()}}},n(u,`ArchitectureValueConverter`),u),p={parser:{TokenBuilder:n(()=>new d,`TokenBuilder`),ValueConverter:n(()=>new f,`ValueConverter`)}};function m(n=t){let i=c(s(n),r),o=c(e({shared:i}),a,p);return i.ServiceRegistry.register(o),{shared:i,Architecture:o}}n(m,`createArchitectureServices`);export{m as n,p as t};
//# sourceMappingURL=chunk-4EGX6M5U.BreLmhuN.js.map