import"./src.CuIhI8vM.js";import{a as e,n as t}from"./chunk-AGHRB4JF.DxL_-brX.js";import{x as n}from"./chunk-CSCIHK7Q.gzGma1mM.js";var r=t(t=>{let{securityLevel:r}=n(),i=e(`body`);return r===`sandbox`&&(i=e((e(`#i${t}`).node()?.contentDocument??document).body)),i.select(`#${t}`)},`selectSvgElement`);export{r as t};
//# sourceMappingURL=chunk-WU5MYG2G.5keauw9d.js.map