.main-graph[data-v-422c4aad]{height:260px;padding-top:2px}.contributor-grid[data-v-422c4aad]{display:grid;grid-template-columns:repeat(2,1fr);gap:1rem}.contributor-grid[data-v-422c4aad]>*{min-width:0}@media(max-width:991.98px){.contributor-grid[data-v-422c4aad]{grid-template-columns:repeat(1,1fr)}}.contributor-name[data-v-422c4aad]{margin-bottom:0}
