import{n as e}from"./chunk-AGHRB4JF.DxL_-brX.js";function t(e,t){e.accDescr&&t.setAccDescription?.(e.accDescr),e.accTitle&&t.setAccTitle?.(e.accTitle),e.title&&t.setDiagramTitle?.(e.title)}e(t,`populateCommonDb`);export{t};
//# sourceMappingURL=chunk-4BX2VUAB.DDLxcafl.js.map