import{o as e}from"./chunk.BnKUq5qt.js";import{i as t}from"./index.CzQRfW04.js";import{m as n,p as r}from"./src.CuIhI8vM.js";function i(e){return typeof e==`string`?new r([[document.querySelector(e)]],[document.documentElement]):new r([[e]],n)}var a=e(t(),1),o=Object.defineProperty,s=(e,t)=>o(e,`name`,{value:t,configurable:!0}),c=(e,t)=>{for(var n in t)o(e,n,{get:t[n],enumerable:!0})},l={trace:0,debug:1,info:2,warn:3,error:4,fatal:5},u={trace:s((...e)=>{},`trace`),debug:s((...e)=>{},`debug`),info:s((...e)=>{},`info`),warn:s((...e)=>{},`warn`),error:s((...e)=>{},`error`),fatal:s((...e)=>{},`fatal`)},d=s(function(e=`fatal`){let t=l.fatal;typeof e==`string`?e.toLowerCase()in l&&(t=l[e]):typeof e==`number`&&(t=e),u.trace=()=>{},u.debug=()=>{},u.info=()=>{},u.warn=()=>{},u.error=()=>{},u.fatal=()=>{},t<=l.fatal&&(u.fatal=console.error?console.error.bind(console,f(`FATAL`),`color: orange`):console.log.bind(console,`\x1B[35m`,f(`FATAL`))),t<=l.error&&(u.error=console.error?console.error.bind(console,f(`ERROR`),`color: orange`):console.log.bind(console,`\x1B[31m`,f(`ERROR`))),t<=l.warn&&(u.warn=console.warn?console.warn.bind(console,f(`WARN`),`color: orange`):console.log.bind(console,`\x1B[33m`,f(`WARN`))),t<=l.info&&(u.info=console.info?console.info.bind(console,f(`INFO`),`color: lightblue`):console.log.bind(console,`\x1B[34m`,f(`INFO`))),t<=l.debug&&(u.debug=console.debug?console.debug.bind(console,f(`DEBUG`),`color: lightgreen`):console.log.bind(console,`\x1B[32m`,f(`DEBUG`))),t<=l.trace&&(u.trace=console.debug?console.debug.bind(console,f(`TRACE`),`color: lightgreen`):console.log.bind(console,`\x1B[32m`,f(`TRACE`)))},`setLogLevel`),f=s(e=>`%c${(0,a.default)().format(`ss.SSS`)} : ${e} : `,`format`);export{i as a,d as i,s as n,u as r,c as t};
//# sourceMappingURL=chunk-AGHRB4JF.DxL_-brX.js.map