.ui.dropdown .menu.show[data-v-9b5858f4]{display:block}.ui.checkbox label[data-v-9b5858f4]{cursor:pointer}.ui.merge-button[data-v-9b5858f4]{position:relative}.ui.merge-button .ui.dropdown[data-v-9b5858f4]{position:static}.ui.merge-button>.ui.dropdown:last-child>.menu[data-v-9b5858f4]:not(.left){left:0;right:auto}.ui.merge-button .ui.dropdown .menu>.item[data-v-9b5858f4]{display:flex;align-items:stretch;padding:0!important}.action-text[data-v-9b5858f4]{padding:.8rem;flex:1}.auto-merge-small[data-v-9b5858f4]{width:40px;display:flex;align-items:center;justify-content:center;position:relative}.auto-merge-small .auto-merge-tip[data-v-9b5858f4]{display:none;left:38px;top:-1px;bottom:-1px;position:absolute;align-items:center;color:var(--color-text);background-color:var(--color-info-bg);border:1px solid var(--color-info-border);border-left:none;padding-right:1rem}.auto-merge-small[data-v-9b5858f4]:hover{color:var(--color-text);background-color:var(--color-info-bg);border:1px solid var(--color-info-border)}.auto-merge-small:hover .auto-merge-tip[data-v-9b5858f4]{display:flex}
