import{n as e,r as t}from"./chunk-AGHRB4JF.DxL_-brX.js";import{c as n}from"./chunk-CSCIHK7Q.gzGma1mM.js";import{t as r}from"./chunk-WU5MYG2G.5keauw9d.js";import{t as i}from"./mermaid-parser.core.DvCkhQiH.js";var a={parse:e(async e=>{let n=await i(`info`,e);t.debug(n)},`parse`)},o={version:`11.15.0`},s={parser:a,db:{getVersion:e(()=>o.version,`getVersion`)},renderer:{draw:e((e,i,a)=>{t.debug(`rendering info diagram
`+e);let o=r(i);n(o,100,400,!0),o.append(`g`).append(`text`).attr(`x`,100).attr(`y`,40).attr(`class`,`version`).attr(`font-size`,32).style(`text-anchor`,`middle`).text(`v${a}`)},`draw`)}};export{s as diagram};
//# sourceMappingURL=infoDiagram-5YYISTIA.CiizO-x_.js.map