import{t as e}from"./chunk.BnKUq5qt.js";var t=e((e=>{Object.defineProperty(e,`__esModule`,{value:!0}),e.default=void 0;function t(e,t){return o(e)||a(e,t)||r(e,t)||n()}function n(){throw TypeError(`Invalid attempt to destructure non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function r(e,t){if(e){if(typeof e==`string`)return i(e,t);var n=Object.prototype.toString.call(e).slice(8,-1);if(n===`Object`&&e.constructor&&(n=e.constructor.name),n===`Map`||n===`Set`)return Array.from(e);if(n===`Arguments`||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n))return i(e,t)}}function i(e,t){(t==null||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}function a(e,t){var n=e==null?null:typeof Symbol<`u`&&e[Symbol.iterator]||e[`@@iterator`];if(n!=null){var r=[],i=!0,a=!1,o,s;try{for(n=n.call(e);!(i=(o=n.next()).done)&&(r.push(o.value),!(t&&r.length===t));i=!0);}catch(e){a=!0,s=e}finally{try{!i&&n.return!=null&&n.return()}finally{if(a)throw s}}return r}}function o(e){if(Array.isArray(e))return e}var s={jan:1,feb:2,mar:3,apr:4,may:5,jun:6,jul:7,aug:8,sep:9,oct:10,nov:11,dec:12},c=/ (?:to|[-/]) | ?(?:--|[–—]) ?/,l=/^(\d{4}-\d{2}-\d{2})\/(\d{4}-\d{2}-\d{2})$/;function u(e){return s[e.toLowerCase().slice(0,3)]}function d(e){let t=new Date(e);return typeof e==`number`&&!isNaN(t.valueOf())?[t.getFullYear(),t.getMonth()+1,t.getDate()]:null}var f=function(e){let n=/^(\d{4}|[-+]\d{6,})-(\d{2})(?:-(\d{2}))?/;if(typeof e!=`string`||!n.test(e))return null;let r=t(e.match(n),4),i=r[1],a=r[2],o=r[3];return+a?+o?[i,a,o]:[i,a]:[i]},p=function(e){let n=/^(?:[a-z]{3},\s*)?(\d{1,2}) ([a-z]{3}) (\d{4,})/i;if(typeof e!=`string`||!n.test(e))return null;let r=t(e.match(n),4),i=r[1],a=r[2],o=r[3];return a=u(a),a?[o,a,i]:null};function m(e){let n=/^(\d{1,2})\/(\d{1,2})\/(\d{2}(?:\d{2})?)/;if(typeof e!=`string`||!n.test(e))return null;let r=t(e.match(n),4),i=r[1],a=r[2],o=r[3];return new Date(o,i,a).getMonth()===parseInt(i)?[o,i,a]:null}function h(e){let n=/^(\d{1,2})[ .\-/](\d{1,2}|[a-z]{3,10})[ .\-/](-?\d+)/i,r=/^(-?\d+)[ .\-/](\d{1,2}|[a-z]{3,10})[ .\-/](\d{1,2})/i,i,a,o;if(typeof e!=`string`)return null;if(n.test(e)){var s=t(e.match(n),4);o=s[1],a=s[2],i=s[3]}else if(r.test(e)){var c=t(e.match(r),4);i=c[1],a=c[2],o=c[3]}else return null;if(u(a))a=u(a);else if(isNaN(a))return null;return[i,a,o]}function g(e){let t=/^([a-z]{3,10}|-?\d+)[^\w-]+([a-z]{3,10}|-?\d+)$/i;if(typeof e==`string`&&t.test(e)){let n=e.match(t).slice(1,3),r;if(u(n[1]))r=u(n.pop());else if(u(n[0]))r=u(n.shift());else if(n.some(isNaN)||n.every(e=>+e<0))return null;else r=+n[0]<0||+n[0]>+n[1]&&+n[1]>0?n.pop():n.shift();return[n.pop(),r]}else return null}function _(e){if(typeof e!=`string`)return null;let n=e.match(/^(\d+) ?(a\.?d\.?|b\.?c\.?)$/i);if(n){let e=t(n.slice(1),2);return[e[0]*(e[1].toLowerCase()[0]===`a`?1:-1)]}else if(/^-?\d+$/.test(e))return[e];else return null}function v(e){let t=d(e)||f(e)||p(e)||m(e)||h(e)||g(e)||_(e);return t&&t.map(e=>parseInt(e))}function y(e){return l.test(e)?e.match(l).slice(1,3):e.split(c)}function b(e,t){let n=[],r=typeof e==`string`&&y(e);t?n.push(e,t):r&&r.length===2?n.push(...r):n.push(e);let i=n.map(v);return i.filter(Boolean).length===n.length?{"date-parts":i}:{raw:t?n.join(`/`):e}}e.default=b})),n=e((e=>{Object.defineProperty(e,`__esModule`,{value:!0}),e.default=void 0;function t(e,t,n){if(e.length>=t)return e;for(;e.length<t;)e=n+e;return e.slice(-t)}e.default=function(e,n=`-`){if(!e[`date-parts`])return e.raw;let r=e[`date-parts`][0].map(e=>e.toString());switch(r.length){case 3:r[2]=t(r[2],2,`0`);case 2:r[1]=t(r[1],2,`0`);case 1:r[0]=t(r[0],4,`0`);break}return r.join(n)}})),r=e((e=>{Object.defineProperty(e,`__esModule`,{value:!0}),Object.defineProperty(e,`format`,{enumerable:!0,get:function(){return i.default}}),Object.defineProperty(e,`parse`,{enumerable:!0,get:function(){return r.default}});var r=a(t()),i=a(n());function a(e){return e&&e.__esModule?e:{default:e}}}));export{r as t};
//# sourceMappingURL=lib.BHqCfTyD.js.map