import{a as e}from"./dist.BKE5SKAa.js";import{foldAll as t,foldCode as n,unfoldAll as r,unfoldCode as i}from"./dist.C3J8NGfd.js";import{a,c as o,n as s,r as c,u as l}from"./dist.CeRwgBQH.js";import{copyLineDown as ee,copyLineUp as te,cursorCharLeft as u,cursorCharRight as d,cursorDocEnd as f,cursorDocStart as p,cursorGroupLeft as m,cursorGroupRight as h,cursorLineBoundaryBackward as g,cursorLineBoundaryForward as _,cursorLineDown as v,cursorLineEnd as y,cursorLineStart as b,cursorLineUp as x,cursorMatchingBracket as ne,cursorPageDown as S,cursorPageUp as C,deleteCharBackward as w,deleteCharForward as T,deleteGroupBackward as E,deleteGroupForward as D,deleteLine as O,deleteToLineEnd as k,deleteToLineStart as re,indentLess as A,indentMore as j,insertNewlineAndIndent as M,lineComment as N,lineUncomment as P,moveLineDown as F,moveLineUp as I,redo as L,selectAll as R,selectCharLeft as z,selectCharRight as B,selectDocEnd as V,selectDocStart as H,selectGroupLeft as U,selectGroupRight as W,selectLine as G,selectLineBoundaryBackward as K,selectLineBoundaryForward as q,selectLineDown as J,selectLineEnd as Y,selectLineStart as ie,selectLineUp as X,selectPageDown as Z,selectPageUp as Q,splitLine as ae,toggleBlockComment as oe,toggleComment as se,transposeChars as ce,undo as le,undoSelection as ue}from"./dist.ZrXXOvNM.js";import{nextDiagnostic as de,openLintPanel as fe}from"./dist.C0gsWESI.js";import{closeSearchPanel as pe,gotoLine as me,openSearchPanel as he,replaceAll as ge,selectMatches as _e,selectNextOccurrence as ve,selectSelectionMatches as ye}from"./dist.BZ_AGDuk.js";var $=e=>t=>{let n=e===`down`,r=t.state.selection;for(let e of r.ranges)r=r.addRange(t.moveVertically(e,n));return t.dispatch({selection:r}),!0},be=[{key:`Ctrl-Space`,run:l},{key:`Escape`,run:c},{key:`ArrowDown`,run:o(!0)},{key:`ArrowUp`,run:o(!1)},{key:`PageDown`,run:o(!0,`page`)},{key:`PageUp`,run:o(!1,`page`)},{key:`Enter`,run:s},{key:`Tab`,run:s},{key:`Mod-f`,run:he,scope:`editor search-panel`},{key:`Escape`,run:pe,scope:`editor search-panel`},{key:`Alt-Enter`,run:_e,scope:`editor search-panel`},{key:`Mod-Alt-Enter`,run:ge,scope:`editor search-panel`},{key:`Ctrl-g`,run:me},{key:`Mod-d`,run:ve,preventDefault:!0},{key:`Shift-Mod-l`,run:ye},{key:`Enter`,run:M,shift:M},{key:`ArrowLeft`,run:u,shift:z,preventDefault:!0},{key:`Mod-ArrowLeft`,mac:`Alt-ArrowLeft`,run:m,shift:U},{key:`ArrowRight`,run:d,shift:B,preventDefault:!0},{key:`Mod-ArrowRight`,mac:`Alt-ArrowRight`,run:h,shift:W},{key:`ArrowUp`,run:x,shift:X,preventDefault:!0},{key:`ArrowDown`,run:v,shift:J,preventDefault:!0},{key:`Home`,run:g,shift:K},{mac:`Cmd-ArrowLeft`,run:g,shift:K},{key:`Mod-Home`,run:p,shift:H},{mac:`Cmd-ArrowUp`,run:p,shift:H},{key:`PageUp`,run:C,shift:Q},{mac:`Ctrl-ArrowUp`,run:C,shift:Q},{key:`PageDown`,run:S,shift:Z},{mac:`Ctrl-ArrowDown`,run:S,shift:Z},{key:`End`,run:_,shift:q},{mac:`Cmd-ArrowRight`,run:_,shift:q},{key:`Mod-Alt-ArrowUp`,linux:`Shift-Alt-ArrowUp`,run:$(`up`),preventDefault:!0},{key:`Mod-Alt-ArrowDown`,linux:`Shift-Alt-ArrowDown`,run:$(`down`),preventDefault:!0},{key:`Shift-Alt-i`,run:t=>{let n=null;for(let r of t.state.selection.ranges)if(!r.empty)for(let i=r.from;i<=r.to;){let a=t.state.doc.lineAt(i),o=Math.min(a.to,r.to);n=n?n.addRange(e.range(o,o)):e.single(o),i=a.to+1}return n?(t.dispatch({selection:n}),!0):!1}},{key:`Mod-End`,run:f,shift:V},{mac:`Cmd-ArrowDown`,run:f,shift:V},{key:`Mod-a`,run:R},{key:`Backspace`,run:a},{key:`Backspace`,run:w,shift:w},{key:`Delete`,run:T},{key:`Mod-Backspace`,mac:`Alt-Backspace`,run:E},{key:`Mod-Delete`,mac:`Alt-Delete`,run:D},{mac:`Mod-Backspace`,run:re},{mac:`Mod-Delete`,run:k},{mac:`Ctrl-b`,run:u,shift:z,preventDefault:!0},{mac:`Ctrl-f`,run:d,shift:B},{mac:`Ctrl-p`,run:x,shift:X},{mac:`Ctrl-n`,run:v,shift:J},{mac:`Ctrl-a`,run:b,shift:ie},{mac:`Ctrl-e`,run:y,shift:Y},{mac:`Ctrl-d`,run:T},{mac:`Ctrl-h`,run:w},{mac:`Ctrl-k`,run:k},{mac:`Ctrl-Alt-h`,run:E},{mac:`Ctrl-o`,run:ae},{mac:`Ctrl-t`,run:ce},{mac:`Ctrl-v`,run:S},{mac:`Alt-v`,run:C},{key:`Shift-Mod-k`,run:O},{key:`Alt-ArrowDown`,run:F},{key:`Alt-ArrowUp`,run:I},{win:`Shift-Alt-ArrowDown`,mac:`Shift-Alt-ArrowDown`,run:ee},{win:`Shift-Alt-ArrowUp`,mac:`Shift-Alt-ArrowUp`,run:te},{key:`Mod-l`,run:G,preventDefault:!0},{key:`Shift-Mod-\\`,run:ne},{key:`Tab`,run:j,shift:A,preventDefault:!0},{key:`Mod-[`,run:A},{key:`Mod-]`,run:j},{key:`Ctrl-Shift-[`,mac:`Cmd-Alt-[`,run:n},{key:`Ctrl-Shift-]`,mac:`Cmd-Alt-]`,run:i},{key:`Mod-k Mod-0`,run:t},{key:`Mod-k Mod-j`,run:r},{key:`Mod-k Mod-c`,run:N},{key:`Mod-k Mod-u`,run:P},{key:`Mod-/`,run:se},{key:`Shift-Alt-a`,run:oe},{key:`Mod-z`,run:le,preventDefault:!0},{key:`Mod-y`,run:L,preventDefault:!0},{key:`Mod-Shift-z`,run:L,preventDefault:!0},{key:`Mod-u`,run:ue,preventDefault:!0},{key:`Mod-Shift-m`,run:fe},{key:`F8`,run:de}];export{be as vscodeKeymap};
//# sourceMappingURL=dist.CqDGeYY4.js.map