import{_ as e,a as t,g as n,i as r,l as i,s as a,t as o,v as s,y as c}from"./chunk-NNHCCRGN.BGI6DATj.js";var l,u=(l=class extends o{constructor(){super([`gitGraph`])}},n(l,`GitGraphTokenBuilder`),l),d={parser:{TokenBuilder:n(()=>new u,`TokenBuilder`),ValueConverter:n(()=>new r,`ValueConverter`)}};function f(n=t){let r=c(s(n),i),o=c(e({shared:r}),a,d);return r.ServiceRegistry.register(o),{shared:r,GitGraph:o}}n(f,`createGitGraphServices`);export{f as n,d as t};
//# sourceMappingURL=chunk-UIBZB4QT.Cj3b_zdz.js.map