import"./src.CuIhI8vM.js";import{a as e,n as t}from"./chunk-AGHRB4JF.DxL_-brX.js";var n=t((t,n)=>{let r;return n===`sandbox`&&(r=e(`#i`+t)),e(n===`sandbox`?r.nodes()[0].contentDocument.body:`body`).select(`[id="${t}"]`)},`getDiagramElement`);export{n as t};
//# sourceMappingURL=chunk-55IACEB6.B2RA2Tk1.js.map