const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["../css/index.DyzB1JtW.css"])))=>i.map(i=>d[i]);
import{t as e}from"./preload-helper.DOHRDkqH.js";import{n as t,r as n}from"./chunk-AGHRB4JF.DxL_-brX.js";import{d as r}from"./chunk-5ZQYHXKU.C2vdTzMn.js";import{b as i,s as a}from"./chunk-CSCIHK7Q.gzGma1mM.js";import{a as o,i as s,s as c}from"./chunk-3OPIFGDE.DMut3ZHV.js";import{a as l,i as u,n as d,r as f}from"./chunk-KSCS5N6A.DmERsiir.js";var p={common:a,getConfig:i,insertCluster:s,insertEdge:d,insertEdgeLabel:f,insertMarkers:u,insertNode:o,interpolateToCurve:r,labelHelper:c,log:n,positionEdgeLabel:l},m={},h=t(e=>{for(let t of e)m[t.name]=t},`registerLayoutLoaders`);t(()=>{h([{name:`dagre`,loader:t(async()=>await e(()=>import(`./dagre-BM42HDAG.FkPrs6WQ.js`),__vite__mapDeps([0]),import.meta.url),`loader`)},...[{name:`cose-bilkent`,loader:t(async()=>await e(()=>import(`./cose-bilkent-S5V4N54A.EBc9AOXc.js`),__vite__mapDeps([0]),import.meta.url),`loader`)}]])},`registerDefaultLayoutLoaders`)();var g=t(async(e,t)=>{if(!(e.layoutAlgorithm in m))throw Error(`Unknown layout algorithm: ${e.layoutAlgorithm}`);if(e.diagramId)for(let t of e.nodes){let n=t.domId||t.id;t.domId=`${e.diagramId}-${n}`}let n=m[e.layoutAlgorithm],r=await n.loader(),{theme:i,themeVariables:a}=e.config,{useGradient:o,gradientStart:s,gradientStop:c}=a,l=t.attr(`id`);if(t.append(`defs`).append(`filter`).attr(`id`,`${l}-drop-shadow`).attr(`height`,`130%`).attr(`width`,`130%`).append(`feDropShadow`).attr(`dx`,`4`).attr(`dy`,`4`).attr(`stdDeviation`,0).attr(`flood-opacity`,`0.06`).attr(`flood-color`,`${i?.includes(`dark`)?`#FFFFFF`:`#000000`}`),t.append(`defs`).append(`filter`).attr(`id`,`${l}-drop-shadow-small`).attr(`height`,`150%`).attr(`width`,`150%`).append(`feDropShadow`).attr(`dx`,`2`).attr(`dy`,`2`).attr(`stdDeviation`,0).attr(`flood-opacity`,`0.06`).attr(`flood-color`,`${i?.includes(`dark`)?`#FFFFFF`:`#000000`}`),o){let e=t.append(`linearGradient`).attr(`id`,t.attr(`id`)+`-gradient`).attr(`gradientUnits`,`objectBoundingBox`).attr(`x1`,`0%`).attr(`y1`,`0%`).attr(`x2`,`100%`).attr(`y2`,`0%`);e.append(`svg:stop`).attr(`offset`,`0%`).attr(`stop-color`,s).attr(`stop-opacity`,1),e.append(`svg:stop`).attr(`offset`,`100%`).attr(`stop-color`,c).attr(`stop-opacity`,1)}return r.render(e,t,p,{algorithm:n.algorithm})},`render`),_=t((e=``,{fallback:t=`dagre`}={})=>{if(e in m)return e;if(t in m)return n.warn(`Layout algorithm ${e} is not registered. Using ${t} as fallback.`),t;throw Error(`Both layout algorithms ${e} and ${t} are not registered.`)},`getRegisteredLayoutAlgorithm`);export{h as n,g as r,_ as t};
//# sourceMappingURL=chunk-LZXEDZCA.BAydbWNX.js.map