import{_ as e,a as t,g as n,l as r,n as i,p as a,t as o,v as s,y as c}from"./chunk-NNHCCRGN.BGI6DATj.js";var l,u,d=(l=class extends i{runCustomConverter(e,t,n){if(e.name===`INDENTATION`)return t?.length||0;if(e.name===`STRING2`)return t.substring(1,t.length-1)}},n(l,`TreeViewValueConverter`),l),f=(u=class extends o{constructor(){super([`treeView-beta`])}},n(u,`TreeViewTokenBuilder`),u),p={parser:{TokenBuilder:n(()=>new f,`TokenBuilder`),ValueConverter:n(()=>new d,`ValueConverter`)}};function m(n=t){let i=c(s(n),r),o=c(e({shared:i}),a,p);return i.ServiceRegistry.register(o),{shared:i,TreeView:o}}n(m,`createTreeViewServices`);export{m as n,p as t};
//# sourceMappingURL=chunk-WCWK7LTN.BaztnQUR.js.map