function e(e){var t=[],n=``,r={".abort":`builtin`,".align":`builtin`,".altmacro":`builtin`,".ascii":`builtin`,".asciz":`builtin`,".balign":`builtin`,".balignw":`builtin`,".balignl":`builtin`,".bundle_align_mode":`builtin`,".bundle_lock":`builtin`,".bundle_unlock":`builtin`,".byte":`builtin`,".cfi_startproc":`builtin`,".comm":`builtin`,".data":`builtin`,".def":`builtin`,".desc":`builtin`,".dim":`builtin`,".double":`builtin`,".eject":`builtin`,".else":`builtin`,".elseif":`builtin`,".end":`builtin`,".endef":`builtin`,".endfunc":`builtin`,".endif":`builtin`,".equ":`builtin`,".equiv":`builtin`,".eqv":`builtin`,".err":`builtin`,".error":`builtin`,".exitm":`builtin`,".extern":`builtin`,".fail":`builtin`,".file":`builtin`,".fill":`builtin`,".float":`builtin`,".func":`builtin`,".global":`builtin`,".gnu_attribute":`builtin`,".hidden":`builtin`,".hword":`builtin`,".ident":`builtin`,".if":`builtin`,".incbin":`builtin`,".include":`builtin`,".int":`builtin`,".internal":`builtin`,".irp":`builtin`,".irpc":`builtin`,".lcomm":`builtin`,".lflags":`builtin`,".line":`builtin`,".linkonce":`builtin`,".list":`builtin`,".ln":`builtin`,".loc":`builtin`,".loc_mark_labels":`builtin`,".local":`builtin`,".long":`builtin`,".macro":`builtin`,".mri":`builtin`,".noaltmacro":`builtin`,".nolist":`builtin`,".octa":`builtin`,".offset":`builtin`,".org":`builtin`,".p2align":`builtin`,".popsection":`builtin`,".previous":`builtin`,".print":`builtin`,".protected":`builtin`,".psize":`builtin`,".purgem":`builtin`,".pushsection":`builtin`,".quad":`builtin`,".reloc":`builtin`,".rept":`builtin`,".sbttl":`builtin`,".scl":`builtin`,".section":`builtin`,".set":`builtin`,".short":`builtin`,".single":`builtin`,".size":`builtin`,".skip":`builtin`,".sleb128":`builtin`,".space":`builtin`,".stab":`builtin`,".string":`builtin`,".struct":`builtin`,".subsection":`builtin`,".symver":`builtin`,".tag":`builtin`,".text":`builtin`,".title":`builtin`,".type":`builtin`,".uleb128":`builtin`,".val":`builtin`,".version":`builtin`,".vtable_entry":`builtin`,".vtable_inherit":`builtin`,".warning":`builtin`,".weak":`builtin`,".weakref":`builtin`,".word":`builtin`},i={};function a(){n=`#`,i.al=`variable`,i.ah=`variable`,i.ax=`variable`,i.eax=`variableName.special`,i.rax=`variableName.special`,i.bl=`variable`,i.bh=`variable`,i.bx=`variable`,i.ebx=`variableName.special`,i.rbx=`variableName.special`,i.cl=`variable`,i.ch=`variable`,i.cx=`variable`,i.ecx=`variableName.special`,i.rcx=`variableName.special`,i.dl=`variable`,i.dh=`variable`,i.dx=`variable`,i.edx=`variableName.special`,i.rdx=`variableName.special`,i.si=`variable`,i.esi=`variableName.special`,i.rsi=`variableName.special`,i.di=`variable`,i.edi=`variableName.special`,i.rdi=`variableName.special`,i.sp=`variable`,i.esp=`variableName.special`,i.rsp=`variableName.special`,i.bp=`variable`,i.ebp=`variableName.special`,i.rbp=`variableName.special`,i.ip=`variable`,i.eip=`variableName.special`,i.rip=`variableName.special`,i.cs=`keyword`,i.ds=`keyword`,i.ss=`keyword`,i.es=`keyword`,i.fs=`keyword`,i.gs=`keyword`}function o(){n=`@`,r.syntax=`builtin`,i.r0=`variable`,i.r1=`variable`,i.r2=`variable`,i.r3=`variable`,i.r4=`variable`,i.r5=`variable`,i.r6=`variable`,i.r7=`variable`,i.r8=`variable`,i.r9=`variable`,i.r10=`variable`,i.r11=`variable`,i.r12=`variable`,i.sp=`variableName.special`,i.lr=`variableName.special`,i.pc=`variableName.special`,i.r13=i.sp,i.r14=i.lr,i.r15=i.pc,t.push(function(e,t){if(e===`#`)return t.eatWhile(/\w/),`number`})}e===`x86`?a():(e===`arm`||e===`armv6`)&&o();function s(e,t){for(var n=!1,r;(r=e.next())!=null;){if(r===t&&!n)return!1;n=!n&&r===`\\`}return n}function c(e,t){for(var n=!1,r;(r=e.next())!=null;){if(r===`/`&&n){t.tokenize=null;break}n=r===`*`}return`comment`}return{name:`gas`,startState:function(){return{tokenize:null}},token:function(e,a){if(a.tokenize)return a.tokenize(e,a);if(e.eatSpace())return null;var o,l,u=e.next();if(u===`/`&&e.eat(`*`))return a.tokenize=c,c(e,a);if(u===n)return e.skipToEnd(),`comment`;if(u===`"`)return s(e,`"`),`string`;if(u===`.`)return e.eatWhile(/\w/),l=e.current().toLowerCase(),o=r[l],o||null;if(u===`=`)return e.eatWhile(/\w/),`tag`;if(u===`{`||u===`}`)return`bracket`;if(/\d/.test(u))return u===`0`&&e.eat(`x`)?(e.eatWhile(/[0-9a-fA-F]/),`number`):(e.eatWhile(/\d/),`number`);if(/\w/.test(u))return e.eatWhile(/\w/),e.eat(`:`)?`tag`:(l=e.current().toLowerCase(),o=i[l],o||null);for(var d=0;d<t.length;d++)if(o=t[d](u,e,a),o)return o},languageData:{commentTokens:{line:n,block:{open:`/*`,close:`*/`}}}}}var t=e(`x86`);e(`arm`);export{t as gas};
//# sourceMappingURL=gas.BfKIzZdV.js.map