import{_ as e,a as t,d as n,g as r,l as i,n as a,t as o,v as s,y as c}from"./chunk-NNHCCRGN.BGI6DATj.js";var l,u,d=(l=class extends o{constructor(){super([`pie`,`showData`])}},r(l,`PieTokenBuilder`),l),f=(u=class extends a{runCustomConverter(e,t,n){if(e.name===`PIE_SECTION_LABEL`)return t.replace(/"/g,``).trim()}},r(u,`PieValueConverter`),u),p={parser:{TokenBuilder:r(()=>new d,`TokenBuilder`),ValueConverter:r(()=>new f,`ValueConverter`)}};function m(r=t){let a=c(s(r),i),o=c(e({shared:a}),n,p);return a.ServiceRegistry.register(o),{shared:a,Pie:o}}r(m,`createPieServices`);export{m as n,p as t};
//# sourceMappingURL=chunk-MZUSXYTE.iMBPWLI7.js.map