.file-search-popup[data-v-4ec2f37d]{position:absolute;background:var(--color-box-body);border:1px solid var(--color-secondary);border-radius:var(--border-radius);width:max-content;max-height:min(calc(100vw - 20px),300px);max-width:min(calc(100vw - 40px),600px);overflow-y:auto}.file-search-popup .is-loading[data-v-4ec2f37d]{width:200px;height:200px}.file-search-results .item[data-v-4ec2f37d]{align-items:flex-start;padding:.5rem .75rem;cursor:pointer;border-bottom:1px solid var(--color-secondary)}.file-search-results .item[data-v-4ec2f37d]:last-child{border-bottom:none}.file-search-results .item[data-v-4ec2f37d]:hover,.file-search-results .item.selected[data-v-4ec2f37d]{background-color:var(--color-hover)}.file-search-results .item .file-icon[data-v-4ec2f37d]{flex-shrink:0;margin-top:.125rem}.file-search-results .item .full-path[data-v-4ec2f37d]{flex:1;overflow-wrap:anywhere}.file-search-results .item .full-path[data-v-4ec2f37d] :nth-child(2n){color:var(--color-red);font-weight:var(--font-weight-semibold)}
