import{n as e}from"./chunk-AGHRB4JF.DxL_-brX.js";import"./chunk-5ZQYHXKU.C2vdTzMn.js";import"./chunk-CSCIHK7Q.gzGma1mM.js";import"./chunk-O5CBEL6O.0No1QAC6.js";import"./chunk-FMBD7UC4.DtA4wKFi.js";import"./chunk-BSJP7CBP.CGAe31Vs.js";import"./chunk-L5ZTLDWV.BwIRc_O6.js";import"./chunk-ND2GUHAM.GVTBVlSu.js";import"./chunk-55IACEB6.B2RA2Tk1.js";import"./chunk-2J33WTMH.bdkH3m-Z.js";import"./chunk-NZK2D7GU.BSKIErzr.js";import"./chunk-3OPIFGDE.DMut3ZHV.js";import"./chunk-KSCS5N6A.DmERsiir.js";import"./chunk-LZXEDZCA.BAydbWNX.js";import{i as t,n,r,t as i}from"./chunk-727SXJPM.kebZ1alO.js";var a={parser:n,get db(){return new i},renderer:r,styles:t,init:e(e=>{e.class||(e.class={}),e.class.arrowMarkerAbsolute=e.arrowMarkerAbsolute},`init`)};export{a as diagram};
//# sourceMappingURL=classDiagram-4FO5ZUOK.DOJhSDhf.js.map