import{t as e}from"./swagger.CJ_cJ0NP.js";async function t(){let t=document.querySelector(`#swagger-ui`),n=t.getAttribute(`data-source`);await e(t,{specText:await(await fetch(n)).text()})}t();
//# sourceMappingURL=swagger.BqAIrvGr.js.map