const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["../css/swagger-render.Be7K_yCa.css"])))=>i.map(i=>d[i]);
import{t as e}from"./preload-helper.DOHRDkqH.js";import{t}from"./swagger.CJ_cJ0NP.js";/* empty css                       */var n=async n=>{try{return await e(()=>Promise.resolve({}),__vite__mapDeps([0]),import.meta.url),await t(n.container,{specText:n.contentString()}),!0}catch(e){return console.error(e),!1}};export{n as frontendRender};
//# sourceMappingURL=frontend-openapi-swagger.DerKfIHB.js.map