import{_ as e,a as t,c as n,g as r,i,l as a,t as o,v as s,y as c}from"./chunk-NNHCCRGN.BGI6DATj.js";var l,u=(l=class extends o{constructor(){super([`info`,`showInfo`])}},r(l,`InfoTokenBuilder`),l),d={parser:{TokenBuilder:r(()=>new u,`TokenBuilder`),ValueConverter:r(()=>new i,`ValueConverter`)}};function f(r=t){let i=c(s(r),a),o=c(e({shared:i}),n,d);return i.ServiceRegistry.register(o),{shared:i,Info:o}}r(f,`createInfoServices`);export{f as n,d as t};
//# sourceMappingURL=chunk-5DO6E6H7.cM0qvEcP.js.map