import{_ as e,a as t,g as n,i as r,l as i,t as a,u as o,v as s,y as c}from"./chunk-NNHCCRGN.BGI6DATj.js";var l,u=(l=class extends a{constructor(){super([`packet`])}},n(l,`PacketTokenBuilder`),l),d={parser:{TokenBuilder:n(()=>new u,`TokenBuilder`),ValueConverter:n(()=>new r,`ValueConverter`)}};function f(n=t){let r=c(s(n),i),a=c(e({shared:r}),o,d);return r.ServiceRegistry.register(a),{shared:r,Packet:a}}n(f,`createPacketServices`);export{f as n,d as t};
//# sourceMappingURL=chunk-MPE355IW.DkR2lY41.js.map