function e(e){for(var t={},n=e.split(` `),r=0;r<n.length;++r)t[n[r]]=!0;return t}var t=e(`if elsif else stop require`),n=e(`true false not`);function r(e,r){var s=e.next();if(s==`/`&&e.eat(`*`))return r.tokenize=a,a(e,r);if(s===`#`)return e.skipToEnd(),`comment`;if(s==`"`)return r.tokenize=o(s),r.tokenize(e,r);if(s==`(`)return r._indent.push(`(`),r._indent.push(`{`),null;if(s===`{`)return r._indent.push(`{`),null;if(s==`)`&&(r._indent.pop(),r._indent.pop()),s===`}`)return r._indent.pop(),null;if(s==`,`||s==`;`||/[{}\(\),;]/.test(s))return null;if(/\d/.test(s))return e.eatWhile(/[\d]/),e.eat(/[KkMmGg]/),`number`;if(s==`:`)return e.eatWhile(/[a-zA-Z_]/),e.eatWhile(/[a-zA-Z0-9_]/),`operator`;e.eatWhile(/\w/);var c=e.current();return c==`text`&&e.eat(`:`)?(r.tokenize=i,`string`):t.propertyIsEnumerable(c)?`keyword`:n.propertyIsEnumerable(c)?`atom`:null}function i(e,t){return t._multiLineString=!0,e.sol()?(e.next()==`.`&&e.eol()&&(t._multiLineString=!1,t.tokenize=r),`string`):(e.eatSpace(),e.peek()==`#`?(e.skipToEnd(),`comment`):(e.skipToEnd(),`string`))}function a(e,t){for(var n=!1,i;(i=e.next())!=null;){if(n&&i==`/`){t.tokenize=r;break}n=i==`*`}return`comment`}function o(e){return function(t,n){for(var i=!1,a;(a=t.next())!=null&&!(a==e&&!i);)i=!i&&a==`\\`;return i||(n.tokenize=r),`string`}}var s={name:`sieve`,startState:function(e){return{tokenize:r,baseIndent:e||0,_indent:[]}},token:function(e,t){return e.eatSpace()?null:(t.tokenize||r)(e,t)},indent:function(e,t,n){var r=e._indent.length;return t&&t[0]==`}`&&r--,r<0&&(r=0),r*n.unit},languageData:{indentOnInput:/^\s*\}$/}};export{s as sieve};
//# sourceMappingURL=sieve.BlBZM_Ml.js.map