function e(e,t){return e.skipToEnd(),t.cur=o,`error`}function t(t,r){return t.match(/^HTTP\/\d\.\d/)?(r.cur=n,`keyword`):t.match(/^[A-Z]+/)&&/[ \t]/.test(t.peek())?(r.cur=i,`keyword`):e(t,r)}function n(t,n){var i=t.match(/^\d+/);if(!i)return e(t,n);n.cur=r;var a=Number(i[0]);return a>=100&&a<400?`atom`:`error`}function r(e,t){return e.skipToEnd(),t.cur=o,null}function i(e,t){return e.eatWhile(/\S/),t.cur=a,`string.special`}function a(t,n){return t.match(/^HTTP\/\d\.\d$/)?(n.cur=o,`keyword`):e(t,n)}function o(e){return e.sol()&&!e.eat(/[ \t]/)?e.match(/^.*?:/)?`atom`:(e.skipToEnd(),`error`):(e.skipToEnd(),`string`)}function s(e){return e.skipToEnd(),null}var c={name:`http`,token:function(e,t){var n=t.cur;return n!=o&&n!=s&&e.eatSpace()?null:n(e,t)},blankLine:function(e){e.cur=s},startState:function(){return{cur:t}}};export{c as http};
//# sourceMappingURL=http.YYMKo4d8.js.map