import{t as e}from"./preload-helper.DOHRDkqH.js";import{g as t}from"./chunk-NNHCCRGN.BGI6DATj.js";import"./chunk-4EGX6M5U.BreLmhuN.js";import"./chunk-N66VUXT2.BnRcapSN.js";import"./chunk-UIBZB4QT.Cj3b_zdz.js";import"./chunk-5DO6E6H7.cM0qvEcP.js";import"./chunk-MPE355IW.DkR2lY41.js";import"./chunk-MZUSXYTE.iMBPWLI7.js";import"./chunk-FHYWG6QK.C-hs5bLS.js";import"./chunk-WCWK7LTN.BaztnQUR.js";import"./chunk-BR22UD5L.BngAao5a.js";import"./chunk-PUPMXCY4.BYFAhBNn.js";var n,r={},i={info:t(async()=>{let{createInfoServices:t}=await e(async()=>{let{createInfoServices:e}=await import(`./info-J43DQDTF.BbHS49c-.js`);return{createInfoServices:e}},[],import.meta.url);r.info=t().Info.parser.LangiumParser},`info`),packet:t(async()=>{let{createPacketServices:t}=await e(async()=>{let{createPacketServices:e}=await import(`./packet-YPE3B663.Cla064lp.js`);return{createPacketServices:e}},[],import.meta.url);r.packet=t().Packet.parser.LangiumParser},`packet`),pie:t(async()=>{let{createPieServices:t}=await e(async()=>{let{createPieServices:e}=await import(`./pie-LRSECV5Y.B1bQGCqH.js`);return{createPieServices:e}},[],import.meta.url);r.pie=t().Pie.parser.LangiumParser},`pie`),treeView:t(async()=>{let{createTreeViewServices:t}=await e(async()=>{let{createTreeViewServices:e}=await import(`./treeView-BLDUP644.DAoNaW3Q.js`);return{createTreeViewServices:e}},[],import.meta.url);r.treeView=t().TreeView.parser.LangiumParser},`treeView`),architecture:t(async()=>{let{createArchitectureServices:t}=await e(async()=>{let{createArchitectureServices:e}=await import(`./architecture-7EHR7CIX.bM4E-ZJO.js`);return{createArchitectureServices:e}},[],import.meta.url);r.architecture=t().Architecture.parser.LangiumParser},`architecture`),gitGraph:t(async()=>{let{createGitGraphServices:t}=await e(async()=>{let{createGitGraphServices:e}=await import(`./gitGraph-WXDBUCRP.DrquKfIm.js`);return{createGitGraphServices:e}},[],import.meta.url);r.gitGraph=t().GitGraph.parser.LangiumParser},`gitGraph`),eventmodeling:t(async()=>{let{createEventModelingServices:t}=await e(async()=>{let{createEventModelingServices:e}=await import(`./eventmodeling-FCH6USID.BQ_D7iUT.js`);return{createEventModelingServices:e}},[],import.meta.url);r.eventmodeling=t().EventModel.parser.LangiumParser},`eventmodeling`),radar:t(async()=>{let{createRadarServices:t}=await e(async()=>{let{createRadarServices:e}=await import(`./radar-GUYGQ44K.BcBoK2L3.js`);return{createRadarServices:e}},[],import.meta.url);r.radar=t().Radar.parser.LangiumParser},`radar`),treemap:t(async()=>{let{createTreemapServices:t}=await e(async()=>{let{createTreemapServices:e}=await import(`./treemap-LRROVOQU.iTjpfpHZ.js`);return{createTreemapServices:e}},[],import.meta.url);r.treemap=t().Treemap.parser.LangiumParser},`treemap`),wardley:t(async()=>{let{createWardleyServices:t}=await e(async()=>{let{createWardleyServices:e}=await import(`./wardley-L42UT6IY.DxMtK5oO.js`);return{createWardleyServices:e}},[],import.meta.url);r.wardley=t().Wardley.parser.LangiumParser},`wardley`)};async function a(e,t){let n=i[e];if(!n)throw Error(`Unknown diagram type: ${e}`);r[e]||await n();let a=r[e].parse(t);if(a.lexerErrors.length>0||a.parserErrors.length>0)throw new o(a);return a.value}t(a,`parse`);var o=(n=class extends Error{constructor(e){let t=e.lexerErrors.map(e=>`Lexer error on line ${e.line!==void 0&&!isNaN(e.line)?e.line:`?`}, column ${e.column!==void 0&&!isNaN(e.column)?e.column:`?`}: ${e.message}`).join(`
`),n=e.parserErrors.map(e=>`Parse error on line ${e.token.startLine!==void 0&&!isNaN(e.token.startLine)?e.token.startLine:`?`}, column ${e.token.startColumn!==void 0&&!isNaN(e.token.startColumn)?e.token.startColumn:`?`}: ${e.message}`).join(`
`);super(`Parsing failed: ${t} ${n}`),this.result=e}},t(n,`MermaidParseError`),n);export{a as t};
//# sourceMappingURL=mermaid-parser.core.DvCkhQiH.js.map