import{n as e}from"./chunk-AGHRB4JF.DxL_-brX.js";var t,n=(t=class{constructor(e){this.init=e,this.records=this.init()}reset(){this.records=this.init()}},e(t,`ImperativeState`),t);export{n as t};
//# sourceMappingURL=chunk-QZHKN3VN.C74v-yOy.js.map