import{t as e}from"./preload-helper.DOHRDkqH.js";import{t}from"./chunk-ZW26E7AF.B7ckZ_NR.js";var n=t(async()=>await e(()=>import(`./render-TAZW7USW.BA-Dp_6_.js`),[],import.meta.url),`loader`),r=[{name:`elk`,loader:n,algorithm:`elk.layered`},...[`elk.stress`,`elk.force`,`elk.mrtree`,`elk.sporeOverlap`].map(e=>({name:e,loader:n,algorithm:e}))];export{r as default};
//# sourceMappingURL=mermaid-layout-elk.core.cvU25EiW.js.map