import{o as e,t}from"./chunk.BnKUq5qt.js";import{c as n,l as r,r as i,t as a}from"./lib-mjs.mWK4Z6JU.js";a();var o=new n({"en-US":`<?xml version="1.0" encoding="utf-8"?>
<locale xmlns="http://purl.org/net/xbiblio/csl" version="1.0" xml:lang="en-US"><info><translator><name>Andrew Dunning</name></translator><translator><name>Sebastian Karcher</name></translator><translator><name>Rintze M. Zelle</name></translator><translator><name>Denis Meier</name></translator><translator><name>Brenton M. Wiernik</name></translator><rights license="http://creativecommons.org/licenses/by-sa/3.0/">This work is licensed under a Creative Commons Attribution-ShareAlike 3.0 License</rights><updated>2015-10-10T23:31:02+00:00</updated></info><style-options punctuation-in-quote="true"/><date form="text"><date-part name="month" suffix=" "/><date-part name="day" suffix=", "/><date-part name="year"/></date><date form="numeric"><date-part name="month" form="numeric-leading-zeros" suffix="/"/><date-part name="day" form="numeric-leading-zeros" suffix="/"/><date-part name="year"/></date><terms><term name="advance-online-publication">advance online publication</term><term name="album">album</term><term name="audio-recording">audio recording</term><term name="film">film</term><term name="henceforth">henceforth</term><term name="loc-cit">loc. cit.</term> <!-- like ibid., the abbreviated form is the regular form  --><term name="no-place">no place</term><term name="no-place" form="short">n.p.</term><term name="no-publisher">no publisher</term> <!-- sine nomine --><term name="no-publisher" form="short">n.p.</term><term name="on">on</term><term name="op-cit">op. cit.</term> <!-- like ibid., the abbreviated form is the regular form  --><term name="original-work-published">original work published</term><term name="personal-communication">personal communication</term><term name="podcast">podcast</term><term name="podcast-episode">podcast episode</term><term name="preprint">preprint</term><term name="radio-broadcast">radio broadcast</term><term name="radio-series">radio series</term><term name="radio-series-episode">radio series episode</term><term name="special-issue">special issue</term><term name="special-section">special section</term><term name="television-broadcast">television broadcast</term><term name="television-series">television series</term><term name="television-series-episode">television series episode</term><term name="video">video</term><term name="working-paper">working paper</term><term name="accessed">accessed</term><term name="and">and</term><term name="and others">and others</term><term name="anonymous">anonymous</term><term name="anonymous" form="short">anon.</term><term name="at">at</term><term name="available at">available at</term><term name="by">by</term><term name="circa">circa</term><term name="circa" form="short">c.</term><term name="cited">cited</term><term name="edition"><single>edition</single><multiple>editions</multiple></term><term name="edition" form="short">ed.</term><term name="et-al">et al.</term><term name="forthcoming">forthcoming</term><term name="from">from</term><term name="ibid">ibid.</term><term name="in">in</term><term name="in press">in press</term><term name="internet">internet</term><term name="interview">interview</term><term name="letter">letter</term><term name="no date">no date</term><term name="no date" form="short">n.d.</term><term name="online">online</term><term name="presented at">presented at the</term><term name="reference"><single>reference</single><multiple>references</multiple></term><term name="reference" form="short"><single>ref.</single><multiple>refs.</multiple></term><term name="retrieved">retrieved</term><term name="scale">scale</term><term name="version">version</term>
<!-- LONG ITEM TYPE FORMS --><term name="article">preprint</term><term name="article-journal">journal article</term><term name="article-magazine">magazine article</term><term name="article-newspaper">newspaper article</term><term name="bill">bill</term><term name="book">book</term><term name="broadcast">broadcast</term><term name="chapter">book chapter</term><term name="classic">classic</term><term name="collection">collection</term><term name="dataset">dataset</term><term name="document">document</term><term name="entry">entry</term><term name="entry-dictionary">dictionary entry</term><term name="entry-encyclopedia">encyclopedia entry</term><term name="event">event</term><!-- figure is in the list of locator terms --><term name="graphic">graphic</term><term name="hearing">hearing</term><term name="interview">interview</term><term name="legal_case">legal case</term><term name="legislation">legislation</term><term name="manuscript">manuscript</term><term name="map">map</term><term name="motion_picture">video recording</term><term name="musical_score">musical score</term><term name="pamphlet">pamphlet</term><term name="paper-conference">conference paper</term><term name="patent">patent</term><term name="performance">performance</term><term name="periodical">periodical</term><term name="personal_communication">personal communication</term><term name="post">post</term><term name="post-weblog">blog post</term><term name="regulation">regulation</term><term name="report">report</term><term name="review">review</term><term name="review-book">book review</term><term name="software">software</term><term name="song">audio recording</term><term name="speech">presentation</term><term name="standard">standard</term><term name="thesis">thesis</term><term name="treaty">treaty</term><term name="webpage">webpage</term>
<!-- SHORT ITEM TYPE FORMS --><term name="article-journal" form="short">journal art.</term><term name="article-magazine" form="short">mag. art.</term><term name="article-newspaper" form="short">newspaper art.</term><term name="book" form="short">bk.</term><term name="chapter" form="short">bk. chap.</term><term name="document" form="short">doc.</term><!-- figure is in the list of locator terms --><term name="graphic" form="short">graph.</term><term name="interview" form="short">interv.</term><term name="manuscript" form="short">MS</term><term name="motion_picture" form="short">video rec.</term><term name="report" form="short">rep.</term><term name="review" form="short">rev.</term><term name="review-book" form="short">bk. rev.</term><term name="song" form="short">audio rec.</term>
<!-- HISTORICAL ERA TERMS --><term name="ad">AD</term><term name="bc">BC</term><term name="bce">BCE</term><term name="ce">CE</term>
<!-- PUNCTUATION --><term name="open-quote">“</term><term name="close-quote">”</term><term name="open-inner-quote">‘</term><term name="close-inner-quote">’</term><term name="page-range-delimiter">–</term><term name="colon">:</term><term name="comma">,</term><term name="semicolon">;</term>
<!-- ORDINALS --><term name="ordinal">th</term><term name="ordinal-01">st</term><term name="ordinal-02">nd</term><term name="ordinal-03">rd</term><term name="ordinal-11">th</term><term name="ordinal-12">th</term><term name="ordinal-13">th</term>
<!-- LONG ORDINALS --><term name="long-ordinal-01">first</term><term name="long-ordinal-02">second</term><term name="long-ordinal-03">third</term><term name="long-ordinal-04">fourth</term><term name="long-ordinal-05">fifth</term><term name="long-ordinal-06">sixth</term><term name="long-ordinal-07">seventh</term><term name="long-ordinal-08">eighth</term><term name="long-ordinal-09">ninth</term><term name="long-ordinal-10">tenth</term>
<!-- LONG LOCATOR FORMS --><term name="act">			 <single>act</single><multiple>acts</multiple>						 </term><term name="appendix">			 <single>appendix</single><multiple>appendices</multiple>						 </term><term name="article-locator">			 <single>article</single><multiple>articles</multiple>						 </term><term name="canon">			 <single>canon</single><multiple>canons</multiple>						 </term><term name="elocation">			 <single>location</single><multiple>locations</multiple>						 </term><term name="equation">			 <single>equation</single><multiple>equations</multiple>						 </term><term name="rule">			 <single>rule</single><multiple>rules</multiple>						 </term><term name="scene">			 <single>scene</single><multiple>scenes</multiple>						 </term><term name="table">			 <single>table</single><multiple>tables</multiple>						 </term><term name="timestamp"> <!-- generally blank --><single></single><multiple></multiple>						 </term><term name="title-locator">			 <single>title</single><multiple>titles</multiple>						 </term><term name="book"><single>book</single><multiple>books</multiple></term><term name="chapter"><single>chapter</single><multiple>chapters</multiple></term><term name="column"><single>column</single><multiple>columns</multiple></term><term name="figure"><single>figure</single><multiple>figures</multiple></term><term name="folio"><single>folio</single><multiple>folios</multiple></term><term name="issue"><single>number</single><multiple>numbers</multiple></term><term name="line"><single>line</single><multiple>lines</multiple></term><term name="note"><single>note</single><multiple>notes</multiple></term><term name="opus"><single>opus</single><multiple>opera</multiple></term><term name="page"><single>page</single><multiple>pages</multiple></term><term name="number-of-pages"><single>page</single><multiple>pages</multiple></term><term name="paragraph"><single>paragraph</single><multiple>paragraphs</multiple></term><term name="part"><single>part</single><multiple>parts</multiple></term><term name="section"><single>section</single><multiple>sections</multiple></term><term name="sub-verbo"><single>sub verbo</single><multiple>sub verbis</multiple></term><term name="verse"><single>verse</single><multiple>verses</multiple></term><term name="volume"><single>volume</single><multiple>volumes</multiple></term>
<!-- SHORT LOCATOR FORMS --><term name="appendix" form="short">			 <single>app.</single><multiple>apps.</multiple>						 </term><term name="article-locator" form="short">			 <single>art.</single><multiple>arts.</multiple></term><term name="elocation" form="short">			 <single>loc.</single><multiple>locs.</multiple></term><term name="equation" form="short">			 <single>eq.</single><multiple>eqs.</multiple></term><term name="rule" form="short">			 <single>r.</single><multiple>rr.</multiple>						 </term><term name="scene" form="short">			 <single>sc.</single><multiple>scs.</multiple>						 </term><term name="table" form="short">			 <single>tbl.</single><multiple>tbls.</multiple>						 </term><term name="timestamp" form="short"> <!-- generally blank --><single></single><multiple></multiple>						 </term><term name="title-locator" form="short">			 <single>tit.</single><multiple>tits.</multiple></term><term name="book" form="short"><single>bk.</single><multiple>bks.</multiple></term><term name="chapter" form="short"><single>chap.</single><multiple>chaps.</multiple></term><term name="column" form="short"><single>col.</single><multiple>cols.</multiple></term><term name="figure" form="short"><single>fig.</single><multiple>figs.</multiple></term><term name="folio" form="short"><single>fol.</single><multiple>fols.</multiple></term><term name="issue" form="short"><single>no.</single><multiple>nos.</multiple></term><term name="line" form="short"><single>l.</single><multiple>ll.</multiple></term><term name="note" form="short"><single>n.</single><multiple>nn.</multiple></term><term name="opus" form="short"><single>op.</single><multiple>opp.</multiple></term><term name="page" form="short"><single>p.</single><multiple>pp.</multiple></term><term name="number-of-pages" form="short"><single>p.</single><multiple>pp.</multiple></term><term name="paragraph" form="short"><single>para.</single><multiple>paras.</multiple></term><term name="part" form="short"><single>pt.</single><multiple>pts.</multiple></term><term name="section" form="short"><single>sec.</single><multiple>secs.</multiple></term><term name="sub-verbo" form="short"><single>s.v.</single><multiple>s.vv.</multiple></term><term name="verse" form="short"><single>v.</single><multiple>vv.</multiple></term><term name="volume" form="short"><single>vol.</single><multiple>vols.</multiple></term>
<!-- SYMBOL LOCATOR FORMS --><term name="paragraph" form="symbol"><single>¶</single><multiple>¶¶</multiple></term><term name="section" form="symbol"><single>§</single><multiple>§§</multiple></term>
<!-- LONG ROLE FORMS --><term name="chair"><single>chair</single><multiple>chairs</multiple></term><term name="compiler"><single>compiler</single><multiple>compilers</multiple></term><term name="contributor"><single>contributor</single><multiple>contributors</multiple></term><term name="curator"><single>curator</single><multiple>curators</multiple></term><term name="executive-producer"><single>executive producer</single><multiple>executive producers</multiple></term><term name="guest"><single>guest</single><multiple>guests</multiple></term><term name="host"><single>host</single><multiple>hosts</multiple></term><term name="narrator"><single>narrator</single><multiple>narrators</multiple></term><term name="organizer"><single>organizer</single><multiple>organizers</multiple></term><term name="performer"><single>performer</single><multiple>performers</multiple></term><term name="producer"><single>producer</single><multiple>producers</multiple></term><term name="script-writer"><single>writer</single><multiple>writers</multiple></term><term name="series-creator"><single>series creator</single><multiple>series creators</multiple></term><term name="director"><single>director</single><multiple>directors</multiple></term><term name="editor"><single>editor</single><multiple>editors</multiple></term><term name="editorial-director"><single>editor</single><multiple>editors</multiple></term><term name="illustrator"><single>illustrator</single><multiple>illustrators</multiple></term><term name="translator"><single>translator</single><multiple>translators</multiple></term><term name="editortranslator"><single>editor &amp; translator</single><multiple>editors &amp; translators</multiple></term>
<!-- SHORT ROLE FORMS --><term name="compiler" form="short"><single>comp.</single><multiple>comps.</multiple></term><term name="contributor" form="short"><single>contrib.</single><multiple>contribs.</multiple></term><term name="curator" form="short"><single>cur.</single><multiple>curs.</multiple></term><term name="executive-producer" form="short"><single>exec. prod.</single><multiple>exec. prods.</multiple></term><term name="narrator" form="short"><single>narr.</single><multiple>narrs.</multiple></term><term name="organizer" form="short"><single>org.</single><multiple>orgs.</multiple></term><term name="performer" form="short"><single>perf.</single><multiple>perfs.</multiple></term><term name="producer" form="short"><single>prod.</single><multiple>prods.</multiple></term><term name="script-writer" form="short"><single>writ.</single><multiple>writs.</multiple></term><term name="series-creator" form="short"><single>cre.</single><multiple>cres.</multiple></term><term name="director" form="short"><single>dir.</single><multiple>dirs.</multiple></term><term name="editor" form="short"><single>ed.</single><multiple>eds.</multiple></term><term name="editorial-director" form="short"><single>ed.</single><multiple>eds.</multiple></term><term name="illustrator" form="short"><single>ill.</single><multiple>ills.</multiple></term><term name="translator" form="short"><single>tran.</single><multiple>trans.</multiple></term><term name="editortranslator" form="short"><single>ed. &amp; tran.</single><multiple>eds. &amp; trans.</multiple></term>
<!-- VERB ROLE FORMS --><term name="chair" form="verb">chaired by</term><term name="compiler" form="verb">compiled by</term><term name="contributor" form="verb">with</term><term name="curator" form="verb">curated by</term><term name="executive-producer" form="verb">executive produced by</term><term name="guest" form="verb">with guest</term><term name="host" form="verb">hosted by</term><term name="narrator" form="verb">narrated by</term><term name="organizer" form="verb">organized by</term><term name="performer" form="verb">performed by</term><term name="producer" form="verb">produced by</term><term name="script-writer" form="verb">written by</term><term name="series-creator" form="verb">created by</term><term name="container-author" form="verb">by</term><term name="director" form="verb">directed by</term><term name="editor" form="verb">edited by</term><term name="editorial-director" form="verb">edited by</term><term name="illustrator" form="verb">illustrated by</term><term name="interviewer" form="verb">interview by</term><term name="recipient" form="verb">to</term><term name="reviewed-author" form="verb">by</term><term name="translator" form="verb">translated by</term><term name="editortranslator" form="verb">edited &amp; translated by</term>
<!-- SHORT VERB ROLE FORMS --><term name="compiler" form="verb-short">comp. by</term><term name="contributor" form="verb-short">w.</term><term name="curator" form="verb-short">cur. by</term><term name="executive-producer" form="verb-short">exec. prod. by</term><term name="guest" form="verb-short">w. guest</term><term name="host" form="verb-short">hosted by</term><term name="narrator" form="verb-short">narr. by</term><term name="organizer" form="verb-short">org. by</term><term name="performer" form="verb-short">perf. by</term><term name="producer" form="verb-short">prod. by</term><term name="script-writer" form="verb-short">writ. by</term><term name="series-creator" form="verb-short">cre. by</term><term name="director" form="verb-short">dir. by</term><term name="editor" form="verb-short">ed. by</term><term name="editorial-director" form="verb-short">ed. by</term><term name="illustrator" form="verb-short">illus. by</term><term name="translator" form="verb-short">trans. by</term><term name="editortranslator" form="verb-short">ed. &amp; trans. by</term>
<!-- LONG MONTH FORMS --><term name="month-01">January</term><term name="month-02">February</term><term name="month-03">March</term><term name="month-04">April</term><term name="month-05">May</term><term name="month-06">June</term><term name="month-07">July</term><term name="month-08">August</term><term name="month-09">September</term><term name="month-10">October</term><term name="month-11">November</term><term name="month-12">December</term>
<!-- SHORT MONTH FORMS --><term name="month-01" form="short">Jan.</term><term name="month-02" form="short">Feb.</term><term name="month-03" form="short">Mar.</term><term name="month-04" form="short">Apr.</term><term name="month-05" form="short">May</term><term name="month-06" form="short">Jun.</term><term name="month-07" form="short">Jul.</term><term name="month-08" form="short">Aug.</term><term name="month-09" form="short">Sep.</term><term name="month-10" form="short">Oct.</term><term name="month-11" form="short">Nov.</term><term name="month-12" form="short">Dec.</term>
<!-- SEASONS --><term name="season-01">Spring</term><term name="season-02">Summer</term><term name="season-03">Autumn</term><term name="season-04">Winter</term></terms>
</locale>
`,"nl-NL":`<?xml version="1.0" encoding="utf-8"?>
<locale xmlns="http://purl.org/net/xbiblio/csl" version="1.0" xml:lang="nl-NL"><info><translator><name>Rintze M. Zelle</name><uri>http://twitter.com/rintzezelle</uri></translator><rights license="http://creativecommons.org/licenses/by-sa/3.0/">This work is licensed under a Creative Commons Attribution-ShareAlike 3.0 License</rights><updated>2017-04-01T12:00:00+00:00</updated></info><style-options punctuation-in-quote="false"/><date form="text"><date-part name="day" suffix=" "/><date-part name="month" suffix=" "/><date-part name="year"/></date><date form="numeric"><date-part name="day" suffix="-" range-delimiter="/"/><date-part name="month" form="numeric" suffix="-" range-delimiter="/"/><date-part name="year"/></date><terms><term name="advance-online-publication">advance online publication</term><term name="album">album</term><term name="audio-recording">audio recording</term><term name="film">film</term><term name="henceforth">henceforth</term><term name="loc-cit">loc. cit.</term> <!-- like ibid., the abbreviated form is the regular form  --><term name="no-place">no place</term><term name="no-place" form="short">n.p.</term><term name="no-publisher">no publisher</term> <!-- sine nomine --><term name="no-publisher" form="short">n.p.</term><term name="on">on</term><term name="op-cit">op. cit.</term> <!-- like ibid., the abbreviated form is the regular form  --><term name="original-work-published">original work published</term><term name="personal-communication">persoonlijke communicatie</term><term name="podcast">podcast</term><term name="podcast-episode">podcast episode</term><term name="preprint">preprint</term><term name="radio-broadcast">radio broadcast</term><term name="radio-series">radio series</term><term name="radio-series-episode">radio series episode</term><term name="special-issue">special issue</term><term name="special-section">special section</term><term name="television-broadcast">television broadcast</term><term name="television-series">television series</term><term name="television-series-episode">television series episode</term><term name="video">video</term><term name="working-paper">working paper</term><term name="accessed">geraadpleegd</term><term name="and">en</term><term name="and others">en anderen</term><term name="anonymous">anoniem</term><term name="anonymous" form="short">anon.</term><term name="at">bij</term><term name="available at">beschikbaar op</term><term name="by">door</term><term name="circa">circa</term><term name="circa" form="short">c.</term><term name="cited">geciteerd</term><term name="edition"><single>druk</single><multiple>drukken</multiple></term><term name="edition" form="short">dr.</term><term name="et-al">e.a.</term><term name="forthcoming">in voorbereiding</term><term name="from">van</term><term name="ibid">ibid.</term><term name="in">in</term><term name="in press">in druk</term><term name="internet">internet</term><term name="interview">interview</term><term name="letter">brief</term><term name="no date">zonder datum</term><term name="no date" form="short">z.d.</term><term name="online">online</term><term name="presented at">gepresenteerd bij</term><term name="reference"><single>referentie</single><multiple>referenties</multiple></term><term name="reference" form="short"><single>ref.</single><multiple>refs.</multiple></term><term name="retrieved">geraadpleegd</term><term name="scale">schaal</term><term name="version">versie</term>
<!-- LONG ITEM TYPE FORMS --><term name="article">preprint</term><term name="article-journal">journal article</term><term name="article-magazine">magazine article</term><term name="article-newspaper">newspaper article</term><term name="bill">bill</term><term name="book">book</term><term name="broadcast">broadcast</term><term name="chapter">book chapter</term><term name="classic">classic</term><term name="collection">collection</term><term name="dataset">dataset</term><term name="document">document</term><term name="entry">entry</term><term name="entry-dictionary">dictionary entry</term><term name="entry-encyclopedia">encyclopedia entry</term><term name="event">event</term><!-- figure is in the list of locator terms --><term name="graphic">graphic</term><term name="hearing">hearing</term><term name="interview">interview</term><term name="legal_case">legal case</term><term name="legislation">legislation</term><term name="manuscript">manuscript</term><term name="map">map</term><term name="motion_picture">video recording</term><term name="musical_score">musical score</term><term name="pamphlet">pamphlet</term><term name="paper-conference">conference paper</term><term name="patent">patent</term><term name="performance">performance</term><term name="periodical">periodical</term><term name="personal_communication">persoonlijke communicatie</term><term name="post">post</term><term name="post-weblog">blog post</term><term name="regulation">regulation</term><term name="report">report</term><term name="review">review</term><term name="review-book">book review</term><term name="software">software</term><term name="song">audio recording</term><term name="speech">presentation</term><term name="standard">standard</term><term name="thesis">thesis</term><term name="treaty">treaty</term><term name="webpage">webpage</term>
<!-- SHORT ITEM TYPE FORMS --><term name="article-journal" form="short">journal art.</term><term name="article-magazine" form="short">mag. art.</term><term name="article-newspaper" form="short">newspaper art.</term><term name="book" form="short">bk.</term><term name="chapter" form="short">bk. chap.</term><term name="document" form="short">doc.</term><!-- figure is in the list of locator terms --><term name="graphic" form="short">graph.</term><term name="interview" form="short">interv.</term><term name="manuscript" form="short">MS</term><term name="motion_picture" form="short">video rec.</term><term name="report" form="short">rep.</term><term name="review" form="short">rev.</term><term name="review-book" form="short">bk. rev.</term><term name="song" form="short">audio rec.</term>
<!-- HISTORICAL ERA TERMS --><term name="ad">AD</term><term name="bc">BC</term><term name="bce">BCE</term><term name="ce">CE</term>
<!-- PUNCTUATION --><term name="open-quote">‘</term><term name="close-quote">’</term><term name="open-inner-quote">“</term><term name="close-inner-quote">”</term><term name="page-range-delimiter">–</term><term name="colon">:</term><term name="comma">,</term><term name="semicolon">;</term>
<!-- ORDINALS --><term name="ordinal">ste</term><term name="ordinal-00" match="whole-number">de</term><term name="ordinal-02" match="last-two-digits">de</term><term name="ordinal-03" match="last-two-digits">de</term><term name="ordinal-04" match="last-two-digits">de</term><term name="ordinal-05" match="last-two-digits">de</term><term name="ordinal-06" match="last-two-digits">de</term><term name="ordinal-07" match="last-two-digits">de</term><term name="ordinal-09" match="last-two-digits">de</term><term name="ordinal-10">de</term><term name="ordinal-11">de</term><term name="ordinal-12">de</term><term name="ordinal-13">de</term><term name="ordinal-14">de</term><term name="ordinal-15">de</term><term name="ordinal-16">de</term><term name="ordinal-17">de</term><term name="ordinal-18">de</term><term name="ordinal-19">de</term>
<!-- LONG ORDINALS --><term name="long-ordinal-01">eerste</term><term name="long-ordinal-02">tweede</term><term name="long-ordinal-03">derde</term><term name="long-ordinal-04">vierde</term><term name="long-ordinal-05">vijfde</term><term name="long-ordinal-06">zesde</term><term name="long-ordinal-07">zevende</term><term name="long-ordinal-08">achtste</term><term name="long-ordinal-09">negende</term><term name="long-ordinal-10">tiende</term>
<!-- LONG LOCATOR FORMS --><term name="act">			 <single>act</single><multiple>acts</multiple>						 </term><term name="appendix">			 <single>appendix</single><multiple>appendices</multiple>						 </term><term name="article-locator">			 <single>article</single><multiple>articles</multiple>						 </term><term name="canon">			 <single>canon</single><multiple>canons</multiple>						 </term><term name="elocation">			 <single>location</single><multiple>locations</multiple>						 </term><term name="equation">			 <single>equation</single><multiple>equations</multiple>						 </term><term name="rule">			 <single>rule</single><multiple>rules</multiple>						 </term><term name="scene">			 <single>scene</single><multiple>scenes</multiple>						 </term><term name="table">			 <single>table</single><multiple>tables</multiple>						 </term><term name="timestamp"> <!-- generally blank --><single></single><multiple></multiple>						 </term><term name="title-locator">			 <single>title</single><multiple>titles</multiple>						 </term><term name="book"><single>boek</single><multiple>boeken</multiple></term><term name="chapter"><single>hoofdstuk</single><multiple>hoofdstukken</multiple></term><term name="column"><single>column</single><multiple>columns</multiple></term><term name="figure"><single>figuur</single><multiple>figuren</multiple></term><term name="folio"><single>folio</single><multiple>folio's</multiple></term><term name="issue"><single>nummer</single><multiple>nummers</multiple></term><term name="line"><single>regel</single><multiple>regels</multiple></term><term name="note"><single>aantekening</single><multiple>aantekeningen</multiple></term><term name="opus"><single>opus</single><multiple>opera</multiple></term><term name="page"><single>pagina</single><multiple>pagina's</multiple></term><term name="number-of-pages"><single>pagina</single><multiple>pagina's</multiple></term><term name="paragraph"><single>paragraaf</single><multiple>paragrafen</multiple></term><term name="part"><single>deel</single><multiple>delen</multiple></term><term name="section"><single>sectie</single><multiple>secties</multiple></term><term name="sub-verbo"><single>sub verbo</single><multiple>sub verbis</multiple></term><term name="verse"><single>vers</single><multiple>versen</multiple></term><term name="volume"><single>volume</single><multiple>volumes</multiple></term>
<!-- SHORT LOCATOR FORMS --><term name="appendix">			 <single>app.</single><multiple>apps.</multiple>						 </term><term name="article-locator">			 <single>art.</single><multiple>arts.</multiple></term><term name="elocation">			 <single>loc.</single><multiple>locs.</multiple></term><term name="equation">			 <single>eq.</single><multiple>eqs.</multiple></term><term name="rule">			 <single>r.</single><multiple>rr.</multiple>						 </term><term name="scene">			 <single>sc.</single><multiple>scs.</multiple>						 </term><term name="table">			 <single>tbl.</single><multiple>tbls.</multiple>						 </term><term name="timestamp"> <!-- generally blank --><single></single><multiple></multiple>						 </term><term name="title-locator">			 <single>tit.</single><multiple>tits.</multiple></term><term name="book" form="short">bk.</term><term name="chapter" form="short">hfdst.</term><term name="column" form="short">col.</term><term name="figure" form="short">fig.</term><term name="folio" form="short">f.</term><term name="issue" form="short">nr.</term><term name="line" form="short">l.</term><term name="note" form="short">n.</term><term name="opus" form="short">op.</term><term name="page" form="short"><single>p.</single><multiple>pp.</multiple></term><term name="number-of-pages" form="short"><single>p.</single><multiple>pp.</multiple></term><term name="paragraph" form="short">par.</term><term name="part" form="short">deel</term><term name="section" form="short">sec.</term><term name="sub-verbo" form="short"><single>s.v.</single><multiple>s.vv.</multiple></term><term name="verse" form="short"><single>v.</single><multiple>vv.</multiple></term><term name="volume" form="short"><single>vol.</single><multiple>vols.</multiple></term>
<!-- SYMBOL LOCATOR FORMS --><term name="paragraph" form="symbol"><single>¶</single><multiple>¶¶</multiple></term><term name="section" form="symbol"><single>§</single><multiple>§§</multiple></term>
<!-- LONG ROLE FORMS --><term name="chair"><single>chair</single><multiple>chairs</multiple></term><term name="compiler"><single>compiler</single><multiple>compilers</multiple></term><term name="contributor"><single>contributor</single><multiple>contributors</multiple></term><term name="curator"><single>curator</single><multiple>curators</multiple></term><term name="executive-producer"><single>executive producer</single><multiple>executive producers</multiple></term><term name="guest"><single>guest</single><multiple>guests</multiple></term><term name="host"><single>host</single><multiple>hosts</multiple></term><term name="narrator"><single>narrator</single><multiple>narrators</multiple></term><term name="organizer"><single>organizer</single><multiple>organizers</multiple></term><term name="performer"><single>performer</single><multiple>performers</multiple></term><term name="producer"><single>producer</single><multiple>producers</multiple></term><term name="script-writer"><single>writer</single><multiple>writers</multiple></term><term name="series-creator"><single>series creator</single><multiple>series creators</multiple></term><term name="director"><single>regisseur</single><multiple>regisseurs</multiple></term><term name="editor"><single>redacteur</single><multiple>redacteuren</multiple></term><term name="editorial-director"><single>redacteur</single><multiple>redacteuren</multiple></term><term name="illustrator"><single>illustrator</single><multiple>illustrators</multiple></term><term name="translator"><single>vertaler</single><multiple>vertalers</multiple></term><term name="editortranslator"><single>redacteur &amp; vertaler</single><multiple>redacteuren &amp; vertalers</multiple></term>
<!-- SHORT ROLE FORMS --><term name="compiler" form="short"><single>comp.</single><multiple>comps.</multiple></term><term name="contributor" form="short"><single>contrib.</single><multiple>contribs.</multiple></term><term name="curator" form="short"><single>cur.</single><multiple>curs.</multiple></term><term name="executive-producer" form="short"><single>exec. prod.</single><multiple>exec. prods.</multiple></term><term name="narrator" form="short"><single>narr.</single><multiple>narrs.</multiple></term><term name="organizer" form="short"><single>org.</single><multiple>orgs.</multiple></term><term name="performer" form="short"><single>perf.</single><multiple>perfs.</multiple></term><term name="producer" form="short"><single>prod.</single><multiple>prods.</multiple></term><term name="script-writer" form="short"><single>writ.</single><multiple>writs.</multiple></term><term name="series-creator" form="short"><single>cre.</single><multiple>cres.</multiple></term><term name="director" form="short"><single>reg.</single><multiple>reg.</multiple></term><term name="editor" form="short"><single>red.</single><multiple>red.</multiple></term><term name="editorial-director" form="short"><single>red.</single><multiple>red.</multiple></term><term name="illustrator" form="short"><single>ill.</single><multiple>ill.</multiple></term><term name="translator" form="short"><single>vert.</single><multiple>vert.</multiple></term><term name="editortranslator" form="short"><single>red. &amp; vert.</single><multiple>red. &amp; vert.</multiple></term>
<!-- VERB ROLE FORMS --><term name="chair" form="verb">chaired by</term><term name="compiler" form="verb">compiled by</term><term name="contributor" form="verb">with</term><term name="curator" form="verb">curated by</term><term name="executive-producer" form="verb">executive produced by</term><term name="guest" form="verb">with guest</term><term name="host" form="verb">hosted by</term><term name="narrator" form="verb">narrated by</term><term name="organizer" form="verb">organized by</term><term name="performer" form="verb">performed by</term><term name="producer" form="verb">produced by</term><term name="script-writer" form="verb">written by</term><term name="series-creator" form="verb">created by</term><term name="container-author" form="verb">door</term><term name="director" form="verb">geregisseerd door</term><term name="editor" form="verb">onder redactie van</term><term name="editorial-director" form="verb">onder redactie van</term><term name="illustrator" form="verb">geïllustreerd door</term><term name="interviewer" form="verb">geïnterviewd door</term><term name="recipient" form="verb">ontvangen door</term><term name="reviewed-author" form="verb">door</term><term name="translator" form="verb">vertaald door</term><term name="editortranslator" form="verb">bewerkt &amp; vertaald door</term>
<!-- SHORT VERB ROLE FORMS --><term name="compiler" form="verb-short">comp. by</term><term name="contributor" form="verb-short">w.</term><term name="curator" form="verb-short">cur. by</term><term name="executive-producer" form="verb-short">exec. prod. by</term><term name="guest" form="verb-short">w. guest</term><term name="host" form="verb-short">hosted by</term><term name="narrator" form="verb-short">narr. by</term><term name="organizer" form="verb-short">org. by</term><term name="performer" form="verb-short">perf. by</term><term name="producer" form="verb-short">prod. by</term><term name="script-writer" form="verb-short">writ. by</term><term name="series-creator" form="verb-short">cre. by</term><term name="director" form="verb-short">geregisseerd door</term><term name="editor" form="verb-short">onder redactie van</term><term name="editorial-director" form="verb-short">bewerkt door</term><term name="illustrator" form="verb-short">geïllustreerd door</term><term name="translator" form="verb-short">vertaald door</term><term name="editortranslator" form="verb-short">bewerkt &amp; vertaald door</term>
<!-- LONG MONTH FORMS --><term name="month-01">januari</term><term name="month-02">februari</term><term name="month-03">maart</term><term name="month-04">april</term><term name="month-05">mei</term><term name="month-06">juni</term><term name="month-07">juli</term><term name="month-08">augustus</term><term name="month-09">september</term><term name="month-10">oktober</term><term name="month-11">november</term><term name="month-12">december</term>
<!-- SHORT MONTH FORMS --><term name="month-01" form="short">jan.</term><term name="month-02" form="short">feb.</term><term name="month-03" form="short">mrt.</term><term name="month-04" form="short">apr.</term><term name="month-05" form="short">mei</term><term name="month-06" form="short">jun.</term><term name="month-07" form="short">jul.</term><term name="month-08" form="short">aug.</term><term name="month-09" form="short">sep.</term><term name="month-10" form="short">okt.</term><term name="month-11" form="short">nov.</term><term name="month-12" form="short">dec.</term>
<!-- SEASONS --><term name="season-01">lente</term><term name="season-02">zomer</term><term name="season-03">herst</term><term name="season-04">winter</term></terms>
</locale>
`,"fr-FR":`<?xml version="1.0" encoding="utf-8"?>
<locale xmlns="http://purl.org/net/xbiblio/csl" version="1.0" xml:lang="fr-FR"><info><translator><name>Grégoire Colly</name></translator><translator><name>Collectif Zotero francophone</name></translator><rights license="http://creativecommons.org/licenses/by-sa/3.0/">This work is licensed under a Creative Commons Attribution-ShareAlike 3.0 License</rights><updated>2012-07-04T23:31:02+00:00</updated></info><style-options punctuation-in-quote="false" limit-day-ordinals-to-day-1="true"/><date form="text"><date-part name="day" suffix=" "/><date-part name="month" suffix=" "/><date-part name="year"/></date><date form="numeric"><date-part name="day" form="numeric-leading-zeros" suffix="/"/><date-part name="month" form="numeric-leading-zeros" suffix="/"/><date-part name="year"/></date><terms><term name="advance-online-publication">publication en ligne anticipée</term><term name="album">album</term><term name="audio-recording">enregistrement audio</term><term name="film">film</term><term name="henceforth">désormais</term><term name="loc-cit">loc.&#160;cit.</term> <!-- like ibid., the abbreviated form is the regular form  --><term name="no-place">sans lieu</term><term name="no-place" form="short">s.&#160;l.</term><term name="no-publisher">sans nom</term> <!-- sine nomine --><term name="no-publisher" form="short">s.&#160;n.</term><term name="on">sur</term><term name="op-cit">op.&#160;cit.</term> <!-- like ibid., the abbreviated form is the regular form  --><term name="original-work-published">édition originale</term><term name="personal-communication">communication personnelle</term><term name="podcast">podcast</term><term name="podcast-episode">épisode de podcast</term><term name="preprint">prépublication</term><term name="radio-broadcast">émission de radio</term><term name="radio-series">série radiophonique</term><term name="radio-series-episode">épisode de série radiophonique</term><term name="special-issue">numéro spécial</term><term name="special-section">section spéciale</term><term name="television-broadcast">émission de télévision</term><term name="television-series">série télévisée</term><term name="television-series-episode">épisode de série télévisée</term><term name="video">vidéo</term><term name="working-paper">document de travail</term><term name="accessed">consulté le</term><term name="and">et</term><term name="and others">et autres</term><term name="anonymous">anonyme</term><term name="anonymous" form="short">anon.</term><term name="at">sur</term><term name="available at">disponible sur</term><term name="by">par</term><term name="circa">vers</term><term name="circa" form="short">v.</term><term name="cited">cité</term><term name="edition" gender="feminine"><single>édition</single><multiple>éditions</multiple></term><term name="edition" form="short">éd.</term><term name="et-al">et al.</term><term name="forthcoming">à paraître</term><term name="from">à l'adresse</term><term name="ibid">ibid.</term><term name="in">in</term><term name="in press">sous presse</term><term name="internet">Internet</term><term name="interview">entretien</term><term name="letter">lettre</term><term name="no date">sans date</term><term name="no date" form="short">s.&#160;d.</term><term name="online">en ligne</term><term name="presented at">présenté à</term><term name="reference"><single>référence</single><multiple>références</multiple></term><term name="reference" form="short"><single>réf.</single><multiple>réf.</multiple></term><term name="retrieved">consulté</term><term name="scale">échelle</term><term name="version">version</term>
<!-- LONG ITEM TYPE FORMS --><term name="article">article</term><term name="article-journal">article de revue</term><term name="article-magazine">article de magazine</term><term name="article-newspaper">article de presse</term><term name="bill">projet de loi</term><term name="book">livre</term><term name="broadcast">émission</term><term name="chapter">chapitre de livre</term><term name="classic">classique</term><term name="collection">collection</term><term name="dataset">jeu de données</term><term name="document">document</term><term name="entry">entrée</term><term name="entry-dictionary">entrée de dictionnaire</term><term name="entry-encyclopedia">entrée d'encyclopédie</term><term name="event">événement</term><!-- figure is in the list of locator terms --><term name="graphic">image</term><term name="hearing">audience</term><term name="interview">interview</term><term name="legal_case">affaire</term><term name="legislation">acte juridique</term><term name="manuscript">manuscrit</term><term name="map">carte</term><term name="motion_picture">enregistrement vidéo</term><term name="musical_score">partition</term><term name="pamphlet">pamphlet</term><term name="paper-conference">article de colloque</term><term name="patent">brevet</term><term name="performance">interprétation</term><term name="periodical">périodique</term><term name="personal_communication">communication personnelle</term><term name="post">billet</term><term name="post-weblog">billet de blog</term><term name="regulation">règlement</term><term name="report">rapport</term><term name="review">recension</term><term name="review-book">recension de livre</term><term name="software">logiciel</term><term name="song">chanson</term><term name="speech">présentation</term><term name="standard">norme</term><term name="thesis">thèse</term><term name="treaty">traité</term><term name="webpage">page web</term>
<!-- SHORT ITEM TYPE FORMS --><term name="article-journal" form="short">art. de revue</term><term name="article-magazine" form="short">art. de mag.</term><term name="article-newspaper" form="short">art. de presse</term><term name="book" form="short">liv.</term><term name="chapter" form="short">chap. de liv.</term><term name="document" form="short">doc.</term><!-- figure is in the list of locator terms --><term name="graphic" form="short">graph.</term><term name="interview" form="short">interv.</term><term name="manuscript" form="short">ms</term><term name="motion_picture" form="short">enr. vidéo</term><term name="report" form="short">rap.</term><term name="review" form="short">recens.</term><term name="review-book" form="short">recens. de liv.</term><term name="song" form="short">enr. audio</term>
<!-- HISTORICAL ERA TERMS --><term name="ad">apr. J.-C.</term><term name="bc">av. J.-C.</term><term name="bce">av. n. è.</term><term name="ce">n. è.</term>
<!-- PUNCTUATION --><term name="open-quote">«&#160;</term><term name="close-quote">&#160;»</term><term name="open-inner-quote">“</term><term name="close-inner-quote">”</term><term name="page-range-delimiter">&#8209;</term> <!-- non-breaking hyphen --><term name="colon">&#160;:</term><term name="comma">,</term><term name="semicolon">&#160;;</term>
<!-- ORDINALS --><term name="ordinal">ᵉ</term><term name="ordinal-01" gender-form="feminine" match="whole-number">ʳᵉ</term><term name="ordinal-01" gender-form="masculine" match="whole-number">ᵉʳ</term>
<!-- LONG ORDINALS --><term name="long-ordinal-01">premier</term><term name="long-ordinal-02">deuxième</term><term name="long-ordinal-03">troisième</term><term name="long-ordinal-04">quatrième</term><term name="long-ordinal-05">cinquième</term><term name="long-ordinal-06">sixième</term><term name="long-ordinal-07">septième</term><term name="long-ordinal-08">huitième</term><term name="long-ordinal-09">neuvième</term><term name="long-ordinal-10">dixième</term>
<!-- LONG LOCATOR FORMS --><term name="act"><single>acte</single><multiple>actes</multiple></term><term name="appendix"><single>appendice</single><multiple>appendices</multiple></term><term name="article-locator"><single>article</single><multiple>articles</multiple></term><term name="canon"><single>canon</single><multiple>canons</multiple></term><term name="elocation"><single>emplacement</single><multiple>emplacements</multiple></term><term name="equation"><single>équation</single><multiple>équations</multiple></term><term name="rule"><single>règle</single><multiple>règles</multiple></term><term name="scene"><single>scène</single><multiple>scènes</multiple></term><term name="table"><single>tableau</single><multiple>tableaux</multiple></term><term name="timestamp"> <!-- generally blank --><single></single><multiple></multiple></term><term name="title-locator"><single>titre</single><multiple>titres</multiple></term><term name="book"><single>livre</single><multiple>livres</multiple></term><term name="chapter"><single>chapitre</single><multiple>chapitres</multiple></term><term name="column"><single>colonne</single><multiple>colonnes</multiple></term><term name="figure"><single>figure</single><multiple>figures</multiple></term><term name="folio"><single>folio</single><multiple>folios</multiple></term><term name="issue" gender="masculine"><single>numéro</single><multiple>numéros</multiple></term><term name="line"><single>ligne</single><multiple>lignes</multiple></term><term name="note"><single>note</single><multiple>notes</multiple></term><term name="opus"><single>opus</single><multiple>opus</multiple></term><term name="page"><single>page</single><multiple>pages</multiple></term><term name="number-of-pages"><single>page</single><multiple>pages</multiple></term><term name="paragraph"><single>paragraphe</single><multiple>paragraphes</multiple></term><term name="part"><single>partie</single><multiple>parties</multiple></term><term name="section"><single>section</single><multiple>sections</multiple></term><term name="sub-verbo"><single>sub verbo</single><multiple>sub verbis</multiple></term><term name="verse"><single>verset</single><multiple>versets</multiple></term><term name="volume" gender="masculine"><single>volume</single><multiple>volumes</multiple></term>
<!-- SHORT LOCATOR FORMS --><term name="appendix"><single>append.</single><multiple>append.</multiple></term><term name="article-locator"><single>art.</single><multiple>art.</multiple></term><term name="elocation"><single>emplact</single><multiple>emplact</multiple></term><term name="equation"><single>eq.</single><multiple>eq.</multiple></term><term name="rule"><single>règle</single><multiple>règles</multiple></term><term name="scene"><single>sc.</single><multiple>sc.</multiple></term><term name="table"><single>tab.</single><multiple>tab.</multiple></term><term name="timestamp"> <!-- generally blank --><single></single><multiple></multiple></term><term name="title-locator"><single>tit.</single><multiple>tit.</multiple></term><term name="book" form="short">liv.</term><term name="chapter" form="short">chap.</term><term name="column" form="short">col.</term><term name="figure" form="short">fig.</term><term name="folio" form="short"><single>fᵒ</single><multiple>fᵒˢ</multiple></term><term name="issue" form="short"><single>nᵒ</single><multiple>nᵒˢ</multiple></term><term name="line" form="short">l.</term><term name="note" form="short">n.</term><term name="opus" form="short">op.</term><term name="page" form="short"><single>p.</single><multiple>p.</multiple></term><term name="number-of-pages" form="short"><single>p.</single><multiple>p.</multiple></term><term name="paragraph" form="short">paragr.</term><term name="part" form="short">part.</term><term name="section" form="short">sect.</term><term name="sub-verbo" form="short"><single>s.&#160;v.</single><multiple>s.&#160;vv.</multiple></term><term name="verse" form="short"><single>v.</single><multiple>v.</multiple></term><term name="volume" form="short"><single>vol.</single><multiple>vol.</multiple></term>
<!-- SYMBOL LOCATOR FORMS --><term name="paragraph" form="symbol"><single>§</single><multiple>§</multiple></term><term name="section" form="symbol"><single>§</single><multiple>§</multiple></term>
<!-- LONG ROLE FORMS --><term name="chair"><single>président</single><multiple>présidents</multiple></term><term name="compiler"><single>compilateur</single><multiple>compilateurs</multiple></term><term name="contributor"><single>contributeur</single><multiple>contributeurs</multiple></term><term name="curator"><single>commissaire</single><multiple>commissaires</multiple></term><term name="executive-producer"><single>producteur exécutif</single><multiple>producteurs exécutifs</multiple></term><term name="guest"><single>invité</single><multiple>invités</multiple></term><term name="host"><single>hôte</single><multiple>hôtes</multiple></term><term name="narrator"><single>narrateur</single><multiple>narrateurs</multiple></term><term name="organizer"><single>organisateur</single><multiple>organisateurs</multiple></term><term name="performer"><single>interprète</single><multiple>interprètes</multiple></term><term name="producer"><single>producteur</single><multiple>producteurs</multiple></term><term name="script-writer"><single>scénariste</single><multiple>scénaristes</multiple></term><term name="series-creator"><single>créateur de série</single><multiple>créateurs de série</multiple></term><term name="director"><single>réalisateur</single><multiple>réalisateurs</multiple></term><term name="editor"><single>éditeur</single><multiple>éditeurs</multiple></term><term name="editorial-director"><single>directeur</single><multiple>directeurs</multiple></term><term name="illustrator"><single>illustrateur</single><multiple>illustrateurs</multiple></term><term name="translator"><single>traducteur</single><multiple>traducteurs</multiple></term><term name="editortranslator"><single>éditeur et traducteur</single><multiple>éditeurs et traducteurs</multiple></term>
<!-- SHORT ROLE FORMS --><term name="compiler" form="short"><single>compil.</single><multiple>compil.</multiple></term><term name="contributor" form="short"><single>contrib.</single><multiple>contrib.</multiple></term><term name="curator" form="short"><single>commiss.</single><multiple>commiss.</multiple></term><term name="executive-producer" form="short"><single>prod. exé.</single><multiple>prod. exé.</multiple></term><term name="narrator" form="short"><single>narr.</single><multiple>narr.</multiple></term><term name="organizer" form="short"><single>org.</single><multiple>org.</multiple></term><term name="performer" form="short"><single>interpr.</single><multiple>interpr.</multiple></term><term name="producer" form="short"><single>prod.</single><multiple>prod.</multiple></term><term name="script-writer" form="short"><single>scénar.</single><multiple>scénar.</multiple></term><term name="series-creator" form="short"><single>créat.</single><multiple>créat.</multiple></term><term name="director" form="short"><single>réal.</single><multiple>réal.</multiple></term><term name="editor" form="short"><single>éd.</single><multiple>éd.</multiple></term><term name="editorial-director" form="short"><single>dir.</single><multiple>dir.</multiple></term><term name="illustrator" form="short"><single>ill.</single><multiple>ill.</multiple></term><term name="translator" form="short"><single>trad.</single><multiple>trad.</multiple></term><term name="editortranslator" form="short"><single>éd. et trad.</single><multiple>éd. et trad.</multiple></term>
<!-- VERB ROLE FORMS --><term name="chair" form="verb">présidé par</term><term name="compiler" form="verb">compilé par</term><term name="contributor" form="verb">avec</term><term name="curator" form="verb">organisé par</term><term name="executive-producer" form="verb">production exécutive par</term><term name="guest" form="verb">avec pour invité</term><term name="host" form="verb">animé par</term><term name="narrator" form="verb">lu par</term><term name="organizer" form="verb">organisé par</term><term name="performer" form="verb">interprété par</term><term name="producer" form="verb">produit par</term><term name="script-writer" form="verb">scénario de</term><term name="series-creator" form="verb">créé par</term><term name="container-author" form="verb">par</term><term name="director" form="verb">réalisé par</term><term name="editor" form="verb">édité par</term><term name="editorial-director" form="verb">sous la direction de</term><term name="illustrator" form="verb">illustré par</term><term name="interviewer" form="verb">entretien réalisé par</term><term name="recipient" form="verb">à</term><term name="reviewed-author" form="verb">par</term><term name="translator" form="verb">traduit par</term><term name="editortranslator" form="verb">édité et traduit par</term>
<!-- SHORT VERB ROLE FORMS --><term name="compiler" form="verb-short">compil. par</term><term name="contributor" form="verb-short">ac</term><term name="curator" form="verb-short">org. par</term><term name="executive-producer" form="verb-short">prod. exé. par</term><term name="guest" form="verb-short">ac pr inv.</term><term name="host" form="verb-short">anim. par</term><term name="narrator" form="verb-short">lu par</term><term name="organizer" form="verb-short">org. par</term><term name="performer" form="verb-short">interpr. par</term><term name="producer" form="verb-short">prod. par</term><term name="script-writer" form="verb-short">scénar. de</term><term name="series-creator" form="verb-short">créé par</term><term name="director" form="verb-short">réal. par</term><term name="editor" form="verb-short">éd. par</term><term name="editorial-director" form="verb-short">ss la dir. de</term><term name="illustrator" form="verb-short">ill. par</term><term name="translator" form="verb-short">trad. par</term><term name="editortranslator" form="verb-short">éd. et trad. par</term>
<!-- LONG MONTH FORMS --><term name="month-01" gender="masculine">janvier</term><term name="month-02" gender="masculine">février</term><term name="month-03" gender="masculine">mars</term><term name="month-04" gender="masculine">avril</term><term name="month-05" gender="masculine">mai</term><term name="month-06" gender="masculine">juin</term><term name="month-07" gender="masculine">juillet</term><term name="month-08" gender="masculine">août</term><term name="month-09" gender="masculine">septembre</term><term name="month-10" gender="masculine">octobre</term><term name="month-11" gender="masculine">novembre</term><term name="month-12" gender="masculine">décembre</term>
<!-- SHORT MONTH FORMS --><term name="month-01" form="short">janv.</term><term name="month-02" form="short">févr.</term><term name="month-03" form="short">mars</term><term name="month-04" form="short">avr.</term><term name="month-05" form="short">mai</term><term name="month-06" form="short">juin</term><term name="month-07" form="short">juill.</term><term name="month-08" form="short">août</term><term name="month-09" form="short">sept.</term><term name="month-10" form="short">oct.</term><term name="month-11" form="short">nov.</term><term name="month-12" form="short">déc.</term>
<!-- SEASONS --><term name="season-01">printemps</term><term name="season-02">été</term><term name="season-03">automne</term><term name="season-04">hiver</term></terms>
</locale>
`,"de-DE":`<?xml version="1.0" encoding="utf-8"?>
<locale xmlns="http://purl.org/net/xbiblio/csl" version="1.0" xml:lang="de-DE"><info><translator><name>Till A. Heilmann</name></translator><translator><name>Ulrich</name></translator><translator><name>Rintze M. Zelle</name></translator><translator><name>Sebastian Karcher</name></translator><translator><name>jakov</name></translator><rights license="http://creativecommons.org/licenses/by-sa/3.0/">This work is licensed under a Creative Commons Attribution-ShareAlike 3.0 License</rights><updated>2012-07-04T23:31:02+00:00</updated></info><style-options punctuation-in-quote="false"/><date form="text"><date-part name="day" form="ordinal" suffix=" "/><date-part name="month" suffix=" "/><date-part name="year"/></date><date form="numeric"><date-part name="day" form="numeric-leading-zeros" suffix="."/><date-part name="month" form="numeric-leading-zeros" suffix="."/><date-part name="year"/></date><terms><term name="advance-online-publication">advance online publication</term><term name="album">album</term><term name="audio-recording">audio recording</term><term name="film">film</term><term name="henceforth">henceforth</term><term name="loc-cit">loc. cit.</term> <!-- like ibid., the abbreviated form is the regular form  --><term name="no-place">no place</term><term name="no-place" form="short">n.p.</term><term name="no-publisher">no publisher</term> <!-- sine nomine --><term name="no-publisher" form="short">n.p.</term><term name="on">on</term><term name="op-cit">op. cit.</term> <!-- like ibid., the abbreviated form is the regular form  --><term name="original-work-published">original work published</term><term name="personal-communication">persönliche Kommunikation</term><term name="podcast">podcast</term><term name="podcast-episode">podcast episode</term><term name="preprint">preprint</term><term name="radio-broadcast">radio broadcast</term><term name="radio-series">radio series</term><term name="radio-series-episode">radio series episode</term><term name="special-issue">special issue</term><term name="special-section">special section</term><term name="television-broadcast">television broadcast</term><term name="television-series">television series</term><term name="television-series-episode">television series episode</term><term name="video">video</term><term name="working-paper">working paper</term><term name="accessed">zugegriffen</term><term name="and">und</term><term name="and others">und andere</term><term name="anonymous">ohne Autor</term><term name="anonymous" form="short">o.&#160;A.</term><term name="at">auf</term><term name="available at">verfügbar unter</term><term name="by">von</term><term name="circa">circa</term><term name="circa" form="short">ca.</term><term name="cited">zitiert</term><term name="edition"><single>Auflage</single><multiple>Auflagen</multiple></term><term name="edition" form="short">Aufl.</term><term name="et-al">u.&#160;a.</term><term name="forthcoming">i.&#160;E.</term><term name="from">von</term><term name="ibid">ebd.</term><term name="in">in</term><term name="in press">im Druck</term><term name="internet">Internet</term><term name="interview">Interview</term><term name="letter">Brief</term><term name="no date">ohne Datum</term><term name="no date" form="short">o.&#160;J.</term><term name="online">online</term><term name="presented at">gehalten auf der</term><term name="reference"><single>Referenz</single><multiple>Referenzen</multiple></term><term name="reference" form="short"><single>Ref.</single><multiple>Ref.</multiple></term><term name="retrieved">abgerufen</term><term name="scale">Maßstab</term><term name="version">Version</term>
<!-- LONG ITEM TYPE FORMS --><term name="article">preprint</term><term name="article-journal">journal article</term><term name="article-magazine">magazine article</term><term name="article-newspaper">newspaper article</term><term name="bill">bill</term><term name="book">book</term><term name="broadcast">broadcast</term><term name="chapter">book chapter</term><term name="classic">classic</term><term name="collection">collection</term><term name="dataset">dataset</term><term name="document">document</term><term name="entry">entry</term><term name="entry-dictionary">dictionary entry</term><term name="entry-encyclopedia">encyclopedia entry</term><term name="event">event</term><!-- figure is in the list of locator terms --><term name="graphic">graphic</term><term name="hearing">hearing</term><term name="interview">interview</term><term name="legal_case">legal case</term><term name="legislation">legislation</term><term name="manuscript">manuscript</term><term name="map">map</term><term name="motion_picture">video recording</term><term name="musical_score">musical score</term><term name="pamphlet">pamphlet</term><term name="paper-conference">conference paper</term><term name="patent">patent</term><term name="performance">performance</term><term name="periodical">periodical</term><term name="personal_communication">persönliche Kommunikation</term><term name="post">post</term><term name="post-weblog">blog post</term><term name="regulation">regulation</term><term name="report">report</term><term name="review">review</term><term name="review-book">book review</term><term name="software">software</term><term name="song">audio recording</term><term name="speech">presentation</term><term name="standard">standard</term><term name="thesis">thesis</term><term name="treaty">treaty</term><term name="webpage">webpage</term>
<!-- SHORT ITEM TYPE FORMS --><term name="article-journal" form="short">journal art.</term><term name="article-magazine" form="short">mag. art.</term><term name="article-newspaper" form="short">newspaper art.</term><term name="book" form="short">bk.</term><term name="chapter" form="short">bk. chap.</term><term name="document" form="short">doc.</term><!-- figure is in the list of locator terms --><term name="graphic" form="short">graph.</term><term name="interview" form="short">interv.</term><term name="manuscript" form="short">MS</term><term name="motion_picture" form="short">video rec.</term><term name="report" form="short">rep.</term><term name="review" form="short">rev.</term><term name="review-book" form="short">bk. rev.</term><term name="song" form="short">audio rec.</term>
<!-- HISTORICAL ERA TERMS --><term name="ad">&#160;n.&#160;Chr.</term><term name="bc">&#160;v.&#160;Chr.</term><term name="bce">BCE</term><term name="ce">CE</term>
<!-- PUNCTUATION --><term name="open-quote">„</term><term name="close-quote">“</term><term name="open-inner-quote">‚</term><term name="close-inner-quote">‘</term><term name="page-range-delimiter">–</term><term name="colon">:</term><term name="comma">,</term><term name="semicolon">;</term>
<!-- ORDINALS --><term name="ordinal">.</term>
<!-- LONG ORDINALS --><term name="long-ordinal-01">erster</term><term name="long-ordinal-02">zweiter</term><term name="long-ordinal-03">dritter</term><term name="long-ordinal-04">vierter</term><term name="long-ordinal-05">fünfter</term><term name="long-ordinal-06">sechster</term><term name="long-ordinal-07">siebter</term><term name="long-ordinal-08">achter</term><term name="long-ordinal-09">neunter</term><term name="long-ordinal-10">zehnter</term>
<!-- LONG LOCATOR FORMS --><term name="act">			 <single>act</single><multiple>acts</multiple>						 </term><term name="appendix">			 <single>appendix</single><multiple>appendices</multiple>						 </term><term name="article-locator">			 <single>article</single><multiple>articles</multiple>						 </term><term name="canon">			 <single>canon</single><multiple>canons</multiple>						 </term><term name="elocation">			 <single>location</single><multiple>locations</multiple>						 </term><term name="equation">			 <single>equation</single><multiple>equations</multiple>						 </term><term name="rule">			 <single>rule</single><multiple>rules</multiple>						 </term><term name="scene">			 <single>scene</single><multiple>scenes</multiple>						 </term><term name="table">			 <single>table</single><multiple>tables</multiple>						 </term><term name="timestamp"> <!-- generally blank --><single></single><multiple></multiple>						 </term><term name="title-locator">			 <single>title</single><multiple>titles</multiple>						 </term><term name="book"><single>Buch</single><multiple>Bücher</multiple></term><term name="chapter"><single>Kapitel</single><multiple>Kapitel</multiple></term><term name="column"><single>Spalte</single><multiple>Spalten</multiple></term><term name="figure"><single>Abbildung</single><multiple>Abbildungen</multiple></term><term name="folio"><single>Blatt</single><multiple>Blätter</multiple></term><term name="issue"><single>Nummer</single><multiple>Nummern</multiple></term><term name="line"><single>Zeile</single><multiple>Zeilen</multiple></term><term name="note"><single>Note</single><multiple>Noten</multiple></term><term name="opus"><single>Opus</single><multiple>Opera</multiple></term><term name="page"><single>Seite</single><multiple>Seiten</multiple></term><term name="number-of-pages"><single>Seite</single><multiple>Seiten</multiple></term><term name="paragraph"><single>Absatz</single><multiple>Absätze</multiple></term><term name="part"><single>Teil</single><multiple>Teile</multiple></term><term name="section"><single>Abschnitt</single><multiple>Abschnitte</multiple></term><term name="sub-verbo"><single>sub verbo</single><multiple>sub verbis</multiple></term><term name="verse"><single>Vers</single><multiple>Verse</multiple></term><term name="volume"><single>Band</single><multiple>Bände</multiple></term>
<!-- SHORT LOCATOR FORMS --><term name="appendix">			 <single>app.</single><multiple>apps.</multiple>						 </term><term name="article-locator">			 <single>art.</single><multiple>arts.</multiple></term><term name="elocation">			 <single>loc.</single><multiple>locs.</multiple></term><term name="equation">			 <single>eq.</single><multiple>eqs.</multiple></term><term name="rule">			 <single>r.</single><multiple>rr.</multiple>						 </term><term name="scene">			 <single>sc.</single><multiple>scs.</multiple>						 </term><term name="table">			 <single>tbl.</single><multiple>tbls.</multiple>						 </term><term name="timestamp"> <!-- generally blank --><single></single><multiple></multiple>						 </term><term name="title-locator">			 <single>tit.</single><multiple>tits.</multiple></term><term name="book" form="short">B.</term><term name="chapter" form="short">Kap.</term><term name="column" form="short">Sp.</term><term name="figure" form="short">Abb.</term><term name="folio" form="short">Fol.</term><term name="issue" form="short">Nr.</term><term name="line" form="short">Z.</term><term name="note" form="short">N.</term><term name="opus" form="short">op.</term><term name="page" form="short"><single>S.</single><multiple>S.</multiple></term><term name="number-of-pages" form="short"><single>S.</single><multiple>S.</multiple></term><term name="paragraph" form="short">Abs.</term><term name="part" form="short">Teil</term><term name="section" form="short">Abschn.</term><term name="sub-verbo" form="short"><single>s.&#160;v.</single><multiple>s.&#160;vv.</multiple></term><term name="verse" form="short"><single>V.</single><multiple>V.</multiple></term><term name="volume" form="short"><single>Bd.</single><multiple>Bde.</multiple></term>
<!-- SYMBOL LOCATOR FORMS --><term name="paragraph" form="symbol"><single>¶</single><multiple>¶¶</multiple></term><term name="section" form="symbol"><single>§</single><multiple>§§</multiple></term>
<!-- LONG ROLE FORMS --><term name="chair"><single>chair</single><multiple>chairs</multiple></term><term name="compiler"><single>compiler</single><multiple>compilers</multiple></term><term name="contributor"><single>contributor</single><multiple>contributors</multiple></term><term name="curator"><single>curator</single><multiple>curators</multiple></term><term name="executive-producer"><single>executive producer</single><multiple>executive producers</multiple></term><term name="guest"><single>guest</single><multiple>guests</multiple></term><term name="host"><single>host</single><multiple>hosts</multiple></term><term name="narrator"><single>narrator</single><multiple>narrators</multiple></term><term name="organizer"><single>organizer</single><multiple>organizers</multiple></term><term name="performer"><single>performer</single><multiple>performers</multiple></term><term name="producer"><single>producer</single><multiple>producers</multiple></term><term name="script-writer"><single>writer</single><multiple>writers</multiple></term><term name="series-creator"><single>series creator</single><multiple>series creators</multiple></term><term name="director"><single>Regisseur</single><multiple>Regisseure</multiple></term><term name="editor"><single>Herausgeber</single><multiple>Herausgeber</multiple></term><term name="collection-editor"><single>Reihenherausgeber</single><multiple>Reihenherausgeber</multiple></term><term name="editorial-director"><single>Herausgeber</single><multiple>Herausgeber</multiple></term><term name="illustrator"><single>Illustrator</single><multiple>Illustratoren</multiple></term><term name="translator"><single>Übersetzer</single><multiple>Übersetzer</multiple></term><term name="editortranslator"><single>Herausgeber&#160;&amp; Übersetzer</single><multiple>Herausgeber&#160;&amp; Übersetzer</multiple></term>
<!-- SHORT ROLE FORMS --><term name="compiler" form="short"><single>comp.</single><multiple>comps.</multiple></term><term name="contributor" form="short"><single>contrib.</single><multiple>contribs.</multiple></term><term name="curator" form="short"><single>cur.</single><multiple>curs.</multiple></term><term name="executive-producer" form="short"><single>exec. prod.</single><multiple>exec. prods.</multiple></term><term name="narrator" form="short"><single>narr.</single><multiple>narrs.</multiple></term><term name="organizer" form="short"><single>org.</single><multiple>orgs.</multiple></term><term name="performer" form="short"><single>perf.</single><multiple>perfs.</multiple></term><term name="producer" form="short"><single>prod.</single><multiple>prods.</multiple></term><term name="script-writer" form="short"><single>writ.</single><multiple>writs.</multiple></term><term name="series-creator" form="short"><single>cre.</single><multiple>cres.</multiple></term><term name="director" form="short"><single>Reg.</single><multiple>Reg.</multiple></term><term name="editor" form="short"><single>Hrsg.</single><multiple>Hrsg.</multiple></term><term name="collection-editor" form="short"><single>Hrsg.</single><multiple>Hrsg.</multiple></term><term name="editorial-director" form="short"><single>Hrsg.</single><multiple>Hrsg.</multiple></term><term name="illustrator" form="short"><single>Ill.</single><multiple>Ill.</multiple></term><term name="translator" form="short"><single>Übers.</single><multiple>Übers.</multiple></term><term name="editortranslator" form="short"><single>Hrsg.&#160;&amp; Übers.</single><multiple>Hrsg.&#160;&amp; Übers.</multiple></term>
<!-- VERB ROLE FORMS --><term name="chair" form="verb">chaired by</term><term name="compiler" form="verb">compiled by</term><term name="contributor" form="verb">with</term><term name="curator" form="verb">curated by</term><term name="executive-producer" form="verb">executive produced by</term><term name="guest" form="verb">with guest</term><term name="host" form="verb">hosted by</term><term name="narrator" form="verb">narrated by</term><term name="organizer" form="verb">organized by</term><term name="performer" form="verb">performed by</term><term name="producer" form="verb">produced by</term><term name="script-writer" form="verb">written by</term><term name="series-creator" form="verb">created by</term><term name="container-author" form="verb">von</term><term name="director" form="verb">Regie von</term><term name="editor" form="verb">herausgegeben von</term><term name="collection-editor" form="verb">herausgegeben von</term><term name="editorial-director" form="verb">herausgegeben von</term><term name="illustrator" form="verb">illustriert von</term><term name="interviewer" form="verb">interviewt von</term><term name="recipient" form="verb">an</term><term name="reviewed-author" form="verb">von</term><term name="translator" form="verb">übersetzt von</term><term name="editortranslator" form="verb">herausgegeben und übersetzt von</term>
<!-- SHORT VERB ROLE FORMS --><term name="compiler" form="verb-short">comp. by</term><term name="contributor" form="verb-short">w.</term><term name="curator" form="verb-short">cur. by</term><term name="executive-producer" form="verb-short">exec. prod. by</term><term name="guest" form="verb-short">w. guest</term><term name="host" form="verb-short">hosted by</term><term name="narrator" form="verb-short">narr. by</term><term name="organizer" form="verb-short">org. by</term><term name="performer" form="verb-short">perf. by</term><term name="producer" form="verb-short">prod. by</term><term name="script-writer" form="verb-short">writ. by</term><term name="series-creator" form="verb-short">cre. by</term><term name="director" form="verb-short">Reg.</term><term name="editor" form="verb-short">hg. von</term><term name="collection-editor" form="verb-short">hg. von</term><term name="editorial-director" form="verb-short">hg. von</term><term name="illustrator" form="verb-short">illus. von</term><term name="translator" form="verb-short">übers. von</term><term name="editortranslator" form="verb-short">hg.&#160;&amp; übers. von</term>
<!-- LONG MONTH FORMS --><term name="month-01">Januar</term><term name="month-02">Februar</term><term name="month-03">März</term><term name="month-04">April</term><term name="month-05">Mai</term><term name="month-06">Juni</term><term name="month-07">Juli</term><term name="month-08">August</term><term name="month-09">September</term><term name="month-10">Oktober</term><term name="month-11">November</term><term name="month-12">Dezember</term>
<!-- SHORT MONTH FORMS --><term name="month-01" form="short">Jan.</term><term name="month-02" form="short">Feb.</term><term name="month-03" form="short">März</term><term name="month-04" form="short">Apr.</term><term name="month-05" form="short">Mai</term><term name="month-06" form="short">Juni</term><term name="month-07" form="short">Juli</term><term name="month-08" form="short">Aug.</term><term name="month-09" form="short">Sep.</term><term name="month-10" form="short">Okt.</term><term name="month-11" form="short">Nov.</term><term name="month-12" form="short">Dez.</term>
<!-- SEASONS --><term name="season-01">Frühjahr</term><term name="season-02">Sommer</term><term name="season-03">Herbst</term><term name="season-04">Winter</term></terms>
</locale>
`,"es-ES":`<?xml version="1.0" encoding="utf-8"?>
<locale xmlns="http://purl.org/net/xbiblio/csl" version="1.0" xml:lang="es-ES"><info><translator><name>javimat</name></translator><rights license="http://creativecommons.org/licenses/by-sa/3.0/">This work is licensed under a Creative Commons Attribution-ShareAlike 3.0 License</rights><updated>2012-07-04T23:31:02+00:00</updated></info><style-options punctuation-in-quote="false"/><date form="text"><date-part name="day" suffix=" de "/><date-part name="month" suffix=" de "/><date-part name="year"/></date><date form="numeric"><date-part name="day" form="numeric-leading-zeros" suffix="/"/><date-part name="month" form="numeric-leading-zeros" suffix="/"/><date-part name="year"/></date><terms><term name="advance-online-publication">advance online publication</term><term name="album">album</term><term name="audio-recording">audio recording</term><term name="film">film</term><term name="henceforth">henceforth</term><term name="loc-cit">loc. cit.</term> <!-- like ibid., the abbreviated form is the regular form  --><term name="no-place">no place</term><term name="no-place" form="short">n.p.</term><term name="no-publisher">no publisher</term> <!-- sine nomine --><term name="no-publisher" form="short">n.p.</term><term name="on">on</term><term name="op-cit">op. cit.</term> <!-- like ibid., the abbreviated form is the regular form  --><term name="original-work-published">original work published</term><term name="personal-communication">comunicación personal</term><term name="podcast">podcast</term><term name="podcast-episode">podcast episode</term><term name="preprint">preprint</term><term name="radio-broadcast">radio broadcast</term><term name="radio-series">radio series</term><term name="radio-series-episode">radio series episode</term><term name="special-issue">special issue</term><term name="special-section">special section</term><term name="television-broadcast">television broadcast</term><term name="television-series">television series</term><term name="television-series-episode">television series episode</term><term name="video">video</term><term name="working-paper">working paper</term><term name="accessed">accedido</term><term name="and">y</term><term name="and others">y otros</term><term name="anonymous">anónimo</term><term name="anonymous" form="short">anón.</term><term name="at">en</term><term name="available at">disponible en</term><term name="by">de</term><term name="circa">circa</term><term name="circa" form="short">c.</term><term name="cited">citado</term><term name="edition"><single>edición</single><multiple>ediciones</multiple></term><term name="edition" form="short">ed.</term><term name="et-al">et&#160;al.</term><term name="forthcoming">previsto</term><term name="from">a partir de</term><term name="ibid">ibid.</term><term name="in">en</term><term name="in press">en imprenta</term><term name="internet">internet</term><term name="interview">entrevista</term><term name="letter">carta</term><term name="no date">sin fecha</term><term name="no date" form="short">s.&#160;f.</term><term name="online">en línea</term><term name="presented at">presentado en</term><term name="reference"><single>referencia</single><multiple>referencias</multiple></term><term name="reference" form="short"><single>ref.</single><multiple>refs.</multiple></term><term name="retrieved">recuperado</term><term name="scale">escala</term><term name="version">versión</term>
<!-- LONG ITEM TYPE FORMS --><term name="article">preprint</term><term name="article-journal">journal article</term><term name="article-magazine">magazine article</term><term name="article-newspaper">newspaper article</term><term name="bill">bill</term><term name="book">book</term><term name="broadcast">broadcast</term><term name="chapter">book chapter</term><term name="classic">classic</term><term name="collection">collection</term><term name="dataset">dataset</term><term name="document">document</term><term name="entry">entry</term><term name="entry-dictionary">dictionary entry</term><term name="entry-encyclopedia">encyclopedia entry</term><term name="event">event</term><!-- figure is in the list of locator terms --><term name="graphic">graphic</term><term name="hearing">hearing</term><term name="interview">interview</term><term name="legal_case">legal case</term><term name="legislation">legislation</term><term name="manuscript">manuscript</term><term name="map">map</term><term name="motion_picture">video recording</term><term name="musical_score">musical score</term><term name="pamphlet">pamphlet</term><term name="paper-conference">conference paper</term><term name="patent">patent</term><term name="performance">performance</term><term name="periodical">periodical</term><term name="personal_communication">comunicación personal</term><term name="post">post</term><term name="post-weblog">blog post</term><term name="regulation">regulation</term><term name="report">report</term><term name="review">review</term><term name="review-book">book review</term><term name="software">software</term><term name="song">audio recording</term><term name="speech">presentation</term><term name="standard">standard</term><term name="thesis">thesis</term><term name="treaty">treaty</term><term name="webpage">webpage</term>
<!-- SHORT ITEM TYPE FORMS --><term name="article-journal" form="short">journal art.</term><term name="article-magazine" form="short">mag. art.</term><term name="article-newspaper" form="short">newspaper art.</term><term name="book" form="short">bk.</term><term name="chapter" form="short">bk. chap.</term><term name="document" form="short">doc.</term><!-- figure is in the list of locator terms --><term name="graphic" form="short">graph.</term><term name="interview" form="short">interv.</term><term name="manuscript" form="short">MS</term><term name="motion_picture" form="short">video rec.</term><term name="report" form="short">rep.</term><term name="review" form="short">rev.</term><term name="review-book" form="short">bk. rev.</term><term name="song" form="short">audio rec.</term>
<!-- HISTORICAL ERA TERMS --><term name="ad">d.&#160;C.</term><term name="bc">a.&#160;C.</term><term name="bce">BCE</term><term name="ce">CE</term>
<!-- PUNCTUATION --><term name="open-quote">«</term><term name="close-quote">»</term><term name="open-inner-quote">“</term><term name="close-inner-quote">”</term><term name="page-range-delimiter">-</term><term name="colon">:</term><term name="comma">,</term><term name="semicolon">;</term>
<!-- ORDINALS --><term name="ordinal">.ª</term>
<!-- LONG ORDINALS --><term name="long-ordinal-01">primera</term><term name="long-ordinal-02">segunda</term><term name="long-ordinal-03">tercera</term><term name="long-ordinal-04">cuarta</term><term name="long-ordinal-05">quinta</term><term name="long-ordinal-06">sexta</term><term name="long-ordinal-07">séptima</term><term name="long-ordinal-08">octava</term><term name="long-ordinal-09">novena</term><term name="long-ordinal-10">décima</term>
<!-- LONG LOCATOR FORMS --><term name="act">			 <single>act</single><multiple>acts</multiple>						 </term><term name="appendix">			 <single>appendix</single><multiple>appendices</multiple>						 </term><term name="article-locator">			 <single>article</single><multiple>articles</multiple>						 </term><term name="canon">			 <single>canon</single><multiple>canons</multiple>						 </term><term name="elocation">			 <single>location</single><multiple>locations</multiple>						 </term><term name="equation">			 <single>equation</single><multiple>equations</multiple>						 </term><term name="rule">			 <single>rule</single><multiple>rules</multiple>						 </term><term name="scene">			 <single>scene</single><multiple>scenes</multiple>						 </term><term name="table">			 <single>table</single><multiple>tables</multiple>						 </term><term name="timestamp"> <!-- generally blank --><single></single><multiple></multiple>						 </term><term name="title-locator">			 <single>title</single><multiple>titles</multiple>						 </term><term name="book"><single>libro</single><multiple>libros</multiple></term><term name="chapter"><single>capítulo</single><multiple>capítulos</multiple></term><term name="column"><single>columna</single><multiple>columnas</multiple></term><term name="figure"><single>figura</single><multiple>figuras</multiple></term><term name="folio"><single>folio</single><multiple>folios</multiple></term><term name="issue"><single>número</single><multiple>números</multiple></term><term name="line"><single>línea</single><multiple>líneas</multiple></term><term name="note"><single>nota</single><multiple>notas</multiple></term><term name="opus"><single>opus</single><multiple>opera</multiple></term><term name="page"><single>página</single><multiple>páginas</multiple></term><term name="number-of-pages"><single>página</single><multiple>páginas</multiple></term><term name="paragraph"><single>párrafo</single><multiple>párrafos</multiple></term><term name="part"><single>parte</single><multiple>partes</multiple></term><term name="section"><single>sección</single><multiple>secciones</multiple></term><term name="sub-verbo"><single>sub voce</single><multiple>sub vocibus</multiple></term><term name="verse"><single>verso</single><multiple>versos</multiple></term><term name="volume"><single>volumen</single><multiple>volúmenes</multiple></term>
<!-- SHORT LOCATOR FORMS --><term name="appendix">			 <single>app.</single><multiple>apps.</multiple>						 </term><term name="article-locator">			 <single>art.</single><multiple>arts.</multiple></term><term name="elocation">			 <single>loc.</single><multiple>locs.</multiple></term><term name="equation">			 <single>eq.</single><multiple>eqs.</multiple></term><term name="rule">			 <single>r.</single><multiple>rr.</multiple>						 </term><term name="scene">			 <single>sc.</single><multiple>scs.</multiple>						 </term><term name="table">			 <single>tbl.</single><multiple>tbls.</multiple>						 </term><term name="timestamp"> <!-- generally blank --><single></single><multiple></multiple>						 </term><term name="title-locator">			 <single>tit.</single><multiple>tits.</multiple></term><term name="book" form="short">lib.</term><term name="chapter" form="short">cap.</term><term name="column" form="short">col.</term><term name="figure" form="short">fig.</term><term name="folio" form="short">f.</term><term name="issue" form="short">n.º</term><term name="line" form="short">l.</term><term name="note" form="short">n.</term><term name="opus" form="short">op.</term><term name="page" form="short"><single>p.</single><multiple>pp.</multiple></term><term name="number-of-pages" form="short"><single>p.</single><multiple>pp.</multiple></term><term name="paragraph" form="short">párr.</term><term name="part" form="short">pt.</term><term name="section" form="short">sec.</term><term name="sub-verbo" form="short"><single>s.&#160;v.</single><multiple>s.&#160;vv.</multiple></term><term name="verse" form="short"><single>v.</single><multiple>vv.</multiple></term><term name="volume" form="short"><single>vol.</single><multiple>vols.</multiple></term>
<!-- SYMBOL LOCATOR FORMS --><term name="paragraph" form="symbol"><single>§</single><multiple>§</multiple></term><term name="section" form="symbol"><single>§</single><multiple>§</multiple></term>
<!-- LONG ROLE FORMS --><term name="chair"><single>chair</single><multiple>chairs</multiple></term><term name="compiler"><single>compiler</single><multiple>compilers</multiple></term><term name="contributor"><single>contributor</single><multiple>contributors</multiple></term><term name="curator"><single>curator</single><multiple>curators</multiple></term><term name="executive-producer"><single>executive producer</single><multiple>executive producers</multiple></term><term name="guest"><single>guest</single><multiple>guests</multiple></term><term name="host"><single>host</single><multiple>hosts</multiple></term><term name="narrator"><single>narrator</single><multiple>narrators</multiple></term><term name="organizer"><single>organizer</single><multiple>organizers</multiple></term><term name="performer"><single>performer</single><multiple>performers</multiple></term><term name="producer"><single>producer</single><multiple>producers</multiple></term><term name="script-writer"><single>writer</single><multiple>writers</multiple></term><term name="series-creator"><single>series creator</single><multiple>series creators</multiple></term><term name="director"><single>director</single><multiple>directores</multiple></term><term name="editor"><single>editor</single><multiple>editores</multiple></term><term name="editorial-director"><single>editor</single><multiple>editores</multiple></term><term name="illustrator"><single>ilustrador</single><multiple>ilustradores</multiple></term><term name="translator"><single>traductor</single><multiple>traductores</multiple></term><term name="editortranslator"><single>editor y traductor</single><multiple>editores y traductores</multiple></term>
<!-- SHORT ROLE FORMS --><term name="compiler" form="short"><single>comp.</single><multiple>comps.</multiple></term><term name="contributor" form="short"><single>contrib.</single><multiple>contribs.</multiple></term><term name="curator" form="short"><single>cur.</single><multiple>curs.</multiple></term><term name="executive-producer" form="short"><single>exec. prod.</single><multiple>exec. prods.</multiple></term><term name="narrator" form="short"><single>narr.</single><multiple>narrs.</multiple></term><term name="organizer" form="short"><single>org.</single><multiple>orgs.</multiple></term><term name="performer" form="short"><single>perf.</single><multiple>perfs.</multiple></term><term name="producer" form="short"><single>prod.</single><multiple>prods.</multiple></term><term name="script-writer" form="short"><single>writ.</single><multiple>writs.</multiple></term><term name="series-creator" form="short"><single>cre.</single><multiple>cres.</multiple></term><term name="director" form="short"><single>dir.</single><multiple>dirs.</multiple></term><term name="editor" form="short"><single>ed.</single><multiple>eds.</multiple></term><term name="editorial-director" form="short"><single>ed.</single><multiple>eds.</multiple></term><term name="illustrator" form="short"><single>ilust.</single><multiple>ilusts.</multiple></term><term name="translator" form="short"><single>trad.</single><multiple>trads.</multiple></term><term name="editortranslator" form="short"><single>ed. y trad.</single><multiple>eds. y trads.</multiple></term>
<!-- VERB ROLE FORMS --><term name="chair" form="verb">chaired by</term><term name="compiler" form="verb">compiled by</term><term name="contributor" form="verb">with</term><term name="curator" form="verb">curated by</term><term name="executive-producer" form="verb">executive produced by</term><term name="guest" form="verb">with guest</term><term name="host" form="verb">hosted by</term><term name="narrator" form="verb">narrated by</term><term name="organizer" form="verb">organized by</term><term name="performer" form="verb">performed by</term><term name="producer" form="verb">produced by</term><term name="script-writer" form="verb">written by</term><term name="series-creator" form="verb">created by</term><term name="container-author" form="verb">de</term><term name="director" form="verb">dirigido por</term><term name="editor" form="verb">editado por</term><term name="editorial-director" form="verb">editado por</term><term name="illustrator" form="verb">ilustrado por</term><term name="interviewer" form="verb">entrevistado por</term><term name="recipient" form="verb">a</term><term name="reviewed-author" form="verb">por</term><term name="translator" form="verb">traducido por</term><term name="editortranslator" form="verb">editado y traducido por</term>
<!-- SHORT VERB ROLE FORMS --><term name="compiler" form="verb-short">comp. by</term><term name="contributor" form="verb-short">w.</term><term name="curator" form="verb-short">cur. by</term><term name="executive-producer" form="verb-short">exec. prod. by</term><term name="guest" form="verb-short">w. guest</term><term name="host" form="verb-short">hosted by</term><term name="narrator" form="verb-short">narr. by</term><term name="organizer" form="verb-short">org. by</term><term name="performer" form="verb-short">perf. by</term><term name="producer" form="verb-short">prod. by</term><term name="script-writer" form="verb-short">writ. by</term><term name="series-creator" form="verb-short">cre. by</term><term name="director" form="verb-short">dir.</term><term name="editor" form="verb-short">ed.</term><term name="editorial-director" form="verb-short">ed.</term><term name="illustrator" form="verb-short">ilust.</term><term name="translator" form="verb-short">trad.</term><term name="editortranslator" form="verb-short">ed. y trad.</term>
<!-- LONG MONTH FORMS --><term name="month-01">enero</term><term name="month-02">febrero</term><term name="month-03">marzo</term><term name="month-04">abril</term><term name="month-05">mayo</term><term name="month-06">junio</term><term name="month-07">julio</term><term name="month-08">agosto</term><term name="month-09">septiembre</term><term name="month-10">octubre</term><term name="month-11">noviembre</term><term name="month-12">diciembre</term>
<!-- SHORT MONTH FORMS --><term name="month-01" form="short">ene.</term><term name="month-02" form="short">feb.</term><term name="month-03" form="short">mar.</term><term name="month-04" form="short">abr.</term><term name="month-05" form="short">may</term><term name="month-06" form="short">jun.</term><term name="month-07" form="short">jul.</term><term name="month-08" form="short">ago.</term><term name="month-09" form="short">sep.</term><term name="month-10" form="short">oct.</term><term name="month-11" form="short">nov.</term><term name="month-12" form="short">dic.</term>
<!-- SEASONS --><term name="season-01">primavera</term><term name="season-02">verano</term><term name="season-03">otoño</term><term name="season-04">invierno</term></terms>
</locale>
`}),s={apa:`<?xml version="1.0" encoding="utf-8"?>
<style xmlns="http://purl.org/net/xbiblio/csl" class="in-text" version="1.0" demote-non-dropping-particle="never" page-range-format="expanded"><info><title>American Psychological Association 7th edition</title><title-short>APA</title-short><id>http://www.zotero.org/styles/apa</id><link href="http://www.zotero.org/styles/apa" rel="self"/><link href="http://www.zotero.org/styles/apa-6th-edition" rel="template"/><link href="https://apastyle.apa.org/style-grammar-guidelines/references/examples" rel="documentation"/><author><name>Brenton M. Wiernik</name><email>zotero@wiernik.org</email></author><category citation-format="author-date"/><category field="psychology"/><category field="generic-base"/><updated>2022-01-31T14:43:56+00:00</updated><rights license="http://creativecommons.org/licenses/by-sa/3.0/">This work is licensed under a Creative Commons Attribution-ShareAlike 3.0 License</rights></info><locale xml:lang="en"><terms><term name="editortranslator" form="short"><single>ed. &amp; trans.</single><multiple>eds. &amp; trans.</multiple></term><term name="translator" form="short">trans.</term><term name="interviewer" form="short"><single>interviewer</single><multiple>interviewers</multiple></term><term name="collection-editor" form="short"><single>ed.</single><multiple>eds.</multiple></term><term name="circa" form="short">ca.</term><term name="bc"> B.C.E.</term><term name="ad"> C.E.</term><term name="letter">personal communication</term><term name="letter" form="short">letter</term><term name="issue" form="long"><single>issue</single><multiple>issues</multiple></term></terms></locale><locale xml:lang="af"><terms><term name="letter">persoonlike kommunikasie</term><term name="letter" form="short">brief</term></terms></locale><locale xml:lang="ar"><terms><term name="letter">اتصال شخصي</term><term name="letter" form="short">خطاب</term></terms></locale><locale xml:lang="bg"><terms><term name="letter">лична комуникация</term><term name="letter" form="short">писмо</term></terms></locale><locale xml:lang="ca"><terms><term name="letter">comunicació personal</term><term name="letter" form="short">carta</term></terms></locale><locale xml:lang="cs"><terms><term name="letter">osobní komunikace</term><term name="letter" form="short">dopis</term></terms></locale><locale xml:lang="cy"><terms><term name="letter">cyfathrebu personol</term><term name="letter" form="short">llythyr</term></terms></locale><locale xml:lang="da"><terms><term name="et-al">et al.</term><term name="letter">personlig kommunikation</term><term name="letter" form="short">brev</term></terms></locale><locale xml:lang="de"><terms><term name="et-al">et al.</term><term name="letter">persönliche Kommunikation</term><term name="letter" form="short">Brief</term></terms></locale><locale xml:lang="el"><terms><term name="letter">προσωπική επικοινωνία</term><term name="letter" form="short">επιστολή</term></terms></locale><locale xml:lang="es"><terms><term name="from">de</term><term name="letter">comunicación personal</term><term name="letter" form="short">carta</term></terms></locale><locale xml:lang="et"><terms><term name="letter">isiklik suhtlus</term><term name="letter" form="short">kiri</term></terms></locale><locale xml:lang="eu"><terms><term name="letter">komunikazio pertsonala</term><term name="letter" form="short">gutuna</term></terms></locale><locale xml:lang="fa"><terms><term name="letter">ارتباط شخصی</term><term name="letter" form="short">نامه</term></terms></locale><locale xml:lang="fi"><terms><term name="letter">henkilökohtainen viestintä</term><term name="letter" form="short">kirje</term></terms></locale><locale xml:lang="fr"><terms><term name="letter">communication personnelle</term><term name="letter" form="short">lettre</term><term name="editor" form="short"><single>éd.</single><multiple>éds.</multiple></term></terms></locale><locale xml:lang="he"><terms><term name="letter">תקשורת אישית</term><term name="letter" form="short">מכתב</term></terms></locale><locale xml:lang="hr"><terms><term name="letter">osobna komunikacija</term><term name="letter" form="short">pismo</term></terms></locale><locale xml:lang="hu"><terms><term name="letter">személyes kommunikáció</term><term name="letter" form="short">levél</term></terms></locale><locale xml:lang="id"><terms><term name="letter">komunikasi pribadi</term><term name="letter" form="short">surat</term></terms></locale><locale xml:lang="is"><terms><term name="letter">persónuleg samskipti</term><term name="letter" form="short">bréf</term></terms></locale><locale xml:lang="it"><terms><term name="letter">comunicazione personale</term><term name="letter" form="short">lettera</term></terms></locale><locale xml:lang="ja"><terms><term name="letter">個人的なやり取り</term><term name="letter" form="short">手紙</term></terms></locale><locale xml:lang="ko"><terms><term name="letter">개인 서신</term><term name="letter" form="short">편지</term></terms></locale><locale xml:lang="la"><terms><term name="letter"/><term name="letter" form="short">epistula</term></terms></locale><locale xml:lang="lt"><terms><term name="letter">communicationis personalis</term><term name="letter" form="short"/></terms></locale><locale xml:lang="lv"><terms><term name="letter">personīga komunikācija</term><term name="letter" form="short">vēstule</term></terms></locale><locale xml:lang="mn"><terms><term name="letter">хувийн харилцаа холбоо</term><term name="letter" form="short">захиа</term></terms></locale><locale xml:lang="nb"><terms><term name="et-al">et al.</term><term name="letter">personlig kommunikasjon</term><term name="letter" form="short">brev</term></terms></locale><locale xml:lang="nl"><terms><term name="et-al">et al.</term><term name="letter">persoonlijke communicatie</term><term name="letter" form="short">brief</term></terms></locale><locale xml:lang="nn"><terms><term name="et-al">et al.</term><term name="letter">personlig kommunikasjon</term><term name="letter" form="short">brev</term></terms></locale><locale xml:lang="pl"><terms><term name="letter">osobista komunikacja</term><term name="letter" form="short">list</term></terms></locale><locale xml:lang="pt"><terms><term name="letter">comunicação pessoal</term><term name="letter" form="short">carta</term></terms></locale><locale xml:lang="ro"><terms><term name="letter">comunicare personală</term><term name="letter" form="short">scrisoare</term></terms></locale><locale xml:lang="ru"><terms><term name="letter">личная переписка</term><term name="letter" form="short">письмо</term></terms></locale><locale xml:lang="sk"><terms><term name="letter">osobná komunikácia</term><term name="letter" form="short">list</term></terms></locale><locale xml:lang="sl"><terms><term name="letter">osebna komunikacija</term><term name="letter" form="short">pismo</term></terms></locale><locale xml:lang="sr"><terms><term name="letter">лична комуникација</term><term name="letter" form="short">писмо</term></terms></locale><locale xml:lang="sv"><terms><term name="letter">personlig kommunikation</term><term name="letter" form="short">brev</term></terms></locale><locale xml:lang="th"><terms><term name="letter">การสื่อสารส่วนบุคคล</term><term name="letter" form="short">จดหมาย</term></terms></locale><locale xml:lang="tr"><terms><term name="letter">kişisel iletişim</term><term name="letter" form="short">mektup</term></terms></locale><locale xml:lang="uk"><terms><term name="letter">особисте спілкування</term><term name="letter" form="short">лист</term></terms></locale><locale xml:lang="vi"><terms><term name="letter">giao tiếp cá nhân</term><term name="letter" form="short">thư</term></terms></locale><locale xml:lang="zh-CN"><terms><term name="letter">的私人交流</term><term name="letter" form="short">信函</term></terms></locale><locale xml:lang="zh-TW"><terms><term name="letter">私人通訊</term><term name="letter" form="short">信函</term></terms></locale><!-- General categories of item types:Periodical: article-journal article-magazine article-newspaper post-weblog review review-bookPeriodical or Booklike: paper-conferenceBooklike: article book broadcast chapter dataset entry entry-dictionary entry-encyclopedia figure graphic interview manuscript map motion_picture musical_score pamphlet patent personal_communication report song speech thesis post webpageLegal: bill legal_case legislation treaty--><!-- APA references contain four parts: author, date, title, source --><macro name="author-bib"><names variable="composer" delimiter=", "><name name-as-sort-order="all" and="symbol" sort-separator=", " initialize-with=". " delimiter=", " delimiter-precedes-last="always"/><substitute><names variable="author"/><names variable="illustrator"/><names variable="director"><name name-as-sort-order="all" and="symbol" sort-separator=", " initialize-with=". " delimiter=", " delimiter-precedes-last="always"/><label form="long" prefix=" (" suffix=")" text-case="title"/></names><choose><if variable="container-title"><choose><if type="book entry entry-dictionary entry-encyclopedia" match="any"><choose><if variable="title"><group delimiter=" "><text macro="title"/><text macro="parenthetical"/></group></if><else><text macro="title-and-descriptions"/></else></choose></if></choose></if></choose><!-- Test for editortranslator and put that first as that becomes available --><names variable="editor" delimiter=", "><name name-as-sort-order="all" and="symbol" sort-separator=", " initialize-with=". " delimiter=", " delimiter-precedes-last="always"/><label form="short" prefix=" (" suffix=")" text-case="title"/></names><names variable="editorial-director"><name name-as-sort-order="all" and="symbol" sort-separator=", " initialize-with=". " delimiter=", " delimiter-precedes-last="always"/><label form="short" prefix=" (" suffix=")" text-case="title"/></names><names variable="collection-editor"><name name-as-sort-order="all" and="symbol" sort-separator=", " initialize-with=". " delimiter=", " delimiter-precedes-last="always"/><label form="short" prefix=" (" suffix=")" text-case="title"/></names><choose><if variable="title"><group delimiter=" "><text macro="title"/><text macro="parenthetical"/></group></if><else><text macro="title-and-descriptions"/></else></choose></substitute></names></macro><macro name="author-intext"><choose><if type="bill legal_case legislation treaty" match="any"><text macro="title-intext"/></if><else-if type="interview personal_communication" match="any"><choose><!-- These variables indicate that the letter is retrievable by the reader. If not, then use the APA in-text-only personal communication format --><if variable="archive container-title DOI publisher URL" match="none"><group delimiter=", "><names variable="author"><name and="symbol" delimiter=", " initialize-with=". "/><substitute><text macro="title-intext"/></substitute></names><!-- Replace with term="personal-communication" if that becomes available --><text term="letter"/></group></if><else><names variable="author" delimiter=", "><name form="short" and="symbol" delimiter=", " initialize-with=". "/><substitute><text macro="title-intext"/></substitute></names></else></choose></else-if><else><names variable="composer" delimiter=", "><name form="short" and="symbol" delimiter=", " initialize-with=". "/><substitute><names variable="author"/><names variable="illustrator"/><names variable="director"/><choose><if variable="container-title"><choose><if type="book entry entry-dictionary entry-encyclopedia" match="any"><text macro="title-intext"/></if></choose></if></choose><names variable="editor"/><names variable="editorial-director"/><text macro="title-intext"/></substitute></names></else></choose></macro><macro name="date-bib"><group delimiter=" " prefix="(" suffix=")"><choose><if is-uncertain-date="issued"><text term="circa" form="short"/></if></choose><group><choose><if variable="issued"><date variable="issued"><date-part name="year"/></date><text variable="year-suffix"/><choose><if type="article-magazine article-newspaper broadcast interview motion_picture pamphlet personal_communication post post-weblog song speech webpage" match="any"><!-- Many video and audio examples in manual give full dates. Err on the side of too much information. --><date variable="issued"><date-part prefix=", " name="month"/><date-part prefix=" " name="day"/></date></if><else-if type="paper-conference"><!-- Capture 'speech' stored as 'paper-conference' --><choose><if variable="collection-editor editor editorial-director issue page volume" match="none"><date variable="issued"><date-part prefix=", " name="month"/><date-part prefix=" " name="day"/></date></if></choose></else-if><!-- Only year: article article-journal book chapter entry entry-dictionary entry-encyclopedia dataset figure graphic manuscript map musical_score paper-conference[published] patent report review review-book thesis --></choose></if><else-if variable="status"><group><text variable="status" text-case="lowercase"/><text variable="year-suffix" prefix="-"/></group></else-if><else><text term="no date" form="short"/><text variable="year-suffix" prefix="-"/></else></choose></group></group></macro><macro name="date-sort-group"><!-- APA sorts 1. no-date items, 2. items with dates, 3. in-press (status) items --><choose><if variable="issued"><text value="1"/></if><else-if variable="status"><text value="2"/></else-if><else><text value="0"/></else></choose></macro><macro name="date-sort-date"><date variable="issued" form="numeric"/></macro><macro name="date-intext"><choose><if variable="issued"><group delimiter="/"><group delimiter=" "><choose><if is-uncertain-date="original-date"><text term="circa" form="short"/></if></choose><date variable="original-date"><date-part name="year"/></date></group><group delimiter=" "><choose><if is-uncertain-date="issued"><text term="circa" form="short"/></if></choose><group><choose><if type="interview personal_communication" match="any"><choose><if variable="archive container-title DOI publisher URL" match="none"><!-- These variables indicate that the communication is retrievable by the reader. If not, then use the in-text-only personal communication format --><date variable="issued" form="text"/></if><else><date variable="issued"><date-part name="year"/></date></else></choose></if><else><date variable="issued"><date-part name="year"/></date></else></choose><text variable="year-suffix"/></group></group></group></if><else-if variable="status"><text variable="status" text-case="lowercase"/><text variable="year-suffix" prefix="-"/></else-if><else><text term="no date" form="short"/><text variable="year-suffix" prefix="-"/></else></choose></macro><!-- APA has two description elements following the title:title (parenthetical) [bracketed]  --><macro name="title-and-descriptions"><choose><if variable="title"><group delimiter=" "><text macro="title"/><text macro="parenthetical"/><text macro="bracketed"/></group></if><else><group delimiter=" "><text macro="bracketed"/><text macro="parenthetical"/></group></else></choose></macro><macro name="title"><choose><if type="post webpage" match="any"><!-- Webpages are always italicized --><text variable="title" font-style="italic"/></if><else-if variable="container-title" match="any"><!-- Other types are italicized based on presence of container-title.Assume that review and review-book are published in periodicals/blogs,not just on a web page (ex. 69) --><text variable="title"/></else-if><else><choose><if type="article-journal article-magazine article-newspaper post-weblog review review-book" match="any"><text variable="title" font-style="italic"/></if><else-if type="paper-conference"><choose><if variable="collection-editor editor editorial-director" match="any"><group delimiter=": " font-style="italic"><text variable="title"/><!-- Replace with volume-title as that becomes available --><choose><if is-numeric="volume" match="none"><group delimiter=" "><label variable="volume" form="short" text-case="capitalize-first"/><text variable="volume"/></group></if></choose></group></if><else><text variable="title" font-style="italic"/></else></choose></else-if><else><group delimiter=": " font-style="italic"><text variable="title"/><!-- Replace with volume-title as that becomes available --><choose><if is-numeric="volume" match="none"><group delimiter=" "><label variable="volume" form="short" text-case="capitalize-first"/><text variable="volume"/></group></if></choose></group></else></choose></else></choose></macro><macro name="title-intext"><choose><if variable="title" match="none"><text macro="bracketed-intext" prefix="[" suffix="]"/></if><else-if type="bill"><!-- If a bill has no number or container-title, assume it is a hearing; italic --><choose><if variable="number container-title" match="none"><text variable="title" form="short" font-style="italic" text-case="title"/></if><else-if variable="title"><text variable="title" form="short" text-case="title"/></else-if><else><group delimiter=" "><text variable="genre"/><group delimiter=" "><choose><if variable="chapter-number container-title" match="none"><!-- Replace with label variable="number" as that becomes available --><text term="issue" form="short"/></if></choose><text variable="number"/></group></group></else></choose></else-if><else-if type="legal_case" match="any"><!-- Cases are italicized --><text variable="title" font-style="italic"/></else-if><else-if type="legislation treaty" match="any"><!-- Legislation and treaties not italicized or quoted --><text variable="title" form="short" text-case="title"/></else-if><else-if type="post webpage" match="any"><!-- Webpages are always italicized --><text variable="title" form="short" font-style="italic" text-case="title"/></else-if><else-if variable="container-title" match="any"><!-- Other types are italicized or quoted based on presence of container-title. As in title macro. --><text variable="title" form="short" quotes="true" text-case="title"/></else-if><else><text variable="title" form="short" font-style="italic" text-case="title"/></else></choose></macro><macro name="parenthetical"><!-- (Secondary contributors; Database location; Genre no. 123; Report Series 123, Version, Edition, Volume, Page) --><group prefix="(" suffix=")"><choose><if type="patent"><!-- authority: U.S. ; genre: patent ; number: 123,445 --><group delimiter=" "><text variable="authority" form="short"/><choose><if variable="genre"><text variable="genre" text-case="capitalize-first"/></if><else><!-- This should be localized --><text value="patent" text-case="capitalize-first"/></else></choose><group delimiter=" "><!-- Replace with label variable="number" if that becomes available --><text term="issue" form="short" text-case="capitalize-first"/><text variable="number"/></group></group></if><else-if type="post webpage" match="any"><!-- For post webpage, container-title is treated as publisher --><group delimiter="; "><text macro="secondary-contributors"/><text macro="database-location"/><text macro="number"/><text macro="locators-booklike"/></group></else-if><else-if variable="container-title"><group delimiter="; "><text macro="secondary-contributors"/><choose><if type="broadcast graphic map motion_picture song" match="any"><!-- For audiovisual media, number information comes after title, not container-title --><text macro="number"/></if></choose></group></else-if><else><group delimiter="; "><text macro="secondary-contributors"/><text macro="database-location"/><text macro="number"/><text macro="locators-booklike"/></group></else></choose></group></macro><macro name="parenthetical-container"><choose><if variable="container-title" match="any"><group prefix="(" suffix=")"><group delimiter="; "><text macro="database-location"/><choose><if type="broadcast graphic map motion_picture song" match="none"><!-- For audiovisual media, number information comes after title, not container-title --><text macro="number"/></if></choose><text macro="locators-booklike"/></group></group></if></choose></macro><macro name="bracketed"><!-- [Descriptive information] --><!-- If there is a number, genre is already printed in macro="number" --><group prefix="[" suffix="]"><choose><if variable="reviewed-author reviewed-title" type="review review-book" match="any"><!-- Reviewed item --><group delimiter="; "><group delimiter=", "><group delimiter=" "><!-- Assume that genre is entered as 'Review of the book' or similar --><choose><if variable="number" match="none"><choose><if variable="genre"><text variable="genre" text-case="capitalize-first"/></if><else-if variable="medium"><text variable="medium" text-case="capitalize-first"/></else-if><else><!-- Replace with term="review" as that becomes available --><text value="Review of"/></else></choose></if><else><choose><if variable="medium"><text variable="medium" text-case="capitalize-first"/></if><else><!-- Replace with term="review" as that becomes available --><text value="Review of"/></else></choose></else></choose><text macro="reviewed-title"/></group><names variable="reviewed-author"><label form="verb-short" suffix=" "/><name and="symbol" initialize-with=". " delimiter=", "/></names></group><choose><if variable="genre" match="any"><choose><if variable="number" match="none"><text variable="medium" text-case="capitalize-first"/></if></choose></if></choose></group></if><else-if type="thesis"><!-- Thesis type and institution --><group delimiter="; "><choose><if variable="number" match="none"><group delimiter=", "><text variable="genre" text-case="capitalize-first"/><choose><if variable="archive DOI URL" match="any"><!-- Include the university in brackets if thesis is published --><text variable="publisher"/></if></choose></group></if></choose><text variable="medium" text-case="capitalize-first"/></group></else-if><else-if variable="interviewer" type="interview" match="any"><!-- Interview information --><choose><if variable="title"><text macro="format"/></if><else-if variable="genre"><group delimiter="; "><group delimiter=" "><text variable="genre" text-case="capitalize-first"/><group delimiter=" "><text term="author" form="verb"/><names variable="interviewer"><name and="symbol" initialize-with=". " delimiter=", "/></names></group></group></group></else-if><else-if variable="interviewer"><group delimiter="; "><names variable="interviewer"><label form="verb" suffix=" " text-case="capitalize-first"/><name and="symbol" initialize-with=". " delimiter=", "/></names><text variable="medium" text-case="capitalize-first"/></group></else-if><else><text macro="format"/></else></choose></else-if><else-if type="personal_communication"><!-- Letter information --><choose><if variable="recipient"><group delimiter="; "><group delimiter=" "><choose><if variable="number" match="none"><choose><if variable="genre"><text variable="genre" text-case="capitalize-first"/></if><else-if variable="medium"><text variable="medium" text-case="capitalize-first"/></else-if><else><text term="letter" form="short" text-case="capitalize-first"/></else></choose></if><else><choose><if variable="medium"><text variable="medium" text-case="capitalize-first"/></if><else><text term="letter" form="short" text-case="capitalize-first"/></else></choose></else></choose><names variable="recipient" delimiter=", "><label form="verb" suffix=" "/><name and="symbol" delimiter=", "/></names></group><choose><if variable="genre" match="any"><choose><if variable="number" match="none"><text variable="medium" text-case="capitalize-first"/></if></choose></if></choose></group></if><else><text macro="format"/></else></choose></else-if><else-if variable="composer" type="song" match="all"><!-- Performer of classical music works --><group delimiter="; "><choose><if variable="number" match="none"><group delimiter=" "><choose><if variable="genre"><text variable="genre" text-case="capitalize-first"/><!-- Replace prefix with performer label as that becomes available --><names variable="author" prefix="recorded by "><name and="symbol" initialize-with=". " delimiter=", "/></names></if><else-if variable="medium"><text variable="medium" text-case="capitalize-first"/><!-- Replace prefix with performer label as that becomes available --><names variable="author" prefix="recorded by "><name and="symbol" initialize-with=". " delimiter=", "/></names></else-if><else><!-- Replace prefix with performer label as that becomes available --><names variable="author" prefix="Recorded by "><name and="symbol" initialize-with=". " delimiter=", "/></names></else></choose></group></if><else><group delimiter=" "><choose><if variable="medium"><text variable="medium" text-case="capitalize-first"/><!-- Replace prefix with performer label as that becomes available --><names variable="author" prefix="recorded by "><name and="symbol" initialize-with=". " delimiter=", "/></names></if><else><!-- Replace prefix with performer label as that becomes available --><names variable="author" prefix="Recorded by "><name and="symbol" initialize-with=". " delimiter=", "/></names></else></choose></group></else></choose><choose><if variable="genre" match="any"><choose><if variable="number" match="none"><text variable="medium" text-case="capitalize-first"/></if></choose></if></choose></group></else-if><else-if variable="container-title" match="none"><!-- Other description --><text macro="format"/></else-if><else><!-- For conference presentations, chapters in reports, software, place bracketed after the container title --><choose><if type="paper-conference speech" match="any"><choose><if variable="collection-editor editor editorial-director issue page volume" match="any"><text macro="format"/></if></choose></if><else-if type="book"><choose><if variable="version" match="none"><text macro="format"/></if></choose></else-if><else-if type="report" match="none"><text macro="format"/></else-if></choose></else></choose></group></macro><macro name="bracketed-intext"><group prefix="[" suffix="]"><choose><if variable="reviewed-author reviewed-title" type="review review-book" match="any"><!-- This should be localized --><text macro="reviewed-title-intext" prefix="Review of "/></if><else-if variable="interviewer" type="interview" match="any"><names variable="interviewer"><label form="verb" suffix=" " text-case="capitalize-first"/><name and="symbol" initialize-with=". " delimiter=", "/><substitute><text macro="format-intext"/></substitute></names></else-if><else-if type="personal_communication"><!-- Letter information --><choose><if variable="recipient"><group delimiter=" "><choose><if variable="number" match="none"><text variable="genre" text-case="capitalize-first"/></if><else><text term="letter" form="short" text-case="capitalize-first"/></else></choose><names variable="recipient" delimiter=", "><label form="verb" suffix=" "/><name and="symbol" delimiter=", "/></names></group></if><else><text macro="format-intext"/></else></choose></else-if><else><text macro="format-intext"/></else></choose></group></macro><macro name="bracketed-container"><group prefix="[" suffix="]"><choose><if type="paper-conference speech" match="any"><!-- Conference presentations should describe the session [container] in bracketed unless published in a proceedings --><choose><if variable="collection-editor editor editorial-director issue page volume" match="none"><text macro="format"/></if></choose></if><else-if type="book" variable="version" match="all"><!-- For entries in mobile app reference works, place bracketed after the container-title --><text macro="format"/></else-if><else-if type="report"><!-- For chapters in reports, place bracketed after the container title --><text macro="format"/></else-if></choose></group></macro><macro name="secondary-contributors"><choose><if type="article-journal article-magazine article-newspaper post-weblog review review-book" match="any"><text macro="secondary-contributors-periodical"/></if><else-if type="paper-conference"><choose><if variable="collection-editor editor editorial-director" match="any"><text macro="secondary-contributors-booklike"/></if><else><text macro="secondary-contributors-periodical"/></else></choose></else-if><else><text macro="secondary-contributors-booklike"/></else></choose></macro><macro name="secondary-contributors-periodical"><group delimiter="; "><choose><if variable="title"><names variable="interviewer" delimiter="; "><name and="symbol" initialize-with=". " delimiter=", "/><label form="short" prefix=", " text-case="title"/></names></if></choose><names variable="translator" delimiter="; "><name and="symbol" initialize-with=". " delimiter=", "/><label form="short" prefix=", " text-case="title"/></names></group></macro><macro name="secondary-contributors-booklike"><group delimiter="; "><choose><if variable="title"><names variable="interviewer"><name and="symbol" initialize-with=". " delimiter=", "/><label form="short" prefix=", " text-case="title"/></names></if></choose><!-- When editortranslator becomes available, add a test: variable="editortranslator" match="none"; then print translator --><choose><if type="post webpage" match="none"><!-- Webpages treat container-title like publisher --><choose><if variable="container-title" match="none"><group delimiter="; "><names variable="container-author"><label form="verb-short" suffix=" " text-case="title"/><name and="symbol" initialize-with=". " delimiter=", "/></names><names variable="editor translator" delimiter="; "><name and="symbol" initialize-with=". " delimiter=", "/><label form="short" prefix=", " text-case="title"/></names></group></if></choose></if><else><group delimiter="; "><names variable="container-author"><label form="verb-short" suffix=" " text-case="title"/><name and="symbol" initialize-with=". " delimiter=", "/></names><names variable="editor translator" delimiter="; "><name and="symbol" initialize-with=". " delimiter=", "/><label form="short" prefix=", " text-case="title"/></names></group></else></choose></group></macro><macro name="database-location"><choose><if variable="archive-place" match="none"><!-- With \`archive-place\`: physical archives. Without: online archives. --><!-- Add archive_collection as that becomes available --><text variable="archive_location"/></if></choose></macro><macro name="number"><choose><if variable="number"><group delimiter=", "><group delimiter=" "><text variable="genre" text-case="title"/><choose><if is-numeric="number"><!-- Replace with label variable="number" if that becomes available --><text term="issue" form="short" text-case="capitalize-first"/><text variable="number"/></if><else><text variable="number"/></else></choose></group><choose><if type="thesis"><choose><!-- Include the university in brackets if thesis is published --><if variable="archive DOI URL" match="any"><text variable="publisher"/></if></choose></if></choose></group></if></choose></macro><macro name="locators-booklike"><choose><if type="article-journal article-magazine article-newspaper broadcast interview patent post post-weblog review review-book speech webpage" match="any"/><else-if type="paper-conference"><choose><if variable="collection-editor editor editorial-director" match="any"><group delimiter=", "><text macro="version"/><text macro="edition"/><text macro="volume-booklike"/></group></if></choose></else-if><else><group delimiter=", "><text macro="version"/><text macro="edition"/><text macro="volume-booklike"/></group></else></choose></macro><macro name="version"><choose><if is-numeric="version"><group delimiter=" "><!-- replace with label variable="version" if that becomes available --><text term="version" text-case="capitalize-first"/><text variable="version"/></group></if><else><text variable="version"/></else></choose></macro><macro name="edition"><choose><if is-numeric="edition"><group delimiter=" "><number variable="edition" form="ordinal"/><label variable="edition" form="short"/></group></if><else><text variable="edition"/></else></choose></macro><macro name="volume-booklike"><group delimiter=", "><!-- Report series [ex. 52] --><choose><if type="report"><group delimiter=" "><text variable="collection-title" text-case="title"/><text variable="collection-number"/></group></if></choose><choose><if variable="volume" match="any"><choose><!-- Non-numeric volumes are already printed as part of the book title --><if is-numeric="volume" match="none"/><else><group delimiter=" "><label variable="volume" form="short" text-case="capitalize-first"/><number variable="volume" form="numeric"/></group></else></choose></if><else><group><!-- Replace with label variable="number-of-volumes" if that becomes available --><text term="volume" form="short" text-case="capitalize-first" suffix=" "/><text term="page-range-delimiter" prefix="1"/><number variable="number-of-volumes" form="numeric"/></group></else></choose><group delimiter=" "><label variable="issue" text-case="capitalize-first"/><text variable="issue"/></group><group delimiter=" "><label variable="page" form="short" suffix=" "/><text variable="page"/></group></group></macro><macro name="reviewed-title"><choose><if variable="reviewed-title"><!-- Not possible to distinguish TV series episode from other reviewed works [Ex. 69] --><text variable="reviewed-title" font-style="italic"/></if><else><!-- Assume title is title of reviewed work --><text variable="title" font-style="italic"/></else></choose></macro><macro name="reviewed-title-intext"><choose><if variable="reviewed-title"><!-- Not possible to distinguish TV series episode from other reviewed works [Ex. 69] --><text variable="reviewed-title" form="short" font-style="italic" text-case="title"/></if><else><!-- Assume title is title of reviewed work --><text variable="title" form="short" font-style="italic" text-case="title"/></else></choose></macro><macro name="format"><choose><if variable="genre medium" match="any"><group delimiter="; "><choose><if variable="number" match="none"><text variable="genre" text-case="capitalize-first"/></if></choose><text variable="medium" text-case="capitalize-first"/></group></if><!-- Generic labels for specific types --><!-- These should be localized when possible --><else-if type="dataset"><text value="Data set"/></else-if><else-if type="book" variable="version" match="all"><!-- Replace with type="software" and term="software" as that becomes available --><text value="Computer software"/></else-if><else-if type="interview personal_communication" match="any"><choose><if variable="archive container-title DOI publisher URL" match="none"><text term="letter" text-case="capitalize-first"/></if><else-if type="interview"><text term="interview" text-case="capitalize-first"/></else-if></choose></else-if><else-if type="map"><text value="Map"/></else-if></choose></macro><macro name="format-intext"><choose><if variable="genre" match="any"><text variable="genre" text-case="capitalize-first"/></if><else-if variable="medium"><text variable="medium" text-case="capitalize-first"/></else-if><!-- Generic labels for specific types --><!-- These should be localized when possible --><else-if type="dataset"><text value="Data set"/></else-if><else-if type="book" variable="version" match="all"><!-- Replace with type="software" and term="software" as that becomes available --><text value="Computer software"/></else-if><else-if type="interview personal_communication" match="any"><choose><if variable="archive container-title DOI publisher URL" match="none"><text term="letter" text-case="capitalize-first"/></if><else-if type="interview"><text term="interview" text-case="capitalize-first"/></else-if></choose></else-if><else-if type="map"><text value="Map"/></else-if></choose></macro><!-- APA 'source' element contains four parts:container, event, publisher, access --><macro name="container"><choose><if type="article-journal article-magazine article-newspaper post-weblog review review-book" match="any"><!-- Periodical items --><text macro="container-periodical"/></if><else-if type="paper-conference"><!-- Determine if paper-conference is a periodical or booklike --><choose><if variable="editor editorial-director collection-editor container-author" match="any"><text macro="container-booklike"/></if><else><text macro="container-periodical"/></else></choose></else-if><else-if type="post webpage" match="none"><!-- post and webpage treat container-title like publisher --><text macro="container-booklike"/></else-if></choose></macro><macro name="container-periodical"><group delimiter=". "><group delimiter=", "><text variable="container-title" font-style="italic" text-case="title"/><choose><if variable="volume"><group><text variable="volume" font-style="italic"/><text variable="issue" prefix="(" suffix=")"/></group></if><else><text variable="issue" font-style="italic"/></else></choose><choose><if variable="page"><text variable="page"/></if><else><!-- Ex. 6: Journal article with article number or eLocator --><!-- This should be localized --><text variable="number" prefix="Article "/></else></choose></group><choose><if variable="issued"><choose><if variable="issue page volume" match="none"><text variable="status" text-case="capitalize-first"/></if></choose></if></choose></group></macro><macro name="container-booklike"><choose><if variable="container-title" match="any"><group delimiter=" "><text term="in" text-case="capitalize-first"/><group delimiter=", "><names variable="editor translator" delimiter=", &amp; "><!-- Change to editortranslator and move editor to substitute as that becomes available --><name and="symbol" initialize-with=". " delimiter=", "/><label form="short" text-case="title" prefix=" (" suffix=")"/><substitute><names variable="editorial-director"/><names variable="collection-editor"/><names variable="container-author"/></substitute></names><group delimiter=": " font-style="italic"><text variable="container-title"/><!-- Replace with volume-title as that becomes available --><choose><if is-numeric="volume" match="none"><group delimiter=" "><label variable="volume" form="short" text-case="capitalize-first"/><text variable="volume"/></group></if></choose></group></group><text macro="parenthetical-container"/><text macro="bracketed-container"/></group></if></choose></macro><macro name="publisher"><group delimiter="; "><choose><if type="thesis"><choose><if variable="archive DOI URL" match="none"><text variable="publisher"/></if></choose></if><else-if type="post webpage" match="any"><!-- For websites, treat container title like publisher --><group delimiter="; "><text variable="container-title" text-case="title"/><text variable="publisher"/></group></else-if><else-if type="paper-conference"><!-- For paper-conference, don't print publisher if in a journal-like proceedings --><choose><if variable="collection-editor editor editorial-director" match="any"><text variable="publisher"/></if></choose></else-if><else-if type="article-journal article-magazine article-newspaper post-weblog" match="none"><text variable="publisher"/></else-if></choose><group delimiter=", "><choose><if variable="archive-place"><!-- With \`archive-place\`: physical archives. Without: online archives. --><!-- For physical archives, print the location before the archive name.For electronic archives, these are printed in macro="description". --><!-- Split "archive_location" into "archive_collection" and "archive_location" as that becomes available --><!-- Must test for archive_collection:With collection: archive_collection (archive_location), archive, archive-placeNo collection: archive (archive_location), archive-place--><text variable="archive_location"/></if></choose><text variable="archive"/><text variable="archive-place"/></group></group></macro><macro name="access"><choose><if variable="DOI" match="any"><text variable="DOI" prefix="https://doi.org/"/></if><else-if variable="URL"><group delimiter=" "><choose><if variable="issued status" match="none"><group delimiter=" "><text term="retrieved" text-case="capitalize-first"/><date variable="accessed" form="text" suffix=","/><text term="from"/></group></if></choose><text variable="URL"/></group></else-if></choose></macro><macro name="event"><choose><if variable="event"><!-- To prevent Zotero from printing event-place due to its double-mapping of all 'place' toboth publisher-place and event-place. Remove this 'choose' when that is changed. --><choose><if variable="collection-editor editor editorial-director issue page volume" match="none"><!-- Don't print event info if published in a proceedings --><group delimiter=", "><text variable="event"/><text variable="event-place"/></group></if></choose></if></choose></macro><!-- After 'source', APA also prints publication history (original publication, reprint info, retraction info) --><macro name="publication-history"><choose><if type="patent" match="none"><group prefix="(" suffix=")"><choose><if variable="references"><!-- This provides the option for more elaborate description of publication history, such as full "reprinted" references(examples 11, 43, 44) or retracted references --><text variable="references"/></if><else><group delimiter=" "><text value="Original work published"/><choose><if is-uncertain-date="original-date"><text term="circa" form="short"/></if></choose><date variable="original-date"><date-part name="year"/></date></group></else></choose></group></if><else><text variable="references" prefix="(" suffix=")"/></else></choose></macro><!-- Legal citations have their own rules --><macro name="legal-cites"><choose><if type="legal_case"><group delimiter=". "><group delimiter=", "><text variable="title"/><group delimiter=" "><text macro="container-legal"/><text macro="date-legal"/></group><text variable="references"/></group><text macro="access"/></group></if><else-if type="bill"><!-- Currently designed to handle bills, resolutions, hearings, rederal reports. --><group delimiter=". "><group delimiter=", "><choose><if variable="number container-title" match="none"><!-- If no number or container-title, then assume it is a hearing --><text variable="title" font-style="italic"/></if><else><text variable="title"/></else></choose><group delimiter=" "><text macro="container-legal"/><text macro="date-legal"/><choose><if variable="number container-title" match="none"><!-- If no number or container-title, then assume it is a hearing --><names variable="author" prefix="(testimony of " suffix=")"><name and="symbol" delimiter=", "/></names></if><else><text variable="status" prefix="(" suffix=")"/></else></choose></group><text variable="references"/></group><text macro="access"/></group></else-if><else-if type="legislation"><!-- Currently designed to handle statutes, codified regulations, executive orders.For uncodified regulations, assume future code section is in status. --><group delimiter=". "><group delimiter=", "><text variable="title"/><group delimiter=" "><text macro="container-legal"/><text macro="date-legal"/><text variable="status" prefix="(" suffix=")"/></group><text variable="references"/></group><text macro="access"/></group></else-if><else-if type="treaty"><!-- APA generally defers to Bluebook for legal citations, but diverges withoutexplanation for treaty items. The Bluebook format that was used in APA 6thed. is used here. --><group delimiter=", "><text variable="title" text-case="title"/><names variable="author"><name initialize-with="." form="short" delimiter="-"/></names><text macro="date-legal"/><text macro="container-legal"/><text macro="access"/></group></else-if></choose></macro><macro name="date-legal"><choose><if type="legal_case"><group prefix="(" suffix=")" delimiter=" "><text variable="authority"/><choose><if variable="container-title" match="any"><!-- Print only year for cases published in reporters--><date variable="issued" form="numeric" date-parts="year"/></if><else><date variable="issued" form="text"/></else></choose></group></if><else-if type="bill legislation" match="any"><group prefix="(" suffix=")" delimiter=" "><group delimiter=" "><date variable="original-date"><date-part name="year"/></date><text term="and" form="symbol"/></group><date variable="issued"><date-part name="year"/></date></group></else-if><else-if type="treaty"><date variable="issued" form="text"/></else-if></choose></macro><macro name="container-legal"><!-- Expect legal item container-titles to be stored in short form --><choose><if type="legal_case"><group delimiter=" "><choose><if variable="container-title"><group delimiter=" "><text variable="volume"/><text variable="container-title"/><group delimiter=" "><!-- Change to label variable="section" as that becomes available --><text term="section" form="symbol"/><text variable="section"/></group><choose><if variable="page page-first" match="any"><text variable="page-first"/></if><else><text value="___"/></else></choose></group></if><else><group delimiter=" "><choose><if is-numeric="number"><!-- Replace with label variable="number" if that becomes available --><text term="issue" form="short" text-case="capitalize-first"/></if></choose><text variable="number"/></group></else></choose></group></if><else-if type="bill"><group delimiter=", "><group delimiter=" "><text variable="genre"/><group delimiter=" "><choose><if variable="chapter-number container-title" match="none"><!-- Replace with label variable="number" as that becomes available --><text term="issue" form="short"/></if></choose><text variable="number"/></group></group><text variable="authority"/><text variable="chapter-number"/><group delimiter=" "><text variable="volume"/><text variable="container-title"/><text variable="page-first"/></group></group></else-if><else-if type="legislation"><choose><if variable="number"><!--There's a public law number--><group delimiter=", "><text variable="number" prefix="Pub. L. No. "/><group delimiter=" "><text variable="volume"/><text variable="container-title"/><text variable="page-first"/></group></group></if><else><group delimiter=" "><text variable="volume"/><text variable="container-title"/><choose><if variable="section"><group delimiter=" "><!-- Change to label variable="section" as that becomes available --><text term="section" form="symbol"/><text variable="section"/></group></if><else><text variable="page-first"/></else></choose></group></else></choose></else-if><else-if type="treaty"><group delimiter=" "><number variable="volume"/><text variable="container-title"/><choose><if variable="page page-first" match="any"><text variable="page-first"/></if><else><group delimiter=" "><!-- Replace with label variable="number" if that becomes available --><text term="issue" form="short" text-case="capitalize-first"/><text variable="number"/></group></else></choose></group></else-if></choose></macro><macro name="citation-locator"><group delimiter=" "><choose><if locator="chapter"><label variable="locator" text-case="capitalize-first"/></if><else><label variable="locator" form="short"/></else></choose><text variable="locator"/></group></macro><citation et-al-min="3" et-al-use-first="1" disambiguate-add-year-suffix="true" disambiguate-add-names="true" disambiguate-add-givenname="true" collapse="year" givenname-disambiguation-rule="primary-name-with-initials"><sort><key macro="author-bib" names-min="3" names-use-first="1"/><key macro="date-sort-group"/><key macro="date-sort-date" sort="ascending"/><key variable="status"/></sort><layout prefix="(" suffix=")" delimiter="; "><group delimiter=", "><text macro="author-intext"/><text macro="date-intext"/><text macro="citation-locator"/></group></layout></citation><bibliography hanging-indent="true" et-al-min="21" et-al-use-first="19" et-al-use-last="true" entry-spacing="0" line-spacing="2"><sort><key macro="author-bib"/><key macro="date-sort-group"/><key macro="date-sort-date" sort="ascending"/><key variable="status"/><key macro="title"/></sort><layout><choose><if type="bill legal_case legislation treaty" match="any"><!-- Legal items have different orders and delimiters --><choose><if variable="DOI URL" match="any"><text macro="legal-cites"/></if><else><text macro="legal-cites" suffix="."/></else></choose></if><else><group delimiter=" "><group delimiter=". " suffix="."><text macro="author-bib"/><text macro="date-bib"/><text macro="title-and-descriptions"/><text macro="container"/><text macro="event"/><text macro="publisher"/></group><text macro="access"/><text macro="publication-history"/></group></else></choose></layout></bibliography>
</style>
`,vancouver:`<?xml version="1.0" encoding="utf-8"?>
<style xmlns="http://purl.org/net/xbiblio/csl" class="in-text" version="1.0" demote-non-dropping-particle="sort-only" initialize-with-hyphen="false" page-range-format="minimal"><info><title>Vancouver</title><id>http://www.zotero.org/styles/vancouver</id><link href="http://www.zotero.org/styles/vancouver" rel="self"/><link href="http://www.nlm.nih.gov/bsd/uniform_requirements.html" rel="documentation"/><author><name>Michael Berkowitz</name><email>mberkowi@gmu.edu</email></author><contributor><name>Sean Takats</name><email>stakats@gmu.edu</email></contributor><contributor><name>Sebastian Karcher</name></contributor><category citation-format="numeric"/><category field="medicine"/><summary>Vancouver style as outlined by International Committee of Medical Journal Editors Uniform Requirements for Manuscripts Submitted to Biomedical Journals: Sample References</summary><updated>2022-04-14T13:48:43+00:00</updated><rights license="http://creativecommons.org/licenses/by-sa/3.0/">This work is licensed under a Creative Commons Attribution-ShareAlike 3.0 License</rights></info><locale xml:lang="en"><date form="text" delimiter=" "><date-part name="year"/><date-part name="month" form="short" strip-periods="true"/><date-part name="day"/></date><terms><term name="collection-editor" form="long"><single>editor</single><multiple>editors</multiple></term><term name="presented at">presented at</term><term name="available at">available from</term><term name="section" form="short">sect.</term></terms></locale><locale xml:lang="fr"><date form="text" delimiter=" "><date-part name="day"/><date-part name="month" form="short" strip-periods="true"/><date-part name="year"/></date></locale><macro name="author"><names variable="author"><name sort-separator=" " initialize-with="" name-as-sort-order="all" delimiter=", " delimiter-precedes-last="always"/><label form="long" prefix=", "/><substitute><names variable="editor"/></substitute></names></macro><macro name="editor"><names variable="editor" suffix="."><name sort-separator=" " initialize-with="" name-as-sort-order="all" delimiter=", " delimiter-precedes-last="always"/><label form="long" prefix=", "/></names></macro><macro name="chapter-marker"><choose><if type="chapter paper-conference entry-dictionary entry-encyclopedia" match="any"><text term="in" text-case="capitalize-first"/></if></choose></macro><macro name="publisher"><choose><!--discard publisher info for articles--><if type="article-journal article-magazine article-newspaper" match="none"><group delimiter=": " suffix=";"><choose><if type="thesis"><text variable="publisher-place" prefix="[" suffix="]"/></if><else-if type="speech"/><else><text variable="publisher-place"/></else></choose><text variable="publisher"/></group></if></choose></macro><macro name="access"><choose><if variable="URL"><group delimiter=": "><text term="available at" text-case="capitalize-first"/><text variable="URL"/></group></if></choose></macro><macro name="accessed-date"><choose><if variable="URL"><group prefix="[" suffix="]" delimiter=" "><text term="cited" text-case="lowercase"/><date variable="accessed" form="text"/></group></if></choose></macro><macro name="container-title"><choose><if type="article-journal article-magazine chapter paper-conference article-newspaper review review-book entry-dictionary entry-encyclopedia" match="any"><group suffix="." delimiter=" "><choose><if type="article-journal review review-book" match="any"><text variable="container-title" form="short" strip-periods="true"/></if><else><text variable="container-title" strip-periods="true"/></else></choose><choose><if variable="URL"><text term="internet" prefix="[" suffix="]" text-case="capitalize-first"/></if></choose></group><text macro="edition" prefix=" "/></if><!--add event-name and event-place once they become available--><else-if type="bill legislation" match="any"><group delimiter=", "><group delimiter=". "><text variable="container-title"/><group delimiter=" "><text term="section" form="short" text-case="capitalize-first"/><text variable="section"/></group></group><text variable="number"/></group></else-if><else-if type="speech"><group delimiter=": " suffix=";"><group delimiter=" "><text variable="genre" text-case="capitalize-first"/><text term="presented at"/></group><text variable="event"/></group></else-if><else><group delimiter=", " suffix="."><choose><if variable="collection-title" match="none"><group delimiter=" "><label variable="volume" form="short" text-case="capitalize-first"/><text variable="volume"/></group></if></choose><text variable="container-title"/></group></else></choose></macro><macro name="title"><text variable="title"/><choose><if type="article-journal article-magazine chapter paper-conference article-newspaper review review-book entry-dictionary entry-encyclopedia" match="none"><choose><if variable="URL"><text term="internet" prefix=" [" suffix="]" text-case="capitalize-first"/></if></choose><text macro="edition" prefix=". "/></if></choose><choose><if type="thesis"><text variable="genre" prefix=" [" suffix="]"/></if></choose></macro><macro name="edition"><choose><if is-numeric="edition"><group delimiter=" "><number variable="edition" form="ordinal"/><text term="edition" form="short"/></group></if><else><text variable="edition" suffix="."/></else></choose></macro><macro name="date"><choose><if type="article-journal article-magazine article-newspaper review review-book" match="any"><group suffix=";" delimiter=" "><date variable="issued" form="text"/><text macro="accessed-date"/></group></if><else-if type="bill legislation" match="any"><group delimiter=", "><date variable="issued" delimiter=" "><date-part name="month" form="short" strip-periods="true"/><date-part name="day"/></date><date variable="issued"><date-part name="year"/></date></group></else-if><else-if type="report"><date variable="issued" delimiter=" "><date-part name="year"/><date-part name="month" form="short" strip-periods="true"/></date><text macro="accessed-date" prefix=" "/></else-if><else-if type="patent"><group suffix="."><group delimiter=", "><text variable="number"/><date variable="issued"><date-part name="year"/></date></group><text macro="accessed-date" prefix=" "/></group></else-if><else-if type="speech"><group delimiter="; "><group delimiter=" "><date variable="issued" delimiter=" "><date-part name="year"/><date-part name="month" form="short" strip-periods="true"/><date-part name="day"/></date><text macro="accessed-date"/></group><text variable="event-place"/></group></else-if><else><group suffix="."><date variable="issued"><date-part name="year"/></date><text macro="accessed-date" prefix=" "/></group></else></choose></macro><macro name="pages"><choose><if type="article-journal article-magazine article-newspaper review review-book" match="any"><text variable="page" prefix=":"/></if><else-if type="book" match="any"><text variable="number-of-pages" prefix=" "/><choose><if is-numeric="number-of-pages"><label variable="number-of-pages" form="short" prefix=" " plural="never"/></if></choose></else-if><else><group prefix=" " delimiter=" "><label variable="page" form="short" plural="never"/><text variable="page"/></group></else></choose></macro><macro name="journal-location"><choose><if type="article-journal article-magazine review review-book" match="any"><text variable="volume"/><text variable="issue" prefix="(" suffix=")"/></if></choose></macro><macro name="collection-details"><choose><if type="article-journal article-magazine article-newspaper review review-book" match="none"><choose><if variable="collection-title"><group delimiter=" " prefix="(" suffix=")"><names variable="collection-editor" suffix="."><name sort-separator=" " initialize-with="" name-as-sort-order="all" delimiter=", " delimiter-precedes-last="always"/><label form="long" prefix=", "/></names><group delimiter="; "><text variable="collection-title"/><group delimiter=" "><label variable="volume" form="short"/><text variable="volume"/></group></group></group></if></choose></if></choose></macro><macro name="report-details"><choose><if type="report"><text variable="number" prefix="Report No.: "/></if></choose></macro><citation collapse="citation-number"><sort><key variable="citation-number"/></sort><layout prefix="(" suffix=")" delimiter=","><text variable="citation-number"/></layout></citation><bibliography et-al-min="7" et-al-use-first="6" second-field-align="flush"><layout><text variable="citation-number" suffix=". "/><group delimiter=". " suffix=". "><text macro="author"/><text macro="title"/></group><group delimiter=" " suffix=". "><group delimiter=": "><text macro="chapter-marker"/><group delimiter=" "><text macro="editor"/><text macro="container-title"/></group></group><text macro="publisher"/><group><text macro="date"/><text macro="journal-location"/><text macro="pages"/></group></group><text macro="collection-details" suffix=". "/><text macro="report-details" suffix=". "/><text macro="access"/></layout></bibliography>
</style>
`,harvard1:`<?xml version="1.0" encoding="utf-8"?>
<style xmlns="http://purl.org/net/xbiblio/csl" class="in-text" version="1.0" demote-non-dropping-particle="sort-only" default-locale="en-GB"><info><title>Cite Them Right 11th edition - Harvard</title><id>http://www.zotero.org/styles/harvard-cite-them-right</id><link href="http://www.zotero.org/styles/harvard-cite-them-right" rel="self"/><link href="http://www.zotero.org/styles/harvard-cite-them-right-10th-edition" rel="template"/><link href="http://www.citethemrightonline.com/" rel="documentation"/><author><name>Patrick O'Brien</name></author><category citation-format="author-date"/><category field="generic-base"/><summary>Harvard according to Cite Them Right, 11th edition.</summary><updated>2021-09-01T10:12:20+00:00</updated><rights license="http://creativecommons.org/licenses/by-sa/3.0/">This work is licensed under a Creative Commons Attribution-ShareAlike 3.0 License</rights></info><locale xml:lang="en-GB"><terms><term name="editor" form="short"><single>ed.</single><multiple>eds</multiple></term><term name="editortranslator" form="verb">edited and translated by</term><term name="edition" form="short">edn.</term></terms></locale><macro name="editor"><choose><if type="chapter paper-conference" match="any"><names variable="container-author" delimiter=", " suffix=", "><name and="text" initialize-with=". " delimiter=", " sort-separator=", " name-as-sort-order="all"/></names><choose><if variable="container-author" match="none"><names variable="editor translator" delimiter=", "><name and="text" initialize-with="." name-as-sort-order="all"/><label form="short" prefix=" (" suffix=")"/></names></if></choose></if></choose></macro><macro name="secondary-contributors"><choose><if type="chapter paper-conference" match="none"><names variable="editor translator" delimiter=". "><label form="verb" text-case="capitalize-first" suffix=" "/><name and="text" initialize-with="."/></names></if><else-if variable="container-author" match="any"><names variable="editor translator" delimiter=". "><label form="verb" text-case="capitalize-first" suffix=" "/><name and="text" initialize-with=". " delimiter=", "/></names></else-if></choose></macro><macro name="author"><names variable="author"><name and="text" delimiter-precedes-last="never" initialize-with="." name-as-sort-order="all"/><label form="short" prefix=" (" suffix=")"/><et-al font-style="italic"/><substitute><names variable="editor"/><names variable="translator"/><choose><if type="article-newspaper article-magazine" match="any"><text variable="container-title" text-case="title" font-style="italic"/></if><else><text macro="title"/></else></choose></substitute></names></macro><macro name="author-short"><names variable="author"><name form="short" and="text" delimiter=", " delimiter-precedes-last="never" initialize-with=". "/><et-al font-style="italic"/><substitute><names variable="editor"/><names variable="translator"/><choose><if type="article-newspaper article-magazine" match="any"><text variable="container-title" text-case="title" font-style="italic"/></if><else><text macro="title"/></else></choose></substitute></names></macro><macro name="access"><choose><if variable="DOI"><text variable="DOI" prefix="doi:"/></if><else-if variable="URL"><text term="available at" suffix=": " text-case="capitalize-first"/><text variable="URL"/><group prefix=" (" delimiter=": " suffix=")"><text term="accessed" text-case="capitalize-first"/><date form="text" variable="accessed"><date-part name="day"/><date-part name="month"/><date-part name="year"/></date></group></else-if></choose></macro><macro name="number-volumes"><choose><if variable="volume" match="none"><group delimiter=" " prefix="(" suffix=")"><text variable="number-of-volumes"/><label variable="volume" form="short" strip-periods="true"/></group></if></choose></macro><macro name="title"><choose><if type="bill book legal_case legislation motion_picture report song thesis webpage graphic" match="any"><group delimiter=". "><group delimiter=" "><group delimiter=" "><text variable="title" font-style="italic"/><text variable="medium" prefix="[" suffix="]"/></group><text macro="number-volumes"/></group><text macro="edition"/></group></if><else><text variable="title" form="long" quotes="true"/></else></choose></macro><macro name="publisher"><choose><if type="thesis"><group delimiter=". "><text variable="genre"/><text variable="publisher"/></group></if><else-if type="report"><group delimiter=". "><group delimiter=" "><text variable="genre"/><text variable="number"/></group><group delimiter=": "><text variable="publisher-place"/><text variable="publisher"/></group></group></else-if><else-if type="article-journal article-newspaper article-magazine" match="none"><group delimiter=" "><group delimiter=", "><choose><if type="speech" variable="event" match="any"><text variable="event" font-style="italic"/></if></choose><group delimiter=": "><text variable="publisher-place"/><text variable="publisher"/></group></group><group prefix="(" suffix=")" delimiter=", "><text variable="collection-title"/><text variable="collection-number"/></group></group></else-if></choose></macro><macro name="year-date"><choose><if variable="issued"><date variable="issued"><date-part name="year"/></date><text variable="year-suffix"/></if><else><text term="no date"/><text variable="year-suffix" prefix=" "/></else></choose></macro><macro name="locator"><choose><if type="article-journal"><text variable="volume"/><text variable="issue" prefix="(" suffix=")"/></if></choose></macro><macro name="published-date"><choose><if type="article-newspaper article-magazine post-weblog speech" match="any"><date variable="issued"><date-part name="day" suffix=" "/><date-part name="month" form="long"/></date></if></choose></macro><macro name="pages"><choose><if type="chapter paper-conference article-journal article article-magazine article-newspaper book review review-book report" match="any"><group delimiter=" "><label variable="page" form="short"/><text variable="page"/></group></if></choose></macro><macro name="container-title"><choose><if variable="container-title"><group delimiter=". "><group delimiter=" "><text variable="container-title" font-style="italic"/><choose><if type="article article-journal" match="any"><choose><if match="none" variable="page volume"><text value="Preprint" prefix="[" suffix="]"/></if></choose></if></choose></group><text macro="edition"/></group></if></choose></macro><macro name="edition"><choose><if is-numeric="edition"><group delimiter=" "><number variable="edition" form="ordinal"/><text term="edition" form="short" strip-periods="true"/></group></if><else><text variable="edition"/></else></choose></macro><macro name="container-prefix"><choose><if type="chapter paper-conference" match="any"><text term="in"/></if></choose></macro><citation et-al-min="4" et-al-use-first="1" disambiguate-add-year-suffix="true" disambiguate-add-names="true" disambiguate-add-givenname="true" collapse="year"><sort><key macro="year-date"/></sort><layout prefix="(" suffix=")" delimiter="; "><group delimiter=", "><group delimiter=", "><text macro="author-short"/><text macro="year-date"/></group><group><label variable="locator" form="short" suffix=" "/><text variable="locator"/></group></group></layout></citation><bibliography and="text" et-al-min="4" et-al-use-first="1"><sort><key macro="author"/><key macro="year-date"/><key variable="title"/></sort><layout suffix="."><group delimiter=". "><group delimiter=" "><text macro="author"/><text macro="year-date" prefix="(" suffix=")"/><group delimiter=", "><text macro="title"/><group delimiter=" "><text macro="container-prefix"/><text macro="editor"/><text macro="container-title"/></group></group></group><text macro="secondary-contributors"/><text macro="publisher"/></group><group delimiter=", " prefix=", "><text macro="locator"/><text macro="published-date"/><text macro="pages"/></group><text macro="access" prefix=". "/></layout></bibliography>
</style>
`};a();var c=new n(s),l=e(t(((e,t)=>{var n={PROCESSOR_VERSION:`1.4.61`,error:function(e){throw typeof Error>`u`?Error(`citeproc-js error: `+e):`citeproc-js error: `+e},debug:function(e){typeof console>`u`?dump(`CSL: `+e+`
`):console.log(`citeproc-js warning: `+e)},toLocaleUpperCase(e){var t=this.tmp.lang_array;try{e=e.toLocaleUpperCase(t)}catch{e=e.toUpperCase()}return e},toLocaleLowerCase(e){var t=this.tmp.lang_array;try{e=e.toLocaleLowerCase(t)}catch{e=e.toLowerCase()}return e},LOCATOR_LABELS_REGEXP:RegExp(`^((vrs|sv|subpara|op|subch|add|amend|annot|app|art|bibliog|bk|ch|cl|col|cmt|dec|dept|div|ex|fig|fld|fol|n|hypo|illus|intro|l|no|p|pp|para|pt|pmbl|princ|pub|r|rn|sched|sec|ser|subdiv|subsec|supp|tbl|tit|vol)\\.)\\s+(.*)`),STATUTE_SUBDIV_PLAIN_REGEX:/(?:(?:^| )(?:vrs|sv|subpara|op|subch|add|amend|annot|app|art|bibliog|bk|ch|cl|col|cmt|dec|dept|div|ex|fig|fld|fol|n|hypo|illus|intro|l|no|p|pp|para|pt|pmbl|princ|pub|r|rn|sched|sec|ser|subdiv|subsec|supp|tbl|tit|vol)\. *)/,STATUTE_SUBDIV_PLAIN_REGEX_FRONT:/(?:^\s*[.,;]*\s*(?:vrs|sv|subpara|op|subch|add|amend|annot|app|art|bibliog|bk|ch|cl|col|cmt|dec|dept|div|ex|fig|fld|fol|n|hypo|illus|intro|l|no|p|pp|para|pt|pmbl|princ|pub|r|rn|sched|sec|ser|subdiv|subsec|supp|tbl|tit|vol)\. *)/,STATUTE_SUBDIV_STRINGS:{"vrs.":`verse`,"sv.":`sub-verbo`,"subpara.":`subparagraph`,"op.":`opus`,"subch.":`subchapter`,"add.":`addendum`,"amend.":`amendment`,"annot.":`annotation`,"app.":`appendix`,"art.":`article`,"bibliog.":`bibliography`,"bk.":`book`,"ch.":`chapter`,"cl.":`clause`,"col.":`column`,"cmt.":`comment`,"dec.":`decision`,"dept.":`department`,"ex.":`example`,"fig.":`figure`,"fld.":`field`,"fol.":`folio`,"n.":`note`,"hypo.":`hypothetical`,"illus.":`illustration`,"intro.":`introduction`,"l.":`line`,"no.":`issue`,"p.":`page`,"pp.":`page`,"para.":`paragraph`,"pt.":`part`,"pmbl.":`preamble`,"princ.":`principle`,"pub.":`publication`,"r.":`rule`,"rn.":`randnummer`,"sched.":`schedule`,"sec.":`section`,"ser.":`series,`,"subdiv.":`subdivision`,"subsec.":`subsection`,"supp.":`supplement`,"tbl.":`table`,"tit.":`title`,"vol.":`volume`},STATUTE_SUBDIV_STRINGS_REVERSE:{verse:`vrs.`,"sub-verbo":`sv.`,"sub verbo":`sv.`,subparagraph:`subpara.`,opus:`op.`,subchapter:`subch.`,addendum:`add.`,amendment:`amend.`,annotation:`annot.`,appendix:`app.`,article:`art.`,bibliography:`bibliog.`,book:`bk.`,chapter:`ch.`,clause:`cl.`,column:`col.`,comment:`cmt.`,decision:`dec.`,department:`dept.`,example:`ex.`,figure:`fig.`,field:`fld.`,folio:`fol.`,note:`n.`,hypothetical:`hypo.`,illustration:`illus.`,introduction:`intro.`,line:`l.`,issue:`no.`,page:`p.`,paragraph:`para.`,part:`pt.`,preamble:`pmbl.`,principle:`princ.`,publication:`pub.`,rule:`r.`,randnummer:`rn.`,schedule:`sched.`,section:`sec.`,"series,":`ser.`,subdivision:`subdiv.`,subsection:`subsec.`,supplement:`supp.`,table:`tbl.`,title:`tit.`,volume:`vol.`},LOCATOR_LABELS_MAP:{vrs:`verse`,sv:`sub-verbo`,subpara:`subparagraph`,op:`opus`,subch:`subchapter`,add:`addendum`,amend:`amendment`,annot:`annotation`,app:`appendix`,art:`article`,bibliog:`bibliography`,bk:`book`,ch:`chapter`,cl:`clause`,col:`column`,cmt:`comment`,dec:`decision`,dept:`department`,ex:`example`,fig:`figure`,fld:`field`,fol:`folio`,n:`note`,hypo:`hypothetical`,illus:`illustration`,intro:`introduction`,l:`line`,no:`issue`,p:`page`,pp:`page`,para:`paragraph`,pt:`part`,pmbl:`preamble`,princ:`principle`,pub:`publication`,r:`rule`,rn:`randnummer`,sched:`schedule`,sec:`section`,ser:`series,`,subdiv:`subdivision`,subsec:`subsection`,supp:`supplement`,tbl:`table`,tit:`title`,vol:`volume`},MODULE_MACROS:{"juris-pretitle":!0,"juris-title":!0,"juris-pretitle-short":!0,"juris-title-short":!0,"juris-main":!0,"juris-main-short":!0,"juris-tail":!0,"juris-tail-short":!0,"juris-locator":!0},MODULE_TYPES:{legal_case:!0,legislation:!0,bill:!0,hearing:!0,gazette:!0,report:!0,regulation:!0,standard:!0,patent:!0,locator:!0},checkNestedBrace:function(e){e.opt.xclass===`note`?(this.depth=0,this.update=function(e){for(var e=e||``,t=e.split(/([\(\)])/),n=1,r=t.length;n<r;n+=2)t[n]===`(`?(this.depth%2==1&&(t[n]=`[`),this.depth+=1):t[n]===`)`&&(this.depth%2==0&&(t[n]=`]`),--this.depth);return t.join(``)}):this.update=function(e){return e}},MULTI_FIELDS:[`event`,`publisher`,`publisher-place`,`event-place`,`title`,`container-title`,`collection-title`,`authority`,`genre`,`title-short`,`medium`,`country`,`jurisdiction`,`archive`,`archive-place`],LangPrefsMap:{title:`titles`,"title-short":`titles`,event:`titles`,genre:`titles`,medium:`titles`,"container-title":`journals`,"collection-title":`titles`,archive:`journals`,publisher:`publishers`,authority:`publishers`,"publisher-place":`places`,"event-place":`places`,"archive-place":`places`,jurisdiction:`places`,number:`places`,edition:`places`,issue:`places`,volume:`places`},AbbreviationSegments:function(){this[`container-title`]={},this[`collection-title`]={},this[`institution-entire`]={},this[`institution-part`]={},this.nickname={},this.number={},this.title={},this.place={},this.hereinafter={},this.classic={},this[`container-phrase`]={},this[`title-phrase`]={}},getAbbrevsDomain:function(e,t,n){var r=null;if(e.opt.availableAbbrevDomains&&t&&t!==`default`){var i=e.locale[e.opt.lang].opts[`jurisdiction-preference`],a=null;if(e.locale[n]&&(a=e.locale[n].opts[`jurisdiction-preference`]),a){for(var o=a.length-1;o>-1;o--)if(e.opt.availableAbbrevDomains[t].indexOf(a[o])>-1){r=a[o];break}}if(!r&&i){for(var o=i.length-1;o>-1;o--)if(e.opt.availableAbbrevDomains[t].indexOf(i[o])>-1){r=i[o];break}}}return r},FIELD_CATEGORY_REMAP:{title:`title`,"container-title":`container-title`,"collection-title":`collection-title`,country:`place`,number:`number`,place:`place`,archive:`container-title`,"title-short":`title`,genre:`title`,event:`title`,medium:`title`,"archive-place":`place`,"publisher-place":`place`,"event-place":`place`,jurisdiction:`place`,"language-name":`place`,"language-name-original":`place`,"call-number":`number`,"chapter-number":`number`,"collection-number":`number`,edition:`number`,page:`number`,issue:`number`,locator:`number`,"locator-extra":`number`,"number-of-pages":`number`,"number-of-volumes":`number`,volume:`number`,"citation-number":`number`,publisher:`institution-part`},parseLocator:function(e){if(this.opt.development_extensions.locator_date_and_revision&&e.locator){e.locator=``+e.locator;var t=e.locator.indexOf(`|`);if(t>-1){var n=e.locator;e.locator=n.slice(0,t),n=n.slice(t+1);var r=n.match(/^([0-9]{4}-[0-9]{2}-[0-9]{2}).*/);r&&(e[`locator-date`]=this.fun.dateparser.parseDateToObject(r[1]),n=n.slice(r[1].length)),e[`locator-extra`]=n.replace(/^\s+/,``).replace(/\s+$/,``)}}return e.locator&&(e.locator=(``+e.locator).replace(/\s+$/,``)),e},normalizeLocaleStr:function(e){if(e){var t=e.split(`-`);return t[0]=t[0].toLowerCase(),t[1]&&(t[1]=t[1].toUpperCase()),t.join(`-`)}},parseNoteFieldHacks:function(e,t,r){if(typeof e.note==`string`){for(var i=[],a=e.note.split(`
`),o=0,s=a.length;o<s;o++){var c=a[o],i=[],l=c.match(n.NOTE_FIELDS_REGEXP);if(l){for(var u=c.split(n.NOTE_FIELDS_REGEXP),d=0,f=u.length-1;d<f;d++)i.push(u[d]),i.push(l[d]);i.push(u[u.length-1]);for(var d=1,f=i.length;d<f&&!(i[d-1].trim()&&(o>0||d>1)&&!i[d-1].match(n.NOTE_FIELD_REGEXP));d+=2)i[d]=`
`+i[d].slice(2,-1).trim()+`
`;a[o]=i.join(``)}}a=a.join(`
`).split(`
`);for(var p=0,m={},o=0,s=a.length;o<s;o++){var c=a[o],h=c.match(n.NOTE_FIELD_REGEXP);if(c.trim()){if(!h){if(o===0)continue;p=o;break}var g=h[1],_=h[2].replace(/^\s+/,``).replace(/\s+$/,``);if(g===`type`)e.type=_,a[o]=``;else if(n.DATE_VARIABLES.indexOf(g.replace(/^alt-/,``))>-1)(!e[g]||r)&&(e[g]=n.DateParser.parseDateToArray(_),(!t||t[g]&&this.isDateString(_))&&(a[o]=``));else if(!e[g]){if(n.NAME_VARIABLES.indexOf(g.replace(/^alt-/,``))>-1){m[g]||(m[g]=[]);var v=_.split(/\s*\|\|\s*/);if(v.length===1)m[g].push({literal:v[0]});else if(v.length===2){var y={family:v[0],given:v[1]};n.parseParticles(y),m[g].push(y)}}else e[g]=_;(!t||t[g])&&(a[o]=``)}}}for(var g in m)e[g]=m[g];if(t){a[p].trim()&&(a[p]=`
`+a[p]);for(var o=p-1;o>-1;o--)a[o].trim()||(a=a.slice(0,o).concat(a.slice(o+1)))}e.note=a.join(`
`).trim()}},checkPrefixSpaceAppend:function(e,t){t||(t=``);var r=``,i=t.replace(/<[^>]+>/g,``).replace(/["'\u201d\u2019\u00bb\u202f\u00a0 ]+$/g,``),a=i.slice(-1);(i.match(n.ENDSWITH_ROMANESQUE_REGEXP)||n.TERMINAL_PUNCTUATION.slice(0,-1).indexOf(a)>-1||a.match(/[\)\],0-9]/))&&(r=` `);var t=(t+r).replace(/\s+/g,` `);return t},checkIgnorePredecessor:function(e,t){var r=t.replace(/<[^>]+>/g,``).replace(/["'\u201d\u2019\u00bb\u202f\u00a0 ]+$/g,``).slice(-1);return n.TERMINAL_PUNCTUATION.slice(0,-1).indexOf(r)>-1&&t.trim().indexOf(` `)>-1?(e.tmp.term_predecessor=!1,!0):!1},checkSuffixSpacePrepend:function(e,t){return t?((t.match(n.STARTSWITH_ROMANESQUE_REGEXP)||[`[`,`(`].indexOf(t.slice(0,1))>-1)&&(t=` `+t),t):``},GENDERS:[`masculine`,`feminine`],ERROR_NO_RENDERED_FORM:1,PREVIEW:`Just for laughs.`,ASSUME_ALL_ITEMS_REGISTERED:2,START:0,END:1,SINGLETON:2,SEEN:6,SUCCESSOR:3,SUCCESSOR_OF_SUCCESSOR:4,SUPPRESS:5,SINGULAR:0,PLURAL:1,LITERAL:!0,BEFORE:1,AFTER:2,DESCENDING:1,ASCENDING:2,PRIMARY:1,SECONDARY:2,POSITION_FIRST:0,POSITION_SUBSEQUENT:1,POSITION_IBID:2,POSITION_IBID_WITH_LOCATOR:3,POSITION_CONTAINER_SUBSEQUENT:4,POSITION_MAP:{0:0,4:1,1:2,2:3,3:4},POSITION_TEST_VARS:[`position`,`first-reference-note-number`,`near-note`],AREAS:[`citation`,`citation_sort`,`bibliography`,`bibliography_sort`,`intext`],CITE_FIELDS:[`first-reference-note-number`,`first-container-reference-note-number`,`locator`,`locator-extra`],SWAPPING_PUNCTUATION:[`.`,`!`,`?`,`:`,`,`],TERMINAL_PUNCTUATION:[`:`,`.`,`;`,`!`,`?`,` `],NONE:0,NUMERIC:1,POSITION:2,TRIGRAPH:3,DATE_PARTS:[`year`,`month`,`day`],DATE_PARTS_ALL:[`year`,`month`,`day`,`season`],DATE_PARTS_INTERNAL:[`year`,`month`,`day`,`year_end`,`month_end`,`day_end`],NAME_PARTS:[`non-dropping-particle`,`family`,`given`,`dropping-particle`,`suffix`,`literal`],DISAMBIGUATE_OPTIONS:[`disambiguate-add-names`,`disambiguate-add-givenname`,`disambiguate-add-year-suffix`],GIVENNAME_DISAMBIGUATION_RULES:[`all-names`,`all-names-with-initials`,`primary-name`,`primary-name-with-initials`,`by-cite`],NAME_ATTRIBUTES:[`and`,`delimiter-precedes-last`,`delimiter-precedes-et-al`,`initialize-with`,`initialize`,`name-as-sort-order`,`sort-separator`,`et-al-min`,`et-al-use-first`,`et-al-subsequent-min`,`et-al-subsequent-use-first`,`form`,`prefix`,`suffix`,`delimiter`],LOOSE:0,STRICT:1,TOLERANT:2,PREFIX_PUNCTUATION:/[.;:]\s*$/,SUFFIX_PUNCTUATION:/^\s*[.;:,\(\)]/,NUMBER_REGEXP:/(?:^\d+|\d+$)/,NAME_INITIAL_REGEXP:/^([A-Z\u0e01-\u0e5b\u00c0-\u017f\u0400-\u042f\u0590-\u05d4\u05d6-\u05ff\u0600-\u06ff\u0370\u0372\u0376\u0386\u0388-\u03ab\u03e2\u03e4\u03e6\u03e8\u03ea\u03ec\u03ee\u03f4\u03f7\u03fd-\u03ff])([a-zA-Z\u0e01-\u0e5b\u00c0-\u017f\u0400-\u052f\u0600-\u06ff\u0370-\u03ff\u1f00-\u1fff]*|)(\.)*/,ROMANESQUE_REGEXP:/[-0-9a-zA-Z\u0e01-\u0e5b\u00c0-\u017f\u0370-\u03ff\u0400-\u052f\u0590-\u05d4\u05d6-\u05ff\u1f00-\u1fff\u0600-\u06ff\u200c\u200d\u200e\u0218\u0219\u021a\u021b\u202a-\u202e]/,ROMANESQUE_NOT_REGEXP:/[^a-zA-Z\u0e01-\u0e5b\u00c0-\u017f\u0370-\u03ff\u0400-\u052f\u0590-\u05d4\u05d6-\u05ff\u1f00-\u1fff\u0600-\u06ff\u200c\u200d\u200e\u0218\u0219\u021a\u021b\u202a-\u202e]/g,STARTSWITH_ROMANESQUE_REGEXP:/^[&a-zA-Z\u0e01-\u0e5b\u00c0-\u017f\u0370-\u03ff\u0400-\u052f\u0590-\u05d4\u05d6-\u05ff\u1f00-\u1fff\u0600-\u06ff\u200c\u200d\u200e\u0218\u0219\u021a\u021b\u202a-\u202e]/,ENDSWITH_ROMANESQUE_REGEXP:/[.;:&a-zA-Z\u0e01-\u0e5b\u00c0-\u017f\u0370-\u03ff\u0400-\u052f\u0590-\u05d4\u05d6-\u05ff\u1f00-\u1fff\u0600-\u06ff\u200c\u200d\u200e\u0218\u0219\u021a\u021b\u202a-\u202e]$/,ALL_ROMANESQUE_REGEXP:/^[a-zA-Z\u0e01-\u0e5b\u00c0-\u017f\u0370-\u03ff\u0400-\u052f\u0590-\u05d4\u05d6-\u05ff\u1f00-\u1fff\u0600-\u06ff\u200c\u200d\u200e\u0218\u0219\u021a\u021b\u202a-\u202e]+$/,VIETNAMESE_SPECIALS:/[\u00c0-\u00c3\u00c8-\u00ca\u00cc\u00cd\u00d2-\u00d5\u00d9\u00da\u00dd\u00e0-\u00e3\u00e8-\u00ea\u00ec\u00ed\u00f2-\u00f5\u00f9\u00fa\u00fd\u0101\u0103\u0110\u0111\u0128\u0129\u0168\u0169\u01a0\u01a1\u01af\u01b0\u1ea0-\u1ef9]/,VIETNAMESE_NAMES:/^(?:(?:[.AaBbCcDdEeGgHhIiKkLlMmNnOoPpQqRrSsTtUuVvXxYy \u00c0-\u00c3\u00c8-\u00ca\u00cc\u00cd\u00d2-\u00d5\u00d9\u00da\u00dd\u00e0-\u00e3\u00e8-\u00ea\u00ec\u00ed\u00f2-\u00f5\u00f9\u00fa\u00fd\u0101\u0103\u0110\u0111\u0128\u0129\u0168\u0169\u01a0\u01a1\u01af\u01b0\u1ea0-\u1ef9]{2,6})(\s+|$))+$/,NOTE_FIELDS_REGEXP:/\{:(?:[\-_a-z]+|[A-Z]+):[^\}]+\}/g,NOTE_FIELD_REGEXP:/^([\-_a-z]+|[A-Z]+):\s*([^\}]+)$/,PARTICLE_GIVEN_REGEXP:/^([^ ]+(?:\u02bb |\u2019 | |\' ) *)(.+)$/,PARTICLE_FAMILY_REGEXP:/^([^ ]+(?:\-|\u02bb|\u2019| |\') *)(.+)$/,DISPLAY_CLASSES:[`block`,`left-margin`,`right-inline`,`indent`],NAME_VARIABLES:`author.chair.collection-editor.compiler.composer.container-author.contributor.curator.director.editor.editor-translator.editorial-director.executive-producer.guest.host.illustrator.interviewer.narrator.organizer.original-author.performer.producer.recipient.reviewed-author.script-writer.series-creator.translator.commenter`.split(`.`),CREATORS:`author.chair.collection-editor.compiler.composer.container-author.contributor.curator.director.editor.editor-translator.editorial-director.executive-producer.guest.host.illustrator.interviewer.narrator.organizer.original-author.performer.producer.recipient.reviewed-author.script-writer.series-creator.translator.commenter`.split(`.`),NUMERIC_VARIABLES:[`call-number`,`chapter-number`,`collection-number`,`division`,`edition`,`page`,`issue`,`locator`,`locator-extra`,`number`,`number-of-pages`,`number-of-volumes`,`part-number`,`printing-number`,`section`,`supplement-number`,`version`,`volume`,`supplement`,`citation-number`],DATE_VARIABLES:[`locator-date`,`issued`,`event-date`,`accessed`,`original-date`,`publication-date`,`available-date`,`submitted`,`alt-issued`,`alt-event`],VARIABLES_WITH_SHORT_FORM:[`title`,`container-title`],TITLE_FIELD_SPLITS:function(e){for(var t=[`title`,`short`,`main`,`sub`,`subjoin`],n={},r=0,i=t.length;r<i;r++)n[t[r]]=e+`title`+(t[r]===`title`?``:`-`+t[r]);return n},demoteNoiseWords:function(e,t,n){var r=e.locale[e.opt.lang].opts[`leading-noise-words`];if(t&&n){t=t.split(/\s+/),t.reverse();for(var i=[],a=t.length-1;a>-1&&r.indexOf(t[a].toLowerCase())>-1;a+=-1)i.push(t.pop());t.reverse();var o=t.join(` `),s=i.join(` `);n===`drop`||!s?t=o:n===`demote`&&(t=[o,s].join(`, `))}return t},extractTitleAndSubtitle:function(e,t){var r=t?` `:``,i=[``];this.opt.development_extensions.split_container_title&&i.push(`container-`);for(var a=0,o=i.length;a<o;a++){var s=i[a],c=n.TITLE_FIELD_SPLITS(s),l=[!1];if(e.multi)for(var u in e.multi._keys[c.short])l.push(u);for(var d=0,f=l.length;d<f;d++){var u=l[d],p={};u?(e.multi._keys[c.title]&&(p[c.title]=e.multi._keys[c.title][u]),e.multi._keys[c.short]&&(p[c.short]=e.multi._keys[c.short][u])):(p[c.title]=e[c.title],p[c.short]=e[c.short]),p[c.main]=p[c.title],p[c.sub]=!1;var m=p[c.short];if(p[c.title]){if(m&&m.toLowerCase()===p[c.title].toLowerCase())p[c.main]=p[c.title],p[c.subjoin]=``,p[c.sub]=``;else if(m){var h=p[c.title].slice(m.replace(/[\?\!]+$/,``).length),g=p[c.title].replace(h.replace(/^[\?\!]+/,``),``).trim(),_=n.TITLE_SPLIT_REGEXP.matchfirst.exec(h);if(_&&g.toLowerCase()===m.toLowerCase())p[c.main]=g,p[c.subjoin]=_[1].replace(/[\?\!]+(\s*)$/,`$1`),p[c.sub]=h.replace(n.TITLE_SPLIT_REGEXP.matchfirst,``),this.opt.development_extensions.force_short_title_casing_alignment&&(p[c.short]=p[c.main]);else{var v=n.TITLE_SPLIT(p[c.title]);v.length==3?(p[c.main]=v[0],p[c.subjoin]=v[1],p[c.sub]=v[2]):(p[c.main]=p[c.title],p[c.subjoin]=``,p[c.sub]=``)}}else{var v=n.TITLE_SPLIT(p[c.title]);if(v.length==3){if(p[c.main]=v[0],p[c.subjoin]=v[1],p[c.sub]=v[2],this.opt.development_extensions.implicit_short_title&&e.type!==`legal_case`&&!e[c.short]&&!p[c.main].match(/^[\-\.[0-9]+$/)){var y=p[c.subjoin].trim();[`?`,`!`].indexOf(y)===-1&&(y=``),p[c.short]=p[c.main]+y}}else p[c.main]=p[c.title],p[c.subjoin]=``,p[c.sub]=``}if(p[c.subjoin]&&p[c.subjoin].match(/([\?\!])/)){var _=p[c.subjoin].match(/(\s*)$/);p[c.main]=p[c.main]+r+p[c.subjoin].trim(),p[c.subjoin]=_[1]}}if(p[c.subjoin]&&(p[c.subjoin].indexOf(`:`)>-1&&(p[c.subjoin]=r+`: `),(p[c.subjoin].indexOf(`-`)>-1||p[c.subjoin].indexOf(`—`)>-1)&&(p[c.subjoin]=`—`)),u)for(var b in p)e.multi._keys[b]||(e.multi._keys[b]={}),e.multi._keys[b][u]=p[b];else for(var b in p)e[b]=p[b]}}},titlecaseSentenceOrNormal:function(e,t,r,i,a){var o=n.TITLE_FIELD_SPLITS(r),s={};if(i&&t.multi?(t.multi._keys[o.title]&&(s[o.title]=t.multi._keys[o.title][i]),t.multi._keys[o.main]&&(s[o.main]=t.multi._keys[o.main][i]),t.multi._keys[o.sub]&&(s[o.sub]=t.multi._keys[o.sub][i]),t.multi._keys[o.subjoin]&&(s[o.subjoin]=t.multi._keys[o.subjoin][i])):(s[o.title]=t[o.title],s[o.main]=t[o.main],s[o.sub]=t[o.sub],s[o.subjoin]=t[o.subjoin]),s[o.main]&&s[o.sub]){var c=s[o.main],l=s[o.subjoin],u=s[o.sub];return a?(c=n.Output.Formatters.sentence(e,c),u=n.Output.Formatters.sentence(e,u)):e.opt.development_extensions.uppercase_subtitles&&(u=n.Output.Formatters[`capitalize-first`](e,u)),[c,l,u].join(``)}else if(s[o.title]){if(a)return n.Output.Formatters.sentence(e,s[o.title]);if(e.opt.development_extensions.uppercase_subtitles){for(var d=n.TITLE_SPLIT(s[o.title]),f=0,p=d.length;f<p;f+=2)d[f]=n.Output.Formatters[`capitalize-first`](e,d[f]);for(var f=1,p=d.length-1;f<p;f+=2){var m=d[f].match(/([:\?\!] )/);m&&(d[f]=(e.opt[`default-locale`][0].slice(0,2).toLowerCase()===`fr`?` `:``)+m[1]),(d[f].indexOf(`-`)>-1||d[f].indexOf(`—`)>-1)&&(d[f]=`—`)}return s[o.title]=d.join(``),s[o.title]}else return s[o.title]}else return``},getSafeEscape:function(e){if([`bibliography`,`citation`].indexOf(e.tmp.area)>-1){var t=[];return e.opt.development_extensions.thin_non_breaking_space_html_hack&&e.opt.mode===`html`&&t.push(function(e){return e.replace(/\u202f/g,`<span style="white-space:nowrap">&thinsp;</span>`)}),t.length?function(r){for(var i=0,a=t.length;i<a;i+=1)r=t[i](r);return n.Output.Formats[e.opt.mode].text_escape(r)}:n.Output.Formats[e.opt.mode].text_escape}else return function(e){return e}},SKIP_WORDS:`about,above,across,afore,after,against,al,along,alongside,amid,amidst,among,amongst,anenst,apropos,apud,around,as,aside,astride,at,athwart,atop,barring,before,behind,below,beneath,beside,besides,between,beyond,but,by,circa,despite,down,during,et,except,for,forenenst,from,given,in,inside,into,lest,like,modulo,near,next,notwithstanding,of,off,on,onto,out,over,per,plus,pro,qua,sans,since,than,through, thru,throughout,thruout,till,to,toward,towards,under,underneath,until,unto,up,upon,versus,vs.,v.,vs,v,via,vis-à-vis,with,within,without,according to,ahead of,apart from,as for,as of,as per,as regards,aside from,back to,because of,close to,due to,except for,far from,inside of,instead of,near to,next to,on to,out from,out of,outside of,prior to,pursuant to,rather than,regardless of,such as,that of,up to,where as,or,yet,so,for,and,nor,a,an,the,de,d',von,van,c,ca`.split(`,`),FORMAT_KEY_SEQUENCE:[`@strip-periods`,`@font-style`,`@font-variant`,`@font-weight`,`@text-decoration`,`@vertical-align`,`@quotes`],INSTITUTION_KEYS:[`font-style`,`font-variant`,`font-weight`,`text-decoration`,`text-case`],SUFFIX_CHARS:`a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,x,y,z`,ROMAN_NUMERALS:[[``,`i`,`ii`,`iii`,`iv`,`v`,`vi`,`vii`,`viii`,`ix`],[``,`x`,`xx`,`xxx`,`xl`,`l`,`lx`,`lxx`,`lxxx`,`xc`],[``,`c`,`cc`,`ccc`,`cd`,`d`,`dc`,`dcc`,`dccc`,`cm`],[``,`m`,`mm`,`mmm`,`mmmm`,`mmmmm`]],LANGS:{"af-ZA":`Afrikaans`,ar:`Arabic`,"bg-BG":`Bulgarian`,"ca-AD":`Catalan`,"cs-CZ":`Czech`,"da-DK":`Danish`,"de-AT":`Austrian`,"de-CH":`German (CH)`,"de-DE":`German (DE)`,"el-GR":`Greek`,"en-GB":`English (GB)`,"en-US":`English (US)`,"es-ES":`Spanish`,"et-EE":`Estonian`,eu:`European`,"fa-IR":`Persian`,"fi-FI":`Finnish`,"fr-CA":`French (CA)`,"fr-FR":`French (FR)`,"he-IL":`Hebrew`,"hr-HR":`Croatian`,"hu-HU":`Hungarian`,"is-IS":`Icelandic`,"it-IT":`Italian`,"ja-JP":`Japanese`,"km-KH":`Khmer`,"ko-KR":`Korean`,"lt-LT":`Lithuanian`,"lv-LV":`Latvian`,"mn-MN":`Mongolian`,"nb-NO":`Norwegian (Bokmål)`,"nl-NL":`Dutch`,"nn-NO":`Norwegian (Nynorsk)`,"pl-PL":`Polish`,"pt-BR":`Portuguese (BR)`,"pt-PT":`Portuguese (PT)`,"ro-RO":`Romanian`,"ru-RU":`Russian`,"sk-SK":`Slovak`,"sl-SI":`Slovenian`,"sr-RS":`Serbian`,"sv-SE":`Swedish`,"th-TH":`Thai`,"tr-TR":`Turkish`,"uk-UA":`Ukrainian`,"vi-VN":`Vietnamese`,"zh-CN":`Chinese (CN)`,"zh-TW":`Chinese (TW)`},LANG_BASES:{af:`af_ZA`,ar:`ar`,bg:`bg_BG`,ca:`ca_AD`,cs:`cs_CZ`,da:`da_DK`,de:`de_DE`,el:`el_GR`,en:`en_US`,es:`es_ES`,et:`et_EE`,eu:`eu`,fa:`fa_IR`,fi:`fi_FI`,fr:`fr_FR`,he:`he_IL`,hr:`hr-HR`,hu:`hu_HU`,is:`is_IS`,it:`it_IT`,ja:`ja_JP`,km:`km_KH`,ko:`ko_KR`,lt:`lt_LT`,lv:`lv-LV`,mn:`mn_MN`,nb:`nb_NO`,nl:`nl_NL`,nn:`nn-NO`,pl:`pl_PL`,pt:`pt_PT`,ro:`ro_RO`,ru:`ru_RU`,sk:`sk_SK`,sl:`sl_SI`,sr:`sr_RS`,sv:`sv_SE`,th:`th_TH`,tr:`tr_TR`,uk:`uk_UA`,vi:`vi_VN`,zh:`zh_CN`},SUPERSCRIPTS:{ª:`a`,"²":`2`,"³":`3`,"¹":`1`,º:`o`,ʰ:`h`,ʱ:`ɦ`,ʲ:`j`,ʳ:`r`,ʴ:`ɹ`,ʵ:`ɻ`,ʶ:`ʁ`,ʷ:`w`,ʸ:`y`,ˠ:`ɣ`,ˡ:`l`,ˢ:`s`,ˣ:`x`,ˤ:`ʕ`,ᴬ:`A`,ᴭ:`Æ`,ᴮ:`B`,ᴰ:`D`,ᴱ:`E`,ᴲ:`Ǝ`,ᴳ:`G`,ᴴ:`H`,ᴵ:`I`,ᴶ:`J`,ᴷ:`K`,ᴸ:`L`,ᴹ:`M`,ᴺ:`N`,ᴼ:`O`,ᴽ:`Ȣ`,ᴾ:`P`,ᴿ:`R`,ᵀ:`T`,ᵁ:`U`,ᵂ:`W`,ᵃ:`a`,ᵄ:`ɐ`,ᵅ:`ɑ`,ᵆ:`ᴂ`,ᵇ:`b`,ᵈ:`d`,ᵉ:`e`,ᵊ:`ə`,ᵋ:`ɛ`,ᵌ:`ɜ`,ᵍ:`g`,ᵏ:`k`,ᵐ:`m`,ᵑ:`ŋ`,ᵒ:`o`,ᵓ:`ɔ`,ᵔ:`ᴖ`,ᵕ:`ᴗ`,ᵖ:`p`,ᵗ:`t`,ᵘ:`u`,ᵙ:`ᴝ`,ᵚ:`ɯ`,ᵛ:`v`,ᵜ:`ᴥ`,ᵝ:`β`,ᵞ:`γ`,ᵟ:`δ`,ᵠ:`φ`,ᵡ:`χ`,"⁰":`0`,ⁱ:`i`,"⁴":`4`,"⁵":`5`,"⁶":`6`,"⁷":`7`,"⁸":`8`,"⁹":`9`,"⁺":`+`,"⁻":`−`,"⁼":`=`,"⁽":`(`,"⁾":`)`,ⁿ:`n`,"℠":`SM`,"™":`TM`,"㆒":`一`,"㆓":`二`,"㆔":`三`,"㆕":`四`,"㆖":`上`,"㆗":`中`,"㆘":`下`,"㆙":`甲`,"㆚":`乙`,"㆛":`丙`,"㆜":`丁`,"㆝":`天`,"㆞":`地`,"㆟":`人`,ˀ:`ʔ`,ˁ:`ʕ`,ۥ:`و`,ۦ:`ي`},SUPERSCRIPTS_REGEXP:RegExp(`[ª²³¹ºʰʱʲʳʴʵʶʷʸˠˡˢˣˤᴬᴭᴮᴰᴱᴲᴳᴴᴵᴶᴷᴸᴹᴺᴼᴽᴾᴿᵀᵁᵂᵃᵄᵅᵆᵇᵈᵉᵊᵋᵌᵍᵏᵐᵑᵒᵓᵔᵕᵖᵗᵘᵙᵚᵛᵜᵝᵞᵟᵠᵡ⁰ⁱ⁴⁵⁶⁷⁸⁹⁺⁻⁼⁽⁾ⁿ℠™㆒㆓㆔㆕㆖㆗㆘㆙㆚㆛㆜㆝㆞㆟ˀˁۥۦ]`,`g`),UPDATE_GROUP_CONTEXT_CONDITION:function(e,t,n,r,i){if(e.opt.use_context_condition){var a=e.tmp.group_context.tip;a.condition?(a.condition.termtxt||(a.condition.termtxt=t,a.condition.valueTerm=n),!a.value_seen&&a.condition.test===`comma-safe-numbers-only`&&i&&(a.value_seen=!0,i.match(/^[0-9]/)||(e.tmp.just_did_number=!1))):r&&r.decorations.filter(e=>e[0]===`@vertical-align`).length>0||r&&r.strings.suffix?e.tmp.just_did_number=!1:t&&(t.match(/[0-9]$/)?e.tmp.just_did_number=!0:e.tmp.just_did_number=!1)}},EVALUATE_GROUP_CONDITION:function(e,t){if(e.opt.use_context_condition){var r,i=t.condition.test===`comma-safe-numbers-only`;if(t.condition.test===`empty-label`)r=!t.condition.termtxt;else if(t.condition.test===`empty-label-no-decor`)r=!t.condition.termtxt||t.condition.termtxt.indexOf(`%s`)>-1;else if([`comma-safe`,`comma-safe-numbers-only`].indexOf(t.condition.test)>-1){var a=t.condition.termtxt,o=!1;t.condition.termtxt&&(o=t.condition.termtxt.slice(0,1).match(n.ALL_ROMANESQUE_REGEXP)),r=e.tmp.just_did_number?t.condition.valueTerm?!i:a?o?!i:[`always`,`after-number`].indexOf(e.opt.require_comma_on_symbol)>-1:!0:t.condition.valueTerm?!1:a?o?!i:e.opt.require_comma_on_symbol===`always`:!1}if(r)var s=!1;else var s=!0;return t.condition.not&&(s=!s),s}},SYS_OPTIONS:[`prioritize_disambiguate_condition`,`csl_reverse_lookup_support`,`main_title_from_short_title`,`uppercase_subtitles`,`force_short_title_casing_alignment`,`implicit_short_title`,`split_container_title`],TITLE_SPLIT_REGEXP:(function(){var e=[`\\.\\s+`,`\\!\\s+`,`\\?\\s+`,`\\s*::*\\s+`,`\\s*—\\s*`,`\\s+\\-\\s+`,`\\s*\\-\\-\\-*\\s*`];return{match:RegExp(`(`+e.join(`|`)+`)`,`g`),matchfirst:RegExp(`^(`+e.join(`|`)+`)`),split:RegExp(`(?:`+e.join(`|`)+`)`)}})(),TITLE_SPLIT:function(e){if(!e)return e;for(var t=e.match(n.TITLE_SPLIT_REGEXP.match),r=e.split(n.TITLE_SPLIT_REGEXP.split),i=r.length-2;i>-1;i--)r[i]=r[i].trim(),r[i]&&r[i].slice(-1).toLowerCase()!==r[i].slice(-1)?(r[i]=r[i]+t[i]+r[i+1],r=r.slice(0,i+1).concat(r.slice(i+2))):r=r.slice(0,i+1).concat([t[i]]).concat(r.slice(i+1));return r},GET_COURT_CLASS:function(e,t,n){var r=``,i=null,a=t.jurisdiction?t.jurisdiction.split(`:`)[0]:null,o=`court_condition_classes`;return n&&(o=`court_key_classes`),a&&t.authority&&(typeof t.authority==`string`?i=t.authority:t.authority[0]&&t.authority[0].literal&&(i=t.authority[0].literal)),i&&(this.lang&&e.locale[this.lang].opts[o]&&e.locale[this.lang].opts[o][a]&&e.locale[this.lang].opts[o][a][i]?r=e.locale[this.lang].opts[o][a][i]:e.locale[e.opt[`default-locale`][0]].opts[o]&&e.locale[e.opt[`default-locale`][0]].opts[o][a]&&e.locale[e.opt[`default-locale`][0]].opts[o][a][i]&&(r=e.locale[e.opt[`default-locale`][0]].opts[o][a][i])),r},SET_COURT_CLASSES:function(e,t,n,r){for(var i=n.getNodesByName(r,`court-class`),a=0,o=n.numberofnodes(i);a<o;a+=1){var s=i[a],c=n.attributes(s),l=c[`@name`],u=c[`@country`],d=c[`@courts`],f=`court_key_classes`;if(e.registry&&(f=`court_condition_classes`),l&&u&&d){d=d.trim().split(/\s+/),e.locale[t].opts[f]||(e.locale[t].opts[f]={}),e.locale[t].opts[f][u]||(e.locale[t].opts[f][u]={});for(var p=0,m=d.length;p<m;p++)e.locale[t].opts[f][u][d[p]]=l}}},INIT_JURISDICTION_MACROS:function(e,t,r,i){if(t[`best-jurisdiction`])return!0;if(!e.sys.retrieveStyleModule||!n.MODULE_MACROS[i]||!t.jurisdiction)return!1;var a=e.getJurisdictionList(t.jurisdiction);if(!e.opt.jurisdictions_seen[a[0]]){var o=e.retrieveAllStyleModules(a);for(var s in o){var c=e.loadStyleModule(s,o[s]);c&&(o[c]||(Object.assign(o,e.retrieveAllStyleModules([c])),e.loadStyleModule(c,o[c],!0)))}}var a=e.getJurisdictionList(t.jurisdiction);e.opt.parallel.enable&&(e.parallel||(e.parallel=new n.Parallel(e)));for(var l=0,u=a.length;l<u;l++){var s=a[l];if(r&&e.juris[s]&&!r[`best-jurisdiction`]&&e.juris[s].types.locator&&(t[`best-jurisdiction`]=s),e.juris[s]&&e.juris[s].types[t.type])return t[`best-jurisdiction`]=s,!0}return!1}};n.XmlJSON=function(e){this.dataObj=e,this.institution={name:`institution`,attrs:{"institution-parts":`long`,delimiter:`, `},children:[{name:`institution-part`,attrs:{name:`long`},children:[]}]}},n.XmlJSON.prototype.clean=function(e){return e},n.XmlJSON.prototype.getStyleId=function(e,t){var n=`id`;t&&(n=`title`);for(var r=``,i=e.children,a=0,o=i.length;a<o;a++)if(i[a].name===`info`)for(var s=i[a].children,c=0,l=s.length;c<l;c++)s[c].name===n&&(r=s[c].children[0]);return r},n.XmlJSON.prototype.children=function(e){return e&&e.children.length?e.children.slice():!1},n.XmlJSON.prototype.nodename=function(e){return e?e.name:null},n.XmlJSON.prototype.attributes=function(e){var t={};for(var n in e.attrs)t[`@`+n]=e.attrs[n];return t},n.XmlJSON.prototype.content=function(e){var t=``;if(!e||!e.children)return t;for(var n=0,r=e.children.length;n<r;n+=1)typeof e.children[n]==`string`&&(t+=e.children[n]);return t},n.XmlJSON.prototype.namespace={},n.XmlJSON.prototype.numberofnodes=function(e){return e&&typeof e.length==`number`?e.length:0},n.XmlJSON.prototype.getAttributeValue=function(e,t,n){var r=``;return n&&(t=n+`:`+t),e&&e.attrs&&(r=e.attrs[t]?e.attrs[t]:``),r},n.XmlJSON.prototype.getNodeValue=function(e,t){var n=``;if(t)for(var r=0,i=e.children.length;r<i;r+=1)e.children[r].name===t&&(n=e.children[r].children.length?e.children[r]:``);else e&&(n=e);return n&&n.children&&n.children.length==1&&typeof n.children[0]==`string`&&(n=n.children[0]),n},n.XmlJSON.prototype.setAttributeOnNodeIdentifiedByNameAttribute=function(e,t,n,r,i){r.slice(0,1)===`@`&&(r=r.slice(1));for(var a=0,o=e.children.length;a<o;a+=1)e.children[a].name===t&&e.children[a].attrs.name===n&&(e.children[a].attrs[r]=i)},n.XmlJSON.prototype.deleteNodeByNameAttribute=function(e,t){var n,r;for(n=0,r=e.children.length;n<r;n+=1)!e.children[n]||typeof e.children[n]==`string`||e.children[n].attrs.name==t&&(e.children=e.children.slice(0,n).concat(e.children.slice(n+1)))},n.XmlJSON.prototype.deleteAttribute=function(e,t){e.attrs[t]!==void 0&&e.attrs.pop(t)},n.XmlJSON.prototype.setAttribute=function(e,t,n){return e.attrs[t]=n,!1},n.XmlJSON.prototype.nodeCopy=function(e,t){if(!t)var t={};if(typeof t==`object`&&t.length===void 0)for(var n in e)typeof e[n]==`string`?t[n]=e[n]:typeof e[n]==`object`&&(e[n].length===void 0?t[n]=this.nodeCopy(e[n],{}):t[n]=this.nodeCopy(e[n],[]));else for(var r=0,i=e.length;r<i;r+=1)typeof e[r]==`string`?t[r]=e[r]:t[r]=this.nodeCopy(e[r],{});return t},n.XmlJSON.prototype.getNodesByName=function(e,t,n,r){if(!r)var r=[];if(!e||!e.children)return r;t===e.name&&(n?n===e.attrs.name&&r.push(e):r.push(e));for(var i=0,a=e.children.length;i<a;i+=1)typeof e.children[i]==`object`&&this.getNodesByName(e.children[i],t,n,r);return r},n.XmlJSON.prototype.nodeNameIs=function(e,t){return e===void 0?!1:t==e.name},n.XmlJSON.prototype.makeXml=function(e){return typeof e==`string`&&(e=e.slice(0,1)===`<`?this.jsonStringWalker.walkToObject(e):JSON.parse(e)),e},n.XmlJSON.prototype.insertChildNodeAfter=function(e,t,n,r){for(var i=0,a=e.children.length;i<a;i+=1)if(t===e.children[i]){e.children=e.children.slice(0,i).concat([r]).concat(e.children.slice(i+1));break}return e},n.XmlJSON.prototype.insertPublisherAndPlace=function(e){if(e.name===`group`){for(var t=!0,n=[`publisher`,`publisher-place`],r=0,i=e.children.length;r<i;r+=1){var a=n.indexOf(e.children[r].attrs.variable);if(e.children[r].name===`text`&&a>-1&&!e.children[r].attrs.prefix&&!e.children[r].attrs.suffix)n=n.slice(0,a).concat(n.slice(a+1));else{t=!1;break}}t&&!n.length&&(e.attrs[`has-publisher-and-publisher-place`]=!0)}for(var r=0,i=e.children.length;r<i;r+=1)typeof e.children[r]==`object`&&this.insertPublisherAndPlace(e.children[r])},n.XmlJSON.prototype.isChildOfSubstitute=function(e){if(e.length>0){var t=e.slice();return t.pop()===`substitute`?!0:this.isChildOfSubstitute(t)}return!1},n.XmlJSON.prototype.addMissingNameNodes=function(e,t){if(t||(t=[]),e.name===`names`&&!this.isChildOfSubstitute(t)){for(var n=!0,r=0,i=e.children.length;r<i;r++)if(e.children[r].name===`name`){n=!1;break}n&&(e.children=[{name:`name`,attrs:{},children:[]}].concat(e.children))}t.push(e.name);for(var r=0,i=e.children.length;r<i;r+=1)typeof e.children[r]==`object`&&this.addMissingNameNodes(e.children[r],t);t.pop()},n.XmlJSON.prototype.addInstitutionNodes=function(e){var t;if(e.name===`names`){for(var r={},i=-1,a=0,o=e.children.length;a<o;a+=1){if(e.children[a].name==`name`){for(var s in e.children[a].attrs)r[s]=e.children[a].attrs[s];r.delimiter=e.children[a].attrs.delimiter,r.and=e.children[a].attrs.and,i=a;for(var c=0,l=e.children[a].children.length;c<l;c+=1)if(e.children[a].children[c].attrs.name===`family`)for(var s in e.children[a].children[c].attrs)r[s]=e.children[a].children[c].attrs[s]}if(e.children[a].name==`institution`){i=-1;break}}if(i>-1){for(var t=this.nodeCopy(this.institution),a=0,o=n.INSTITUTION_KEYS.length;a<o;a+=1){var u=n.INSTITUTION_KEYS[a];r[u]!==void 0&&(t.children[0].attrs[u]=r[u]),r.delimiter&&(t.attrs.delimiter=r.delimiter),r.and&&(t.attrs.and=r.and)}e.children=e.children.slice(0,i+1).concat([t]).concat(e.children.slice(i+1))}}for(var a=0,o=e.children.length;a<o;a+=1)typeof e.children[a]!=`string`&&this.addInstitutionNodes(e.children[a])},n.XmlJSON.prototype.flagDateMacros=function(e){for(var t=0,n=e.children.length;t<n;t+=1)e.children[t].name===`macro`&&this.inspectDateMacros(e.children[t])&&(e.children[t].attrs[`macro-has-date`]=`true`)},n.XmlJSON.prototype.inspectDateMacros=function(e){if(!e||!e.children)return!1;if(e.name===`date`)return!0;for(var t=0,n=e.children.length;t<n;t+=1)if(this.inspectDateMacros(e.children[t]))return!0;return!1},n.stripXmlProcessingInstruction=function(e){return e&&(e=e.replace(/^<\?[^?]+\?>/,``),e=e.replace(/<!--[^>]+-->/g,``),e=e.replace(/^\s+/g,``),e=e.replace(/\s+$/g,``),e)},n.parseXml=function(e){var t={children:[]},n=[t.children];function r(e){e=e.split(/(?:\r\n|\n|\r)/).join(` `).replace(/>[	 ]+</g,`><`).replace(/<\!--.*?-->/g,``);for(var t=e.split(`><`),n=null,r=0,i=t.length;r<i;r++)r>0&&(t[r]=`<`+t[r]),r<t.length-1&&(t[r]=t[r]+`>`),typeof n!=`number`&&(t[r].slice(0,7)===`<style `||t[r].slice(0,8)==`<locale `)&&(n=r);t=t.slice(n);for(var r=t.length-2;r>-1;r--)if(t[r].slice(1).indexOf(`<`)===-1){var a=t[r].slice(0,5);t[r].slice(-2)!==`/>`&&(a===`<term`?t[r+1].slice(0,6)===`</term`&&(t[r]=t[r]+t[r+1],t=t.slice(0,r+1).concat(t.slice(r+2))):[`<sing`,`<mult`].indexOf(a)>-1&&t[r].slice(-2)!==`/>`&&t[r+1].slice(0,1)===`<`&&(t[r]=t[r]+t[r+1],t=t.slice(0,r+1).concat(t.slice(r+2))))}return t}function i(e){return e.split(`&amp;`).join(`&`).split(`&quot;`).join(`"`).split(`&gt;`).join(`>`).split(`&lt;`).join(`<`).replace(/&#([0-9]{1,6});/gi,function(e,t){var n=parseInt(t,10);return String.fromCharCode(n)}).replace(/&#x([a-f0-9]{1,6});/gi,function(e,t){var n=parseInt(t,16);return String.fromCharCode(n)})}function a(e){var t=e.match(/([^\'\"=	 ]+)=(?:\"[^\"]*\"|\'[^\']*\')/g);if(t)for(var n=0,r=t.length;n<r;n++)t[n]=t[n].replace(/=.*/,``);return t}function o(e,t){var n=RegExp(`^.*[	 ]+`+t+`=("(?:[^"]*)"|'(?:[^']*)').*$`),r=e.match(n);return r?r[1].slice(1,-1):null}function s(e){var t=RegExp(`^<([^	 />]+)`),n=e.match(t);return n?n[1]:null}function c(e){var t={};t.name=s(e),t.attrs={};var n=a(e);if(n)for(var r=0,c=n.length;r<c;r++){var l={name:n[r],value:o(e,n[r])};t.attrs[l.name]=i(l.value)}return t.children=[],t}function l(e){return i(e.match(/^.*>([^<]*)<.*$/)[1])}function u(e){n.slice(-1)[0].push(e)}function d(e){n.push(e.children)}function f(e){var t;e.slice(1).indexOf(`<`)>-1?(t=c(e.slice(0,e.indexOf(`>`)+1)),t.children=[l(e)],u(t)):e.slice(-2)===`/>`?(t=c(e),s(e)===`term`&&t.children.push(``),u(t)):e.slice(0,2)===`</`?n.pop():(t=c(e),u(t),d(t))}for(var p=r(e),m=0,h=p.length;m<h;m++){var g=p[m];f(g)}return t.children[0]},n.XmlDOM=function(e){this.dataObj=e,typeof DOMParser>`u`?(DOMParser=function(){},DOMParser.prototype.parseFromString=function(e,t){if(typeof ActiveXObject<`u`){var n=new ActiveXObject(`MSXML.DomDocument`);return n.async=!1,n.loadXML(e),n}else if(typeof XMLHttpRequest<`u`){var n=new XMLHttpRequest;return t||(t=`text/xml`),n.open(`GET`,`data:`+t+`;charset=utf-8,`+encodeURIComponent(e),!1),n.overrideMimeType&&n.overrideMimeType(t),n.send(null),n.responseXML}else if(typeof marknote<`u`)return new marknote.Parser().parse(e)},this.hasAttributes=function(e){return!!(e.attributes&&e.attributes.length)}):this.hasAttributes=function(e){return!!(e.attributes&&e.attributes.length)},this.importNode=function(e,t){return e.importNode===void 0?this._importNode(e,t,!0):e.importNode(t,!0)},this._importNode=function(e,t,n){switch(t.nodeType){case 1:var r=e.createElement(t.nodeName);if(t.attributes&&t.attributes.length>0)for(var i=0,a=t.attributes.length;i<a;)r.setAttribute(t.attributes[i].nodeName,t.getAttribute(t.attributes[i++].nodeName));if(n&&t.childNodes&&t.childNodes.length>0)for(var i=0,a=t.childNodes.length;i<a;)r.appendChild(this._importNode(e,t.childNodes[i++],n));return r;case 3:case 4:case 8:}},this.parser=new DOMParser;var t=this.parser.parseFromString(`<docco><institution institution-parts="long" delimiter=", " substitute-use-first="1" use-last="1"><institution-part name="long"/></institution></docco>`,`text/xml`);this.institution=t.getElementsByTagName(`institution`).item(0),this.institutionpart=t.getElementsByTagName(`institution-part`).item(0),this.ns=`http://purl.org/net/xbiblio/csl`},n.XmlDOM.prototype.clean=function(e){return e=e.replace(/<\?[^?]+\?>/g,``),e=e.replace(/<![^>]+>/g,``),e=e.replace(/^\s+/,``),e=e.replace(/\s+$/,``),e=e.replace(/^\n*/,``),e},n.XmlDOM.prototype.getStyleId=function(e,t){var n=``,r=`id`;t&&(r=`title`);var i=e.getElementsByTagName(r);return i&&i.length&&(i=i.item(0)),i&&(n=i.textContent),n||(n=i.innerText),n||(n=i.innerHTML),n},n.XmlDOM.prototype.children=function(e){var t,n,r,i;if(e){for(i=[],t=e.childNodes,n=0,r=t.length;n<r;n+=1)t[n].nodeName!=`#text`&&i.push(t[n]);return i}else return[]},n.XmlDOM.prototype.nodename=function(e){return e.nodeName},n.XmlDOM.prototype.attributes=function(e){var t={},n,r,i,a;if(e&&this.hasAttributes(e))for(n=e.attributes,i=0,a=n.length;i<a;i+=1)r=n[i],t[`@`+r.name]=r.value;return t},n.XmlDOM.prototype.content=function(e){return e.textContent===void 0?e.innerText===void 0?e.txt:e.innerText:e.textContent},n.XmlDOM.prototype.namespace={xml:`http://www.w3.org/XML/1998/namespace`},n.XmlDOM.prototype.numberofnodes=function(e){return e?e.length:0},n.XmlDOM.prototype.getAttributeName=function(e){return e.name},n.XmlDOM.prototype.getAttributeValue=function(e,t,n){var r=``;return n&&(t=n+`:`+t),e&&this.hasAttributes(e)&&e.getAttribute(t)&&(r=e.getAttribute(t)),r},n.XmlDOM.prototype.getNodeValue=function(e,t){var n=null;if(t){var r=e.getElementsByTagName(t);r.length>0&&(n=r[0].textContent===void 0?r[0].innerText===void 0?r[0].text:r[0].innerText:r[0].textContent)}return n===null&&e&&e.childNodes&&(e.childNodes.length==0||e.childNodes.length==1&&e.firstChild.nodeName==`#text`)&&(n=e.textContent===void 0?e.innerText===void 0?e.text:e.innerText:e.textContent),n===null&&(n=e),n},n.XmlDOM.prototype.setAttributeOnNodeIdentifiedByNameAttribute=function(e,t,n,r,i){var a,o,s,c;for(r.slice(0,1)===`@`&&(r=r.slice(1)),s=e.getElementsByTagName(t),a=0,o=s.length;a<o;a+=1)c=s[a],c.getAttribute(`name`)==n&&c.setAttribute(r,i)},n.XmlDOM.prototype.deleteNodeByNameAttribute=function(e,t){var n,r,i,a=e.childNodes;for(n=0,r=a.length;n<r;n+=1)i=a[n],!(!i||i.nodeType==i.TEXT_NODE)&&this.hasAttributes(i)&&i.getAttribute(`name`)==t&&e.removeChild(a[n])},n.XmlDOM.prototype.deleteAttribute=function(e,t){e.removeAttribute(t)},n.XmlDOM.prototype.setAttribute=function(e,t,n){return e.ownerDocument||(e=e.firstChild),[`function`,`unknown`].indexOf(typeof e.setAttribute)>-1&&e.setAttribute(t,n),!1},n.XmlDOM.prototype.nodeCopy=function(e){return e.cloneNode(!0)},n.XmlDOM.prototype.getNodesByName=function(e,t,n){var r=[],i=e.getElementsByTagName(t),a,o,s;for(o=0,s=i.length;o<s;o+=1)a=i.item(o),!(n&&!(this.hasAttributes(a)&&a.getAttribute(`name`)==n))&&r.push(a);return r},n.XmlDOM.prototype.nodeNameIs=function(e,t){return t==e.nodeName},n.XmlDOM.prototype.makeXml=function(e){return e||(e=`<docco><bogus/></docco>`),e=e.replace(/\s*<\?[^>]*\?>\s*\n*/g,``),this.parser.parseFromString(e,`application/xml`).firstChild},n.XmlDOM.prototype.insertChildNodeAfter=function(e,t,n,r){var i=this.importNode(t.ownerDocument,r);return e.replaceChild(i,t),e},n.XmlDOM.prototype.insertPublisherAndPlace=function(e){for(var t=e.getElementsByTagName(`group`),n=0,r=t.length;n<r;n+=1){for(var i=t.item(n),a=[],o=0,s=i.childNodes.length;o<s;o+=1)i.childNodes.item(o).nodeType!==1&&a.push(o);if(i.childNodes.length-a.length===2){for(var c=[],o=0,s=2;o<s;o+=1)if(!(a.indexOf(o)>-1)){for(var l=i.childNodes.item(o),u=[],d=0,f=l.childNodes.length;d<f;d+=1)l.childNodes.item(d).nodeType!==1&&u.push(d);if(l.childNodes.length-u.length===0&&(c.push(l.getAttribute(`variable`)),l.getAttribute(`suffix`)||l.getAttribute(`prefix`))){c=[];break}}c.indexOf(`publisher`)>-1&&c.indexOf(`publisher-place`)>-1&&i.setAttribute(`has-publisher-and-publisher-place`,!0)}}},n.XmlDOM.prototype.isChildOfSubstitute=function(e){return e.parentNode?e.parentNode.tagName.toLowerCase()===`substitute`?!0:this.isChildOfSubstitute(e.parentNode):!1},n.XmlDOM.prototype.addMissingNameNodes=function(e){for(var t=e.getElementsByTagName(`names`),n=0,r=t.length;n<r;n+=1){var i=t.item(n),a=i.getElementsByTagName(`name`);if((!a||a.length===0)&&!this.isChildOfSubstitute(i)){var o=i.ownerDocument.createElement(`name`);i.appendChild(o)}}},n.XmlDOM.prototype.addInstitutionNodes=function(e){var t=e.getElementsByTagName(`names`),r,i,a,o,s,c,l,u;for(l=0,u=t.length;l<u;l+=1)if(r=t.item(l),s=r.getElementsByTagName(`name`),s.length!=0&&(i=r.getElementsByTagName(`institution`),i.length==0)){a=this.importNode(e.ownerDocument,this.institution),o=a.getElementsByTagName(`institution-part`).item(0),c=s.item(0),r.insertBefore(a,c.nextSibling);for(var d=0,f=n.INSTITUTION_KEYS.length;d<f;d+=1){var p=n.INSTITUTION_KEYS[d],m=c.getAttribute(p);m&&o.setAttribute(p,m)}for(var h=c.getElementsByTagName(`name-part`),d=0,f=h.length;d<f;d+=1)if(h[d].getAttribute(`name`)===`family`)for(var g=0,_=n.INSTITUTION_KEYS.length;g<_;g+=1){var p=n.INSTITUTION_KEYS[g],m=h[d].getAttribute(p);m&&o.setAttribute(p,m)}}},n.XmlDOM.prototype.flagDateMacros=function(e){var t,n,r,i,a=e.getElementsByTagName(`macro`);for(t=0,n=a.length;t<n;t+=1)r=a.item(t),i=r.getElementsByTagName(`date`),i.length&&r.setAttribute(`macro-has-date`,`true`)},n.setupXml=function(e){var t={},r=null;return e===void 0?n.error(`unable to parse XML input`):typeof e==`string`?(e=e.replace(`^﻿`,``).replace(/^\s+/,``),t=e.slice(0,1)===`<`?n.parseXml(e):JSON.parse(e),r=new n.XmlJSON(t)):r=e.getAttribute===void 0?e.toXMLString===void 0?new n.XmlJSON(e):new n.XmlE4X(e):new n.XmlDOM(e),r||n.error(`citeproc-js error: unable to parse CSL style or locale object`),r},n.getSortCompare=function(e){if(n.stringCompare)return n.stringCompare;var t=this,r,i={sensitivity:`base`,ignorePunctuation:!0,numeric:!0};e||(e=`en-US`),r=function(r,a){return n.toLocaleLowerCase.call(t,r).localeCompare(n.toLocaleLowerCase.call(t,a),e,i)};var a=function(e){return e.replace(/^[\[\]\'\"]*/g,``)},o=function(){return r(`[x`,`x`)?function(e,t){return r(a(e),a(t))}:!1}();return function(e,t){return o?o(e,t):r(e,t)}},n.ambigConfigDiff=function(e,t){var n,r,i,a;if(e.names.length!==t.names.length)return 1;for(n=0,r=e.names.length;n<r;n+=1)if(e.names[n]!==t.names[n])return 1;else for(i=0,a=e.givens[n];i<a;i+=1)if(e.givens[n][i]!==t.givens[n][i])return 1;return e.disambiguate!=t.disambiguate||e.year_suffix!==t.year_suffix?1:0},n.cloneAmbigConfig=function(e,t){var n,r,i,a,o,s={};for(s.names=[],s.givens=[],s.year_suffix=!1,s.disambiguate=!1,n=0,r=e.names.length;n<r;n+=1)o=e.names[n],s.names[n]=o;for(n=0,r=e.givens.length;n<r;n+=1){for(o=[],i=0,a=e.givens[n].length;i<a;i+=1)o.push(e.givens[n][i]);s.givens.push(o)}return t?(s.year_suffix=t.year_suffix,s.disambiguate=t.disambiguate):(s.year_suffix=e.year_suffix,s.disambiguate=e.disambiguate),s},n.getAmbigConfig=function(){var e=this.tmp.disambig_request;return e||(e=this.tmp.disambig_settings),n.cloneAmbigConfig(e)},n.getMaxVals=function(){return this.tmp.names_max.mystack.slice()},n.getMinVal=function(){return this.tmp[`et-al-min`]},n.tokenExec=function(e,t,r){var i,a,o,s=!1;i=e.next,a=!1,e.test&&(i=function(t){return t?(this.tmp.jump.replace(`succeed`),e.succeed):(this.tmp.jump.replace(`fail`),e.fail)}.call(this,e.test(t,r)));for(var c=0,l=e.execs.length;c<l;c++)o=e.execs[c],a=o.call(e,this,t,r),a&&(i=a);return s&&n.debug(e.name+` (`+e.tokentype+`) ---> done`),i},n.expandMacro=function(e,t){var r=e.postponed_macro,i,a,o,s=e.strings.sort_direction;e=new n.Token(`group`,n.START);var c=!1,l=!1;i=this.cslXml.getNodesByName(this.cslXml.dataObj,`macro`,r),i.length&&(l=this.cslXml.getAttributeValue(i[0],`cslid`),c=this.cslXml.getAttributeValue(i[0],`macro-has-date`)),c&&(r=r+`@`+this.build.current_default_locale,o=function(e){e.tmp.extension&&(e.tmp[`doing-macro-with-date`]=!0)},e.execs.push(o)),this.build.macro_stack.indexOf(r)>-1?n.error(`CSL processor error: call to macro "`+r+`" would cause an infinite loop`):this.build.macro_stack.push(r),e.cslid=l,n.MODULE_MACROS[r]&&(e.juris=r,this.opt.update_mode=n.POSITION),n.Node.group.build.call(e,this,t,!0),this.cslXml.getNodeValue(i)||n.error(`CSL style error: undefined macro "`+r+`"`);var u=n.getMacroTarget.call(this,r);if(u&&(n.buildMacro.call(this,u,i),n.configureMacro.call(this,u)),!this.build.extension){var o=function(e){return function(t,r,i){for(var a=0;a<t.macros[e].length;)a=n.tokenExec.call(t,t.macros[e][a],r,i)}}(r),d=new n.Token(`text`,n.SINGLETON);d.execs.push(o),t.push(d)}a=new n.Token(`group`,n.END),a.strings.sort_direction=s,c&&(o=function(e){e.tmp.extension&&(e.tmp[`doing-macro-with-date`]=!1)},a.execs.push(o)),e.juris&&(a.juris=r),n.Node.group.build.call(a,this,t,!0),this.build.macro_stack.pop()},n.getMacroTarget=function(e){var t=!1;return this.build.extension?t=this[this.build.root+this.build.extension].tokens:this.macros[e]||(t=[],this.macros[e]=t),t},n.buildMacro=function(e,t){n.makeBuilder(this,e)(t.length===void 0?t:t[0])},n.configureMacro=function(e){this.build.extension||this.configureTokenList(e)},n.XmlToToken=function(e,t,r,i){var a=e.cslXml.nodename(this),o,s,c,l,u,d;if(!(e.build.skip&&e.build.skip!==a)){if(!a){o=e.cslXml.content(this),o&&(e.build.text=o);return}if(n.Node[e.cslXml.nodename(this)]||n.error(`Undefined node name "`+a+`".`),s=e.cslXml.attributes(this),c=n.setDecorations.call(this,e,s),l=new n.Token(a,t),t!==n.END||a===`if`||a===`else-if`||a===`layout`){for(var u in s)if(s.hasOwnProperty(u)){if(t===n.END&&u!==`@language`&&u!==`@locale`)continue;if(s.hasOwnProperty(u))if(n.Attributes[u])try{n.Attributes[u].call(l,e,``+s[u])}catch(e){n.error(u+` attribute: `+e)}else n.debug(`warning: undefined attribute "`+u+`" in style`)}l.decorations=c,n.DATE_VARIABLES.indexOf(s[`@variable`])>-1&&i.push(l.variables)}else t===n.END&&s[`@variable`]&&(l.hasVariable=!0,n.DATE_VARIABLES.indexOf(s[`@variable`])>-1&&(l.variables=i.pop()));d=r||e[e.build.area].tokens,n.Node[a].build.call(l,e,d,!0)}},n.DateParser=function(){for(var e=[[`明治`,1867],[`大正`,1911],[`昭和`,1925],[`平成`,1988]],t={},r=0,i=e.length;r<i;r++){var a=e[r][0],o=e[r][1];t[a]=o}for(var s=[],c={},r=0,i=e.length;r<i;r++){var l=e[r],o=l[0];s.push(o),c[l[0]]=l[1]}var u=s.join(`|`),d=RegExp(`(?:`+u+`)(?:[0-9]+)`),f=RegExp(`(?:`+u+`)(?:[0-9]+)`,`g`),p=/(\u6708|\u5E74)/g,m=/\u65E5/g,h=/\u301c/g,g=`([?0-9]{4}(?:%%NUMD%%[?0-9]{1,2}){0,2}(?![0-9])|(?:[?0-9]{1,2}%%NUMD%%){0,2}[?0-9]{4}(?![0-9])|[?0-9]{1,3}|[%%DATED%%]|[?~]|[^-/~?0-9]+)`,_=new RegExp(g.replace(/%%NUMD%%/g,`-`).replace(/%%DATED%%/g,`-`)),v=new RegExp(g.replace(/%%NUMD%%/g,`-`).replace(/%%DATED%%/g,`/`)),y=new RegExp(g.replace(/%%NUMD%%/g,`/`).replace(/%%DATED%%/g,`-`));this.monthStrings=`january february march april may june july august september october november december spring summer fall winter spring summer`.split(` `),this.setOrderDayMonth=function(){this.monthGuess=1,this.dayGuess=0},this.setOrderMonthDay=function(){this.monthGuess=0,this.dayGuess=1},this.resetDateParserMonths=function(){this.monthSets=[];for(var e=0,t=this.monthStrings.length;e<t;e++)this.monthSets.push([this.monthStrings[e]]);this.monthAbbrevs=[];for(var e=0,t=this.monthSets.length;e<t;e++){this.monthAbbrevs.push([]);for(var n=0,r=this.monthSets[e].length;n<r;n++)this.monthAbbrevs[e].push(this.monthSets[e][0].slice(0,3))}this.monthRexes=[];for(var e=0,t=this.monthAbbrevs.length;e<t;e++)this.monthRexes.push(RegExp(`(?:`+this.monthAbbrevs[e].join(`|`)+`)`))},this.addDateParserMonths=function(e){if(typeof e==`string`&&(e=e.split(/\s+/)),e.length!==12&&e.length!==16){n.debug(`month [+season] list of `+e.length+`, expected 12 or 16. Ignoring.`);return}for(var t=0,r=e.length;t<r;t++){for(var i=null,a=!1,o=3,s={},c=0,l=this.monthAbbrevs.length;c<l;c++){if(s[c]={},c===t){for(var u=0,d=this.monthAbbrevs[t].length;u<d;u++)if(this.monthAbbrevs[t][u]===e[t].slice(0,this.monthAbbrevs[t][u].length)){a=!0;break}}else for(var u=0,d=this.monthAbbrevs[c].length;u<d;u++)if(i=this.monthAbbrevs[c][u].length,this.monthAbbrevs[c][u]===e[t].slice(0,i)){for(;this.monthSets[c][u].slice(0,i)===e[t].slice(0,i);)if(i>e[t].length||i>this.monthSets[c][u].length){n.debug(`unable to disambiguate month string in date parser: `+e[t]);break}else i+=1;o=i,s[c][u]=i}for(var f in s)for(var p in s[f])i=s[f][p],f=parseInt(f,10),p=parseInt(p,10),this.monthAbbrevs[f][p]=this.monthSets[f][p].slice(0,i)}a||(this.monthSets[t].push(e[t]),this.monthAbbrevs[t].push(e[t].slice(0,o)))}this.monthRexes=[],this.monthRexStrs=[];for(var t=0,r=this.monthAbbrevs.length;t<r;t++)this.monthRexes.push(RegExp(`^(?:`+this.monthAbbrevs[t].join(`|`)+`)`)),this.monthRexStrs.push(`^(?:`+this.monthAbbrevs[t].join(`|`)+`)`);if(this.monthAbbrevs.length===18)for(var t=12,r=14;t<r;t++)this.monthRexes[t+4]=RegExp(`^(?:`+this.monthAbbrevs[t].join(`|`)+`)`),this.monthRexStrs[t+4]=`^(?:`+this.monthAbbrevs[t].join(`|`)+`)`},this.convertDateObjectToArray=function(e){e[`date-parts`]=[],e[`date-parts`].push([]);for(var t=0,n,r=0,i=3;r<i&&(n=[`year`,`month`,`day`][r],e[n]);r++)t+=1,e[`date-parts`][0].push(e[n]),delete e[n];e[`date-parts`].push([]);for(var r=0,i=t;r<i&&(n=[`year_end`,`month_end`,`day_end`][r],e[n]);r++)e[`date-parts`][1].push(e[n]),delete e[n];return e[`date-parts`][0].length!==e[`date-parts`][1].length&&e[`date-parts`].pop(),e},this.convertDateObjectToString=function(e){for(var t=[],r=0,i=3;r<i&&e[n.DATE_PARTS_ALL[r]];r+=1)t.push(e[n.DATE_PARTS_ALL[r]]);return t.join(`-`)},this._parseNumericDate=function(e,t,n,r){n||(n=``);for(var i=r.split(t),a=0,o=i.length;a<o;a++)if(i[a].length===4){e[`year`+n]=i[a].replace(/^0*/,``),i=a?i.slice(0,a):i.slice(1);break}for(var a=0,o=i.length;a<o;a++)i[a]=parseInt(i[a],10);if(i.length===1||i.length===2&&!i[1]){var s=i[0];s&&(e[`month`+n]=``+i[0])}else if(i.length===2)if(i[this.monthGuess]>12){var s=i[this.dayGuess],c=i[this.monthGuess];s&&(e[`month`+n]=``+s,c&&(e[`day`+n]=``+c))}else{var s=i[this.monthGuess],c=i[this.dayGuess];s&&(e[`month`+n]=``+s,c&&(e[`day`+n]=``+c))}},this.parseDateToObject=function(e){var t=e,r=-1,i=-1,a=!1,o;if(e){if(e=e.replace(/^(.*[0-9])T[0-9].*/,`$1`),e.slice(0,1)===`-`&&(a=!0,e=e.slice(1)),e.match(/^[0-9]{1,3}$/))for(;e.length<4;)e=`0`+e;e=``+e,e=e.replace(/\s*[0-9]{2}:[0-9]{2}(?::[0-9]+)/,``);var s=e.match(p);if(s){e=e.replace(/\s+/g,``),e=e.replace(m,``),e=e.replace(p,`-`),e=e.replace(h,`/`),e=e.replace(/\-\//g,`/`),e=e.replace(/-$/g,``);var l=e.split(d);o=[];var u=e.match(f);if(u){for(var g=[],b=0,x=u.length;b<x;b++)g=g.concat(u[b].match(/([^0-9]+)([0-9]+)/).slice(1));for(var b=0,x=l.length;b<x;b++)if(o.push(l[b]),b!==x-1){var S=b*2;o.push(g[S]),o.push(g[S+1])}}else o=l;for(var b=1,x=o.length;b<x;b+=3)o[b+1]=c[o[b]]+parseInt(o[b+1],10),o[b]=``;e=o.join(``),e=e.replace(/\s*-\s*$/,``).replace(/\s*-\s*\//,`/`),e=e.replace(/\.\s*$/,``),e=e.replace(/\.(?! )/,``),r=e.indexOf(`/`),i=e.indexOf(`-`)}}e=e.replace(/([A-Za-z])\./g,`$1`);var C=``,w=``,T={},E,D;if(e.slice(0,1)===`"`&&e.slice(-1)===`"`)return T.literal=e.slice(1,-1),T;r>-1&&i>-1?e.split(`/`).length>3?(E=`-`,e=e.replace(/\_/g,`-`),D=`/`,o=e.split(y)):(E=`/`,e=e.replace(/\_/g,`/`),D=`-`,o=e.split(v)):(e=e.replace(/\//g,`-`),e=e.replace(/\_/g,`-`),E=`-`,D=`-`,o=e.split(_));for(var O=[],b=0,x=o.length;b<x;b++){var s=o[b].match(/^\s*([\-\/]|[^\-\/\~\?0-9]+|[\-~?0-9]+)\s*$/);s&&O.push(s[1])}var k=O.indexOf(E),A=[],j=!1;k>-1?(A.push([0,k]),A.push([k+1,O.length]),j=!0):A.push([0,O.length]);for(var M=``,b=0,x=A.length;b<x;b++){var N=A[b],P=O.slice(N[0],N[1]);outer:for(var F=0,I=P.length;F<I;F++){var L=P[F];if(L.indexOf(D)>-1){this._parseNumericDate(T,D,M,L);continue}if(L.match(/[0-9]{4}/)){T[`year`+M]=L.replace(/^0*/,``);continue}(L===`~`||L===`?`||L===`c`||L.match(/^cir/))&&(T.circa=!0);for(var R=0,z=this.monthRexes.length;R<z;R++)if(L.toLocaleLowerCase().match(this.monthRexes[R])){T[`month`+M]=``+(parseInt(R,10)+1);continue outer}if(L.match(/^[0-9]+$/)&&(C=L),L.toLocaleLowerCase().match(/^bc/)&&C){T[`year`+M]=``+C*-1,C=``;continue}if(L.toLocaleLowerCase().match(/^ad/)&&C){T[`year`+M]=``+C,C=``;continue}if(L.toLocaleLowerCase().match(/(?:mic|tri|hil|eas)/)&&!T[`season`+M]){w=L;continue}}C&&(T[`day`+M]=C,C=``),w&&!T[`season`+M]&&(T[`season`+M]=w.trim(),w=``),M=`_end`}if(j)for(var F=0,I=n.DATE_PARTS_ALL.length;F<I;F++){var B=n.DATE_PARTS_ALL[F];T[B]&&!T[B+`_end`]?T[B+`_end`]=T[B]:!T[B]&&T[B+`_end`]&&(T[B]=T[B+`_end`])}(!T.year||T.year&&T.day&&!T.month)&&(T={literal:t});for(var ee=[`year`,`month`,`day`,`year_end`,`month_end`,`day_end`],b=0,x=ee.length;b<x;b++){var te=ee[b];typeof T[te]==`string`&&T[te].match(/^[0-9]+$/)&&(T[te]=parseInt(T[te],10))}return a&&Object.keys(T).indexOf(`year`)>-1&&(T.year*=-1),T},this.parseDateToArray=function(e){return this.convertDateObjectToArray(this.parseDateToObject(e))},this.parseDateToString=function(e){return this.convertDateObjectToString(this.parseDateToObject(e))},this.parse=function(e){return this.parseDateToObject(e)},this.setOrderMonthDay(),this.resetDateParserMonths()},n.DateParser=new n.DateParser,n.Engine=function(e,t,r,i){var a,o;for(var s in this.processor_version=n.PROCESSOR_VERSION,this.csl_version=`1.0`,this.sys=e,typeof Object.assign!=`function`&&Object.defineProperty(Object,`assign`,{value:function(e){if(e==null)throw TypeError(`Cannot convert undefined or null to object`);for(var t=Object(e),n=1;n<arguments.length;n++){var r=arguments[n];if(r!=null)for(var i in r)Object.prototype.hasOwnProperty.call(r,i)&&(t[i]=r[i])}return t},writable:!0,configurable:!0}),e.variableWrapper&&(n.VARIABLE_WRAPPER_PREPUNCT_REX=RegExp(`^([`+[` `].concat(n.SWAPPING_PUNCTUATION).join(``)+`]*)(.*)`)),n.retrieveStyleModule&&(this.sys.retrieveStyleModule=n.retrieveStyleModule),n.getAbbreviation&&(this.sys.getAbbreviation=n.getAbbreviation),this.sys.stringCompare&&(n.stringCompare=this.sys.stringCompare),this.sys.AbbreviationSegments=n.AbbreviationSegments,this.transform=new n.Transform(this),this.setParseNames=function(e){this.opt[`parse-names`]=e},this.opt=new n.Engine.Opt,this.tmp=new n.Engine.Tmp,this.build=new n.Engine.Build,this.fun=new n.Engine.Fun(this),this.configure=new n.Engine.Configure,this.citation_sort=new n.Engine.CitationSort,this.bibliography_sort=new n.Engine.BibliographySort,this.citation=new n.Engine.Citation(this),this.bibliography=new n.Engine.Bibliography,this.intext=new n.Engine.InText,this.output=new n.Output.Queue(this),this.dateput=new n.Output.Queue(this),this.cslXml=n.setupXml(t),n.SYS_OPTIONS){var c=n.SYS_OPTIONS[s];typeof this.sys[c]==`boolean`&&(this.opt.development_extensions[c]=this.sys[c])}(this.opt.development_extensions.uppercase_subtitles||this.opt.development_extensions.implicit_short_title)&&(this.opt.development_extensions.main_title_from_short_title=!0),this.opt.development_extensions.csl_reverse_lookup_support&&(this.build.cslNodeId=0,this.setCslNodeIds=function(e,t){var n=this.cslXml.children(e);this.cslXml.setAttribute(e,`cslid`,this.build.cslNodeId),this.opt.nodenames.push(t),this.build.cslNodeId+=1;for(var r=0,i=this.cslXml.numberofnodes(n);r<i;r+=1)t=this.cslXml.nodename(n[r]),t&&this.setCslNodeIds(n[r],t)},this.setCslNodeIds(this.cslXml.dataObj,`style`)),this.cslXml.addMissingNameNodes(this.cslXml.dataObj),this.cslXml.addInstitutionNodes(this.cslXml.dataObj),this.cslXml.insertPublisherAndPlace(this.cslXml.dataObj),this.cslXml.flagDateMacros(this.cslXml.dataObj),a=this.cslXml.attributes(this.cslXml.dataObj),a[`@sort-separator`]===void 0&&this.cslXml.setAttribute(this.cslXml.dataObj,`sort-separator`,`, `),this.opt[`initialize-with-hyphen`]=!0,this.setStyleAttributes(),this.opt.xclass=this.cslXml.getAttributeValue(this.cslXml.dataObj,`class`),this.opt.class=this.opt.xclass,this.opt.styleID=this.cslXml.getStyleId(this.cslXml.dataObj),this.opt.styleName=this.cslXml.getStyleId(this.cslXml.dataObj,!0),this.opt.version.slice(0,4)===`1.1m`&&(this.opt.development_extensions.consolidate_legal_items=!0,this.opt.development_extensions.consolidate_container_items=!0,this.opt.development_extensions.main_title_from_short_title=!0,this.opt.development_extensions.expect_and_symbol_form=!0,this.opt.development_extensions.require_explicit_legal_case_title_short=!0,this.opt.development_extensions.force_jurisdiction=!0,this.opt.development_extensions.force_title_abbrev_fallback=!0),r&&(r=r.replace(`_`,`-`),r=n.normalizeLocaleStr(r)),this.opt[`default-locale`][0]&&(this.opt[`default-locale`][0]=this.opt[`default-locale`][0].replace(`_`,`-`),this.opt[`default-locale`][0]=n.normalizeLocaleStr(this.opt[`default-locale`][0])),r&&i&&(this.opt[`default-locale`]=[r]),r&&!i&&this.opt[`default-locale`][0]&&(r=this.opt[`default-locale`][0]),this.opt[`default-locale`].length===0&&(r||(r=`en-US`),this.opt[`default-locale`].push(`en-US`)),r||(r=this.opt[`default-locale`][0]),o=n.localeResolve(r),this.opt.lang=o.best,this.opt[`default-locale`][0]=o.best,this.locale={},this.opt[`default-locale-sort`]||(this.opt[`default-locale-sort`]=this.opt[`default-locale`][0]),`dale|`.localeCompare(`daleb`,this.opt[`default-locale-sort`])>-1?this.opt.sort_sep=`@`:this.opt.sort_sep=`|`,this.localeConfigure(o);function l(e){var e=e.slice();return RegExp(`(?:(?:[?!:]*\\s+|-|^)(?:`+e.join(`|`)+`)(?=[!?:]*\\s+|-|$))`,`g`)}this.locale[this.opt.lang].opts[`skip-words-regexp`]=l(this.locale[this.opt.lang].opts[`skip-words`]),this.output.adjust=new n.Output.Queue.adjust(this.getOpt(`punctuation-in-quote`)),this.registry=new n.Registry(this),this.macros={},this.build.area=`citation`;var u=this.cslXml.getNodesByName(this.cslXml.dataObj,this.build.area);this.buildTokenLists(u,this[this.build.area].tokens),this.build.area=`bibliography`;var u=this.cslXml.getNodesByName(this.cslXml.dataObj,this.build.area);this.buildTokenLists(u,this[this.build.area].tokens),this.build.area=`intext`;var u=this.cslXml.getNodesByName(this.cslXml.dataObj,this.build.area);this.buildTokenLists(u,this[this.build.area].tokens),this.opt.parallel.enable&&(this.parallel=new n.Parallel(this)),this.juris={},this.configureTokenLists(),this.disambiguate=new n.Disambiguation(this),this.splice_delimiter=!1,this.fun.dateparser=n.DateParser,this.fun.flipflopper=new n.Util.FlipFlopper(this),this.setCloseQuotesArray(),this.fun.ordinalizer.init(this),this.fun.long_ordinalizer.init(this),this.fun.page_mangler=n.Util.PageRangeMangler.getFunction(this,`page`),this.fun.year_mangler=n.Util.PageRangeMangler.getFunction(this,`year`),this.setOutputFormat(`html`)},n.Engine.prototype.setCloseQuotesArray=function(){var e=[];e.push(this.getTerm(`close-quote`)),e.push(this.getTerm(`close-inner-quote`)),e.push(`"`),e.push(`'`),this.opt.close_quotes_array=e},n.makeBuilder=function(e,t){var r=[],i=[];function a(a){i.push(a),n.XmlToToken.call(a,e,n.START,t,r)}function o(){var a=i.pop();n.XmlToToken.call(a,e,n.END,t,r)}function s(i){n.XmlToToken.call(i,e,n.SINGLETON,t,r)}function c(t,r,i){i||(i=[]),t||(t=[]),t.length===void 0&&(t=[t]);for(var l=0;l<t.length;l++){var u=t[l];e.cslXml.nodename(u)!==null&&(r&&e.cslXml.nodename(u)===`date`&&(n.Util.fixDateNode.call(e,r,l,u),u=e.cslXml.children(r)[l]),e.cslXml.numberofnodes(e.cslXml.children(u))?(a(u),c(e.cslXml.children(u),u,i),o()):s(u))}}return c},n.Engine.prototype.buildTokenLists=function(e,t){this.cslXml.getNodeValue(e)&&n.makeBuilder(this,t)(e.length===void 0?e:e[0])},n.Engine.prototype.setStyleAttributes=function(){var e,t,r,e={};for(r in e.name=this.cslXml.nodename(this.cslXml.dataObj),t=this.cslXml.attributes(this.cslXml.dataObj),t)t.hasOwnProperty(r)&&n.Attributes[r].call(e,this,t[r])},n.Engine.prototype.getTerm=function(e,t,r,i,a,o){e&&e.match(/[A-Z]/)&&e===e.toUpperCase()&&(n.debug(`Warning: term key is in uppercase form: `+e),e=e.toLowerCase());var s=o?this.opt[`default-locale`][0]:this.opt.lang,c=n.Engine.getField(n.LOOSE,this.locale[s].terms,e,t,r,i);return!c&&e===`range-delimiter`&&(c=`–`),c===void 0&&(a===n.STRICT?n.error(`Error in getTerm: term "`+e+`" does not exist.`):a===n.TOLERANT&&(c=``)),c&&(this.tmp.cite_renders_content=!0),c},n.Engine.prototype.getDate=function(e,t){var n=t?this.opt[`default-locale`]:this.opt.lang;return this.locale[n].dates[e]?this.locale[n].dates[e]:!1},n.Engine.prototype.getOpt=function(e){return this.locale[this.opt.lang].opts[e]===void 0?!1:this.locale[this.opt.lang].opts[e]},n.Engine.prototype.getVariable=function(e,t,r,i){return n.Engine.getField(n.LOOSE,e,t,r,i)},n.Engine.prototype.getDateNum=function(e,t){return e===void 0?0:e[t]},n.Engine.getField=function(e,t,r,i,a,o){var s=``,c,l,u,d,f;if(t[r]===void 0)if(e===n.STRICT)n.error(`Error in getField: term "`+r+`" does not exist.`);else return;for(f=o&&t[r][o]?t[r][o]:t[r],c=[],i===`symbol`?c=[`symbol`,`short`]:i===`verb-short`?c=[`verb-short`,`verb`]:i!==`long`&&(c=[i]),c=c.concat([`long`]),d=c.length,u=0;u<d;u+=1)if(l=c[u],typeof f==`string`||typeof f==`number`)s=f;else if(f[l]!==void 0){s=typeof f[l]==`string`||typeof f[l]==`number`?f[l]:typeof a==`number`?f[l][a]:f[l][0];break}return s},n.Engine.prototype.configureTokenLists=function(){var e,t,r=n.AREAS.length;for(t=0;t<r;t+=1){e=n.AREAS[t];var i=this[e].tokens;this.configureTokenList(i)}return this.version=n.version,this.state},n.Engine.prototype.configureTokenList=function(e){var t=[`year`,`month`,`day`],r,i,a,o,s,c=e.length-1,l;for(o=c;o>-1;o+=-1){if(r=e[o],r.name===`date`&&n.END===r.tokentype&&(i=[]),r.name===`date-part`&&r.strings.name)for(l=t.length,s=0;s<l;s+=1)a=t[s],a===r.strings.name&&i.push(r.strings.name);r.name===`date`&&n.START===r.tokentype&&(i.reverse(),r.dateparts=i),r.next=o+1,r.name&&n.Node[r.name].configure&&n.Node[r.name].configure.call(r,this,o)}},n.Engine.prototype.refetchItems=function(e){for(var t=[],n=0,r=e.length;n<r;n+=1)t.push(this.refetchItem(``+e[n]));return t},n.ITERATION=0,n.Engine.prototype.retrieveItem=function(e){var t,r,i;if(!this.tmp.loadedItemIDs[e])this.tmp.loadedItemIDs[e]=!0;else return this.registry.refhash[e];if(this.opt.development_extensions.normalize_lang_keys_to_lowercase&&typeof this.opt.development_extensions.normalize_lang_keys_to_lowercase==`boolean`){for(var i=0,a=this.opt[`default-locale`].length;i<a;i+=1)this.opt[`default-locale`][i]=this.opt[`default-locale`][i].toLowerCase();for(var i=0,a=this.opt[`locale-translit`].length;i<a;i+=1)this.opt[`locale-translit`][i]=this.opt[`locale-translit`][i].toLowerCase();for(var i=0,a=this.opt[`locale-translat`].length;i<a;i+=1)this.opt[`locale-translat`][i]=this.opt[`locale-translat`][i].toLowerCase();this.opt.development_extensions.normalize_lang_keys_to_lowercase=100}if(n.ITERATION+=1,t=JSON.parse(JSON.stringify(this.sys.retrieveItem(``+e))),this.opt.development_extensions.normalize_lang_keys_to_lowercase){if(t.multi){if(t.multi._keys)for(var o in t.multi._keys)for(var s in t.multi._keys[o])s!==s.toLowerCase()&&(t.multi._keys[o][s.toLowerCase()]=t.multi._keys[o][s],delete t.multi._keys[o][s]);if(t.multi.main)for(var o in t.multi.main)t.multi.main[o]=t.multi.main[o].toLowerCase()}for(var i=0,a=n.NAME_VARIABLES.length;i>a;i+=1){var c=n.NAME_VARIABLES[i];if(t[c]&&t[c].multi)for(var l=0,u=t[c].length;l<u;l+=1){var d=t[c][l];if(d.multi){if(d.multi._key)for(var s in d.multi._key)s!==s.toLowerCase()&&(d.multi._key[s.toLowerCase()]=d.multi._key[s],delete d.multi._key[s]);d.multi.main&&(d.multi.main=d.multi.main.toLowerCase())}}}}if(t.language&&t.language.match(/[><]/)){var r=t.language.match(/(.*?)([<>])(.*)/);r[2]===`<`?(t[`language-name`]=r[1],t[`language-name-original`]=r[3]):(t[`language-name`]=r[3],t[`language-name-original`]=r[1]),this.opt.multi_layout?t[`language-name-original`]&&(t.language=t[`language-name-original`]):t[`language-name`]&&(t.language=t[`language-name`])}if(t.page){t[`page-first`]=t.page;var r=(``+t.page).split(/\s*(?:&|, |-|\u2013)\s*/);r[0].slice(-1)!==`\\`&&(t[`page-first`]=r[0])}for(var s in this.opt.development_extensions.field_hack&&t.note&&n.parseNoteFieldHacks(t,!1,this.opt.development_extensions.allow_field_hack_date_override),t)if(n.DATE_VARIABLES.indexOf(s.replace(/^alt-/,``))>-1){var f=t[s];f&&(this.opt.development_extensions.raw_date_parsing&&f.raw&&(!f[`date-parts`]||f[`date-parts`].length===0)&&(f=this.fun.dateparser.parseDateToObject(f.raw)),t[s]=this.dateParseArray(f))}if(this.opt.development_extensions.consolidate_legal_items&&t.type&&[`bill`,`gazette`,`legislation`,`regulation`,`treaty`].indexOf(t.type)>-1){for(var p,m=[`type`,`title`,`jurisdiction`,`genre`,`volume`,`container-title`],h=[],i=0,a=m.length;i<a;i+=1)p=m[i],t[p]&&h.push(t[p]);m=[`original-date`,`issued`];for(var i=0,a=m.length;i<a;i+=1)if(p=m[i],t[p]&&t[p].year){var g=t[p].year;h.push(g);break}t.legislation_id=h.join(`::`)}if(this.bibliography.opt.track_container_items&&this.bibliography.opt.track_container_items.indexOf(t.type)>-1){for(var p,m=[`type`,`container-title`,`publisher`,`edition`],_=[],i=0,a=m.length;i<a;i+=1)p=m[i],t[p]&&_.push(t[p]);t.container_id=_.join(`::`)}if(this.opt.development_extensions.force_jurisdiction&&typeof t.authority==`string`&&(t.authority=[{literal:t.authority,multi:{_key:{}}}],t.multi&&t.multi._keys&&t.multi._keys.authority))for(var s in t.authority[0].multi._key={},t.multi._keys.authority)t.authority[0].multi._key[s]={literal:t.multi._keys.authority[s]};if(t[`title-short`]||(t[`title-short`]=t.shortTitle),this.opt.development_extensions.main_title_from_short_title){var v=this.opt[`default-locale`][0].slice(0,2).toLowerCase()===`fr`;n.extractTitleAndSubtitle.call(this,t,v)}var y=[`bill`,`legal_case`,`legislation`,`gazette`,`regulation`].indexOf(t.type)>-1;this.opt.development_extensions.force_jurisdiction&&y&&(t.jurisdiction||(t.jurisdiction=`us`));var b;if(!y&&t.title&&this.sys.getAbbreviation){t.jurisdiction,b=this.sys.normalizeAbbrevsKey?this.sys.normalizeAbbrevsKey(`title`,t.title):t.title;var x=this.transform.loadAbbreviation(t.jurisdiction,`title`,b,t.language);this.transform.abbrevs[x].title&&this.transform.abbrevs[x].title[b]&&(t[`title-short`]=this.transform.abbrevs[x].title[b])}if(t[`container-title-short`]||(t[`container-title-short`]=t.journalAbbreviation),t[`container-title`]&&this.sys.getAbbreviation){b=this.sys.normalizeAbbrevsKey?this.sys.normalizeAbbrevsKey(t[`container-title`]):t[`container-title`];var x=this.transform.loadAbbreviation(t.jurisdiction,`container-title`,b,t.language);this.transform.abbrevs[x][`container-title`]&&this.transform.abbrevs[x][`container-title`][b]&&(t[`container-title-short`]=this.transform.abbrevs[x][`container-title`][b])}if(t.jurisdiction&&(t.country=t.jurisdiction.split(`:`)[0]),this.registry.refhash[e]){if(JSON.stringify(this.registry.refhash[e])!=JSON.stringify(t)){for(var s in this.registry.refhash[e])delete this.registry.refhash[e][s];this.tmp.taintedItemIDs[t.id]=!0,Object.assign(this.registry.refhash[e],t)}}else this.registry.refhash[e]=t;return this.registry.refhash[e]},n.Engine.prototype.refetchItem=function(e){return this.registry.refhash[e]},n.Engine.prototype.setOpt=function(e,t,n){e.name===`style`||e.name===`cslstyle`?(this.opt.inheritedAttributes[t]=n,this.citation.opt.inheritedAttributes[t]=n,this.bibliography.opt.inheritedAttributes[t]=n):[`citation`,`bibliography`].indexOf(e.name)>-1?this[e.name].opt.inheritedAttributes[t]=n:e.strings[t]=n},n.Engine.prototype.inheritOpt=function(e,t,n,r){if(e.strings[t]!==void 0)return e.strings[t];var i=this[this.tmp.root].opt.inheritedAttributes[n||t];return i===void 0?r:i},n.Engine.prototype.remapSectionVariable=function(e){for(var t=0,r=e.length;t<r;t+=1){var i=e[t][0],a=e[t][1];if([`bill`,`gazette`,`legislation`,`regulation`,`treaty`].indexOf(i.type)>-1){if(a.locator){a.locator=a.locator.trim();var o=a.locator.match(n.STATUTE_SUBDIV_PLAIN_REGEX_FRONT);o||(a.label?a.locator=n.STATUTE_SUBDIV_STRINGS_REVERSE[a.label]+` `+a.locator:a.locator=`p. `+a.locator)}var s=null;if(i.section){i.section=i.section.trim();var o=i.section.match(n.STATUTE_SUBDIV_PLAIN_REGEX_FRONT);o?s=o[0].trim():(i.section=`sec. `+i.section,s=`sec.`)}if(i.section)if(!a.locator)a.locator=i.section;else{var o=a.locator.match(/^([^ ]*)\s*(.*)/),c=` `;o?(o[1]===`p.`&&s!==`p.`&&(a.locator=o[2]),[`[`,`(`,`.`,`,`,`;`,`:`,`?`].indexOf(a.locator.slice(0,1))>-1&&(c=``)):c=``,a.locator=i.section+c+a.locator}a.label=``}}},n.Engine.prototype.setNumberLabels=function(e){if(e.number&&[`bill`,`gazette`,`legislation`,`regulation`,`treaty`].indexOf(e.type)>-1&&this.opt.development_extensions.consolidate_legal_items&&!this.tmp.shadow_numbers.number){this.tmp.shadow_numbers.number={},this.tmp.shadow_numbers.number.values=[],this.tmp.shadow_numbers.number.plural=0,this.tmp.shadow_numbers.number.numeric=!1,this.tmp.shadow_numbers.number.label=!1;var t=``+e.number;t=t.split(`\\`).join(``);var r=t.split(/\s+/)[0],i=n.STATUTE_SUBDIV_STRINGS[r];if(i){var a=t.split(n.STATUTE_SUBDIV_PLAIN_REGEX);if(a.length>1){for(var o=[],s=1,c=a.length;s<c;s+=1)o.push(a[s].replace(/\s*$/,``).replace(/^\s*/,``));t=o.join(` `)}else t=a[0];this.tmp.shadow_numbers.number.label=i,this.tmp.shadow_numbers.number.values.push([`Blob`,t,!1]),this.tmp.shadow_numbers.number.numeric=!1}else this.tmp.shadow_numbers.number.values.push([`Blob`,t,!1]),this.tmp.shadow_numbers.number.numeric=!0}},n.substituteOne=function(e){return function(t,n){return n?e.replace(`%%STRING%%`,n):``}},n.substituteTwo=function(e){return function(t){var n=e.replace(`%%PARAM%%`,t);return function(e,t){return t?n.replace(`%%STRING%%`,t):``}}},n.Mode=function(e){var t={},r=n.Output.Formats[e],i,a,o,s;for(i in r){if(i.slice(0,1)!==`@`){t[i]=r[i];continue}a=!1,o=r[i],s=i.split(`/`),typeof o==`string`&&o.indexOf(`%%STRING%%`)>-1?a=o.indexOf(`%%PARAM%%`)>-1?n.substituteTwo(o):n.substituteOne(o):typeof o==`boolean`&&!o?a=n.Output.Formatters.passthrough:typeof o==`function`?a=o:n.error(`Bad `+e+` config entry for `+i+`: `+o),s.length===1?t[s[0]]=a:s.length===2&&(t[s[0]]||(t[s[0]]={}),t[s[0]][s[1]]=a)}return t},n.setDecorations=function(e,t){var r=[],i,a;for(a in n.FORMAT_KEY_SEQUENCE){var i=n.FORMAT_KEY_SEQUENCE[a];t[i]&&(r.push([i,t[i]]),delete t[i])}return r},n.Doppeler=function(e,t){var n=RegExp(`(`+e+`)`,`g`),r=new RegExp(e,`g`);this.split=function(e){t&&(e=t(e));var i=e.match(n);if(!i)return{tags:[],strings:[e]};for(var a=e.split(r),o=i.length-1;o>-1;o--)typeof i[o]==`number`&&(i[o]=``),i[o]===`'`&&a[o+1].length>0&&(a[o+1]=i[o]+a[o+1],i[o]=``);return{tags:i,strings:a,origStrings:a.slice()}},this.join=function(e){for(var t=e.strings.slice(-1),n=e.tags.length-1;n>-1;n--)t.push(e.tags[n]),t.push(e.strings[n]);return t.reverse(),t.join(``)}},n.Engine.prototype.normalDecorIsOrphan=function(e,t){if(t[1]===`normal`){for(var n=!1,r=this.tmp.area===`citation`?[this.citation.opt.layout_decorations].concat(e.alldecor):e.alldecor,i=r.length-1;i>-1;i+=-1)for(var a=r[i].length-1;a>-1;a+=-1)r[i][a][0]===t[0]&&r[i][a][1]!==`normal`&&(n=!0);if(!n)return!0}return!1},n.Engine.prototype.getCitationLabel=function(e){var t=``,r=this.getTrigraphParams(),i=r[0],a=this.getTerm(`reference`,`short`,0);a===void 0&&(a=`reference`),a=a.replace(`.`,``),a=a.slice(0,1).toUpperCase()+a.slice(1);for(var o=0,s=n.NAME_VARIABLES.length;o<s;o+=1){var c=n.NAME_VARIABLES[o];if(e[c]){var l=e[c];i=l.length>r.length?r[r.length-1]:r[l.length-1];for(var u=0,d=l.length;u<d&&u!==i.authors.length;u+=1){var f=this.nameOutput.getName(l[u],`locale-translit`,!0).name;f&&f.family?(a=f.family,a=a.replace(/^([ \'\u2019a-z]+\s+)/,``)):f&&f.literal&&(a=f.literal);var p=a.toLowerCase().match(/^(a\s+|the\s+|an\s+)/);if(p&&(a=a.slice(p[1].length)),a=a.replace(n.ROMANESQUE_NOT_REGEXP,``),!a)break;a=a.slice(0,i.authors[u]),a.length>1?a=a.slice(0,1).toUpperCase()+a.slice(1).toLowerCase():a.length===1&&(a=a.toUpperCase()),t+=a}break}}if(!t&&e.title){for(var m=this.locale[this.opt.lang].opts[`skip-words`],h=e.title.split(/\s+/),o=h.length-1;o>-1;o--)m.indexOf(h[o])>-1&&(h=h.slice(0,o).concat(h.slice(o+1)));var g=h.join(``);g=g.slice(0,r[0].authors[0]),g.length>1?g=g.slice(0,1).toUpperCase()+g.slice(1).toLowerCase():g.length===1&&(g=g.toUpperCase()),t=g}var _=`0000`;return e.issued&&e.issued.year&&(_=``+e.issued.year),_=_.slice(i.year*-1),t+=_,t},n.Engine.prototype.getTrigraphParams=function(){var e=[],t=this.opt.trigraph.split(`:`);(!this.opt.trigraph||this.opt.trigraph.slice(0,1)!==`A`)&&n.error(`Bad trigraph definition: `+this.opt.trigraph);for(var r=0,i=t.length;r<i;r+=1){for(var a=t[r],o={authors:[],year:0},s=0,c=a.length;s<c;s+=1)switch(a.slice(s,s+1)){case`A`:o.authors.push(1);break;case`a`:o.authors[o.authors.length-1]+=1;break;case`0`:o.year+=1;break;default:n.error(`Invalid character in trigraph definition: `+this.opt.trigraph)}e.push(o)}return e},n.Engine.prototype.setOutputFormat=function(e){this.opt.mode=e,this.fun.decorate=n.Mode(e),this.output[e]||(this.output[e]={},this.output[e].tmp={})},n.Engine.prototype.getSortFunc=function(){return function(e,t){return e=e.split(`-`),t=t.split(`-`),e.length<t.length?1:e.length>t.length?-1:(e=e.slice(-1)[0],t=t.slice(-1)[0],e.length<t.length?1:e.length>t.length?-1:0)}},n.Engine.prototype.setLangTagsForCslSort=function(e){var t,n;if(e)for(this.opt[`locale-sort`]=[],t=0,n=e.length;t<n;t+=1)this.opt[`locale-sort`].push(e[t]);this.opt[`locale-sort`].sort(this.getSortFunc())},n.Engine.prototype.setLangTagsForCslTransliteration=function(e){var t,n;if(this.opt[`locale-translit`]=[],e)for(t=0,n=e.length;t<n;t+=1)this.opt[`locale-translit`].push(e[t]);this.opt[`locale-translit`].sort(this.getSortFunc())},n.Engine.prototype.setLangTagsForCslTranslation=function(e){var t,n;if(this.opt[`locale-translat`]=[],e)for(t=0,n=e.length;t<n;t+=1)this.opt[`locale-translat`].push(e[t]);this.opt[`locale-translat`].sort(this.getSortFunc())},n.Engine.prototype.setLangPrefsForCites=function(e,t){var n=this.opt[`cite-lang-prefs`];t||(t=function(e){return e.toLowerCase()});for(var r=[`Persons`,`Institutions`,`Titles`,`Journals`,`Publishers`,`Places`],i=0,a=r.length;i<a;i+=1){var o=t(r[i]),s=r[i].toLowerCase();if(e[o]){for(var c=[];e[o].length>1;)c.push(e[o].pop());var l={orig:1,translit:2,translat:3};for(c.length===2&&l[c[0]]<l[c[1]]&&c.reverse();c.length;)e[o].push(c.pop());for(var u=n[s];u.length;)u.pop();for(var d=0,f=e[o].length;d<f;d+=1)u.push(e[o][d])}}},n.Engine.prototype.setLangPrefsForCiteAffixes=function(e){if(e&&e.length===48){for(var t=this.opt.citeAffixes,n=0,r=[`persons`,`institutions`,`titles`,`journals`,`publishers`,`places`],i=[`translit`,`orig`,`translit`,`translat`],a,o=0,s=r.length;o<s;o+=1)for(var c=0,l=i.length;c<l;c+=1)a=``,n%8==4?!t[r[o]][`locale-`+i[c]].prefix&&!t[r[o]][`locale-`+i[c]].suffix&&(a=e[n]?e[n]:``,t[r[o]][`locale-`+i[c]].prefix=a,a=e[n]?e[n+1]:``,t[r[o]][`locale-`+i[c]].suffix=a):(a=e[n]?e[n]:``,t[r[o]][`locale-`+i[c]].prefix=a,a=e[n]?e[n+1]:``,t[r[o]][`locale-`+i[c]].suffix=a),n+=2;this.opt.citeAffixes=t}},n.Engine.prototype.setAutoVietnameseNamesOption=function(e){e?this.opt[`auto-vietnamese-names`]=!0:this.opt[`auto-vietnamese-names`]=!1},n.Engine.prototype.setAbbreviations=function(e){this.sys.setAbbreviations&&this.sys.setAbbreviations(e)},n.Engine.prototype.setSuppressTrailingPunctuation=function(e){this.citation.opt.suppressTrailingPunctuation=!!e},n.Output={},n.Output.Queue=function(e){this.levelname=[`top`],this.state=e,this.queue=[],this.empty=new n.Token(`empty`);var t={};t.empty=this.empty,this.formats=new n.Stack(t),this.current=new n.Stack(this.queue)},n.Output.Queue.prototype.pop=function(){var e=this.current.value();return e.length?e.pop():e.blobs.pop()},n.Output.Queue.prototype.getToken=function(e){return this.formats.value()[e]},n.Output.Queue.prototype.mergeTokenStrings=function(e,t){var r=this.formats.value()[e],i=this.formats.value()[t],a=r,o;if(i){r||(r=new n.Token(e,n.SINGLETON),r.decorations=[]),a=new n.Token(e,n.SINGLETON);var o=``;for(var o in r.strings)r.strings.hasOwnProperty(o)&&(a.strings[o]=r.strings[o]);for(var o in i.strings)i.strings.hasOwnProperty(o)&&(a.strings[o]=i.strings[o]);a.decorations=r.decorations.concat(i.decorations)}return a},n.Output.Queue.prototype.addToken=function(e,t,r){var i=new n.Token(`output`),a;if(typeof r==`string`&&(r=this.formats.value()[r]),r&&r.strings){for(a in r.strings)r.strings.hasOwnProperty(a)&&(i.strings[a]=r.strings[a]);i.decorations=r.decorations}typeof t==`string`&&(i.strings.delimiter=t),this.formats.value()[e]=i},n.Output.Queue.prototype.pushFormats=function(e){e||(e={}),e.empty=this.empty,this.formats.push(e)},n.Output.Queue.prototype.popFormats=function(){this.formats.pop()},n.Output.Queue.prototype.startTag=function(e,t){var n={};this.state.tmp[`doing-macro-with-date`]&&this.state.tmp.extension&&(t=this.empty,e=`empty`),n[e]=t,this.pushFormats(n),this.openLevel(e)},n.Output.Queue.prototype.endTag=function(e){this.closeLevel(e),this.popFormats()},n.Output.Queue.prototype.openLevel=function(e){var t,r;typeof e==`object`?t=new n.Blob(void 0,e):e===void 0?t=new n.Blob(void 0,this.formats.value().empty,`empty`):((!this.formats.value()||!this.formats.value()[e])&&n.error(`CSL processor error: call to nonexistent format token "`+e+`"`),t=new n.Blob(void 0,this.formats.value()[e],e)),r=this.current.value(),!this.state.tmp.just_looking&&this.checkNestedBrace&&(t.strings.prefix=this.checkNestedBrace.update(t.strings.prefix)),r.push(t),this.current.push(t)},n.Output.Queue.prototype.closeLevel=function(e){e&&e!==this.current.value().levelname&&n.error(`Level mismatch error:  wanted `+e+` but found `+this.current.value().levelname);var t=this.current.pop();!this.state.tmp.just_looking&&this.checkNestedBrace&&(t.strings.suffix=this.checkNestedBrace.update(t.strings.suffix))},n.Output.Queue.prototype.append=function(e,t,r,i,a){var o,s,c,l=!0;if(r&&(i=!0),this.state.tmp[`doing-macro-with-date`]&&!r){if(t!==`macro-with-date`)return!1;t===`macro-with-date`&&(t=`empty`)}if(e===void 0||(typeof e==`number`&&(e=``+e),!r&&this.state.tmp.element_trace&&this.state.tmp.element_trace.value()===`suppress-me`))return!1;if(s=!1,t?t===`literal`?(o=!0,l=!1):o=typeof t==`string`?this.formats.value()[t]:t:o=this.formats.value().empty,o||n.error(`CSL processor error: unknown format token name: `+t),o.strings&&o.strings.delimiter===void 0&&(o.strings.delimiter=``),typeof e==`string`&&e.length&&(e=e.replace(/ ([:;?!\u00bb])/g,` $1`).replace(/\u00ab /g,`« `),this.last_char_rendered=e.slice(-1),e=e.replace(/\s+'/g,` '`),r||(e=e.replace(/^'/g,` '`)),i?r&&(this.state.tmp.term_predecessor_name=!0):(this.state.tmp.term_predecessor=!0,this.state.tmp.in_cite_predecessor=!0)),s=new n.Blob(e,o),c=this.current.value(),c===void 0&&this.current.mystack.length===0&&(this.current.mystack.push([]),c=this.current.value()),typeof s.blobs==`string`&&(i?r&&(this.state.tmp.term_predecessor_name=!0):(this.state.tmp.term_predecessor=!0,this.state.tmp.in_cite_predecessor=!0)),typeof e==`string`){if(typeof s.blobs==`string`&&s.blobs.slice(0,1)!==` `){for(var u=``,d=s.blobs;n.TERMINAL_PUNCTUATION.indexOf(d.slice(0,1))>-1;)u+=d.slice(0,1),d=d.slice(1);d&&u&&(s.strings.prefix=s.strings.prefix+u,s.blobs=d)}s.strings[`text-case`]&&(s.blobs=n.Output.Formatters[s.strings[`text-case`]](this.state,e)),this.state.tmp.strip_periods&&!a&&(s.blobs=s.blobs.replace(/\.([^a-z]|$)/g,`$1`));for(var f=s.decorations.length-1;f>-1;f+=-1)s.decorations[f][0]===`@quotes`&&s.decorations[f][1]!==`false`&&(s.punctuation_in_quote=this.state.getOpt(`punctuation-in-quote`)),s.blobs.match(n.ROMANESQUE_REGEXP)||s.decorations[f][0]===`@font-style`&&(s.decorations=s.decorations.slice(0,f).concat(s.decorations.slice(f+1)));c.push(s),this.state.fun.flipflopper.processTags(s)}else l?c.push(s):c.push(e);return!0},n.Output.Queue.prototype.string=function(e,t,r){var i,a,o,s,c,l=n.getSafeEscape(this.state),u=t.slice(),d=[];if(u.length===0)return d;var f=``;r?f=r.strings.delimiter:(e.tmp.count_offset_characters=!1,e.tmp.offset_characters=0),r&&r.new_locale&&(r.old_locale=e.opt.lang,e.opt.lang=r.new_locale);for(var p,m,h,g,i=0,a=u.length;i<a;i+=1){if(p=u[i],p.strings.first_blob&&(e.tmp.count_offset_characters=p.strings.first_blob),typeof p.blobs==`string`){if(typeof p.num==`number`)d.push(p);else if(p.blobs){p.particle&&(p.blobs=p.particle+p.blobs,p.particle=``),c=l(p.blobs);var _=c.length;if(!e.tmp.suppress_decorations)for(o=0,s=p.decorations.length;o<s;o+=1)g=p.decorations[o],g[0]!==`@showid`&&(e.normalDecorIsOrphan(p,g)||(c=e.fun.decorate[g[0]][g[1]].call(p,e,c,g[2])));if(c&&c.length){if(c=l(p.strings.prefix)+c+l(p.strings.suffix),e.opt.development_extensions.csl_reverse_lookup_support&&!e.tmp.suppress_decorations)for(o=0,s=p.decorations.length;o<s;o+=1)g=p.decorations[o],g[0]===`@showid`&&(c=e.fun.decorate[g[0]][g[1]].call(p,e,c,g[2]));d.push(c),e.tmp.count_offset_characters&&(e.tmp.offset_characters+=_+p.strings.suffix.length+p.strings.prefix.length)}}}else if(p.blobs.length){var v=e.output.string(e,p.blobs,p);if(r&&v!==`string`&&v.length>1&&p.strings.delimiter)for(var y=!1,o=0,s=v.length;o<s;o++)typeof v[o]==`string`?y&&(v[o]=p.strings.delimiter+v[o]):y=!0;d=d.concat(v)}p.strings.first_blob&&e.registry.registry[p.strings.first_blob]&&(e.registry.registry[p.strings.first_blob].offset=e.tmp.offset_characters,e.tmp.count_offset_characters=!1)}for(i=0,a=d.length-1;i<a;i+=1)typeof d[i].num==`number`&&typeof d[i+1].num==`number`&&!d[i+1].UGLY_DELIMITER_SUPPRESS_HACK&&(d[i].strings.suffix=d[i].strings.suffix+(f||``),d[i+1].successor_prefix=``,d[i+1].UGLY_DELIMITER_SUPPRESS_HACK=!0);for(var b=0,i=0,a=d.length;i<a;i+=1)typeof d[i]==`string`&&(b=parseInt(i,10)+1,i<d.length-1&&typeof d[i+1]==`object`&&(f&&!d[i+1].UGLY_DELIMITER_SUPPRESS_HACK&&(d[i]+=l(f)),d[i+1].UGLY_DELIMITER_SUPPRESS_HACK=!0));if(r&&(r.decorations.length||r.strings.suffix))b=d.length;else if(r&&r.strings.prefix){for(var i=0,a=d.length;i<a;i++)if(d[i].num!==void 0){b=i,i===0&&(d[i].strings.prefix=r.strings.prefix+d[i].strings.prefix);break}}var x=e.output.renderBlobs(d.slice(0,b),f,!1,r);if(x&&r&&(r.decorations.length||r.strings.suffix||r.strings.prefix)){if(!e.tmp.suppress_decorations)for(var i=0,a=r.decorations.length;i<a;i+=1)g=r.decorations[i],!([`@cite`,`@bibliography`,`@display`,`@showid`].indexOf(g[0])>-1)&&(e.normalDecorIsOrphan(p,g)||g[0]&&typeof x==`string`&&(x=e.fun.decorate[g[0]][g[1]].call(r,e,x,g[2])));if(c=x,m=r.strings.suffix,c&&c.length&&(h=r.strings.prefix,c=l(h)+c+l(m),e.tmp.count_offset_characters&&(e.tmp.offset_characters+=h.length+m.length)),x=c,!e.tmp.suppress_decorations)for(var i=0,a=r.decorations.length;i<a;i+=1)g=r.decorations[i],[`@cite`,`@bibliography`,`@display`,`@showid`].indexOf(g[0])!==-1&&typeof x==`string`&&(x=e.fun.decorate[g[0]][g[1]].call(r,e,x,g[2]))}var S=d.slice(b,d.length);return!S.length&&x?d=[x]:S.length&&!x?d=S:x&&S.length&&(d=[x].concat(S)),r===void 0?(this.queue=[],this.current.mystack=[],this.current.mystack.push(this.queue),e.tmp.suppress_decorations&&(d=e.output.renderBlobs(d,void 0,!1))):typeof r==`boolean`&&(d=e.output.renderBlobs(d,void 0,!0)),r&&r.new_locale&&(e.opt.lang=r.old_locale),d},n.Output.Queue.prototype.clearlevel=function(){var e=this.current.value(),t,n=e.blobs.length;for(t=0;t<n;t+=1)e.blobs.pop()},n.Output.Queue.prototype.renderBlobs=function(e,t,r,i){var a,o,s,c,l,u,d,f,p,m,h=n.getSafeEscape(this.state);if(t||(t=``),a=this.state,o=``,s=``,u=e.length,this.state.tmp.area===`citation`&&!this.state.tmp.just_looking&&u===1&&typeof e[0]==`object`&&i)return e[0].strings.prefix=i.strings.prefix+e[0].strings.prefix,e[0].strings.suffix=e[0].strings.suffix+i.strings.suffix,e[0].decorations=e[0].decorations.concat(i.decorations),e[0].params=i.params,e[0];var g=!0;for(l=0;l<u;l+=1)e[l].checkNext?(e[l].checkNext(e[l+1],g),g=!1):g=!(e[l+1]&&e[l+1].splice_prefix);var _=!0;for(l=e.length-1;l>0;l+=-1)e[l].checkLast?_&&e[l].checkLast(e[l-1])&&(_=!1):_=!0;for(u=e.length,l=0;l<u;l+=1)if(c=e[l],o&&(s=t),typeof c==`string`)o+=h(s),o+=c,a.tmp.count_offset_characters&&(a.tmp.offset_characters+=s.length);else if(r)o=o?[o,c]:[c];else if(c.status!==n.SUPPRESS){p=c.particle?c.particle+c.num:c.formatter.format(c.num,c.gender);var v=p.replace(/<[^>]*>/g,``).length;this.append(p,`empty`,!0);var y=this.pop(),b=a.tmp.count_offset_characters;if(p=this.string(a,[y],!1),a.tmp.count_offset_characters=b,c.strings[`text-case`]&&(p=n.Output.Formatters[c.strings[`text-case`]](this.state,p)),p&&this.state.tmp.strip_periods&&(p=p.replace(/\.([^a-z]|$)/g,`$1`)),!a.tmp.suppress_decorations)for(f=c.decorations.length,d=0;d<f;d+=1)m=c.decorations[d],!a.normalDecorIsOrphan(c,m)&&(p=a.fun.decorate[m[0]][m[1]].call(c,a,p,m[2]));p=h(c.strings.prefix)+p+h(c.strings.suffix);var x=``;c.status===n.END?x=h(c.range_prefix):c.status===n.SUCCESSOR?x=h(c.successor_prefix):c.status===n.START?x=l>0&&!c.suppress_splice_prefix?h(c.splice_prefix):``:c.status===n.SEEN&&(x=h(c.splice_prefix)),o+=x,o+=p,a.tmp.count_offset_characters&&(a.tmp.offset_characters+=x.length+c.strings.prefix.length+v+c.strings.suffix.length)}return o},n.Output.Queue.purgeEmptyBlobs=function(e){if(!(typeof e!=`object`||typeof e.blobs!=`object`||!e.blobs.length))for(var t=e.blobs.length-1;t>-1;t--){n.Output.Queue.purgeEmptyBlobs(e.blobs[t]);var r=e.blobs[t];if(!r||!r.blobs||!r.blobs.length){for(var i=[];e.blobs.length-1>t;)i.push(e.blobs.pop());for(e.blobs.pop();i.length;)e.blobs.push(i.pop())}}},n.Output.Queue.adjust=function(e){var t={";":!0,":":!0},n={".":!0,"!":!0,"?":!0},r={"!":{".":`!`,"?":`!?`,":":`!`,",":`!,`,";":`!;`},"?":{"!":`?!`,".":`?`,":":`?`,",":`?,`,";":`?;`},".":{"!":`.!`,"?":`.?`,":":`.:`,",":`.,`,";":`.;`},":":{"!":`!`,"?":`?`,".":`:`,",":`:,`,";":`:;`},",":{"!":`,!`,"?":`,?`,":":`,:`,".":`,.`,";":`,;`},";":{"!":`!`,"?":`?`,":":`;`,",":`;,`,".":`;`}},i={},a={},o={},s={};for(var c in r)o[c]=!0,s[c]=!0,t[c]||(i[c]=!0),n[c]||(a[c]=!0);s[` `]=!0,s[`\xA0`]=!0;var l={};for(var c in r)for(var u in r[c])l[u]||(l[u]={}),l[u][c]=r[c][u];function d(e){return typeof e.num==`number`||e.blobs&&e.blobs.length===1&&typeof e.blobs[0].num==`number`}function f(e){if(typeof e.num==`number`)return!0;if(!e.blobs||typeof e.blobs!=`object`)return!1;if(f(e.blobs[e.blobs.length-1]))return!0}function p(e,t){var n=!1,r=[`@font-style`,`@font-variant`,`@font-weight`,`@text-decoration`,`@vertical-align`];if(t&&r.push(`@quotes`),e.decorations){for(var i=0,a=e.decorations.length;i<a;i++)if(r.indexOf(e.decorations[i][0])>-1){n=!0;break}}return n}function m(e){if(e.decorations){for(var t=0,n=e.decorations.length;t<n;t++)if(e.decorations[t][0]===`@quotes`&&e.decorations[t][1]!==`false`)return!0}return typeof e.blobs==`object`?m(e.blobs[e.blobs.length-1]):!1}function h(e,t){var n=t.strings.suffix.slice(-1);!n&&typeof t.blobs==`string`&&(n=t.blobs.slice(-1));var r=l[e][n];return r&&r.length===1?!0:typeof t.blobs==`object`?!!h(e,t.blobs[t.blobs.length-1]):!1}function g(e,t){if(!o[t])return!1;if(typeof e.blobs==`string`)return e.blobs.slice(-1)===t;var n=e.blobs[e.blobs.length-1];return n?n.strings.suffix.slice(-1)?n.strings.suffix.slice(-1)==t:g(n,t):!1}function _(e,t,n,i,a){var o=t===`blobs`?e:e.strings,s=i===`blobs`?n:n.strings,c=o[t].slice(-1),u=s[i].slice(0,1);function d(){s[i]=s[i].slice(1)}function f(){o[t]=o[t].slice(0,-1)}function p(e){s[i]=e+s[i]}function m(e){o[t]+=e}var h=a?f:d;function g(){return l[u]}function _(){return r[c]}var v=a?_:g;function y(){var e=r[c][u];typeof e==`string`?(f(),d(),p(e)):(p(c),f())}function b(){var e=l[u][c];typeof e==`string`?(f(),d(),m(e)):(m(u),d())}var x=a?y:b;c===u?h():v()&&x()}function v(e){if(e.blobs&&typeof e.blobs==`string`){o[e.strings.suffix.slice(0,1)]&&e.strings.suffix.slice(0,1)===e.blobs.slice(-1)&&(e.strings.suffix=e.strings.suffix.slice(1));return}else if(typeof e!=`object`||typeof e.blobs!=`object`||!e.blobs.length)return;for(var t=p(e,!0),n=e.blobs.length-1;n>-1;n--){this.upward(e.blobs[n]);var r=e.strings,i=e.blobs[n].strings;if(n===0){r.prefix.slice(-1)===` `&&i.prefix.slice(0,1)===` `&&(i.prefix=i.prefix.slice(1));var a=i.prefix.slice(0,1);!t&&s[a]&&!r.prefix&&(r.prefix+=a,i.prefix=i.prefix.slice(1))}if(n===e.blobs.length-1){var a=i.suffix.slice(-1);!t&&[` `].indexOf(a)>-1&&(r.suffix.slice(0,1)!==a&&(r.suffix=a+r.suffix),i.suffix=i.suffix.slice(0,-1))}r.delimiter&&n>0&&s[r.delimiter.slice(-1)]&&r.delimiter.slice(-1)===i.prefix.slice(0,1)&&(i.prefix=i.prefix.slice(1))}}function y(e){if(!(typeof e!=`object`||typeof e.blobs!=`object`||!e.blobs.length)){for(var t=e.blobs.length-1;t>-1;t--)if(this.leftward(e.blobs[t]),t<e.blobs.length-1&&!e.strings.delimiter){var n=e.blobs[t],r=n.strings.suffix.slice(-1),i=e.blobs[t+1],a=i.strings.prefix.slice(0,1),s=p(n)||p(i),c=typeof r==`number`||typeof a==`number`;if(!s&&!c&&o[a]&&!c){var l=a===n.strings.suffix.slice(-1),u=!n.strings.suffix&&typeof n.blobs==`string`&&n.blobs.slice(-1)===a;!l&&!u?_(n,`suffix`,i,`prefix`):i.strings.prefix=i.strings.prefix.slice(1)}}}}function b(t){if(t.blobs&&typeof t.blobs==`string`){o[t.strings.suffix.slice(0,1)]&&t.strings.suffix.slice(0,1)===t.blobs.slice(-1)&&(t.strings.suffix=t.strings.suffix.slice(1));return}else if(typeof t!=`object`||typeof t.blobs!=`object`||!t.blobs.length)return;for(var n=t.strings,r=0,i=t.blobs.length;r<i&&!d(t.blobs[r]);r++);if(n.delimiter&&o[n.delimiter.slice(0,1)]){for(var a=n.delimiter.slice(0,1),r=t.blobs.length-2;r>-1;r--){var c=t.blobs[r].strings;c.suffix.slice(-1)!==a&&(c.suffix+=a)}n.delimiter=n.delimiter.slice(1)}for(var r=t.blobs.length-1;r>-1;r--){var l=t.blobs[r],c=t.blobs[r].strings,u=p(l,!0),v=d(l);if(r===t.blobs.length-1){var y=n.suffix.slice(0,1),b=!1;o[y]&&(b=h(y,l),!b&&e&&(b=m(l))),b&&o[y]&&(f(l)||(typeof l.blobs==`string`?_(l,`blobs`,t,`suffix`):_(l,`suffix`,t,`suffix`),n.suffix.slice(0,1)===`.`&&(c.suffix+=n.suffix.slice(0,1),n.suffix=n.suffix.slice(1)))),c.suffix.slice(-1)===`\xA0`&&n.suffix.slice(0,1)===` `&&(n.suffix=n.suffix.slice(1)),s[c.suffix.slice(0,1)]&&(typeof l.blobs==`string`&&l.blobs.slice(-1)===c.suffix.slice(0,1)&&(c.suffix=c.suffix.slice(1)),c.suffix.slice(-1)===n.suffix.slice(0,1)&&(n.suffix=n.suffix.slice(0,-1))),g(t,t.strings.suffix.slice(0,1))&&(t.strings.suffix=t.strings.suffix.slice(1))}else if(n.delimiter)s[n.delimiter.slice(0,1)]&&n.delimiter.slice(0,1)===c.suffix.slice(-1)&&(t.blobs[r].strings.suffix=t.blobs[r].strings.suffix.slice(0,-1));else{var x=t.blobs[r+1].strings;!d(l)&&!u&&s[c.suffix.slice(-1)]&&c.suffix.slice(-1)===x.prefix.slice(0,1)&&(x.prefix=x.prefix.slice(1))}!v&&!u&&o[c.suffix.slice(0,1)]&&typeof l.blobs==`string`&&_(l,`blobs`,l,`suffix`),this.downward(t.blobs[r])}}function x(e){var t=e.strings.suffix.slice(0,1);if(typeof e.blobs==`string`)for(;i[t];)_(e,`blobs`,e,`suffix`),t=e.strings.suffix.slice(0,1);else for(;i[t];)_(e.blobs[e.blobs.length-1],`suffix`,e,`suffix`),t=e.strings.suffix.slice(0,1)}function S(e){if(typeof e.blobs==`string`)for(var t=e.blobs.slice(-1);a[t];)_(e,`blobs`,e,`suffix`,!0),t=e.blobs.slice(-1);else for(var t=e.blobs[e.blobs.length-1].strings.suffix.slice(-1);a[t];)_(e.blobs[e.blobs.length-1],`suffix`,e,`suffix`,!0),t=e.blobs[e.blobs.length-1].strings.suffix.slice(-1)}function C(t){if(!(typeof t!=`object`||typeof t.blobs!=`object`||!t.blobs.length)){for(var n,r=0,i=t.blobs.length;r<i;r++){for(var a=t.blobs[r],o=!1,s=0,c=a.decorations.length;s<c;s++){var l=a.decorations[s];l[0]===`@quotes`&&l[1]!==`false`&&(o=!0)}o&&(e?x(a):S(a)),n=this.fix(t.blobs[r]),a.blobs&&typeof a.blobs==`string`&&(n=a.blobs.slice(-1))}return n}}this.upward=v,this.leftward=y,this.downward=b,this.fix=C},n.Engine.Opt=function(){this.parallel={enable:!1},this.has_disambiguate=!1,this.mode=`html`,this.dates={},this.jurisdictions_seen={},this.suppressedJurisdictions={},this.inheritedAttributes={},this[`locale-sort`]=[],this[`locale-translit`]=[],this[`locale-translat`]=[],this.citeAffixes={persons:{"locale-orig":{prefix:``,suffix:``},"locale-translit":{prefix:``,suffix:``},"locale-translat":{prefix:``,suffix:``}},institutions:{"locale-orig":{prefix:``,suffix:``},"locale-translit":{prefix:``,suffix:``},"locale-translat":{prefix:``,suffix:``}},titles:{"locale-orig":{prefix:``,suffix:``},"locale-translit":{prefix:``,suffix:``},"locale-translat":{prefix:``,suffix:``}},journals:{"locale-orig":{prefix:``,suffix:``},"locale-translit":{prefix:``,suffix:``},"locale-translat":{prefix:``,suffix:``}},publishers:{"locale-orig":{prefix:``,suffix:``},"locale-translit":{prefix:``,suffix:``},"locale-translat":{prefix:``,suffix:``}},places:{"locale-orig":{prefix:``,suffix:``},"locale-translit":{prefix:``,suffix:``},"locale-translat":{prefix:``,suffix:``}}},this[`default-locale`]=[],this.update_mode=n.NONE,this.bib_mode=n.NONE,this.sort_citations=!1,this[`et-al-min`]=0,this[`et-al-use-first`]=1,this[`et-al-use-last`]=!1,this[`et-al-subsequent-min`]=!1,this[`et-al-subsequent-use-first`]=!1,this[`demote-non-dropping-particle`]=`display-and-sort`,this[`parse-names`]=!0,this.citation_number_slug=!1,this.trigraph=`Aaaa00:AaAa00:AaAA00:AAAA00`,this.nodenames=[],this.gender={},this[`cite-lang-prefs`]={persons:[`orig`],institutions:[`orig`],titles:[`orig`],journals:[`orig`],publishers:[`orig`],places:[`orig`],number:[`orig`]},this.has_layout_locale=!1,this.disable_duplicate_year_suppression=[],this.use_context_condition=!1,this.jurisdiction_fallbacks={},this.development_extensions={},this.development_extensions.field_hack=!0,this.development_extensions.allow_field_hack_date_override=!0,this.development_extensions.locator_date_and_revision=!0,this.development_extensions.locator_label_parse=!0,this.development_extensions.raw_date_parsing=!0,this.development_extensions.clean_up_csl_flaws=!0,this.development_extensions.consolidate_legal_items=!1,this.development_extensions.csl_reverse_lookup_support=!1,this.development_extensions.wrap_url_and_doi=!1,this.development_extensions.thin_non_breaking_space_html_hack=!1,this.development_extensions.apply_citation_wrapper=!1,this.development_extensions.main_title_from_short_title=!1,this.development_extensions.uppercase_subtitles=!1,this.development_extensions.normalize_lang_keys_to_lowercase=!1,this.development_extensions.strict_text_case_locales=!1,this.development_extensions.expect_and_symbol_form=!1,this.development_extensions.require_explicit_legal_case_title_short=!1,this.development_extensions.spoof_institutional_affiliations=!1,this.development_extensions.force_jurisdiction=!1,this.development_extensions.parse_names=!0,this.development_extensions.hanging_indent_legacy_number=!1,this.development_extensions.throw_on_empty=!1,this.development_extensions.strict_inputs=!0,this.development_extensions.prioritize_disambiguate_condition=!1,this.development_extensions.force_short_title_casing_alignment=!0,this.development_extensions.implicit_short_title=!1,this.development_extensions.force_title_abbrev_fallback=!1,this.development_extensions.split_container_title=!1,this.development_extensions.legacy_institution_name_ordering=!1,this.development_extensions.etal_min_etal_usefirst_hack=!1},n.Engine.Tmp=function(){this.names_max=new n.Stack,this.names_base=new n.Stack,this.givens_base=new n.Stack,this.value=[],this.namepart_decorations={},this.namepart_type=!1,this.area=`citation`,this.root=`citation`,this.extension=``,this.can_substitute=new n.Stack(0,n.LITERAL),this.element_rendered_ok=!1,this.element_trace=new n.Stack(`style`),this.nameset_counter=0,this.group_context=new n.Stack({term_intended:!1,variable_attempt:!1,variable_success:!1,output_tip:void 0,label_form:void 0,parallel_first:void 0,parallel_last:void 0,parallel_delimiter_override:void 0,condition:!1,force_suppress:!1,done_vars:[]}),this.term_predecessor=!1,this.in_cite_predecessor=!1,this.jump=new n.Stack(0,n.LITERAL),this.decorations=new n.Stack,this.tokenstore_stack=new n.Stack,this.last_suffix_used=``,this.last_names_used=[],this.last_years_used=[],this.years_used=[],this.names_used=[],this.taintedItemIDs={},this.taintedCitationIDs={},this.initialize_with=new n.Stack,this.disambig_request=!1,this[`name-as-sort-order`]=!1,this.suppress_decorations=!1,this.disambig_settings=new n.AmbigConfig,this.bib_sort_keys=[],this.prefix=new n.Stack(``,n.LITERAL),this.suffix=new n.Stack(``,n.LITERAL),this.delimiter=new n.Stack(``,n.LITERAL),this.cite_locales=[],this.cite_affixes={citation:!1,bibliography:!1,citation_sort:!1,bibliography_sort:!1},this.strip_periods=0,this.shadow_numbers={},this.authority_stop_last=0,this.loadedItemIDs={},this.condition_counter=0,this.condition_lang_val_arr=[],this.condition_lang_counter_arr=[]},n.Engine.Fun=function(e){this.match=new n.Util.Match,this.suffixator=new n.Util.Suffixator(n.SUFFIX_CHARS),this.romanizer=new n.Util.Romanizer,this.ordinalizer=new n.Util.Ordinalizer(e),this.long_ordinalizer=new n.Util.LongOrdinalizer},n.Engine.Build=function(){this[`alternate-term`]=!1,this.in_bibliography=!1,this.in_style=!1,this.skip=!1,this.postponed_macro=!1,this.layout_flag=!1,this.name=!1,this.names_variables=[[]],this.name_label=[{}],this.form=!1,this.term=!1,this.macro={},this.macro_stack=[],this.text=!1,this.lang=!1,this.area=`citation`,this.root=`citation`,this.extension=``,this.substitute_level=new n.Stack(0,n.LITERAL),this.names_level=0,this.render_nesting_level=0,this.render_seen=!1,this.bibliography_key_pos=0},n.Engine.Configure=function(){this.tests=[],this.fail=[],this.succeed=[]},n.Engine.Citation=function(e){this.opt={inheritedAttributes:{}},this.tokens=[],this.srt=new n.Registry.Comparifier(e,`citation_sort`),this.opt.collapse=[],this.opt[`disambiguate-add-names`]=!1,this.opt[`disambiguate-add-givenname`]=!1,this.opt[`disambiguate-add-year-suffix`]=!1,this.opt[`givenname-disambiguation-rule`]=`by-cite`,this.opt[`near-note-distance`]=5,this.opt.topdecor=[],this.opt.layout_decorations=[],this.opt.layout_prefix=``,this.opt.layout_suffix=``,this.opt.layout_delimiter=``,this.opt.sort_locales=[],this.opt.max_number_of_names=0,this.root=`citation`},n.Engine.Bibliography=function(){this.opt={inheritedAttributes:{}},this.tokens=[],this.opt.collapse=[],this.opt.topdecor=[],this.opt.layout_decorations=[],this.opt.layout_prefix=``,this.opt.layout_suffix=``,this.opt.layout_delimiter=``,this.opt[`line-spacing`]=1,this.opt[`entry-spacing`]=1,this.opt.sort_locales=[],this.opt.max_number_of_names=0,this.root=`bibliography`},n.Engine.BibliographySort=function(){this.tokens=[],this.opt={},this.opt.sort_directions=[],this.opt.topdecor=[],this.opt.citation_number_sort_direction=n.ASCENDING,this.opt.citation_number_secondary=!1,this.tmp={},this.keys=[],this.root=`bibliography`},n.Engine.CitationSort=function(){this.tokens=[],this.opt={},this.opt.sort_directions=[],this.keys=[],this.opt.topdecor=[],this.root=`citation`},n.Engine.InText=function(){this.opt={inheritedAttributes:{}},this.tokens=[],this.opt.collapse=[],this.opt[`disambiguate-add-names`]=!1,this.opt[`disambiguate-add-givenname`]=!1,this.opt[`disambiguate-add-year-suffix`]=!1,this.opt[`givenname-disambiguation-rule`]=`by-cite`,this.opt[`near-note-distance`]=5,this.opt.topdecor=[],this.opt.layout_decorations=[],this.opt.layout_prefix=``,this.opt.layout_suffix=``,this.opt.layout_delimiter=``,this.opt.sort_locales=[],this.opt.max_number_of_names=0,this.root=`intext`},n.Engine.prototype.previewCitationCluster=function(e,t,r,i){var a=this.opt.mode;this.setOutputFormat(i),e.citationID&&delete e.citationID;var o=this.processCitationCluster(e,t,r,n.PREVIEW);return this.setOutputFormat(a),o[1]},n.Engine.prototype.appendCitationCluster=function(e){for(var t=[],n=this.registry.citationreg.citationByIndex.length,r=0;r<n;r+=1){var i=this.registry.citationreg.citationByIndex[r];t.push([``+i.citationID,i.properties.noteIndex])}return this.processCitationCluster(e,t,[])[1]},n.Engine.prototype.processCitationCluster=function(e,t,r,i){var a,o,s,c,l,u,d,f,p,m,h,g,_,v,y,b,x,S;this.debug=!1,this.tmp.loadedItemIDs={},this.tmp.citation_errors=[],this.registry.return_data={bibchange:!1},this.setCitationId(e);var C,w,T;if(i===n.PREVIEW){this.debug&&n.debug(`****** start state save *********`),C=this.registry.citationreg.citationByIndex.slice(),w=this.registry.reflist.slice();for(var E=t.concat(r),D={},O=[],c=0,l=E.length;c<l;c+=1)for(a=this.registry.citationreg.citationById[E[c][0]],u=0,d=a.citationItems.length;u<d;u+=1)D[a.citationItems[u].id]=!0,O.push(``+a.citationItems[u].id);for(u=0,d=e.citationItems.length;u<d;u+=1)D[e.citationItems[u].id]=!0,O.push(``+e.citationItems[u].id);T={};for(var c=0,l=w.length;c<l;c+=1)if(!D[w[c].id]){var k=this.registry.registry[w[c].id].ambig,A=this.registry.ambigcites[k];if(A)for(u=0,d=A.length;u<d;u+=1)T[A[u]]=n.cloneAmbigConfig(this.registry.registry[A[u]].disambig)}this.debug&&n.debug(`****** end state save *********`)}this.tmp.taintedCitationIDs={};for(var j=[],M={},c=0,l=e.citationItems.length;c<l;c+=1){for(var g in v={},e.citationItems[c])v[g]=e.citationItems[c][g];if(_=this.retrieveItem(``+v.id),_.id&&this.transform.loadAbbreviation(`default`,`hereinafter`,_.id,_.language),v=n.parseLocator.call(this,v),this.opt.development_extensions.consolidate_legal_items&&this.remapSectionVariable([[_,v]]),this.opt.development_extensions.locator_label_parse&&v.locator&&[`bill`,`gazette`,`legislation`,`regulation`,`treaty`].indexOf(_.type)===-1&&(!v.label||v.label===`page`)){var x=n.LOCATOR_LABELS_REGEXP.exec(v.locator);if(x){var N=n.LOCATOR_LABELS_MAP[x[2]];this.getTerm(N)&&(v.label=N,v.locator=x[3])}}var P=[_,v];j.push(P),e.citationItems[c].item=_}e.sortedItems=j;var F=[],I={},L;for(c=0,l=t.length;c<l;c+=1)o=t[c],this.opt.development_extensions.strict_inputs&&(I[o[0]]&&n.error(`Previously referenced citationID `+o[0]+` encountered in citationsPre`),o[1]&&(L>o[1]&&n.debug(`Note index sequence is not sane at citationsPre[`+c+`]`),L=o[1])),this.registry.citationreg.citationById[o[0]].properties.noteIndex=o[1],F.push(this.registry.citationreg.citationById[o[0]]),I[o[0]]=this.registry.citationreg.citationById[o[0]];for(e.properties||(e.properties={noteIndex:0}),this.opt.development_extensions.strict_inputs&&(I[e.citationID]&&n.error(`Citation with previously referenced citationID `+e.citationID),e.properties.noteIndex&&(L>e.properties.noteIndex&&n.debug(`Note index sequence is not sane for citation `+e.citationID),L=e.properties.noteIndex)),F.push(e),I[e.citationID]=e,c=0,l=r.length;c<l;c+=1)s=r[c],this.opt.development_extensions.strict_inputs&&(I[s[0]]&&n.error(`Previously referenced citationID `+s[0]+` encountered in citationsPost`),s[1]&&(L>s[1]&&n.debug(`Note index sequence is not sane at postCitation[`+c+`]`),L=s[1])),this.registry.citationreg.citationById[s[0]].properties.noteIndex=s[1],F.push(this.registry.citationreg.citationById[s[0]]),I[s[0]]=this.registry.citationreg.citationById[s[0]];this.registry.citationreg.citationByIndex=F,this.registry.citationreg.citationById=I,this.registry.citationreg.citationsByItemId={},this.opt.update_mode===n.POSITION&&(b=[],y=[],S={});for(var R=[],c=0,l=F.length;c<l;c+=1){for(F[c].properties.index=c,u=0,d=F[c].sortedItems.length;u<d;u+=1)v=F[c].sortedItems[u],this.registry.citationreg.citationsByItemId[v[1].id]||(this.registry.citationreg.citationsByItemId[v[1].id]=[],R.push(``+v[1].id)),this.registry.citationreg.citationsByItemId[v[1].id].indexOf(F[c])===-1&&this.registry.citationreg.citationsByItemId[v[1].id].push(F[c]);this.opt.update_mode===n.POSITION&&(F[c].properties.noteIndex?y.push(F[c]):(F[c].properties.noteIndex=0,b.push(F[c])))}if(i!==n.ASSUME_ALL_ITEMS_REGISTERED&&(this.debug&&n.debug(`****** start update items *********`),this.updateItems(R,null,null,!0),this.debug&&n.debug(`****** endo update items *********`)),!this.opt.citation_number_sort&&j&&j.length>1&&this.citation_sort.tokens.length>0){for(var c=0,l=j.length;c<l;c+=1)j[c][1].sortkeys=n.getSortKeys.call(this,j[c][0],`citation_sort`);if(this.opt.grouped_sort&&!e.properties.unsorted){for(var c=0,l=j.length;c<l;c+=1){var z=j[c][1].sortkeys;this.tmp.authorstring_request=!0;var B=this.registry.registry[j[c][0].id].disambig;this.tmp.authorstring_request=!0,n.getAmbiguousCite.call(this,j[c][0],B);var ee=this.registry.authorstrings[j[c][0].id];this.tmp.authorstring_request=!1,j[c][1].sortkeys=[ee].concat(z)}j.sort(this.citation.srt.compareCompositeKeys);for(var te=!1,ne=!1,re=!1,c=0,l=j.length;c<l;c+=1)j[c][1].sortkeys[0]!==te&&(re=j[c][1].sortkeys[0],ne=j[c][1].sortkeys[1]),j[c][1].sortkeys[0]=``+ne+c,te=re}e.properties.unsorted||j.sort(this.citation.srt.compareCompositeKeys)}this.opt.parallel.enable&&this.parallel.StartCitation(e.sortedItems);var V;if(this.opt.update_mode===n.POSITION)for(var c=0;c<2;c+=1){var H={},U={},W={};for(V=[b,y][c],u=0,d=V.length;u<d;u+=1){var G=V[u];for(V[u].properties.noteIndex||(V[u].properties.noteIndex=0),V[u].properties.noteIndex=parseInt(V[u].properties.noteIndex,10),u>0&&G.properties.noteIndex&&V[u-1].properties.noteIndex>G.properties.noteIndex&&(S={},H={},U={},W={}),f=0,p=G.sortedItems.length;f<p;f+=1)G.sortedItems[f][1].parallel&&G.sortedItems[f][1].parallel!==`first`||(S[G.properties.noteIndex]?S[G.properties.noteIndex]+=1:S[G.properties.noteIndex]=1);for(f=0,p=V[u].sortedItems.length;f<p;f+=1){v=V[u].sortedItems[f];var ie=v[0].id,K=v[0].legislation_id?v[0].legislation_id:v[0].id,q=v[0].legislation_id?v[0].legislation_id:v[0].container_id?v[0].container_id:v[0].id,ae=v[1][`locator-extra`],J=v[1].locator,oe=v[1].label,se,ce;if(f>0)if(G.sortedItems[f-1][0].legislation_id)se=G.sortedItems[f-1][0].legislation_id;else{se=G.sortedItems[f-1][1].id,ce=G.sortedItems[f-1][1][`locator-extra`];for(var Y=f-2;Y>-1;Y--)G.sortedItems[Y][1].parallel===`first`&&(se=G.sortedItems[Y][1].id,ce=G.sortedItems[Y][1][`locator-extra`])}if(i===n.PREVIEW&&G.citationID!=e.citationID){H[v[1].id]===void 0&&(H[K]=G.properties.noteIndex),U[q]=G.properties.noteIndex;continue}var le={};if(le.position=v[1].position,le[`first-reference-note-number`]=v[1][`first-reference-note-number`],le[`first-container-reference-note-number`]=v[1][`first-container-reference-note-number`],le[`near-note`]=v[1][`near-note`],v[1][`first-reference-note-number`]=0,v[1][`first-container-reference-note-number`]=0,v[1][`near-note`]=!1,this.registry.citationreg.citationsByItemId[ie]&&this.opt.xclass===`note`&&this.opt.has_disambiguate){var ue=this.registry.registry[v[0].id][`citation-count`],de=this.registry.citationreg.citationsByItemId[ie].length;if(this.registry.registry[v[0].id][`citation-count`]=this.registry.citationreg.citationsByItemId[ie].length,typeof ue==`number`){if(ue<2!=de<2)for(var Y=0,fe=this.registry.citationreg.citationsByItemId[ie].length;Y<fe;Y++)M[this.registry.registry[v[0].id].ambig]=!0,this.tmp.taintedCitationIDs[this.registry.citationreg.citationsByItemId[ie][Y].citationID]=!0}else for(var Y=0,fe=this.registry.citationreg.citationsByItemId[ie].length;Y<fe;Y++)M[this.registry.registry[v[0].id].ambig]=!0,this.tmp.taintedCitationIDs[this.registry.citationreg.citationsByItemId[ie][Y].citationID]=!0}var pe,me;if(U[q]===void 0&&G.properties.mode!==`author-only`)H[K]=G.properties.noteIndex,U[q]=G.properties.noteIndex,W[q]=G.properties.noteIndex,v[1].position=n.POSITION_FIRST;else{var he=!1,ge=!1,X=null;if(u>0)var X=V[u-1];var _e=V[u];if(u>0){var ve=1;X.properties.mode===`author-only`&&u>1&&(ve=2);var ye=u-ve;V[ye].sortedItems.length&&(pe=V[ye].sortedItems.slice(-1)[0][1].id,me=V[u-ve].sortedItems.slice(-1)[0][1][`locator-extra`]),X.sortedItems.length&&X.sortedItems[0].slice(-1)[0].legislation_id&&(pe=X.sortedItems[0].slice(-1)[0].legislation_id)}if(u>0&&f===0&&X.properties.noteIndex!==_e.properties.noteIndex){var be=!1,xe=X.sortedItems[0][0].id;if(X.sortedItems[0][0].legislation_id&&(xe=X.sortedItems[0][0].legislation_id),xe==K&&X.properties.noteIndex>=_e.properties.noteIndex-1){var Se=X.sortedItems[0][1][`locator-extra`],Ce=_e.sortedItems[0][1][`locator-extra`];(S[X.properties.noteIndex]===1||X.properties.noteIndex===0)&&Se===Ce&&(be=!0)}be?he=!0:ge=!0}else f>0&&se==K&&ce==ae||f===0&&u>0&&X.properties.noteIndex==_e.properties.noteIndex&&X.sortedItems.length&&pe==K&&me==ae?he=!0:ge=!0;var we,Z,Te,Ee,De;he&&(we=f>0?G.sortedItems[f-1][1]:V[u-1].sortedItems[0][1],we.locator?(Te=we.label?we.label:``,Z=``+we.locator+Te):Z=we.locator,J?(De=oe||``,Ee=``+J+De):Ee=J),he&&Z&&!Ee&&(he=!1,ge=!0),he&&(!Z&&Ee?v[1].position=n.POSITION_IBID_WITH_LOCATOR:!Z&&!Ee||Z&&Ee===Z?v[1].position=n.POSITION_IBID:Z&&Ee&&Ee!==Z?v[1].position=n.POSITION_IBID_WITH_LOCATOR:(he=!1,ge=!0)),ge&&(v[1].position=n.POSITION_CONTAINER_SUBSEQUENT,H[K]===void 0?H[K]=G.properties.noteIndex:v[1].position=n.POSITION_SUBSEQUENT),(ge||he)&&(G.properties.mode===`author-only`&&(v[1].position=n.POSITION_FIRST),W[q]!=G.properties.noteIndex&&(v[1][`first-container-reference-note-number`]=W[q],this.registry.registry[v[0].id]&&(this.registry.registry[v[0].id][`first-container-reference-note-number`]=W[q])),H[K]!=G.properties.noteIndex&&(v[1][`first-reference-note-number`]=H[K],this.registry.registry[v[0].id]&&(this.registry.registry[v[0].id][`first-reference-note-number`]=H[K])))}if(G.properties.noteIndex){var Oe=parseInt(G.properties.noteIndex,10)-parseInt(U[q],10);v[1].position!==n.POSITION_FIRST&&Oe<=this.citation.opt[`near-note-distance`]&&(v[1][`near-note`]=!0),U[q]=G.properties.noteIndex}else v[1].position!==n.POSITION_FIRST&&(v[1][`near-note`]=!0);if(G.citationID!=e.citationID)for(m=0,h=n.POSITION_TEST_VARS.length;m<h;m+=1){var ke=n.POSITION_TEST_VARS[m];v[1][ke]!==le[ke]&&(this.registry.registry[v[0].id]&&ke===`first-reference-note-number`&&(M[this.registry.registry[v[0].id].ambig]=!0,this.tmp.taintedItemIDs[v[0].id]=!0),this.tmp.taintedCitationIDs[G.citationID]=!0)}this.sys.variableWrapper&&(v[1].index=G.properties.index,v[1].noteIndex=G.properties.noteIndex)}}}if(this.opt.citation_number_sort&&j&&j.length>1&&this.citation_sort.tokens.length>0&&!e.properties.unsorted){for(var c=0,l=j.length;c<l;c+=1)j[c][1].sortkeys=n.getSortKeys.call(this,j[c][0],`citation_sort`);j.sort(this.citation.srt.compareCompositeKeys)}for(var g in this.tmp.taintedItemIDs)if(this.tmp.taintedItemIDs.hasOwnProperty(g)&&(V=this.registry.citationreg.citationsByItemId[g],V))for(var c=0,l=V.length;c<l;c+=1)this.tmp.taintedCitationIDs[V[c].citationID]=!0;var Ae=[];if(i===n.PREVIEW){this.debug&&n.debug(`****** start run processor *********`);try{Ae=this.process_CitationCluster.call(this,e.sortedItems,e)}catch(e){n.error(`Error running CSL processor for preview: `+e)}this.debug&&(n.debug(`****** end run processor *********`),n.debug(`****** start state restore *********`)),this.registry.citationreg.citationByIndex=C,this.registry.citationreg.citationById={};for(var c=0,l=C.length;c<l;c+=1)this.registry.citationreg.citationById[C[c].citationID]=C[c];this.debug&&n.debug(`****** start final update *********`);for(var je=[],c=0,l=w.length;c<l;c+=1)je.push(``+w[c].id);for(var g in this.updateItems(je,null,null,!0),this.debug&&n.debug(`****** end final update *********`),T)T.hasOwnProperty(g)&&(this.registry.registry[g].disambig=T[g]);this.debug&&n.debug(`****** end state restore *********`)}else{for(var Me in M)this.disambiguate.run(Me,e);var Q;for(var g in this.tmp.taintedCitationIDs)if(g!=e.citationID){var $=this.registry.citationreg.citationById[g];if(!$.properties.unsorted){for(var c=0,l=$.sortedItems.length;c<l;c+=1)$.sortedItems[c][1].sortkeys=n.getSortKeys.call(this,$.sortedItems[c][0],`citation_sort`);$.sortedItems.sort(this.citation.srt.compareCompositeKeys)}this.tmp.citation_pos=$.properties.index,this.tmp.citation_note_index=$.properties.noteIndex,this.tmp.citation_id=``+$.citationID,Q=[],Q.push($.properties.index),Q.push(this.process_CitationCluster.call(this,$.sortedItems,$)),Q.push($.citationID),Ae.push(Q)}this.tmp.taintedItemIDs={},this.tmp.taintedCitationIDs={},this.tmp.citation_pos=e.properties.index,this.tmp.citation_note_index=e.properties.noteIndex,this.tmp.citation_id=``+e.citationID,Q=[],Q.push(t.length),Q.push(this.process_CitationCluster.call(this,j,e)),Q.push(e.citationID),Ae.push(Q),Ae.sort(function(e,t){return e[0]>t[0]?1:e[0]<t[0]?-1:0})}return this.registry.return_data.citation_errors=this.tmp.citation_errors.slice(),[this.registry.return_data,Ae]},n.Engine.prototype.process_CitationCluster=function(e,t){var r=``;if(t&&t.properties&&t.properties.mode===`composite`){t.properties.mode=`author-only`;var i=n.getCitationCluster.call(this,e,t);t.properties.mode=`suppress-author`;var a=``;t.properties.infix&&(this.output.append(t.properties.infix),a=this.output.string(this,this.output.queue),typeof a==`object`&&(a=a.join(``)));var o=n.getCitationCluster.call(this,e,t);t.properties.mode=`composite`,i&&a&&n.SWAPPING_PUNCTUATION.concat([`’`,`'`]).indexOf(a[0])>-1&&(i+=a,a=!1),r=[i,a,o].filter(function(e){return e}).join(` `)}else r=n.getCitationCluster.call(this,e,t);return r},n.Engine.prototype.makeCitationCluster=function(e){var t=[],r,i,a=e.length,o,s;for(i=0;i<a;i+=1){for(var c in o={},e[i])o[c]=e[i][c];if(s=this.retrieveItem(``+o.id),this.opt.development_extensions.locator_label_parse&&o.locator&&[`bill`,`gazette`,`legislation`,`regulation`,`treaty`].indexOf(s.type)===-1&&(!o.label||o.label===`page`)){var l=n.LOCATOR_LABELS_REGEXP.exec(o.locator);if(l){var u=n.LOCATOR_LABELS_MAP[l[2]];this.getTerm(u)&&(o.label=u,o.locator=l[3])}}o.locator&&(o.locator=(``+o.locator).replace(/\s+$/,``)),r=[s,o],t.push(r)}if(this.opt.development_extensions.consolidate_legal_items&&this.remapSectionVariable(t),t&&t.length>1&&this.citation_sort.tokens.length>0){for(a=t.length,i=0;i<a;i+=1)t[i][1].sortkeys=n.getSortKeys.call(this,t[i][0],`citation_sort`);t.sort(this.citation.srt.compareCompositeKeys)}return this.tmp.citation_errors=[],n.getCitationCluster.call(this,t)},n.getAmbiguousCite=function(e,t,r,i){var a,o=this.tmp.group_context.tip,s={term_intended:o.term_intended,variable_attempt:o.variable_attempt,variable_success:o.variable_success,output_tip:o.output_tip,label_form:o.label_form,non_parallel:o.non_parallel,parallel_last:o.parallel_last,parallel_first:o.parallel_first,parallel_last_override:o.parallel_last_override,parallel_delimiter_override:o.parallel_delimiter_override,parallel_delimiter_override_on_suppress:o.parallel_delimiter_override_on_suppress,condition:o.condition,force_suppress:o.force_suppress,done_vars:o.done_vars.slice()};t?this.tmp.disambig_request=t:this.tmp.disambig_request=!1;var c={position:n.POSITION_SUBSEQUENT,"near-note":!0};i&&(c.locator=i.locator,c.label=i.label),this.registry.registry[e.id]&&this.registry.citationreg.citationsByItemId&&this.registry.citationreg.citationsByItemId[e.id]&&this.registry.citationreg.citationsByItemId[e.id].length&&r&&this.citation.opt[`givenname-disambiguation-rule`]===`by-cite`&&(c[`first-reference-note-number`]=this.registry.registry[e.id][`first-reference-note-number`]),this.tmp.area=`citation`,this.tmp.root=`citation`;var l=this.tmp.suppress_decorations;this.tmp.suppress_decorations=!0,this.tmp.just_looking=!0,n.getCite.call(this,e,c,null,!1);for(var u=0,d=this.output.queue.length;u<d;u+=1)n.Output.Queue.purgeEmptyBlobs(this.output.queue[u]);if(this.opt.development_extensions.clean_up_csl_flaws)for(var f=0,p=this.output.queue.length;f<p;f+=1)this.output.adjust.upward(this.output.queue[f]),this.output.adjust.leftward(this.output.queue[f]),this.output.adjust.downward(this.output.queue[f]),this.output.adjust.fix(this.output.queue[f]);var a=this.output.string(this,this.output.queue);return this.tmp.just_looking=!1,this.tmp.suppress_decorations=l,this.tmp.group_context.replace(s),a},n.getSpliceDelimiter=function(e,t,r){if(this.citation.opt[`after-collapse-delimiter`]!==void 0)e||t&&!this.tmp.have_collapsed||!t&&!this.tmp.have_collapsed&&this.citation.opt.collapse!==`year-suffix`?this.tmp.splice_delimiter=this.citation.opt[`after-collapse-delimiter`]:this.tmp.splice_delimiter=this.citation.opt.layout_delimiter;else if(this.tmp.use_cite_group_delimiter)this.tmp.splice_delimiter=this.citation.opt.cite_group_delimiter;else if(this.tmp.have_collapsed&&this.opt.xclass===`in-text`&&this.opt.update_mode!==n.NUMERIC)this.tmp.splice_delimiter=`, `;else if(this.tmp.cite_locales[r-1]){var i=this.tmp.cite_affixes[this.tmp.area][this.tmp.cite_locales[r-1]];i&&i.delimiter&&(this.tmp.splice_delimiter=i.delimiter)}else this.tmp.splice_delimiter||(this.tmp.splice_delimiter=``);return this.tmp.splice_delimiter},n.getCitationCluster=function(e,t){var r,i,a,o,s,c,l,u,d,f,p,m,h,g,_,v,y,b,x,S,C,w,T=``;this.output.checkNestedBrace=new n.checkNestedBrace(this),t&&(S=t.citationID,C=t.properties.mode===`author-only`?!!t.properties.mode:!1,this.opt.xclass!==`note`&&(w=t.properties.mode===`suppress-author`?!!t.properties.mode:!1),t.properties.prefix&&(T=n.checkPrefixSpaceAppend(this,t.properties.prefix))),e=e||[],this.tmp.last_primary_names_string=!1,b=n.getSafeEscape(this),this.tmp.area=`citation`,this.tmp.root=`citation`,r=``,i=[],this.tmp.last_suffix_used=``,this.tmp.last_names_used=[],this.tmp.last_years_used=[],this.tmp.backref_index=[],this.tmp.cite_locales=[],this.tmp.just_looking||(this.tmp.abbrev_trimmer={QUASHES:{}});var E=this.output.checkNestedBrace.update(this.citation.opt.layout_prefix+T),D=!1;if(this.citation.opt.suppressTrailingPunctuation&&(D=!0),S&&this.registry.citationreg.citationById[S].properties[`suppress-trailing-punctuation`]&&(D=!0),this.opt.xclass===`note`){for(var O=[],k=!1,A=!1,j=[],M=0,N=e.length;M<N;M+=1){var P=e[M][0].type,F=e[M][0].title,I=e[M][1].position,L=e[M][0].id;F&&P===`legal_case`&&L!==A&&I&&((F!==k||O.length===0)&&(j=[],O.push(j)),j.push(e[M][1])),k=F,A=L}for(M=0,N=O.length;M<N;M+=1)if(j=O[M],!(j.length<2)){var R=j.slice(-1)[0].locator;if(R)for(var z=0,B=j.length-1;z<B;z+=1)j[z].locator&&(R=!1);R&&(j[0].locator=R,delete j.slice(-1)[0].locator,j[0].label=j.slice(-1)[0].label,j.slice(-1)[0].label&&delete j.slice(-1)[0].label)}}for(a=[],o=e.length,e[0]&&e[0][1]&&(C?(delete e[0][1][`suppress-author`],e[0][1][`author-only`]=!0):w&&(delete e[0][1][`author-only`],e[0][1][`suppress-author`]=!0)),this.opt.parallel.enable&&this.parallel.StartCitation(e),s=0;s<o;s+=1){this.tmp.cite_index=s,h=e[s][0],c=e[s][1],c=n.parseLocator.call(this,c),l=this.tmp.have_collapsed;var ee=!1;if(s>0&&e[s-1][1]&&(ee=!!e[s-1][1].locator),u={},this.tmp.shadow_numbers={},!this.tmp.just_looking&&this.opt.hasPlaceholderTerm){var te=this.output;this.output=new n.Output.Queue(this),this.output.adjust=new n.Output.Queue.adjust,n.getAmbiguousCite.call(this,h,null,!1,c),this.output=te}if(this.tmp.in_cite_predecessor=!1,s>0?n.getCite.call(this,h,c,``+e[s-1][0].id,!0):(this.tmp.term_predecessor=!1,n.getCite.call(this,h,c,null,!0)),this.tmp.cite_renders_content||(x={citationID:``+this.tmp.citation_id,index:this.tmp.citation_pos,noteIndex:this.tmp.citation_note_index,itemID:``+h.id,citationItems_pos:s,error_code:n.ERROR_NO_RENDERED_FORM},this.tmp.citation_errors.push(x)),u.splice_delimiter=n.getSpliceDelimiter.call(this,ee,l,s),c&&c[`author-only`]&&(this.tmp.suppress_decorations=!0),s>0){y=e[s-1][1];var ne=y.suffix&&[`;`,`.`,`,`].indexOf(y.suffix.slice(-1))>-1,re=!y.suffix&&c.prefix&&[`;`,`.`,`,`].indexOf(c.prefix.slice(0,1))>-1;if(ne||re){var V=u.splice_delimiter.indexOf(` `);V>-1&&!re?u.splice_delimiter=u.splice_delimiter.slice(V):u.splice_delimiter=``}}if(u.suppress_decorations=this.tmp.suppress_decorations,u.have_collapsed=this.tmp.have_collapsed,a.push(u),c[`author-only`])break}d=0,m=this.output.queue.slice();var H=``;t&&(H=n.checkSuffixSpacePrepend(this,t.properties.suffix));var U=this.citation.opt.layout_suffix,W=this.tmp.cite_locales[this.tmp.cite_locales.length-1];W&&this.tmp.cite_affixes[this.tmp.area][W]&&this.tmp.cite_affixes[this.tmp.area][W].suffix&&(U=this.tmp.cite_affixes[this.tmp.area][W].suffix),n.TERMINAL_PUNCTUATION.slice(0,-1).indexOf(U.slice(0,1))>-1&&(U=U.slice(0,1)),U=this.output.checkNestedBrace.update(H+U);for(var M=0,N=this.output.queue.length;M<N;M+=1)n.Output.Queue.purgeEmptyBlobs(this.output.queue[M]);if(!this.tmp.suppress_decorations&&this.output.queue.length&&(this.opt.development_extensions.apply_citation_wrapper&&this.sys.wrapCitationEntry&&!this.tmp.just_looking&&this.tmp.area===`citation`||(D||(this.output.queue[this.output.queue.length-1].strings.suffix=U),this.output.queue[0].strings.prefix=E)),this.opt.development_extensions.clean_up_csl_flaws)for(var z=0,B=this.output.queue.length;z<B;z+=1)this.output.adjust.upward(this.output.queue[z]),this.output.adjust.leftward(this.output.queue[z]),this.output.adjust.downward(this.output.queue[z]),this.tmp.last_chr=this.output.adjust.fix(this.output.queue[z]);for(s=0,o=m.length;s<o;s+=1){var G=[];if(this.output.queue=[m[s]],this.tmp.suppress_decorations=a[s].suppress_decorations,this.tmp.splice_delimiter=a[s].splice_delimiter,m[s].parallel_delimiter&&(this.tmp.splice_delimiter=m[s].parallel_delimiter),this.tmp.have_collapsed=a[s].have_collapsed,f=this.output.string(this,this.output.queue),this.tmp.suppress_decorations=!1,typeof f==`string`)return this.tmp.suppress_decorations=!1,f||(this.opt.development_extensions.throw_on_empty?n.error(`Citation would render no content`):f=`[NO_PRINTED_FORM]`),f;if(typeof f==`object`&&f.length===0&&!c[`suppress-author`]){if(s===0){var ie=`[CSL STYLE ERROR: reference with no printed form.]`,K=s===0?b(this.citation.opt.layout_prefix):``,q=s===m.length-1?b(this.citation.opt.layout_suffix):``;f.push(K+ie+q)}else if(s===m.length-1){var ae=i[i.length-1];typeof ae==`string`?i[i.length-1]+=b(this.citation.opt.layout_suffix):typeof ae==`object`&&(ae.strings.suffix+=b(this.citation.opt.layout_suffix))}}if(G.length&&typeof f[0]==`string`){f.reverse();var J=f.pop();J&&J.slice(0,1)===`,`?G.push(J):typeof G.slice(-1)[0]==`string`&&G.slice(-1)[0].slice(-1)===`,`?G.push(` `+J):J&&G.push(b(this.tmp.splice_delimiter)+J)}else f.reverse(),p=f.pop(),p!==void 0&&(G.length&&typeof G[G.length-1]==`string`&&(G[G.length-1]+=p.successor_prefix),G.push(p));for(g=f.length,_=0;_<g;_+=1){if(v=f[_],typeof v==`string`){G.push(b(this.tmp.splice_delimiter)+v);continue}p=f.pop(),p!==void 0&&G.push(p)}G.length===0&&!e[s][1][`suppress-author`]&&(d+=1),G.length>1&&typeof G[0]!=`string`&&(G=[this.output.renderBlobs(G)]),G.length&&(typeof G[0]==`string`?s>0&&(G[0]=b(this.tmp.splice_delimiter)+G[0]):s>0?G[0].splice_prefix=this.tmp.splice_delimiter:G[0].splice_prefix=``),i=i.concat(G)}if(r+=this.output.renderBlobs(i),r&&!this.tmp.suppress_decorations)for(o=this.citation.opt.layout_decorations.length,s=0;s<o;s+=1)u=this.citation.opt.layout_decorations[s],u[1]!==`normal`&&(!c||!c[`author-only`])&&(r=this.fun.decorate[u[0]][u[1]](this,r));return this.tmp.suppress_decorations=!1,r||(this.opt.development_extensions.throw_on_empty?n.error(`Citation would render no content`):r=`[NO_PRINTED_FORM]`),r},n.getCite=function(e,t,r,i){var a,o,s=this.tmp.area;for(t&&t[`author-only`]&&this.intext&&this.intext.tokens.length>0&&(this.tmp.area=`intext`),this.tmp.cite_renders_content=!1,this.tmp.probably_rendered_something=!1,this.tmp.prevItemID=r,n.citeStart.call(this,e,t,i),a=0,this.tmp.name_node={},this.nameOutput=new n.NameOutput(this,e,t);a<this[this.tmp.area].tokens.length;)a=n.tokenExec.call(this,this[this.tmp.area].tokens[a],e,t);return n.citeEnd.call(this,e,t),!this.tmp.cite_renders_content&&!this.tmp.just_looking&&this.tmp.area===`bibliography`&&(o={index:this.tmp.bibliography_pos,itemID:``+e.id,error_code:n.ERROR_NO_RENDERED_FORM},this.tmp.bibliography_errors.push(o)),this.tmp.area=s,``+e.id},n.citeStart=function(e,t,r){if(this.tmp.lang_array=[],e.language){var i=e.language.match(/^([a-zA-Z]+).*/);i&&this.tmp.lang_array.push(i[1].toLowerCase())}if(this.tmp.lang_array.push(this.opt.lang),r||(this.tmp.shadow_numbers={}),this.tmp.disambiguate_count=0,this.tmp.disambiguate_maxMax=0,this.tmp.same_author_as_previous_cite=!1,this.tmp.suppress_decorations?this.tmp.subsequent_author_substitute_ok=!1:this.tmp.subsequent_author_substitute_ok=!0,this.tmp.lastchr=``,this.tmp.area===`citation`&&this.citation.opt.collapse&&this.citation.opt.collapse.length?this.tmp.have_collapsed=!0:this.tmp.have_collapsed=!1,this.tmp.render_seen=!1,this.tmp.disambig_request&&!this.tmp.disambig_override?this.tmp.disambig_settings=this.tmp.disambig_request:this.registry.registry[e.id]&&!this.tmp.disambig_override?(this.tmp.disambig_request=this.registry.registry[e.id].disambig,this.tmp.disambig_settings=this.registry.registry[e.id].disambig):this.tmp.disambig_settings=new n.AmbigConfig,this.tmp.area!==`citation`){if(!this.registry.registry[e.id])this.tmp.disambig_restore=new n.AmbigConfig;else if(this.tmp.disambig_restore=n.cloneAmbigConfig(this.registry.registry[e.id].disambig),this.tmp.area===`bibliography`&&this.tmp.disambig_settings&&this.tmp.disambig_override&&(this.opt[`disambiguate-add-names`]&&(this.tmp.disambig_settings.names=this.registry.registry[e.id].disambig.names.slice(),this.tmp.disambig_request&&(this.tmp.disambig_request.names=this.registry.registry[e.id].disambig.names.slice())),this.opt[`disambiguate-add-givenname`])){this.tmp.disambig_request=this.tmp.disambig_settings,this.tmp.disambig_settings.givens=this.registry.registry[e.id].disambig.givens.slice(),this.tmp.disambig_request.givens=this.registry.registry[e.id].disambig.givens.slice();for(var a=0,o=this.tmp.disambig_settings.givens.length;a<o;a+=1)this.tmp.disambig_settings.givens[a]=this.registry.registry[e.id].disambig.givens[a].slice();for(var a=0,o=this.tmp.disambig_request.givens.length;a<o;a+=1)this.tmp.disambig_request.givens[a]=this.registry.registry[e.id].disambig.givens[a].slice()}}this.tmp.names_used=[],this.tmp.nameset_counter=0,this.tmp.years_used=[],this.tmp.names_max.clear(),this.tmp.just_looking||(!t||t.parallel===`first`||!t.parallel)&&(this.tmp.abbrev_trimmer={QUASHES:{}}),this.tmp.splice_delimiter=this[this.tmp.area].opt.layout_delimiter,this.bibliography_sort.keys=[],this.citation_sort.keys=[],this.tmp.has_done_year_suffix=!1,this.tmp.last_cite_locale=!1,!this.tmp.just_looking&&t&&!t.position&&this.registry.registry[e.id]&&(this.tmp.disambig_restore=n.cloneAmbigConfig(this.registry.registry[e.id].disambig)),this.tmp.first_name_string=!1,this.tmp.authority_stop_last=0},n.citeEnd=function(e,t){if(this.tmp.disambig_restore&&this.registry.registry[e.id]){this.registry.registry[e.id].disambig.names=this.tmp.disambig_restore.names.slice(),this.registry.registry[e.id].disambig.givens=this.tmp.disambig_restore.givens.slice();for(var n=0,r=this.registry.registry[e.id].disambig.givens.length;n<r;n+=1)this.registry.registry[e.id].disambig.givens[n]=this.tmp.disambig_restore.givens[n].slice()}if(this.tmp.disambig_restore=!1,t&&t.suffix?this.tmp.last_suffix_used=t.suffix:this.tmp.last_suffix_used=``,this.tmp.last_years_used=this.tmp.years_used.slice(),this.tmp.last_names_used=this.tmp.names_used.slice(),this.tmp.cut_var=!1,this.tmp.disambig_request=!1,this.tmp.cite_locales.push(this.tmp.last_cite_locale),this.tmp.issued_date&&this.tmp.renders_collection_number){for(var i=[],n=this.tmp.issued_date.list.length-1;n>this.tmp.issued_date.pos;n+=-1)i.push(this.tmp.issued_date.list.pop());for(this.tmp.issued_date.list.pop(),n=i.length-1;n>-1;n+=-1)this.tmp.issued_date.list.push(i.pop())}this.tmp.issued_date=!1,this.tmp.renders_collection_number=!1},n.Engine.prototype.makeBibliography=function(e){var t=!1,r,i,a,o,s,c,l,u;if(!e&&(this.bibliography.opt.exclude_types||this.bibliography.opt.exclude_with_fields)){if(e={exclude:[]},this.bibliography.opt.exclude_types)for(var d in this.bibliography.opt.exclude_types){var f=this.bibliography.opt.exclude_types[d];e.exclude.push({field:`type`,value:f})}if(this.bibliography.opt.exclude_with_fields)for(var d in this.bibliography.opt.exclude_with_fields){var p=this.bibliography.opt.exclude_with_fields[d];e.exclude.push({field:p,value:!0})}}if(!this.bibliography.tokens.length)return!1;if(typeof e==`string`&&(this.opt.citation_number_slug=e,e=!1),t){for(o=this.bibliography.tokens.length,s=0;s<o;s+=1)c=this.bibliography.tokens[s],n.debug(`bibtok: `+c.name);for(n.debug(`---`),o=this.citation.tokens.length,s=0;s<o;s+=1)this.citation.tokens[s],n.debug(`cittok: `+c.name);for(n.debug(`---`),o=this.bibliography_sort.tokens.length,s=0;s<o;s+=1)this.bibliography_sort.tokens[s],n.debug(`bibsorttok: `+c.name)}r=n.getBibliographyEntries.call(this,e),l=r[0],u=r[1];var m=r[2];for(i={maxoffset:0,entryspacing:this.bibliography.opt[`entry-spacing`],linespacing:this.bibliography.opt[`line-spacing`],"second-field-align":!1,entry_ids:l,bibliography_errors:this.tmp.bibliography_errors.slice(),done:m},this.bibliography.opt[`second-field-align`]&&(i[`second-field-align`]=this.bibliography.opt[`second-field-align`]),o=this.registry.reflist.length,s=0;s<o;s+=1)a=this.registry.reflist[s],a.offset>i.maxoffset&&(i.maxoffset=a.offset);return this.bibliography.opt.hangingindent&&(i.hangingindent=this.bibliography.opt.hangingindent),i.bibstart=this.fun.decorate.bibstart,i.bibend=this.fun.decorate.bibend,this.opt.citation_number_slug=!1,[i,u]},n.getBibliographyEntries=function(e){var t=[],r,i,a,o,s,c,l,u,d,f,p,m,h,g,_,v,y,b,x=[],S,C;this.tmp.area=`bibliography`,this.tmp.root=`bibliography`,this.tmp.last_rendered_name=!1,this.tmp.bibliography_errors=[],this.tmp.bibliography_pos=0,r=e&&e.page_start&&e.page_length?this.registry.getSortedIds():this.refetchItems(this.registry.getSortedIds()),this.tmp.disambig_override=!0;function w(e,t){return e===t}function T(e,t){for(d=t.length,f=0;f<d;f+=1)if(w(e,t[f]))return!0;return!1}function E(e,t){return typeof e==`boolean`||!e?e?!!t:!t:typeof t==`string`?w(e,t):t?T(e,t):!1}y={};var D;if(e&&e.page_start&&e.page_length&&(D=0,e.page_start!==!0))for(g=0,_=r.length;g<_&&(y[r[g]]=!0,e.page_start!=r[g]);g+=1);var O=[],k={};for(this.tmp.container_item_count={},r=r.filter(e=>{var t=e;return e.legislation_id?k[e.legislation_id]?t=!1:k[e.legislation_id]=!0:e.container_id&&(this.tmp.container_item_count[e.container_id]||(this.tmp.container_item_count[e.container_id]=0),this.tmp.container_item_count[e.container_id]++,this.bibliography.opt.consolidate_containers.indexOf(e.type)>-1&&(k[e.container_id]?t=!1:k[e.container_id]=!0)),t}),this.tmp.container_item_pos={},g=0,_=r.length;g<_;g+=1){if(e&&e.page_start&&e.page_length){if(y[r[g]])continue;if(l=this.refetchItem(r[g]),D===e.page_length)break}else if(l=r[g],y[l.id])continue;if(e){if(i=!0,e.include){for(i=!1,S=0,C=e.include.length;S<C;S+=1)if(u=e.include[S],E(u.value,l[u.field])){i=!0;break}}else if(e.exclude){for(a=!1,S=0,C=e.exclude.length;S<C;S+=1)if(u=e.exclude[S],E(u.value,l[u.field])){a=!0;break}a&&(i=!1)}else if(e.select){for(i=!1,o=!0,S=0,C=e.select.length;S<C;S+=1)u=e.select[S],E(u.value,l[u.field])||(o=!1);o&&(i=!0)}if(e.quash){for(o=!0,S=0,C=e.quash.length;S<C;S+=1)u=e.quash[S],E(u.value,l[u.field])||(o=!1);o&&(i=!1)}if(!i)continue}if(h&&n.debug(`BIB: `+l.id),l.container_id&&(this.tmp.container_item_pos[l.container_id]||(this.tmp.container_item_pos[l.container_id]=0),this.tmp.container_item_pos[l.container_id]++),s=new n.Token(`group`,n.START),s.decorations=[[`@bibliography`,`entry`]].concat(this.bibliography.opt.layout_decorations),this.output.startTag(`bib_entry`,s),l.system_id&&this.sys.embedBibliographyEntry?this.output.current.value().item_id=l.system_id:this.output.current.value().system_id=l.id,m=[],this.registry.registry[l.id].master&&!(e&&e.page_start&&e.page_length)){b=[[l,{id:l.id}]],v=this.registry.registry[l.id].siblings;for(var S=0,C=v.length;S<C;S++)b.push([this.refetchItem(v[S]),{id:v[S]}]);for(this.parallel.StartCitation(b),this.registry.registry[l.id].parallel_delimiter_override?this.output.queue[0].strings.delimiter=this.registry.registry[l.id].parallel_delimiter_override:this.output.queue[0].strings.delimiter=`, `,this.tmp.term_predecessor=!1,this.tmp.cite_index=0,S=0,C=b.length;S<C;S+=1)S<b.length-1?this.tmp.parallel_and_not_last=!0:delete this.tmp.parallel_and_not_last,m.push(``+n.getCite.call(this,b[S][0],b[S][1])),this.tmp.cite_index++,y[b[S][0].id]=!0}else this.registry.registry[l.id].siblings||(this.tmp.term_predecessor=!1,this.tmp.cite_index=0,m.push(``+n.getCite.call(this,l)),e&&e.page_start&&e.page_length&&(D+=1));for(x.push(``),this.tmp.bibliography_pos+=1,O.push(m),this.output.endTag(`bib_entry`),this.output.queue[0].blobs.length&&this.output.queue[0].blobs[0].blobs.length&&(p=this.output.queue[0].blobs[0].blobs[0].strings?this.output.queue[0].blobs[0].blobs:this.output.queue[0].blobs,p[0].strings.prefix=this.bibliography.opt.layout_prefix+p[0].strings.prefix),S=0,C=this.output.queue.length;S<C;S+=1)n.Output.Queue.purgeEmptyBlobs(this.output.queue[S]);for(S=0,C=this.output.queue.length;S<C;S+=1)this.output.adjust.upward(this.output.queue[S]),this.output.adjust.leftward(this.output.queue[S]),this.output.adjust.downward(this.output.queue[S],!0),this.output.adjust.fix(this.output.queue[S]);if(c=this.output.string(this,this.output.queue)[0],!c&&this.opt.update_mode===n.NUMERIC){var A=t.length+1+`. [CSL STYLE ERROR: reference with no printed form.]`;c=n.Output.Formats[this.opt.mode][`@bibliography/entry`](this,A)}c&&t.push(c)}var j=!1;if(e&&e.page_start&&e.page_length){var M=r.slice(-1)[0],N=O.slice(-1)[0];(!M||!N||M==N)&&(j=!0)}return this.tmp.disambig_override=!1,[O,t,j]},n.Engine.prototype.setCitationId=function(e,t){var n=!1,r,i;if(!e.citationID||t){for(r=Math.floor(Math.random()*0x5af3107a4000);;){if(i=0,this.registry.citationreg.citationById[r])i=!i&&r<5e13?1:-1;else{e.citationID=`a`+r.toString(32);break}i===1?r+=1:r+=-1}n=``+r}return this.registry.citationreg.citationById[e.citationID]=e,n},n.Engine.prototype.rebuildProcessorState=function(e,t,r){e||(e=[]),t||(t=`html`);for(var i={},a=[],o=0,s=e.length;o<s;o+=1)for(var c=0,l=e[o].citationItems.length;c<l;c+=1){var u=``+e[o].citationItems[c].id;i[u]||a.push(u),i[u]=!0}this.updateItems(a);var d=[],f=[],p=[],m=this.opt.mode;this.setOutputFormat(t);for(var o=0,s=e.length;o<s;o+=1){var h=this.processCitationCluster(e[o],d,f,n.ASSUME_ALL_ITEMS_REGISTERED);d.push([e[o].citationID,e[o].properties.noteIndex]);for(var c=0,l=h[1].length;c<l;c+=1){var g=h[1][c][0];p[g]=[d[g][0],d[g][1],h[1][c][1]]}}return this.updateUncitedItems(r),this.setOutputFormat(m),p},n.Engine.prototype.restoreProcessorState=function(e){var t,r,i,a,o,s,c,l=[],u=[],d;e||(e=[]);var f=[],p={};for(t=0,r=e.length;t<r;t+=1)p[e[t].citationID]&&this.setCitationId(e[t],!0),p[e[t].citationID]=!0,f.push(e[t].properties.index);var m=e.slice();for(m.sort(function(e,t){return e.properties.index<t.properties.index?-1:e.properties.index>t.properties.index?1:0}),t=0,r=m.length;t<r;t+=1)m[t].properties.index=t;for(t=0,r=m.length;t<r;t+=1){for(d=[],i=0,a=m[t].citationItems.length;i<a;i+=1)o=m[t].citationItems[i],o.sortkeys===void 0&&(o.sortkeys=[]),s=this.retrieveItem(``+o.id),c=[s,o],d.push(c),m[t].citationItems[i].item=s,u.push(``+o.id);m[t].properties.unsorted||d.sort(this.citation.srt.compareCompositeKeys),m[t].sortedItems=d,this.registry.citationreg.citationById[m[t].citationID]=m[t]}for(this.updateItems(u),t=0,r=e.length;t<r;t+=1)l.push([``+e[t].citationID,e[t].properties.noteIndex]);var h=[];return e&&e.length?h=this.processCitationCluster(e[0],[],l.slice(1)):(this.registry=new n.Registry(this),this.tmp=new n.Engine.Tmp,this.disambiguate=new n.Disambiguation(this)),h},n.Engine.prototype.updateItems=function(e,t,r,i){var a=!1,o=this.tmp.area,s=this.tmp.root,c=this.tmp.extension;if(this.bibliography_sort.tokens.length===0&&(t=!0),this.tmp.area=`citation`,this.tmp.root=`citation`,this.tmp.extension=``,i||(this.tmp.loadedItemIDs={}),a&&n.debug(`--> init <--`),this.registry.init(e),r)for(var l in this.registry.ambigcites)this.registry.ambigsTouched[l]=!0;return this.registry.dodeletes(this.registry.myhash),this.registry.doinserts(this.registry.mylist),this.registry.dorefreshes(),this.registry.rebuildlist(t),this.registry.setsortkeys(),this.registry.setdisambigs(),this.registry.sorttokens(t),this.registry.renumber(),this.tmp.extension=c,this.tmp.area=o,this.tmp.root=s,this.registry.getSortedIds()},n.Engine.prototype.updateUncitedItems=function(e,t){var n,r=this.tmp.area,i=this.tmp.root,a=this.tmp.extension;if(this.bibliography_sort.tokens.length===0&&(t=!0),this.tmp.area=`citation`,this.tmp.root=`citation`,this.tmp.extension=``,this.tmp.loadedItemIDs={},e||(e=[]),typeof e==`object`){if(e.length===void 0)for(var o in n=e,e=[],n)e.push(o);else if(typeof e.length==`number`){n={};for(var s=0,c=e.length;s<c;s+=1)n[e[s]]=!0}}return this.registry.init(e,!0),this.registry.dopurge(n),this.registry.doinserts(this.registry.mylist),this.registry.dorefreshes(),this.registry.rebuildlist(t),this.registry.setsortkeys(),this.registry.setdisambigs(),this.registry.sorttokens(t),this.registry.renumber(),this.tmp.extension=a,this.tmp.area=r,this.tmp.root=i,this.registry.getSortedIds()},n.localeResolve=function(e,t){var r,i;return t||(t=`en-US`),e||(e=t),r={},i=e.split(/[\-_]/),r.base=n.LANG_BASES[i[0]],r.base===void 0?{base:t,best:e,bare:i[0]}:(i.length===1&&(r.generic=!0),i.length===1||i[1]===`x`?r.best=r.base.replace(`_`,`-`):r.best=i.slice(0,2).join(`-`),r.base=r.base.replace(`_`,`-`),r.bare=i[0],r)},n.Engine.prototype.localeConfigure=function(e,t){var r;if(!(t&&this.locale[e.best])&&(e.best===`en-US`?(r=n.setupXml(this.sys.retrieveLocale(`en-US`)),this.localeSet(r,`en-US`,e.best)):e.best!==`en-US`&&(e.base!==e.best&&(r=n.setupXml(this.sys.retrieveLocale(e.base)),this.localeSet(r,e.base,e.best)),r=n.setupXml(this.sys.retrieveLocale(e.best)),this.localeSet(r,e.best,e.best)),this.localeSet(this.cslXml,``,e.best),this.localeSet(this.cslXml,e.bare,e.best),e.base!==e.best&&this.localeSet(this.cslXml,e.base,e.best),this.localeSet(this.cslXml,e.best,e.best),this.locale[e.best].terms[`page-range-delimiter`]===void 0&&([`fr`,`pt`].indexOf(e.best.slice(0,2).toLowerCase())>-1?this.locale[e.best].terms[`page-range-delimiter`]=`-`:this.locale[e.best].terms[`page-range-delimiter`]=`–`),this.locale[e.best].terms[`year-range-delimiter`]===void 0&&(this.locale[e.best].terms[`year-range-delimiter`]=`–`),this.locale[e.best].terms[`citation-range-delimiter`]===void 0&&(this.locale[e.best].terms[`citation-range-delimiter`]=`–`),this.opt.development_extensions.normalize_lang_keys_to_lowercase)){for(var i=[`default-locale`,`locale-sort`,`locale-translit`,`locale-translat`],a=0,o=i.length;a<o;a+=1)for(var s=0,c=this.opt[i[a]].length;s<c;s+=1)this.opt[i[a]][s]=this.opt[i[a]][s].toLowerCase();this.opt.lang=this.opt.lang.toLowerCase()}},n.Engine.prototype.localeSet=function(e,t,r){var i,a,o,s,c,l,u,d,f,p,m,h,g,_,v,y;if(t=t.replace(`_`,`-`),r=r.replace(`_`,`-`),this.opt.development_extensions.normalize_lang_keys_to_lowercase&&(t=t.toLowerCase(),r=r.toLowerCase()),this.locale[r]||(this.locale[r]={},this.locale[r].terms={},this.locale[r].opts={},this.locale[r].opts[`skip-words`]=n.SKIP_WORDS,this.locale[r].opts[`leading-noise-words`]||(this.locale[r].opts[`leading-noise-words`]=[]),this.locale[r].dates={},this.locale[r].ord={"1.0.1":!1,keys:{}},this.locale[r][`noun-genders`]={}),a=e.makeXml(),e.nodeNameIs(e.dataObj,`locale`))a=e.dataObj;else{o=e.getNodesByName(e.dataObj,`locale`);var b=!1;for(c=0,h=e.numberofnodes(o);c<h;c+=1)if(i=o[c],!b&&e.getAttributeValue(i,`lang`,`xml`)===t)a=i,b=!0;else{var x=e.getAttributeValue(i,`lang`,`xml`),S=e.getNodesByName(i,`style-options`);if(x&&S&&S.length){var C=e.getAttributeValue(S[0],`jurisdiction-preference`);C&&(this.locale[x]||(this.locale[x]={opts:{}}),this.locale[x].opts[`jurisdiction-preference`]=C.split(/\s+/))}}}for(o=e.getNodesByName(a,`type`),v=0,y=e.numberofnodes(o);v<y;v+=1){var w=o[v],T=e.getAttributeValue(w,`name`),E=e.getAttributeValue(w,`gender`);this.opt.gender[T]=E}if(e.getNodesByName(a,`term`,`ordinal`).length){for(var D in this.locale[r].ord.keys)delete this.locale[r].terms[D];this.locale[r].ord={"1.0.1":!1,keys:{}}}o=e.getNodesByName(a,`term`);var O={"last-digit":{},"last-two-digits":{},"whole-number":{}},k=!1,A={};for(c=0,h=e.numberofnodes(o);c<h;c+=1){if(l=o[c],d=e.getAttributeValue(l,`name`),d===`sub verbo`&&(d=`sub-verbo`),d.slice(0,7)===`ordinal`){if(d===`ordinal`)k=!0;else{var j=e.getAttributeValue(l,`match`),M=d.slice(8),g=e.getAttributeValue(l,`gender-form`);g||(g=`neuter`),j||(j=`last-two-digits`,M.slice(0,1)===`0`&&(j=`last-digit`)),M.slice(0,1)===`0`&&(M=M.slice(1)),O[j][M]||(O[j][M]={}),O[j][M][g]=d}this.locale[r].ord.keys[d]=!0}this.locale[r].terms[d]===void 0&&(this.locale[r].terms[d]={}),u=`long`,g=!1,e.getAttributeValue(l,`form`)&&(u=e.getAttributeValue(l,`form`)),e.getAttributeValue(l,`gender-form`)&&(g=e.getAttributeValue(l,`gender-form`)),e.getAttributeValue(l,`gender`)&&(this.locale[r][`noun-genders`][d]=e.getAttributeValue(l,`gender`)),g?(this.locale[r].terms[d][g]={},this.locale[r].terms[d][g][u]=[],_=this.locale[r].terms[d][g],A[d]=!0):(this.locale[r].terms[d][u]=[],_=this.locale[r].terms[d]),e.numberofnodes(e.getNodesByName(l,`multiple`))?(_[u][0]=e.getNodeValue(l,`single`),_[u][0].indexOf(`%s`)>-1&&(this.opt.hasPlaceholderTerm=!0),_[u][1]=e.getNodeValue(l,`multiple`),_[u][1].indexOf(`%s`)>-1&&(this.opt.hasPlaceholderTerm=!0)):(_[u]=e.getNodeValue(l),_[u].indexOf(`%s`)>-1&&(this.opt.hasPlaceholderTerm=!0))}if(this.locale[r].terms.supplement||(this.locale[r].terms.supplement={}),this.locale[r].terms.supplement.long||(this.locale[r].terms.supplement.long=[`supplement`,`supplements`]),k){for(var N in A){var P={},F=0;for(var I in this.locale[r].terms[N])[`masculine`,`feminine`].indexOf(I)>-1?P[I]=this.locale[r].terms[N][I]:F+=1;if(!F){if(P.feminine)for(var I in P.feminine)this.locale[r].terms[N][I]=P.feminine[I];else if(P.masculine)for(var I in P.masculine)this.locale[r].terms[N][I]=P.masculine[I]}}this.locale[r].ord[`1.0.1`]=O}for(d in this.locale[r].terms)for(v=0,y=2;v<y;v+=1)if(g=n.GENDERS[v],this.locale[r].terms[d][g])for(u in this.locale[r].terms[d])this.locale[r].terms[d][g][u]||(this.locale[r].terms[d][g][u]=this.locale[r].terms[d][u]);for(o=e.getNodesByName(a,`style-options`),c=0,h=e.numberofnodes(o);c<h;c+=1)for(m in f=o[c],s=e.attributes(f),s)if(s.hasOwnProperty(m)){if(m===`@punctuation-in-quote`||m===`@limit-day-ordinals-to-day-1`)s[m]===`true`?this.locale[r].opts[m.slice(1)]=!0:this.locale[r].opts[m.slice(1)]=!1;else if(m===`@jurisdiction-preference`){var L=s[m].split(/\s+/);this.locale[r].opts[m.slice(1)]=L}else if(m===`@skip-words`){var R=s[m].split(/\s*,\s*/);this.locale[r].opts[m.slice(1)]=R}else if(m===`@leading-noise-words`){var z=s[m].split(/\s*,\s*/);this.locale[r].opts[`leading-noise-words`]=z}else if(m===`@name-as-sort-order`){this.locale[r].opts[`name-as-sort-order`]={};for(var B=s[m].split(/\s+/),v=0,y=B.length;v<y;v+=1)this.locale[r].opts[`name-as-sort-order`][B[v]]=!0}else if(m===`@name-as-reverse-order`){this.locale[r].opts[`name-as-reverse-order`]={};for(var B=s[m].split(/\s+/),v=0,y=B.length;v<y;v+=1)this.locale[r].opts[`name-as-reverse-order`][B[v]]=!0}else if(m===`@name-never-short`){this.locale[r].opts[`name-never-short`]={};for(var B=s[m].split(/\s+/),v=0,y=B.length;v<y;v+=1)this.locale[r].opts[`name-never-short`][B[v]]=!0}}for(o=e.getNodesByName(a,`date`),c=0,h=e.numberofnodes(o);c<h;c+=1){var p=o[c];this.locale[r].dates[e.getAttributeValue(p,`form`)]=p}n.SET_COURT_CLASSES(this,r,e,a)},n.getLocaleNames=function(e,t){var r=n.setupXml(e);function i(e,t){var r=[`base`,`best`];if(t)for(var i=n.localeResolve(t),a=0,o=r.length;a<o;a++)i[r[a]]&&e.indexOf(i[r[a]])===-1&&e.push(i[r[a]])}var a=[`en-US`];function o(e){for(var t=r.getNodesByName(r.dataObj,e),n=0,i=t.length;n<i;n++){var o=r.getAttributeValue(t[n],`locale`);if(o){o=o.split(/ +/);for(var s=0,c=o.length;s<c;s++)this.extendLocaleList(a,o[s])}}}i(a,t);var s=r.getNodesByName(r.dataObj,`style`)[0];i(a,r.getAttributeValue(s,`default-locale`));for(var c=[`layout`,`if`,`else-if`,`condition`],l=0,u=c.length;l<u;l++)o(r,a,c[l]);return a},n.Node={},n.Node.bibliography={build:function(e,t){this.tokentype===n.START&&(e.build.area=`bibliography`,e.build.root=`bibliography`,e.build.extension=``,this.execs.push(function(e){e.tmp.area=`bibliography`,e.tmp.root=`bibliography`,e.tmp.extension=``})),t.push(this)}},n.Node.choose={build:function(e,t){var r;this.tokentype===n.START&&(r=function(e){e.tmp.jump.push(void 0,n.LITERAL)}),this.tokentype===n.END&&(r=function(e){e.tmp.jump.pop()}),this.execs.push(r),t.push(this)},configure:function(e,t){this.tokentype===n.END?(e.configure.fail.push(t),e.configure.succeed.push(t)):(e.configure.fail.pop(),e.configure.succeed.pop())}},n.Node.citation={build:function(e,t){if(this.tokentype===n.START&&(e.build.area=`citation`,e.build.root=`citation`,e.build.extension=``,this.execs.push(function(e){e.tmp.area=`citation`,e.tmp.root=`citation`,e.tmp.extension=``})),this.tokentype===n.END){if(e.opt.grouped_sort=e.opt.xclass===`in-text`&&e.citation.opt.collapse&&e.citation.opt.collapse.length||e.citation.opt.cite_group_delimiter&&e.citation.opt.cite_group_delimiter.length&&e.opt.update_mode!==n.POSITION&&e.opt.update_mode!==n.NUMERIC,e.opt.grouped_sort&&e.citation_sort.opt.sort_directions.length){var r=e.citation_sort.opt.sort_directions[0].slice();e.citation_sort.opt.sort_directions=[r].concat(e.citation_sort.opt.sort_directions)}e.citation.srt=new n.Registry.Comparifier(e,`citation_sort`)}t.push(this)}},n.Node[`#comment`]={build:function(){}},n.Node.date={build:function(e,t){var r,i,a,o,s,c,l,u,d,f;(this.tokentype===n.START||this.tokentype===n.SINGLETON)&&(e.dateput.string(e,e.dateput.queue),e.tmp.date_token=n.Util.cloneToken(this),e.tmp.date_token.strings.prefix=``,e.tmp.date_token.strings.suffix=``,e.dateput.openLevel(this),e.build.date_parts=[],e.build.date_variables=this.variables,e.build.extension||n.Util.substituteStart.call(this,e,t),r=e.build.extension?n.dateMacroAsSortKey:function(e,t,n){var r;if(e.tmp.element_rendered_ok=!1,e.tmp.donesies=[],e.tmp.dateparts=[],r=[],this.variables.length&&!(e.tmp.just_looking&&this.variables[0]===`accessed`)){for(i=t[this.variables[0]],i===void 0&&(i={"date-parts":[[0]]},e.opt.development_extensions.locator_date_and_revision&&n&&this.variables[0]===`locator-date`&&n[`locator-date`]&&(i=n[`locator-date`])),e.tmp.date_object=i,a=this.dateparts.length,o=0;o<a;o+=1)s=this.dateparts[o],e.tmp.date_object[s+`_end`]===void 0?s===`month`&&e.tmp.date_object.season_end!==void 0&&r.push(s):r.push(s);for(c=[],l=[`year`,`month`,`day`],a=l.length,o=0;o<a;o+=1)r.indexOf(l[o])>-1&&c.push(l[o]);for(r=c.slice(),u=2,a=r.length,o=0;o<a;o+=1)if(s=r[o],d=e.tmp.date_object[s],f=e.tmp.date_object[s+`_end`],d!==f){u=o;break}e.tmp.date_collapse_at=r.slice(u)}else e.tmp.date_object=!1},this.execs.push(r),r=function(e,t){if(t[this.variables[0]]&&(e.output.startTag(`date`,this),this.variables[0]===`issued`&&(t.type===`legal_case`||t.type===`legislation`)&&e.opt.disable_duplicate_year_suppression.indexOf(t.country)===-1&&!e.tmp.extension&&``+t[`collection-number`]==``+e.tmp.date_object.year&&this.dateparts.length===1&&this.dateparts[0]===`year`)){for(var n in e.tmp.date_object)if(e.tmp.date_object.hasOwnProperty(n)&&n.slice(0,4)===`year`){e.tmp.issued_date={};var r=e.output.current.mystack.slice(-2)[0].blobs;e.tmp.issued_date.list=r,e.tmp.issued_date.pos=r.length-1}}},this.execs.push(r)),!e.build.extension&&(this.tokentype===n.END||this.tokentype===n.SINGLETON)&&(r=function(e,t){t[this.variables[0]]&&e.output.endTag()},this.execs.push(r)),t.push(this),(this.tokentype===n.END||this.tokentype===n.SINGLETON)&&(e.build.extension||n.Util.substituteEnd.call(this,e,t))}},n.Node[`date-part`]={build:function(e,t){var r,i,a,o,s,c,l,u,d,f,p,m,h,g,_,v,y,b,x,S,C;this.strings.form||(this.strings.form=`long`),e.build.date_parts.push(this.strings.name);var w=e.build.date_variables[0];function T(t,r,i){if(!i)return i;if(i=``+n.Util.Dates[this.strings.name][t](e,i,r,this.default_locale),this.strings.name===`month`){if(e.tmp.strip_periods)i=i.replace(/\./g,``);else for(var a=0,o=this.decorations.length;a<o;a+=1)if(this.decorations[a][0]===`@strip-periods`&&this.decorations[a][1]===`true`){i=i.replace(/\./g,``);break}}return i}r=function(e,t){if(e.tmp.date_object)e.tmp.probably_rendered_something=!0;else return;var r=``;if(o=!0,s=``,c=``,e.tmp.donesies.push(this.strings.name),e.tmp.date_object.literal&&this.strings.name===`year`&&(r=e.tmp.date_object.literal,e.output.append(e.tmp.date_object.literal,this)),e.tmp.date_object&&(s=e.tmp.date_object[this.strings.name],c=e.tmp.date_object[this.strings.name+`_end`]),this.strings.name===`year`&&s===0&&!e.tmp.suppress_decorations&&(s=!1),l=!e.tmp.suppress_decorations,u=e.tmp.have_collapsed,d=e[e.tmp.area].opt.collapse===`year-suffix`||e[e.tmp.area].opt.collapse===`year-suffix-ranged`,f=e.opt[`disambiguate-add-year-suffix`],l&&f&&d&&(e.tmp.years_used.push(s),p=e.tmp.last_years_used.length>=e.tmp.years_used.length,p&&u&&e.tmp.last_years_used[e.tmp.years_used.length-1]===s&&(s=!1)),s!==void 0){m=!1,h=!1,this.strings.name===`year`&&(parseInt(s,10)<500&&parseInt(s,10)>0&&(h=e.getTerm(`ad`)),parseInt(s,10)<0&&(m=e.getTerm(`bc`),s=parseInt(s,10)*-1),c&&(parseInt(c,10)<500&&parseInt(c,10)>0&&e.getTerm(`ad`),parseInt(c,10)<0&&(e.getTerm(`bc`),c=parseInt(c,10)*-1)));for(var E=``+e.tmp.date_object.month;E.length<2;)E=`0`+E;E=`month-`+E;var D=e.locale[e.opt.lang][`noun-genders`][E];if(this.strings.form){var O=this.strings.form,k=this.strings.form;this.strings.name===`day`&&O===`ordinal`&&e.locale[e.opt.lang].opts[`limit-day-ordinals-to-day-1`]&&(s!=1&&(O=`numeric`),c!=1&&(k=`numeric`)),s=T.call(this,O,D,s),c=T.call(this,k,D,c)}if(e.output.openLevel(`empty`),e.tmp.date_collapse_at.length){for(g=!0,a=e.tmp.date_collapse_at.length,i=0;i<a;i+=1)if(S=e.tmp.date_collapse_at[i],e.tmp.donesies.indexOf(S)===-1){g=!1;break}if(g){if(``+c!=`0`){if(e.dateput.queue.length===0&&(o=!0),e.opt[`year-range-format`]&&e.opt[`year-range-format`]!==`expanded`&&!e.tmp.date_object.day&&!e.tmp.date_object.month&&!e.tmp.date_object.season&&this.strings.name===`year`&&s&&c){c=e.fun.year_mangler(s+`-`+c,!0);var A=e.getTerm(`year-range-delimiter`);c=c.slice(c.indexOf(A)+1)}r=c,e.dateput.append(c,this),o&&(C=e.dateput.current.value().blobs[0],C&&(C.strings.prefix=``))}r=s,e.output.append(s,this),_=e.output.current.value(),C=_.blobs[_.blobs.length-1],C&&(C.strings.suffix=``),this.strings[`range-delimiter`]?e.output.append(this.strings[`range-delimiter`]):e.output.append(e.getTerm(`year-range-delimiter`),`empty`),e.dateput.closeLevel(),v=e.dateput.current.value(),_.blobs=_.blobs.concat(v),e.dateput.string(e,e.dateput.queue),e.dateput.openLevel(e.tmp.date_token),e.tmp.date_collapse_at=[]}else r=s,e.output.append(s,this),e.tmp.date_collapse_at.indexOf(this.strings.name)>-1&&``+c!=`0`&&(e.dateput.queue.length===0&&(o=!0),e.dateput.openLevel(`empty`),r=c,e.dateput.append(c,this),o&&(C=e.dateput.current.value().blobs[0],C&&(C.strings.prefix=``)),m&&(r=m,e.dateput.append(m)),h&&(r=h,e.dateput.append(h)),e.dateput.closeLevel())}else r=s,e.output.append(s,this);m&&(r=m,e.output.append(m)),h&&(r=h,e.output.append(h)),e.output.closeLevel()}else this.strings.name===`month`&&e.tmp.date_object.season&&(s=``+e.tmp.date_object.season,s&&s.match(/^[1-4]$/)?(e.tmp.group_context.tip.variable_success=!0,r=`winter`,e.output.append(e.getTerm(`season-0`+s),this)):s&&(r=s,e.output.append(s,this)));e.tmp.value=[],t[w]&&(s||e.tmp.have_collapsed)&&!e.opt.has_year_suffix&&this.strings.name===`year`&&!e.tmp.just_looking&&e.registry.registry[t.id]&&e.registry.registry[t.id].disambig.year_suffix!==!1&&!e.tmp.has_done_year_suffix&&(e.tmp.has_done_year_suffix=!0,r=`x`,b=parseInt(e.registry.registry[t.id].disambig.year_suffix,10),y=new n.NumericBlob(e,!1,b,this,t.id),this.successor_prefix=e[e.build.area].opt.layout_delimiter,this.splice_prefix=e[e.build.area].opt.layout_delimiter,x=new n.Util.Suffixator(n.SUFFIX_CHARS),y.setFormatter(x),e[e.tmp.area].opt.collapse===`year-suffix-ranged`&&(y.range_prefix=e.getTerm(`citation-range-delimiter`)),e[e.tmp.area].opt.cite_group_delimiter?y.successor_prefix=e[e.tmp.area].opt.cite_group_delimiter:e[e.tmp.area].opt[`year-suffix-delimiter`]?y.successor_prefix=e[e.tmp.area].opt[`year-suffix-delimiter`]:y.successor_prefix=e[e.tmp.area].opt.layout_delimiter,y.UGLY_DELIMITER_SUPPRESS_HACK=!0,e.output.append(y,`literal`)),r&&!e.tmp.group_context.tip.condition&&(e.tmp.just_did_number=r.match(/[0-9]$/),e.output.current.tip.strings.suffix&&(e.tmp.just_did_number=!1))},this.execs.push(r),t.push(this)}},n.Node[`else-if`]={build:function(e,t){n.Conditions.TopNode.call(this,e,t),t.push(this)},configure:function(e,t){n.Conditions.Configure.call(this,e,t)}},n.Node.else={build:function(e,t){t.push(this)},configure:function(e,t){this.tokentype===n.START&&(e.configure.fail[e.configure.fail.length-1]=t)}},n.Node[`et-al`]={build:function(e,t){(e.build.area===`citation`||e.build.area===`bibliography`)&&this.execs.push(function(e){e.tmp.etal_node=this,typeof this.strings.term==`string`&&(e.tmp.etal_term=this.strings.term)}),t.push(this)}},n.Node.group={build:function(e,t,r){var i,a;if(this.realGroup=r,this.tokentype===n.START&&(n.Util.substituteStart.call(this,e,t),e.build.substitute_level.value()&&e.build.substitute_level.replace(e.build.substitute_level.value()+1),this.juris||t.push(this),i=function(e){if(e.output.startTag(`group`,this),this.strings.label_form_override&&(e.tmp.group_context.tip.label_form||(e.tmp.group_context.tip.label_form=this.strings.label_form_override)),this.strings.label_capitalize_if_first_override&&(e.tmp.group_context.tip.label_capitalize_if_first||(e.tmp.group_context.tip.label_capitalize_if_first=this.strings.label_capitalize_if_first_override)),this.realGroup){e.tmp.group_context.tip.condition&&n.UPDATE_GROUP_CONTEXT_CONDITION(e,this.strings.prefix,null,this);var t=!1,r=!1;e.tmp.group_context.mystack.length&&(e.output.current.value().parent=e.tmp.group_context.tip.output_tip);var i=e.tmp.group_context.tip.label_form;i||(i=this.strings.label_form_override);var a=e.tmp.group_context.tip.label_capitalize_if_first;a||(a=this.strings.label_capitalize_if_first),e.tmp.group_context.tip.condition?(t=e.tmp.group_context.tip.condition,r=e.tmp.group_context.tip.force_suppress):this.strings.reject?t={test:this.strings.reject,not:!0}:this.strings.require&&(t={test:this.strings.require,not:!1});var o={old_term_predecessor:e.tmp.term_predecessor,term_intended:!1,variable_attempt:!1,variable_success:!1,variable_success_parent:e.tmp.group_context.tip.variable_success,output_tip:e.output.current.tip,label_form:i,label_static:e.tmp.group_context.tip.label_static,label_capitalize_if_first:a,parallel_delimiter_override:this.strings.set_parallel_delimiter_override,parallel_delimiter_override_on_suppress:this.strings.set_parallel_delimiter_override_on_suppress,condition:t,force_suppress:r,done_vars:e.tmp.group_context.tip.done_vars.slice()};if(this.non_parallel){var s=e.tmp.group_context.tip.non_parallel;s||(s={}),Object.assign(s,this.non_parallel),o.non_parallel=s}if(this.parallel_first){var c=e.tmp.group_context.tip.parallel_first;c||(c={}),Object.assign(c,this.parallel_first),o.parallel_first=c}if(this.parallel_last){var l=e.tmp.group_context.tip.parallel_last;l||(l={}),Object.assign(l,this.parallel_last),o.parallel_last=l}if(e.tmp.abbrev_trimmer&&e.tmp.abbrev_trimmer.LAST_TO_FIRST&&o.parallel_last)for(var u in o.parallel_first||(o.parallel_first={}),e.tmp.abbrev_trimmer.LAST_TO_FIRST)o.parallel_last[u]&&(o.parallel_first[u]=!0,delete o.parallel_last[u]);if(e.tmp.group_context.push(o),e.tmp.abbrev_trimmer&&this.parallel_last_to_first)for(var u in e.tmp.abbrev_trimmer.LAST_TO_FIRST||(e.tmp.abbrev_trimmer.LAST_TO_FIRST={}),this.parallel_last_to_first)e.tmp.abbrev_trimmer.LAST_TO_FIRST[u]=!0}},a=[],a.push(i),this.execs=a.concat(this.execs),this.strings[`has-publisher-and-publisher-place`]&&(e.build[`publisher-special`]=!0,this.strings[`subgroup-delimiter`]&&(i=function(e,t){if(t.publisher&&t[`publisher-place`]){var r=t.publisher.split(/;\s*/),i=t[`publisher-place`].split(/;\s*/);r.length>1&&r.length===i.length&&(e.publisherOutput=new n.PublisherOutput(e,this),e.publisherOutput[`publisher-list`]=r,e.publisherOutput[`publisher-place-list`]=i)}},this.execs.push(i))),this.juris)){var o=new n.Token(`choose`,n.START);n.Node.choose.build.call(o,e,t);var s=new n.Token(`if`,n.START);i=function(t){return function(r,i){return n.INIT_JURISDICTION_MACROS(e,r,i,t)}}(this.juris),s.tests||(s.tests=[]),s.tests.push(i),s.test=e.fun.match.any(s,e,s.tests),t.push(s);var c=new n.Token(`text`,n.SINGLETON);i=function(e,t,r){var i=t;r&&r[`best-jurisdiction`]&&this.juris===`juris-locator`&&(i=r);var a=0;if(e.juris[i[`best-jurisdiction`]][this.juris])for(;a<e.juris[i[`best-jurisdiction`]][this.juris].length;)a=n.tokenExec.call(e,e.juris[i[`best-jurisdiction`]][this.juris][a],t,r)},c.juris=this.juris,c.execs.push(i),t.push(c);var l=new n.Token(`if`,n.END);n.Node.if.build.call(l,e,t);var u=new n.Token(`else`,n.START);n.Node.else.build.call(u,e,t)}if(this.tokentype===n.END&&(e.build[`publisher-special`]&&(e.build[`publisher-special`]=!1,i=function(e){e.publisherOutput&&(e.publisherOutput.render(),e.publisherOutput=!1)},this.execs.push(i)),i=function(e,t,r){if(e.tmp.group_context.tip.condition||e.output.current.tip.strings.suffix&&(e.tmp.just_did_number=!1),e.output.endTag(),this.realGroup){var i=e.tmp.group_context.pop();if(i.parallel_delimiter_override&&(e.tmp.group_context.tip.parallel_delimiter_override=i.parallel_delimiter_override,!e.tmp.just_looking&&e.registry.registry[t.id].master&&(e.registry.registry[t.id].parallel_delimiter_override=i.parallel_delimiter_override)),i.parallel_delimiter_override_on_suppress&&(e.tmp.group_context.tip.parallel_delimiter_override_on_suppress=i.parallel_delimiter_override_on_suppress),e.tmp.area===`bibliography_sort`){var a=i.done_vars.indexOf(`citation-number`);this.strings.sort_direction&&a>-1&&e.tmp.group_context.length()==1&&(this.strings.sort_direction===n.DESCENDING?e.bibliography_sort.opt.citation_number_sort_direction=n.DESCENDING:e.bibliography_sort.opt.citation_number_sort_direction=n.ASCENDING,i.done_vars=i.done_vars.slice(0,a).concat(i.done_vars.slice(a+1)))}if(i.condition&&(i.force_suppress=n.EVALUATE_GROUP_CONDITION(e,i)),e.tmp.group_context.tip.condition&&(e.tmp.group_context.tip.force_suppress=i.force_suppress),!i.force_suppress&&(i.variable_success||i.term_intended&&!i.variable_attempt)){this.isJurisLocatorLabel||(e.tmp.group_context.tip.variable_success=!0);var o=e.output.current.value().blobs;if(e.output.current.value().blobs.length-1,!e.tmp.just_looking&&(i.non_parallel||i.parallel_last||i.parallel_first||i.parallel_delimiter_override||i.parallel_delimiter_override_on_suppress)){var s=e.parallel.checkRepeats(i);if(s&&o&&o.pop(),e.tmp.cite_index>0&&(s||!i.parallel_first&&!i.parallel_last&&!i.non_parallel)){var c=e.tmp.suppress_repeats[e.tmp.cite_index-1];s&&i.parallel_delimiter_override_on_suppress&&(c.SIBLING||c.ORPHAN)?e.output.queue.slice(-1)[0].parallel_delimiter=i.parallel_delimiter_override_on_suppress:i.parallel_delimiter_override&&c.SIBLING&&(e.output.queue.slice(-1)[0].parallel_delimiter=i.parallel_delimiter_override)}}}else{if(e.tmp.term_predecessor=i.old_term_predecessor,e.tmp.group_context.tip.variable_attempt=i.variable_attempt,i.force_suppress&&!e.tmp.group_context.tip.condition&&(e.tmp.group_context.tip.variable_attempt=!0,e.tmp.group_context.tip.variable_success=i.variable_success_parent),i.force_suppress)for(var l=0,u=i.done_vars.length;l<u;l++)for(var d=i.done_vars[l],f=0,p=e.tmp.done_vars.length;f<p;f++)e.tmp.done_vars[f]===d&&(e.tmp.done_vars=e.tmp.done_vars.slice(0,f).concat(e.tmp.done_vars.slice(f+1)));e.output.current.value().blobs&&e.output.current.value().blobs.pop()}}},this.execs.push(i),this.juris)){var d=new n.Token(`else`,n.END);n.Node.else.build.call(d,e,t);var f=new n.Token(`choose`,n.END);n.Node.choose.build.call(f,e,t)}this.tokentype===n.END&&(this.juris||t.push(this),e.build.substitute_level.value()&&e.build.substitute_level.replace(e.build.substitute_level.value()-1),n.Util.substituteEnd.call(this,e,t))}},n.Node.if={build:function(e,t){n.Conditions.TopNode.call(this,e,t),t.push(this)},configure:function(e,t){n.Conditions.Configure.call(this,e,t)}},n.Node.conditions={build:function(e){this.tokentype===n.START&&e.tmp.conditions.addMatch(this.match),this.tokentype===n.END&&e.tmp.conditions.matchCombine()}},n.Node.condition={build:function(e){if(this.tokentype===n.SINGLETON){var t=e.fun.match[this.match](this,e,this.tests);e.tmp.conditions.addTest(t)}}},n.Conditions={},n.Conditions.TopNode=function(e){var t;(this.tokentype===n.START||this.tokentype===n.SINGLETON)&&(this.locale&&(e.opt.lang=this.locale),!this.tests||!this.tests.length?e.tmp.conditions=new n.Conditions.Engine(e,this):this.test=e.fun.match[this.match](this,e,this.tests),e.build.substitute_level.value()===0&&(t=function(e){e.tmp.condition_counter++},this.execs.push(t))),(this.tokentype===n.END||this.tokentype===n.SINGLETON)&&(e.build.substitute_level.value()===0&&(t=function(e){e.tmp.condition_counter--,e.tmp.condition_lang_counter_arr.length>0&&e.tmp.condition_lang_counter_arr.slice(-1)[0]===e.tmp.condition_counter&&(e.opt.lang=e.tmp.condition_lang_val_arr.pop(),e.tmp.condition_lang_counter_arr.pop()),this.locale_default&&(e.output.current.value().old_locale=this.locale_default,e.output.closeLevel(`empty`),e.opt.lang=this.locale_default)},this.execs.push(t)),t=function(e){return this[e.tmp.jump.value()]},this.execs.push(t),this.locale_default&&(e.opt.lang=this.locale_default))},n.Conditions.Configure=function(e,t){this.tokentype===n.START?(this.fail=e.configure.fail.slice(-1)[0],this.succeed=this.next,e.configure.fail[e.configure.fail.length-1]=t):this.tokentype===n.SINGLETON?(this.fail=this.next,this.succeed=e.configure.succeed.slice(-1)[0],e.configure.fail[e.configure.fail.length-1]=t):(this.succeed=e.configure.succeed.slice(-1)[0],this.fail=this.next)},n.Conditions.Engine=function(e,t){this.token=t,this.state=e},n.Conditions.Engine.prototype.addTest=function(e){this.token.tests||(this.token.tests=[]),this.token.tests.push(e)},n.Conditions.Engine.prototype.addMatch=function(e){this.token.match=e},n.Conditions.Engine.prototype.matchCombine=function(){this.token.test=this.state.fun.match[this.token.match](this.token,this.state,this.token.tests)},n.Node.info={build:function(e){this.tokentype===n.START?e.build.skip=`info`:e.build.skip=!1}},n.Node.institution={build:function(e,t){[n.SINGLETON,n.START].indexOf(this.tokentype)>-1&&this.execs.push(function(e){typeof this.strings.delimiter==`string`?e.tmp.institution_delimiter=this.strings.delimiter:e.tmp.institution_delimiter=e.tmp.name_delimiter,e.inheritOpt(this,`and`)===`text`?this.and_term=e.getTerm(`and`,`long`,0):e.inheritOpt(this,`and`)===`symbol`?e.opt.development_extensions.expect_and_symbol_form?this.and_term=e.getTerm(`and`,`symbol`,0):this.and_term=`&`:e.inheritOpt(this,`and`)===`none`&&(this.and_term=e.tmp.institution_delimiter),this.and_term===void 0&&e.tmp.and_term&&(this.and_term=e.tmp.and_term),n.STARTSWITH_ROMANESQUE_REGEXP.test(this.and_term)?(this.and_prefix_single=` `,this.and_prefix_multiple=`, `,typeof e.tmp.institution_delimiter==`string`&&(this.and_prefix_multiple=e.tmp.institution_delimiter),this.and_suffix=` `):(this.and_prefix_single=``,this.and_prefix_multiple=``,this.and_suffix=``),e.inheritOpt(this,`delimiter-precedes-last`)===`always`?this.and_prefix_single=e.tmp.institution_delimiter:e.inheritOpt(this,`delimiter-precedes-last`)===`never`&&this.and_prefix_multiple&&(this.and_prefix_multiple=` `),this.and={},this.and_term===void 0?this.strings.delimiter!==`undefined`&&(this.and.single=new n.Blob(e.tmp.institution_delimiter),this.and.single.strings.prefix=``,this.and.single.strings.suffix=``,this.and.multiple=new n.Blob(e.tmp.institution_delimiter),this.and.multiple.strings.prefix=``,this.and.multiple.strings.suffix=``):(e.output.append(this.and_term,`empty`,!0),this.and.single=e.output.pop(),this.and.single.strings.prefix=this.and_prefix_single,this.and.single.strings.suffix=this.and_suffix,e.output.append(this.and_term,`empty`,!0),this.and.multiple=e.output.pop(),this.and.multiple.strings.prefix=this.and_prefix_multiple,this.and.multiple.strings.suffix=this.and_suffix),e.nameOutput.institution=this}),t.push(this)},configure:function(e){[n.SINGLETON,n.START].indexOf(this.tokentype)>-1&&(e.build.has_institution=!0)}},n.Node[`institution-part`]={build:function(e,t){var n;this.strings.name===`long`?n=this.strings[`if-short`]?function(e){e.nameOutput.institutionpart[`long-with-short`]=this}:function(e){e.nameOutput.institutionpart.long=this}:this.strings.name===`short`&&(n=function(e){e.nameOutput.institutionpart.short=this}),this.execs.push(n),t.push(this)}},n.Node.key={build:function(e,t){t=e[e.build.root+`_sort`].tokens;var r,i=!1,a=new n.Token(`key`,n.START);e.tmp.root=e.build.root,a.strings[`et-al-min`]=e.inheritOpt(this,`et-al-min`),a.strings[`et-al-use-first`]=e.inheritOpt(this,`et-al-use-first`),a.strings[`et-al-use-last`]=e.inheritOpt(this,`et-al-use-last`),r=function(e){e.tmp.done_vars=[]},a.execs.push(r),r=function(e){e.output.openLevel(`empty`)},a.execs.push(r);var o=[];if(this.strings.sort_direction===n.DESCENDING?(o.push(1),o.push(-1)):(o.push(-1),o.push(1)),e[e.build.area].opt.sort_directions.push(o),n.DATE_VARIABLES.indexOf(this.variables[0])>-1&&(e.build.date_key=!0),r=function(e){e.tmp.sort_key_flag=!0,e.inheritOpt(this,`et-al-min`)&&(e.tmp[`et-al-min`]=e.inheritOpt(this,`et-al-min`)),e.inheritOpt(this,`et-al-use-first`)&&(e.tmp[`et-al-use-first`]=e.inheritOpt(this,`et-al-use-first`)),typeof e.inheritOpt(this,`et-al-use-last`)==`boolean`&&(e.tmp[`et-al-use-last`]=e.inheritOpt(this,`et-al-use-last`))},a.execs.push(r),t.push(a),this.variables.length){var s=this.variables[0];if(n.NAME_VARIABLES.indexOf(s)>-1){var c=new n.Token(`names`,n.START);c.tokentype=n.START,c.variables=this.variables,n.Node.names.build.call(c,e,t);var l=new n.Token(`name`,n.SINGLETON);l.tokentype=n.SINGLETON,l.strings[`name-as-sort-order`]=`all`,l.strings[`sort-separator`]=` `,l.strings[`et-al-use-last`]=e.inheritOpt(this,`et-al-use-last`),l.strings[`et-al-min`]=e.inheritOpt(this,`et-al-min`),l.strings[`et-al-use-first`]=e.inheritOpt(this,`et-al-use-first`),n.Node.name.build.call(l,e,t);var u=new n.Token(`institution`,n.SINGLETON);u.tokentype=n.SINGLETON,n.Node.institution.build.call(u,e,t);var d=new n.Token(`names`,n.END);d.tokentype=n.END,n.Node.names.build.call(d,e,t)}else{var f=new n.Token(`text`,n.SINGLETON);f.strings.sort_direction=this.strings.sort_direction,f.dateparts=this.dateparts,n.NUMERIC_VARIABLES.indexOf(s)>-1?r=s===`citation-number`?function(e,t){if(e.tmp.area===`bibliography_sort`&&(this.strings.sort_direction===n.DESCENDING?e.bibliography_sort.opt.citation_number_sort_direction=n.DESCENDING:e.bibliography_sort.opt.citation_number_sort_direction=n.ASCENDING),e.tmp.area===`citation_sort`&&e.bibliography_sort.tmp.citation_number_map)var r=e.bibliography_sort.tmp.citation_number_map[e.registry.registry[t.id].seq];else var r=e.registry.registry[t.id].seq;r&&(r=n.Util.padding(``+r)),e.output.append(r,this)}:function(e,t){var r=!1;r=t[s],r&&(r=n.Util.padding(r)),e.output.append(r,this)}:s===`citation-label`?r=function(e,t){var n=e.getCitationLabel(t);e.output.append(n,this)}:n.DATE_VARIABLES.indexOf(s)>-1?(r=n.dateAsSortKey,f.variables=this.variables):r=s===`title`?e.transform.getOutputFunction(this.variables,`title`,!1,!1,!0):s===`court-class`?function(e,t,r){n.INIT_JURISDICTION_MACROS(e,t,r,`juris-main`);var i=n.GET_COURT_CLASS(e,t,!0);e.output.append(i,`empty`)}:function(e,t){var n=t[s];e.output.append(n,`empty`)},f.execs.push(r),t.push(f)}}else{var p=new n.Token(`text`,n.SINGLETON);p.strings.sort_direction=this.strings.sort_direction,p.postponed_macro=this.postponed_macro,n.expandMacro.call(e,p,t)}var m=new n.Token(`key`,n.END);r=function(e){var t=e.output.string(e,e.output.queue);e.sys.normalizeUnicode&&(t=e.sys.normalizeUnicode(t)),t=t?t.split(` `).join(e.opt.sort_sep)+e.opt.sort_sep:``,i&&n.debug(`keystring: `+t+` `+typeof t),t===``&&(t=void 0),typeof t!=`string`&&(t=void 0),e[e[e.tmp.area].root+`_sort`].keys.push(t),e.tmp.value=[]},m.execs.push(r),e.build.date_key&&(e.build.area===`citation`&&e.build.extension===`_sort`&&(e[e.build.area].opt.sort_directions.push([-1,1]),r=function(e,t){var r=e.registry.registry[t.id].disambig.year_suffix;r||(r=0);var i=n.Util.padding(``+r);e[e.tmp.area].keys.push(i)},m.execs.push(r)),e.build.date_key=!1),r=function(e){e.tmp[`et-al-min`]=void 0,e.tmp[`et-al-use-first`]=void 0,e.tmp[`et-al-use-last`]=void 0,e.tmp.sort_key_flag=!1},m.execs.push(r),t.push(m)}},n.Node.label={build:function(e,t){if(this.strings.term)this.execs.push(function(e,t,r){var i=n.evaluateLabel(this,e,t,r);r&&this.strings.term===`locator`&&(r.section_form_override=this.strings.form),i&&(e.tmp.group_context.tip.term_intended=!0),n.UPDATE_GROUP_CONTEXT_CONDITION(e,i,null,this),i.indexOf(`%s`)===-1&&(this.strings.capitalize_if_first&&!e.tmp.term_predecessor&&!(e.opt.class===`in-text`&&e.tmp.area===`citation`)&&(i=n.Output.Formatters[`capitalize-first`](e,i)),e.output.append(i,this))});else{this.strings.form||(this.strings.form=`long`);for(var r=e.build.names_variables[e.build.names_variables.length-1],i=e.build.name_label[e.build.name_label.length-1],a=0,o=r.length;a<o;a+=1)i[r[a]]||(i[r[a]]={});if(e.build.name_flag)for(var a=0,o=r.length;a<o;a+=1)i[r[a]].after=this;else for(var a=0,o=r.length;a<o;a+=1)i[r[a]].before=this}t.push(this)}},n.Node.layout={build:function(e,t){var r,i,a,o;function s(){e.build.area===`bibliography`&&(a=new n.Token(`text`,n.SINGLETON),r=function(e){if(!e.tmp.parallel_and_not_last){var t=e.tmp.cite_affixes[e.tmp.area][e.tmp.last_cite_locale]?e.tmp.cite_affixes[e.tmp.area][e.tmp.last_cite_locale].suffix:e.bibliography.opt.layout_suffix,n=e.output.current.value();e.opt.using_display?n.blobs[n.blobs.length-1].strings.suffix=t:n.strings.suffix=t}e.bibliography.opt[`second-field-align`]&&e.output.endTag(`bib_other`)},a.execs.push(r),t.push(a))}this.tokentype===n.START&&(this.locale_raw?e.build.current_default_locale=this.locale_raw:e.build.current_default_locale=e.opt[`default-locale`],r=function(e,t,r){if(e.opt.development_extensions.apply_citation_wrapper&&e.sys.wrapCitationEntry&&!e.tmp.just_looking&&t.system_id&&e.tmp.area===`citation`){var i=new n.Token(`group`,n.START);i.decorations=[[`@cite`,`entry`]],e.output.startTag(`cite_entry`,i),e.output.current.value().item_id=t.system_id,r&&(e.output.current.value().locator_txt=r.locator_txt,e.output.current.value().suffix_txt=r.suffix_txt)}},this.execs.push(r)),this.tokentype===n.START&&!e.tmp.cite_affixes[e.build.area]&&(r=function(e,t,n){if(e.tmp.done_vars=[],n&&n[`author-only`]&&e.tmp.done_vars.push(`locator`),e.opt.suppressedJurisdictions[t.country]&&t.country&&[`treaty`,`patent`].indexOf(t.type)===-1&&e.tmp.done_vars.push(`country`),!e.tmp.just_looking&&e.registry.registry[t.id]&&e.registry.registry[t.id].parallel&&e.tmp.done_vars.push(`first-reference-note-number`),!e.tmp.just_looking&&e.tmp.abbrev_trimmer&&t.jurisdiction)for(var r in e.tmp.abbrev_trimmer.QUASHES[t.jurisdiction])e.tmp.done_vars.push(r);e.tmp.rendered_name=!1},this.execs.push(r),r=function(e){e.tmp.sort_key_flag=!1},this.execs.push(r),r=function(e){e.tmp.nameset_counter=0},this.execs.push(r),r=function(e,t){var r=new n.Token;e.output.openLevel(r)},this.execs.push(r),t.push(this),e.build.area===`citation`&&(i=new n.Token(`text`,n.SINGLETON),r=function(e,t,r){if(r&&r.prefix){var i=n.checkPrefixSpaceAppend(e,r.prefix);e.tmp.just_looking||(i=e.output.checkNestedBrace.update(i));var a=n.checkIgnorePredecessor(e,i);e.output.append(i,this,!1,a)}},i.execs.push(r),t.push(i)));var c;if(this.locale_raw&&(c=new n.Token(`dummy`,n.START),c.locale=this.locale_raw,c.strings.delimiter=this.strings.delimiter,c.strings.suffix=this.strings.suffix,e.tmp.cite_affixes[e.build.area]||(e.tmp.cite_affixes[e.build.area]={})),this.tokentype===n.START&&(e.build.layout_flag=!0,this.locale_raw||(e[e.tmp.area].opt.topdecor=[this.decorations],e[e.tmp.area+`_sort`].opt.topdecor=[this.decorations],e[e.build.area].opt.layout_prefix=this.strings.prefix,e[e.build.area].opt.layout_suffix=this.strings.suffix,e[e.build.area].opt.layout_delimiter=this.strings.delimiter,e[e.build.area].opt.layout_decorations=this.decorations,e.tmp.cite_affixes[e.build.area]&&(o=new n.Token(`else`,n.START),n.Node.else.build.call(o,e,t))),this.locale_raw)){if(e.build.layout_locale_flag)c.name=`else-if`,n.Attributes[`@locale-internal`].call(c,e,this.locale_raw),n.Node[`else-if`].build.call(c,e,t);else{var l=new n.Token(`choose`,n.START);n.Node.choose.build.call(l,e,t),c.name=`if`,n.Attributes[`@locale-internal`].call(c,e,this.locale_raw),n.Node.if.build.call(c,e,t)}e.tmp.cite_affixes[e.build.area][c.locale]={},e.tmp.cite_affixes[e.build.area][c.locale].delimiter=this.strings.delimiter,e.tmp.cite_affixes[e.build.area][c.locale].suffix=this.strings.suffix}this.tokentype===n.END&&(this.locale_raw&&(s(),e.build.layout_locale_flag?(c.name=`else-if`,c.tokentype=n.END,n.Attributes[`@locale-internal`].call(c,e,this.locale_raw),n.Node[`else-if`].build.call(c,e,t)):(c.name=`if`,c.tokentype=n.END,n.Attributes[`@locale-internal`].call(c,e,this.locale_raw),n.Node.if.build.call(c,e,t),e.build.layout_locale_flag=!0)),this.locale_raw||(s(),e.tmp.cite_affixes[e.build.area]&&e.build.layout_locale_flag&&(o=new n.Token(`else`,n.END),n.Node.else.build.call(o,e,t),o=new n.Token(`choose`,n.END),n.Node.choose.build.call(o,e,t)),e.build_layout_locale_flag=!0,e.build.area===`citation`&&(a=new n.Token(`text`,n.SINGLETON),r=function(e,t,r){if(r&&r.suffix){var i=n.checkSuffixSpacePrepend(e,r.suffix);e.tmp.just_looking||(i=e.output.checkNestedBrace.update(i)),e.output.append(i,this)}},a.execs.push(r),t.push(a)),r=function(e){e.output.closeLevel()},this.execs.push(r),r=function(e,t){e.opt.development_extensions.apply_citation_wrapper&&e.sys.wrapCitationEntry&&!e.tmp.just_looking&&t.system_id&&e.tmp.area===`citation`&&e.output.endTag()},this.execs.push(r),t.push(this),e.build.layout_flag=!1,e.build.layout_locale_flag=!1))}},n.Node.macro={build:function(){}},n.Node.alternative={build:function(e,t){if(this.tokentype===n.START){var r=new n.Token(`choose`,n.START);n.Node.choose.build.call(r,e,t);var i=new n.Token(`if`,n.START);n.Attributes[`@alternative-node-internal`].call(i,e),n.Node.if.build.call(i,e,t);var a=function(e,t){if(e.tmp.oldItem=t,e.tmp.oldLang=e.opt.lang,e.tmp.abort_alternative=!0,t[`language-name`]&&t[`language-name-original`]){var r=JSON.parse(JSON.stringify(t));r.language=r[`language-name`];var i=n.localeResolve(r.language,e.opt[`default-locale`][0]);if(e.opt.multi_layout)for(var a in e.opt.multi_layout){var o=e.opt.multi_layout[a],s=!1;for(var c in o){var l=o[c];if(i.best===l.best||i.base===l.base||i.bare===l.bare){s=o[0].best;break}}s||(s=e.opt[`default-locale`][0]),e.opt.lang=s}for(var u in r)if([`id`,`type`,`language`,`multi`].indexOf(u)===-1&&u.slice(0,4)!==`alt-`)if(r.multi&&r.multi._keys[u]){var d=!0;for(var f in r.multi._keys[u])if(i.bare===f.replace(/^([a-zA-Z]+).*/,`$1`)){d=!1;break}d&&delete r[u]}else delete r[u];for(var u in r)u.slice(0,4)===`alt-`?(r[u.slice(4)]=r[u],e.tmp.abort_alternative=!1):r.multi&&r.multi._keys&&!r[`alt-`+u]&&r.multi._keys[u]&&(r.multi._keys[u][i.best]?(r[u]=r.multi._keys[u][i.best],e.tmp.abort_alternative=!1):r.multi._keys[u][i.base]?(r[u]=r.multi._keys[u][i.base],e.tmp.abort_alternative=!1):r.multi._keys[u][i.bare]&&(r[u]=r.multi._keys[u][i.bare],e.tmp.abort_alternative=!1))}e.output.openLevel(this),e.registry.refhash[t.id]=r,e.nameOutput=new n.NameOutput(e,r)};this.execs.push(a),t.push(this);var r=new n.Token(`choose`,n.START);n.Node.choose.build.call(r,e,t);var i=new n.Token(`if`,n.START);n.Attributes[`@alternative-node-internal`].call(i,e);var a=function(e){e.tmp.abort_alternative=!0};i.execs.push(a),n.Node.if.build.call(i,e,t)}else if(this.tokentype===n.END){var i=new n.Token(`if`,n.END);n.Node.if.build.call(i,e,t);var r=new n.Token(`choose`,n.END);n.Node.choose.build.call(r,e,t);var a=function(e,t){e.output.closeLevel(),e.registry.refhash[t.id]=e.tmp.oldItem,e.opt.lang=e.tmp.oldLang,e.nameOutput=new n.NameOutput(e,e.tmp.oldItem),e.tmp.abort_alternative=!1};this.execs.push(a),t.push(this);var i=new n.Token(`if`,n.END);n.Node.if.build.call(i,e,t);var r=new n.Token(`choose`,n.END);n.Node.choose.build.call(r,e,t)}}},n.Node[`alternative-text`]={build:function(e,t){this.tokentype===n.SINGLETON&&this.execs.push(function(e,t){var t=e.refetchItem(t.id);n.getCite.call(e,t)}),t.push(this)}},n.NameOutput=function(e,t,n){this.debug=!1,this.state=e,this.debug&&this.state.sys.print(`(1)`),this.Item=t,this.item=n,this.nameset_base=0,this.etal_spec={},this._first_creator_variable=!1,this._please_chop=!1},n.NameOutput.prototype.init=function(e){this.requireMatch=e.requireMatch,this.state.tmp.term_predecessor&&(this.state.tmp.subsequent_author_substitute_ok=!1),this.nameset_offset&&(this.nameset_base+=this.nameset_offset),this.nameset_offset=0,this.names=e,this.variables=e.variables,this.state.tmp.value=[],this.state.tmp.rendered_name=[],this.state.tmp.label_blob=!1,this.state.tmp.etal_node=!1,this.state.tmp.etal_term=!1;for(var t=0,n=this.variables.length;t<n;t+=1)this.Item[this.variables[t]]&&this.Item[this.variables[t]].length&&(this.state.tmp.value=this.state.tmp.value.concat(this.Item[this.variables[t]]));if(this[`et-al`]=void 0,this.with=void 0,this.name=void 0,this.institutionpart={},this.state.tmp.group_context.tip.variable_attempt=!0,this.labelVariable=this.variables[0],this.state.tmp.value.length&&this.checkCommonAuthor(this.requireMatch)){for(var t in this.state.tmp.can_substitute.pop(),this.state.tmp.can_substitute.push(!0),this.variables){var r=this.state.tmp.done_vars.indexOf(this.variables[t]);r>-1&&(this.state.tmp.done_vars=this.state.tmp.done_vars.slice(0,r).concat(this.state.tmp.done_vars.slice(t+1)))}this.state.tmp.common_term_match_fail=!0,this.variables=[]}},n.NameOutput.prototype.reinit=function(e,t){if(this.requireMatch=e.requireMatch,this.labelVariable=t,this.state.tmp.can_substitute.value()){this.nameset_offset=0,this.variables=e.variables;var r=this.state.tmp.value.slice();this.state.tmp.value=[];for(var i=0,a=this.variables.length;i<a;i+=1)this.Item[this.variables[i]]&&this.Item[this.variables[i]].length&&(this.state.tmp.value=this.state.tmp.value.concat(this.Item[this.variables[i]]));this.state.tmp.value.length&&this.state.tmp.can_substitute.replace(!1,n.LITERAL),this.state.tmp.value=r}if(this.checkCommonAuthor(this.requireMatch)){for(var i in this.state.tmp.can_substitute.pop(),this.state.tmp.can_substitute.push(!0),this.variables){var o=this.state.tmp.done_vars.indexOf(this.variables[i]);o>-1&&(this.state.tmp.done_vars=this.state.tmp.done_vars.slice(0,o).concat(this.state.tmp.done_vars.slice(i+1)))}this.variables=[]}},n.NameOutput.prototype.outputNames=function(){var e,t,r=this.variables;if(this.institution.and&&((!this.institution.and.single.blobs||!this.institution.and.single.blobs.length)&&(this.institution.and.single.blobs=this.name.and.single.blobs),(!this.institution.and.multiple.blobs||!this.institution.and.multiple.blobs.length)&&(this.institution.and.multiple.blobs=this.name.and.multiple.blobs)),this.variable_offset={},this.family)for(this.family_decor=n.Util.cloneToken(this.family),this.family_decor.strings.prefix=``,this.family_decor.strings.suffix=``,e=0,t=this.family.execs.length;e<t;e+=1)this.family.execs[e].call(this.family_decor,this.state,this.Item);else this.family_decor=!1;if(this.given)for(this.given_decor=n.Util.cloneToken(this.given),this.given_decor.strings.prefix=``,this.given_decor.strings.suffix=``,e=0,t=this.given.execs.length;e<t;e+=1)this.given.execs[e].call(this.given_decor,this.state,this.Item);else this.given_decor=!1;if(this.debug&&this.state.sys.print(`(2)`),this.getEtAlConfig(),this.debug&&this.state.sys.print(`(3)`),this.divideAndTransliterateNames(),this.debug&&this.state.sys.print(`(4)`),this.truncatePersonalNameLists(),this.debug&&this.state.sys.print(`(5)`),this.debug&&this.state.sys.print(`(6)`),this.disambigNames(),this.constrainNames(),this.debug&&this.state.sys.print(`(7)`),this.name.strings.form===`count`){(this.state.tmp.extension||this.names_count!=0)&&(this.state.output.append(this.names_count,`empty`),this.state.tmp.group_context.tip.variable_success=!0);return}this.debug&&this.state.sys.print(`(8)`),this.setEtAlParameters(),this.debug&&this.state.sys.print(`(9)`),this.setCommonTerm(this.requireMatch),this.debug&&this.state.sys.print(`(10)`),this.renderAllNames(),this.debug&&this.state.sys.print(`(11)`);var i=[];for(e=0,t=r.length;e<t;e+=1){var a=r[e],o=[],s=!1,c=null;if(!this.state.opt.development_extensions.spoof_institutional_affiliations)c=this._join([this.freeters[a]],``);else{this.debug&&this.state.sys.print(`(11a)`);for(var l=0,u=this.institutions[a].length;l<u;l+=1)o.push(this.joinPersonsAndInstitutions([this.persons[a][l],this.institutions[a][l]]));if(this.debug&&this.state.sys.print(`(11b)`),this.institutions[a].length){var d=this.nameset_base+this.variable_offset[a];this.freeters[a].length&&(d+=1),s=this.joinInstitutionSets(o,d)}this.debug&&this.state.sys.print(`(11c)`);var c=this.joinFreetersAndInstitutionSets([this.freeters[a],s]);this.debug&&this.state.sys.print(`(11d)`)}if(c&&(this.state.tmp.extension||(c=this._applyLabels(c,a)),i.push(c)),this.debug&&this.state.sys.print(`(11e)`),this.common_term)break}for(this.debug&&this.state.sys.print(`(12)`),this.state.output.openLevel(`empty`),this.state.output.current.value().strings.delimiter=this.state.inheritOpt(this.names,`delimiter`,`names-delimiter`),this.debug&&this.state.sys.print(`(13)`),e=0,t=i.length;e<t;e+=1)this.state.output.append(i[e],`literal`,!0);!this.state.tmp.just_looking&&i.length>0&&(this.state.tmp.probably_rendered_something=!0),this.debug&&this.state.sys.print(`(14)`),this.state.output.closeLevel(`empty`),this.debug&&this.state.sys.print(`(15)`);var f=this.state.output.pop();this.state.tmp.name_node.top=f,this.debug&&this.state.sys.print(`(16)`);var p=n.Util.cloneToken(this.names);if(this.state.tmp.group_context.tip.condition&&n.UPDATE_GROUP_CONTEXT_CONDITION(this.state,this.names.strings.prefix,null,this.names),this.state.output.append(f,p),this.state.tmp.term_predecessor_name&&(this.state.tmp.term_predecessor=!0),this.debug&&this.state.sys.print(`(17)`),this.debug&&this.state.sys.print(`(18)`),r[0]!==`authority`){var m=[],h=this.Item[r[0]];if(h)for(var e=0,t=h.length;e<t;e+=1){var g=n.Util.Names.getRawName(h[e]);g&&m.push(g)}m=m.join(`, `),m&&(this.state.tmp.name_node.string=m)}if(this.state.tmp.name_node.string&&!this.state.tmp.first_name_string&&(this.state.tmp.first_name_string=this.state.tmp.name_node.string),this.Item.type===`classic`&&this.state.tmp.first_name_string){var _=[];_.push(this.state.tmp.first_name_string),this.Item.title&&_.push(this.Item.title),_=_.join(`, `),_&&this.state.sys.getAbbreviation&&(this.state.sys.normalizeAbbrevsKey&&(_=this.state.sys.normalizeAbbrevsKey(`classic`,_)),this.state.transform.loadAbbreviation(`default`,`classic`,_,this.Item.language),this.state.transform.abbrevs.default.classic[_]&&(this.state.tmp.done_vars.push(`title`),this.state.output.append(this.state.transform.abbrevs.default.classic[_],`empty`,!0),f=this.state.output.pop(),this.state.tmp.name_node.top.blobs.pop(),this.state.tmp.name_node.top.blobs.push(f)))}this._collapseAuthor(),this.variables=[],this.state.tmp.authority_stop_last=0,this.debug&&this.state.sys.print(`(19)`)},n.NameOutput.prototype._applyLabels=function(e,t){var n;if(!this.label||!this.label[this.labelVariable])return e;var r=0,i=this.freeters_count[t]+this.institutions_count[t];if(i>1)r=1;else{for(var a=0,o=this.persons[t].length;a<o;a+=1)i+=this.persons_count[t][a];i>1&&(r=1)}return this.label[this.labelVariable].before?(typeof this.label[this.labelVariable].before.strings.plural==`number`&&(r=this.label[this.labelVariable].before.strings.plural),n=this._buildLabel(t,r,`before`,this.labelVariable),this.state.output.openLevel(`empty`),this.state.output.append(n,this.label[this.labelVariable].before,!0),this.state.output.append(e,`literal`,!0),this.state.output.closeLevel(`empty`),e=this.state.output.pop()):this.label[this.labelVariable].after&&(typeof this.label[this.labelVariable].after.strings.plural==`number`&&(r=this.label[this.labelVariable].after.strings.plural),n=this._buildLabel(t,r,`after`,this.labelVariable),this.state.output.openLevel(`empty`),this.state.output.append(e,`literal`,!0),this.state.output.append(n,this.label[this.labelVariable].after,!0),this.state.tmp.label_blob=this.state.output.pop(),this.state.output.append(this.state.tmp.label_blob,`literal`,!0),this.state.output.closeLevel(`empty`),e=this.state.output.pop()),e},n.NameOutput.prototype._buildLabel=function(e,t,r,i){this.common_term&&(e=this.common_term);var a=!1,o=this.label[i][r];return o&&(a=n.castLabel(this.state,o,e,t,n.TOLERANT)),a},n.NameOutput.prototype._collapseAuthor=function(){var e,t,n;this.state.tmp.name_node.top.blobs.length!==0&&(this.nameset_base===0&&this.Item[this.variables[0]]&&!this._first_creator_variable&&(this._first_creator_variable=this.variables[0]),(this.state[this.state.tmp.area].opt.collapse&&this.state[this.state.tmp.area].opt.collapse.length||this.state[this.state.tmp.area].opt.cite_group_delimiter&&this.state[this.state.tmp.area].opt.cite_group_delimiter.length)&&(this.state.tmp.authorstring_request?(t=``,e=this.state.tmp.name_node.top.blobs.slice(-1)[0].blobs,n=this.state.tmp.offset_characters,e&&(t=this.state.output.string(this.state,e,!1)),this.state.tmp.offset_characters=n,this.state.registry.authorstrings[this.Item.id]=t):!this.state.tmp.just_looking&&!this.state.tmp.suppress_decorations&&(this.state[this.state.tmp.area].opt.collapse&&this.state[this.state.tmp.area].opt.collapse.length||this.state[this.state.tmp.area].opt.cite_group_delimiter&&this.state[this.state.tmp.area].opt.cite_group_delimiter)&&(t=``,e=this.state.tmp.name_node.top.blobs.slice(-1)[0].blobs,n=this.state.tmp.offset_characters,e&&(t=this.state.output.string(this.state,e,!1)),t===this.state.tmp.last_primary_names_string?((this.item[`suppress-author`]||this.state[this.state.tmp.area].opt.collapse&&this.state[this.state.tmp.area].opt.collapse.length)&&(this.state.tmp.name_node.top.blobs.pop(),this.state.tmp.name_node.children=[],this.state.tmp.offset_characters=n),this.state[this.state.tmp.area].opt.cite_group_delimiter&&this.state[this.state.tmp.area].opt.cite_group_delimiter&&(this.state.tmp.use_cite_group_delimiter=!0)):(this.state.tmp.last_primary_names_string=t,this.variables.indexOf(this._first_creator_variable)>-1&&this.item&&this.item[`suppress-author`]&&this.Item.type!==`legal_case`&&(this.state.tmp.name_node.top.blobs.pop(),this.state.tmp.name_node.children=[],this.state.tmp.offset_characters=n,this.state.tmp.term_predecessor=!1),this.state.tmp.have_collapsed=!1,this.state[this.state.tmp.area].opt.cite_group_delimiter&&this.state[this.state.tmp.area].opt.cite_group_delimiter&&(this.state.tmp.use_cite_group_delimiter=!1)))))},n.NameOutput.prototype.isPerson=function(e){return!(e.literal||!e.given&&e.family&&e.isInstitution)},n.NameOutput.prototype.truncatePersonalNameLists=function(){var e,t,n,r,i,a;for(e in this.freeters_count={},this.persons_count={},this.institutions_count={},this.freeters)this.freeters.hasOwnProperty(e)&&(this.freeters_count[e]=this.freeters[e].length,this.freeters[e]=this._truncateNameList(this.freeters,e));for(e in this.persons)if(this.persons.hasOwnProperty(e))for(this.institutions_count[e]=this.institutions[e].length,this._truncateNameList(this.institutions,e),this.persons[e]=this.persons[e].slice(0,this.institutions[e].length),this.persons_count[e]=[],r=0,i=this.persons[e].length;r<i;r+=1)this.persons_count[e][r]=this.persons[e][r].length,this.persons[e][r]=this._truncateNameList(this.persons,e,r);if(a=this.state.opt.development_extensions.etal_min_etal_usefirst_hack&&this.etal_min===1&&this.etal_use_first===1&&!(this.state.tmp.extension||this.state.tmp.just_looking)?e:!1,a||this._please_chop)for(t=0,n=this.variables.length;t<n;t+=1){e=this.variables[t],this.freeters[e].length&&(this._please_chop===e?(this.freeters[e]=this.freeters[e].slice(1),this.freeters_count[e]+=-1,this._please_chop=!1):a&&!this._please_chop&&(this.freeters[e]=this.freeters[e].slice(0,1),this.freeters_count[e]=1,this.institutions[e]=[],this.persons[e]=[],this._please_chop=a));for(var r=0,i=this.persons[e].length;r<i;r++)if(this.persons[e][r].length){if(this._please_chop===e){this.persons[e][r]=this.persons[e][r].slice(1),this.persons_count[e][r]+=-1,this._please_chop=!1;break}else if(a&&!this._please_chop){this.freeters[e]=this.persons[e][r].slice(0,1),this.freeters_count[e]=1,this.institutions[e]=[],this.persons[e]=[],this._please_chop=a;break}}this.institutions[e].length&&(this._please_chop===e?(this.institutions[e]=this.institutions[e].slice(1),this.institutions_count[e]+=-1,this._please_chop=!1):a&&!this._please_chop&&(this.institutions[e]=this.institutions[e].slice(0,1),this.institutions_count[e]=1,this._please_chop=a))}for(t=0,n=this.variables.length;t<n;t+=1){this.institutions[e].length&&(this.nameset_offset+=1);for(var r=0,i=this.persons[e].length;r<i;r++)this.persons[e][r].length&&(this.nameset_offset+=1)}},n.NameOutput.prototype._truncateNameList=function(e,t,n){var r=n===void 0?e[t]:e[t][n];if(this.state[this.state[this.state.tmp.area].root].opt.max_number_of_names&&r.length>50&&r.length>this.state[this.state[this.state.tmp.area].root].opt.max_number_of_names+2){var i=this.state[this.state[this.state.tmp.area].root].opt.max_number_of_names;r=r.slice(0,i+1).concat(r.slice(-1))}return r},n.NameOutput.prototype.divideAndTransliterateNames=function(){var e,t,n,r,i=this.Item,a=this.variables;for(this.varnames=a.slice(),this.freeters={},this.persons={},this.institutions={},e=0,t=a.length;e<t;e+=1){var o=a[e];this.variable_offset[o]=this.nameset_offset;var s=this._normalizeVariableValue(i,o);if(this.name.strings[`suppress-min`]&&s.length>=this.name.strings[`suppress-min`]&&(s=[]),this.name.strings[`suppress-max`]&&s.length<=this.name.strings[`suppress-max`]&&(s=[]),this._getFreeters(o,s),this._getPersonsAndInstitutions(o,s),this.state.opt.development_extensions.spoof_institutional_affiliations){if(this.name.strings[`suppress-min`]===0)for(this.freeters[o]=[],n=0,r=this.persons[o].length;n<r;n+=1)this.persons[o][n]=[];else if(this.institution.strings[`suppress-min`]===0){for(this.institutions[o]=[],this.freeters[o]=this.freeters[o].concat(this.persons[o]),n=0,r=this.persons[o].length;n<r;n+=1)for(var c=0,l=this.persons[o][n].length;c<l;c+=1)this.freeters[o].push(this.persons[o][n][c]);this.persons[o]=[]}}}},n.NameOutput.prototype._normalizeVariableValue=function(e,t){var r;return typeof e[t]==`string`||typeof e[t]==`number`?(n.debug(`name variable "`+t+`" is string or number, not array. Attempting to fix.`),r=[{literal:e[t]+``}]):e[t]?typeof e[t].length==`number`?r=e[t].slice():(n.debug(`name variable "`+t+`" is object, not array. Attempting to fix.`),e[t]=[e[t]],r=e[t].slice()):r=[],r},n.NameOutput.prototype._getFreeters=function(e,t){if(this.freeters[e]=[],this.state.opt.development_extensions.spoof_institutional_affiliations)for(var n=t.length-1;n>-1&&this.isPerson(t[n]);n--){var r=this._checkNickname(t.pop());r&&this.freeters[e].push(r)}else for(var n=t.length-1;n>-1;n--){var r=t.pop();if(this.isPerson(r))var r=this._checkNickname(r);this.freeters[e].push(r)}this.freeters[e].reverse(),this.freeters[e].length&&(this.nameset_offset+=1)},n.NameOutput.prototype._getPersonsAndInstitutions=function(e,t){if(this.persons[e]=[],this.institutions[e]=[],this.state.opt.development_extensions.spoof_institutional_affiliations){for(var n=[],r=!1,i=!0,a=t.length-1;a>-1;a+=-1)if(this.isPerson(t[a])){var o=this._checkNickname(t[a]);o&&n.push(o)}else r=!0,this.institutions[e].push(t[a]),i||(n.reverse(),this.persons[e].push(n),n=[]),i=!1;r&&(n.reverse(),this.persons[e].push(n),this.persons[e].reverse(),this.institutions[e].reverse())}},n.NameOutput.prototype._clearValues=function(e){for(var t=e.length-1;t>-1;t+=-1)e.pop()},n.NameOutput.prototype._checkNickname=function(e){if([`interview`,`personal_communication`].indexOf(this.Item.type)>-1){var t=``;if(t=n.Util.Names.getRawName(e),t&&this.state.sys.getAbbreviation&&!(this.item&&this.item[`suppress-author`])){var r=t;this.state.sys.normalizeAbbrevsKey&&(r=this.state.sys.normalizeAbbrevsKey(`author`,t)),this.state.transform.loadAbbreviation(`default`,`nickname`,r,this.Item.language);var i=this.state.transform.abbrevs.default.nickname[r];i&&(e=i===`!here>>>`?!1:{family:i,given:``})}}return e},n.NameOutput.prototype._purgeEmptyBlobs=function(e){for(var t=e.length-1;t>-1;t+=-1)(!e[t]||e[t].length===0||!e[t].blobs.length)&&(e=e.slice(0,t).concat(e.slice(t+1)));return e},n.NameOutput.prototype.joinPersons=function(e,t,n,r){var i;return e=this._purgeEmptyBlobs(e),r||(r=`name`),i=n===void 0?this.etal_spec[t].freeters===1?this._joinEtAl(e):this.etal_spec[t].freeters===2?this._joinEllipsis(e):this.state.tmp.sort_key_flag?this._join(e,this.state.inheritOpt(this.name,`delimiter`,`name-delimiter`,`, `)):this._joinAnd(e):this.etal_spec[t].persons[n]===1?this._joinEtAl(e):this.etal_spec[t].persons[n]===2?this._joinEllipsis(e):this.state.tmp.sort_key_flag?this._join(e,this.state.inheritOpt(this.name,`delimiter`,`name-delimiter`,`, `)):this._joinAnd(e),i},n.NameOutput.prototype.joinInstitutionSets=function(e,t){var n;return e=this._purgeEmptyBlobs(e),n=this.etal_spec[t].institutions===1?this._joinEtAl(e,`institution`):this.etal_spec[t].institutions===2?this._joinEllipsis(e,`institution`):this._joinAnd(e),n},n.NameOutput.prototype.joinPersonsAndInstitutions=function(e){e=this._purgeEmptyBlobs(e);var t=this._join(e,this.state.tmp.name_delimiter);return t.isInstitution=!0,t},n.NameOutput.prototype.joinFreetersAndInstitutionSets=function(e){return e=this._purgeEmptyBlobs(e),this._join(e,`[never here]`,this.with.single,this.with.multiple)},n.NameOutput.prototype._getAfterInvertedName=function(e,t,n){if(n&&e.length>1&&this.state.inheritOpt(this.name,`delimiter-precedes-last`)===`after-inverted-name`){var r=e[e.length-2];r.blobs.length>0&&r.blobs[0].isInverted&&(n.strings.prefix=t)}return n},n.NameOutput.prototype._getAndJoin=function(e,t){var n=!1;if(e.length>1){var r=`single`;e.length>2&&(r=`multiple`),n=e[e.length-1].isInstitution?this.institution.and[r]:this.name.and[r],n=JSON.parse(JSON.stringify(n)),n=this._getAfterInvertedName(e,t,n)}return n},n.NameOutput.prototype._joinEtAl=function(e){var t=this.state.inheritOpt(this.name,`delimiter`,`name-delimiter`,`, `),n=this._join(e,t);return this.state.output.openLevel(this._getToken(`name`)),this.state.output.current.value().strings.delimiter=``,this.state.output.append(n,`literal`,!0),e.length>1?this.state.output.append(this[`et-al`].multiple,`literal`,!0):e.length===1&&this.state.output.append(this[`et-al`].single,`literal`,!0),this.state.output.closeLevel(),this.state.output.pop()},n.NameOutput.prototype._joinEllipsis=function(e){var t=this.state.inheritOpt(this.name,`delimiter`,`name-delimiter`,`, `),n=!1;if(e.length>1){var r=`single`;e.length>2&&(r=`multiple`),n=JSON.parse(JSON.stringify(this.name.ellipsis[r])),n=this._getAfterInvertedName(e,t,n)}return this._join(e,t,n)},n.NameOutput.prototype._joinAnd=function(e){var t=this.state.inheritOpt(this.name,`delimiter`,`name-delimiter`,`, `),n=this._getAndJoin(e,t);return this._join(e,t,n)},n.NameOutput.prototype._join=function(e,t,n){var r,i;if(!e||(e=this._purgeEmptyBlobs(e),!e.length))return!1;if(e.length>1)if(e.length===2)n?e=[e[0],n,e[1]]:e[0].strings.suffix+=t;else{for(var a=n?1:0,o=e.pop(),r=0,i=e.length-a;r<i;r++)e[r].strings.suffix+=t;e.push(n),e.push(o)}for(this.state.output.openLevel(),r=0,i=e.length;r<i;r+=1)this.state.output.append(e[r],!1,!0);return this.state.output.closeLevel(),this.state.output.pop()},n.NameOutput.prototype._getToken=function(e){var t=this[e];return e===`institution`?new n.Token:t},n.NameOutput.prototype.checkCommonAuthor=function(e){if(!e)return!1;var t=!1;if(this.variables.length===2){var n=this.variables.slice();n.sort(),t=n.join(``)}if(!t)return!1;var r=!1;if(this.state.locale[this.state.opt.lang].terms[t]&&(r=!0),!r)return this.state.tmp.done_vars.push(this.variables[0]),this.state.tmp.done_vars.push(this.variables[1]),!1;var i=this.Item[this.variables[0]],a=this.Item[this.variables[1]],o=this._compareNamesets(i,a);return o===!0&&(this.state.tmp.done_vars.push(this.variables[0]),this.state.tmp.done_vars.push(this.variables[1])),!o},n.NameOutput.prototype.setCommonTerm=function(){var e=this.variables.slice();if(e.sort(),this.common_term=e.join(``),this.common_term){var t=!1;if(this.label&&this.label[this.variables[0]]&&(this.label[this.variables[0]].before?t=this.state.getTerm(this.common_term,this.label[this.variables[0]].before.strings.form,0):this.label[this.variables[0]].after&&(t=this.state.getTerm(this.common_term,this.label[this.variables[0]].after.strings.form,0))),!this.state.locale[this.state.opt.lang].terms[this.common_term]||!t||this.variables.length<2){this.common_term=!1;return}for(var n=0,r=0,i=this.variables.length-1;r<i;r+=1){var a=this.variables[r],o=this.variables[r+1];if(this.freeters[a].length||this.freeters[o].length){if(this.etal_spec[a].freeters!==this.etal_spec[o].freeters||!this._compareNamesets(this.freeters[a],this.freeters[o])){this.common_term=!1;return}n+=1}if(this.persons[a].length!==this.persons[o].length){this.common_term=!1;return}for(var s=0,c=this.persons[a].length;s<c;s+=1)if(this.etal_spec[a].persons[s]!==this.etal_spec[o].persons[s]||!this._compareNamesets(this.persons[a][s],this.persons[o][s])){this.common_term=!1;return}}}},n.NameOutput.prototype._compareNamesets=function(e,t){if(!e||!t||e.length!==t.length)return!1;for(var r=0,i=t.length;r<i;r+=1)for(var a=0,o=n.NAME_PARTS.length;a<o;a+=1){var s=n.NAME_PARTS[a];if(!e[r]||e[r][s]!=t[r][s])return!1}return!0},n.NameOutput.prototype.constrainNames=function(){this.names_count=0;for(var e,t=0,n=this.variables.length;t<n;t+=1){var r=this.variables[t];e=this.nameset_base+t,this.freeters[r].length&&(this.state.tmp.names_max.push(this.freeters[r].length,`literal`),this._imposeNameConstraints(this.freeters,this.freeters_count,r,e),this.names_count+=this.freeters[r].length),this.institutions[r].length&&(this.state.tmp.names_max.push(this.institutions[r].length,`literal`),this._imposeNameConstraints(this.institutions,this.institutions_count,r,e),this.persons[r]=this.persons[r].slice(0,this.institutions[r].length),this.names_count+=this.institutions[r].length);for(var i=0,a=this.persons[r].length;i<a;i+=1)this.persons[r][i].length&&(this.state.tmp.names_max.push(this.persons[r][i].length,`literal`),this._imposeNameConstraints(this.persons[r],this.persons_count[r],i,e),this.names_count+=this.persons[r][i].length)}},n.NameOutput.prototype._imposeNameConstraints=function(e,t,n,r){var i=e[n],a=this.state.tmp[`et-al-min`];this.state.tmp.suppress_decorations?this.state.tmp.disambig_request&&this.state.tmp.disambig_request.names[r]?a=this.state.tmp.disambig_request.names[r]:t[n]>=this.etal_min&&(a=this.etal_use_first):(this.state.tmp.disambig_request&&this.state.tmp.disambig_request.names[r]>this.etal_use_first?a=t[n]<this.etal_min?t[n]:this.state.tmp.disambig_request.names[r]:t[n]>=this.etal_min&&(a=this.etal_use_first),this.etal_use_last&&a>this.etal_min-2&&(a=this.etal_min-2));var o=this.etal_min>=this.etal_use_first,s=t[n]>a;a>t[n]&&(a=i.length),o&&s&&(this.etal_use_last?e[n]=i.slice(0,a).concat(i.slice(-1)):e[n]=i.slice(0,a)),this.state.tmp.disambig_settings.names[r]=e[n].length,this.state.disambiguate.padBase(this.state.tmp.disambig_settings)},n.NameOutput.prototype.disambigNames=function(){for(var e,t=0,n=this.variables.length;t<n;t+=1){var r=this.variables[t];if(e=this.nameset_base+t,this.freeters[r].length&&this._runDisambigNames(this.freeters[r],e),this.institutions[r].length){this.state.tmp.disambig_settings.givens[e]===void 0&&(this.state.tmp.disambig_settings.givens[e]=[]);for(var i=0,a=this.institutions[r].length;i<a;i+=1)this.state.tmp.disambig_settings.givens[e][i]===void 0&&this.state.tmp.disambig_settings.givens[e].push(2)}for(var i=0,a=this.persons[r].length;i<a;i+=1)this.persons[r][i].length&&this._runDisambigNames(this.persons[r][i],e)}},n.NameOutput.prototype._runDisambigNames=function(e,t){var r,i,a,o,s,c,l;for(s=0,c=e.length;s<c;s+=1)if(!(!e[s].given&&!e[s].family)){if(a=this.state.inheritOpt(this.name,`initialize-with`),this.state.registry.namereg.addname(``+this.Item.id,e[s],s),r=this.state.tmp.disambig_settings.givens[t],r===void 0)for(var u=0,d=t+1;u<d;u+=1)this.state.tmp.disambig_settings.givens[u]||(this.state.tmp.disambig_settings.givens[u]=[]);if(r=this.state.tmp.disambig_settings.givens[t][s],r===void 0&&(i=this.state.inheritOpt(this.name,`form`,`name-form`,`long`),o=this.state.registry.namereg.evalname(``+this.Item.id,e[s],s,0,i,a),this.state.tmp.disambig_settings.givens[t].push(o)),i=this.state.inheritOpt(this.name,`form`,`name-form`,`long`),l=this.state.registry.namereg.evalname(``+this.Item.id,e[s],s,0,i,a),this.state.tmp.disambig_request){var f=this.state.tmp.disambig_settings.givens[t][s];f===1&&this.state.citation.opt[`givenname-disambiguation-rule`]===`by-cite`&&(this.state.inheritOpt(this.name,`initialize-with`)===void 0||e[s].given===void 0)&&(f=2),o=f,this.state.opt[`disambiguate-add-givenname`]&&e[s].given&&(o=this.state.registry.namereg.evalname(``+this.Item.id,e[s],s,o,this.state.inheritOpt(this.name,`form`,`name-form`,`long`),this.state.inheritOpt(this.name,`initialize-with`)))}else o=l;!this.state.tmp.just_looking&&this.item&&this.item.position===n.POSITION_FIRST&&l>o&&(o=l),this.state.tmp.sort_key_flag||(this.state.tmp.disambig_settings.givens[t][s]=o,typeof a==`string`&&(this.name.strings.initialize===void 0||!0===this.name.strings.initialize)&&(this.state.tmp.disambig_settings.use_initials=!0))}},n.NameOutput.prototype.getEtAlConfig=function(){var e=this.item;this[`et-al`]={},this.state.output.append(this.etal_term,this.etal_style,!0),this[`et-al`].single=this.state.output.pop(),this[`et-al`].single.strings.suffix=this.etal_suffix,this[`et-al`].single.strings.prefix=this.etal_prefix_single,this.state.output.append(this.etal_term,this.etal_style,!0),this[`et-al`].multiple=this.state.output.pop(),this[`et-al`].multiple.strings.suffix=this.etal_suffix,this[`et-al`].multiple.strings.prefix=this.etal_prefix_multiple,e===void 0&&(e={}),e.position?(this.state.inheritOpt(this.name,`et-al-subsequent-min`)?this.etal_min=this.state.inheritOpt(this.name,`et-al-subsequent-min`):this.etal_min=this.state.inheritOpt(this.name,`et-al-min`),this.state.inheritOpt(this.name,`et-al-subsequent-use-first`)?this.etal_use_first=this.state.inheritOpt(this.name,`et-al-subsequent-use-first`):this.etal_use_first=this.state.inheritOpt(this.name,`et-al-use-first`)):(this.state.tmp[`et-al-min`]?this.etal_min=this.state.tmp[`et-al-min`]:this.etal_min=this.state.inheritOpt(this.name,`et-al-min`),this.state.tmp[`et-al-use-first`]?this.etal_use_first=this.state.tmp[`et-al-use-first`]:this.etal_use_first=this.state.inheritOpt(this.name,`et-al-use-first`),typeof this.state.tmp[`et-al-use-last`]==`boolean`?this.etal_use_last=this.state.tmp[`et-al-use-last`]:this.etal_use_last=this.state.inheritOpt(this.name,`et-al-use-last`)),this.state.tmp[`et-al-min`]||(this.state.tmp[`et-al-min`]=this.etal_min)},n.NameOutput.prototype.setEtAlParameters=function(){var e,t,n,r;for(e=0,t=this.variables.length;e<t;e+=1){var i=this.variables[e];for(this.etal_spec[i]===void 0&&(this.etal_spec[i]={freeters:0,institutions:0,persons:[]}),this.etal_spec[this.nameset_base+e]=this.etal_spec[i],this.freeters[i].length&&this._setEtAlParameter(`freeters`,i),n=0,r=this.persons[i].length;n<r;n+=1)this.etal_spec[i][n]===void 0&&(this.etal_spec[i].persons[n]=0),this._setEtAlParameter(`persons`,i,n);this.institutions[i].length&&this._setEtAlParameter(`institutions`,i)}},n.NameOutput.prototype._setEtAlParameter=function(e,t,n){var r,i;e===`persons`?(r=this.persons[t][n],i=this.persons_count[t][n]):(r=this[e][t],i=this[e+`_count`][t]),r.length<i&&!this.state.tmp.sort_key_flag?this.etal_use_last?e===`persons`?this.etal_spec[t].persons[n]=2:this.etal_spec[t][e]=2:e===`persons`?this.etal_spec[t].persons[n]=1:this.etal_spec[t][e]=1:e===`persons`?this.etal_spec[t].persons[n]=0:this.etal_spec[t][e]=0},n.NameOutput.prototype.renderAllNames=function(){for(var e,t=0,n=this.variables.length;t<n;t+=1){var r=this.variables[t];(this.freeters[r].length||this.institutions[r].length)&&(this.state.tmp.group_context.tip.condition||(this.state.tmp.just_did_number=!1)),e=this.nameset_base+t,this.freeters[r].length&&(this.freeters[r]=this._renderNames(r,this.freeters[r],e));for(var i=0,a=this.institutions[r].length;i<a;i+=1)this.persons[r][i]=this._renderNames(r,this.persons[r][i],e,i)}this.renderInstitutionNames()},n.NameOutput.prototype.renderInstitutionNames=function(){for(var e=0,t=this.variables.length;e<t;e+=1)for(var n=this.variables[e],r=0,i=this.institutions[n].length;r<i;r+=1){var a,o=this.institutions[n][r],r,i,s=this.state.tmp.extension?[`sort`]:o.isInstitution||o.literal?this.state.opt[`cite-lang-prefs`].institutions:this.state.opt[`cite-lang-prefs`].persons,c={primary:`locale-orig`,secondary:!1,tertiary:!1};if(s)for(var l=[`primary`,`secondary`,`tertiary`],u=0,d=l.length;u<d&&!(s.length-1<u);u+=1)s[u]&&(c[l[u]]=`locale-`+s[u]);else c.primary=`locale-translat`;this.state.tmp.area!==`bibliography`&&!(this.state.tmp.area===`citation`&&this.state.opt.xclass===`note`&&this.item&&!this.item.position)&&(c.secondary=!1,c.tertiary=!1),this.setRenderedName(o);var a=this._renderInstitutionName(n,o,c,r);this.institutions[n][r]=a}},n.NameOutput.prototype._renderInstitutionName=function(e,t,n,r){var i,a,o,s,c,l,u,d=this.getName(t,n.primary,!0),f=d.name,p=d.usedOrig;if(f&&(f=this.fixupInstitution(f,e,r)),i=!1,n.secondary){d=this.getName(t,n.secondary,!1,p);var i=d.name;p=d.usedOrig,i&&(i=this.fixupInstitution(i,e,r))}a=!1,n.tertiary&&(d=this.getName(t,n.tertiary,!1,p),a=d.name,a&&(a=this.fixupInstitution(a,e,r)));var m={l:{pri:!1,sec:!1,ter:!1},s:{pri:!1,sec:!1,ter:!1}};switch(f&&(m.l.pri=f.long,m.s.pri=f.short.length?f.short:f.long),i&&(m.l.sec=i.long,m.s.sec=i.short.length?i.short:i.long),a&&(m.l.ter=a.long,m.s.ter=a.short.length?a.short:a.long),this.institution.strings[`institution-parts`]){case`short`:f.short.length?(s=this._getShortStyle(),c=[this._composeOneInstitutionPart([m.s.pri,m.s.sec,m.s.ter],n,s,e)]):(o=this._getLongStyle(f,e,r),c=[this._composeOneInstitutionPart([m.l.pri,m.l.sec,m.l.ter],n,o,e)]);break;case`short-long`:o=this._getLongStyle(f,e,r),s=this._getShortStyle(),l=this._renderOneInstitutionPart(f.short,s),u=this._composeOneInstitutionPart([m.l.pri,m.l.sec,m.l.ter],n,o,e),c=[l,u];break;case`long-short`:o=this._getLongStyle(f,e,r),s=this._getShortStyle(),l=this._renderOneInstitutionPart(f.short,s),u=this._composeOneInstitutionPart([m.l.pri,m.l.sec,m.l.ter],n,o,e),c=[u,l];break;default:o=this._getLongStyle(f,e,r),c=[this._composeOneInstitutionPart([m.l.pri,m.l.sec,m.l.ter],n,o,e)];break}var h=this._join(c,` `);return h&&(h.isInstitution=!0),this.state.tmp.name_node.children.push(h),h},n.NameOutput.prototype._composeOneInstitutionPart=function(e,t,r){var i=!1,a=!1,o=!1,s,c,l;if(e[0]){if(s=n.Util.cloneToken(r),this.state.opt.citeAffixes[t.primary]&&this.state.opt.citeAffixes.institutions[t.primary].prefix===`<i>`){for(var u=!1,d=0,f=s.decorations.length;d<f;d+=1)r.decorations[d][0]===`@font-style`&&s.decorations[d][1]===`italic`&&(u=!0);u||s.decorations.push([`@font-style`,`italic`])}i=this._renderOneInstitutionPart(e[0],s)}e[1]&&(a=this._renderOneInstitutionPart(e[1],r)),e[2]&&(o=this._renderOneInstitutionPart(e[2],r));var p;if(a||o){this.state.output.openLevel(`empty`),this.state.output.append(i),c=n.Util.cloneToken(r),t.secondary&&(c.strings.prefix=this.state.opt.citeAffixes.institutions[t.secondary].prefix,c.strings.suffix=this.state.opt.citeAffixes.institutions[t.secondary].suffix,c.strings.prefix||(c.strings.prefix=` `));var m=new n.Token;m.decorations.push([`@font-style`,`normal`]),m.decorations.push([`@font-weight`,`normal`]),this.state.output.openLevel(m),this.state.output.append(a,c),this.state.output.closeLevel(),l=n.Util.cloneToken(r),t.tertiary&&(l.strings.prefix=this.state.opt.citeAffixes.institutions[t.tertiary].prefix,l.strings.suffix=this.state.opt.citeAffixes.institutions[t.tertiary].suffix,l.strings.prefix||(l.strings.prefix=` `));var h=new n.Token;h.decorations.push([`@font-style`,`normal`]),h.decorations.push([`@font-weight`,`normal`]),this.state.output.openLevel(h),this.state.output.append(o,l),this.state.output.closeLevel(),this.state.output.closeLevel(),p=this.state.output.pop()}else p=i;return p},n.NameOutput.prototype._renderOneInstitutionPart=function(e,t){for(var r=0,i=e.length;r<i;r+=1)if(e[r]){var a=e[r];if(this.state.tmp.strip_periods)a=a.replace(/\./g,``);else for(var o=0,s=t.decorations.length;o<s;o+=1)if(t.decorations[o][0]===`@strip-periods`&&t.decorations[o][1]===`true`){a=a.replace(/\./g,``);break}this.state.tmp.group_context.tip.variable_success=!0,this.state.tmp.can_substitute.replace(!1,n.LITERAL),a===`!here>>>`?e[r]=!1:(this.state.output.append(a,t,!0),e[r]=this.state.output.pop())}return this.institution.strings[`part-separator`]===void 0&&(this.institution.strings[`part-separator`]=this.state.tmp.name_delimiter),this._join(e,this.institution.strings[`part-separator`])},n.NameOutput.prototype._renderNames=function(e,t,r,i){var a=!1;if(t.length){for(var o=[],s=0,c=t.length;s<c;s+=1){var l=t[s],a,u=this.state.tmp.extension?[`sort`]:l.isInstitution||l.literal?this.state.opt[`cite-lang-prefs`].institutions:this.state.opt[`cite-lang-prefs`].persons,d={primary:`locale-orig`,secondary:!1,tertiary:!1};if(u)for(var f=[`primary`,`secondary`,`tertiary`],p=0,m=f.length;p<m&&!(u.length-1<p);p+=1)d[f[p]]=`locale-`+u[p];else d.primary=`locale-translat`;if((this.state.tmp.sort_key_flag||this.state.tmp.area!==`bibliography`&&!(this.state.tmp.area===`citation`&&this.state.opt.xclass===`note`&&this.item&&!this.item.position))&&(d.secondary=!1,d.tertiary=!1),this.setRenderedName(l),!l.literal&&!l.isInstitution){var h=this._renderPersonalName(e,l,d,r,s,i),g=n.Util.cloneToken(this.name);this.state.output.append(h,g,!0),o.push(this.state.output.pop())}else o.push(this._renderInstitutionName(e,l,d,i))}a=this.joinPersons(o,r,i)}return a},n.NameOutput.prototype._renderPersonalName=function(e,t,r,i,a,o){var s=this.getName(t,r.primary,!0),c=this._renderOnePersonalName(s.name,i,a,o),l=!1;r.secondary&&(s=this.getName(t,r.secondary,!1,s.usedOrig),s.name&&(l=this._renderOnePersonalName(s.name,i,a,o)));var u=!1;r.tertiary&&(s=this.getName(t,r.tertiary,!1,s.usedOrig),s.name&&(u=this._renderOnePersonalName(s.name,i,a,o)));var d;if(l||u){this.state.output.openLevel(`empty`),this.state.output.append(c);var f=new n.Token;r.secondary&&(f.strings.prefix=this.state.opt.citeAffixes.persons[r.secondary].prefix,f.strings.suffix=this.state.opt.citeAffixes.persons[r.secondary].suffix,f.strings.prefix||(f.strings.prefix=` `)),this.state.output.append(l,f);var p=new n.Token;r.tertiary&&(p.strings.prefix=this.state.opt.citeAffixes.persons[r.tertiary].prefix,p.strings.suffix=this.state.opt.citeAffixes.persons[r.tertiary].suffix,p.strings.prefix||(p.strings.prefix=` `)),this.state.output.append(u,p),this.state.output.closeLevel(),d=this.state.output.pop()}else d=c;return d},n.NameOutput.prototype._isRomanesque=function(e){var t=2;e.family.replace(/\"/g,``).match(n.ROMANESQUE_REGEXP)||(t=0),!t&&e.given&&e.given.match(n.STARTSWITH_ROMANESQUE_REGEXP)&&(t=1);var r;return t==2&&(e.multi&&e.multi.main?r=e.multi.main.slice(0,2):this.Item.language&&(r=this.Item.language.slice(0,2)),[`ja`,`zh`].indexOf(r)>-1&&(t=1)),t},n.NameOutput.prototype._renderOnePersonalName=function(e,t,r,i){var a=e,o=this._droppingParticle(a,t,i),s=this._familyName(a),c=this._nonDroppingParticle(a),l=this._givenName(a,t,r),u=l.blob,d=this._nameSuffix(a);u===!1&&(o=!1,d=!1);var f=this.state.inheritOpt(this.name,`sort-separator`);f||(f=``);var p=a[`comma-suffix`]?`, `:` `,m=this._isRomanesque(a);function h(e){return e?typeof e.blobs==`string`?[`’`,`'`,`-`,` `].indexOf(e.blobs.slice(-1))>-1:h(e.blobs[e.blobs.length-1]):!1}var g=h(c),_=[`fr`,`ru`,`cs`].indexOf(this.state.opt[`default-locale`][0].slice(0,2))>-1?`\xA0`:` `,v,y,b,x;if(m===0)v=this._join([c,s,u],``);else if(m===1||a[`static-ordering`])y=this._join([c,s],_),v=this._join([y,u],` `);else if(a[`reverse-ordering`])y=this._join([c,s],_),v=this._join([u,y],` `);else if(this.state.tmp.sort_key_flag)this.state.opt[`demote-non-dropping-particle`]===`never`?(y=this._join([c,s],_),y=this._join([y,o],` `),y=this._join([y,u],this.state.opt.sort_sep),v=this._join([y,d],` `)):(x=this._join([u,o,c],` `),y=this._join([s,x],this.state.opt.sort_sep),v=this._join([y,d],` `));else if(this.state.inheritOpt(this.name,`name-as-sort-order`)===`all`||this.state.inheritOpt(this.name,`name-as-sort-order`)===`first`&&r===0&&(i===0||i===void 0))[`Lord`,`Lady`].indexOf(a.given)>-1&&(f=`, `),[`always`,`display-and-sort`].indexOf(this.state.opt[`demote-non-dropping-particle`])>-1?(x=this._join([u,o],a[`comma-dropping-particle`]+` `),x=this._join([x,c],` `),x&&this.given&&(x.strings.prefix=this.given.strings.prefix,x.strings.suffix=this.given.strings.suffix),s&&this.family&&(s.strings.prefix=this.family.strings.prefix,s.strings.suffix=this.family.strings.suffix),y=this._join([s,x],f),v=this._join([y,d],f)):(b=g?this._join([c,s],``):this._join([c,s],_),b&&this.family&&(b.strings.prefix=this.family.strings.prefix,b.strings.suffix=this.family.strings.suffix),x=this._join([u,o],a[`comma-dropping-particle`]+` `),x&&this.given&&(x.strings.prefix=this.given.strings.prefix,x.strings.suffix=this.given.strings.suffix),y=this._join([b,x],f),v=this._join([y,d],f)),v.isInverted=!0;else{if(a[`dropping-particle`]&&a.family&&!a[`non-dropping-particle`]){var S=a[`dropping-particle`];[`'`,`ʼ`,`’`,`-`].indexOf(S.slice(-1))>-1&&S.slice(0,-1)!==`de`&&(s=this._join([o,s],``),o=!1)}g?(x=this._join([c,s],``),x=this._join([o,x],_)):x=this._join([o,c,s],_),x=this._join([x,d],p),x&&this.family&&(x.strings.prefix=this.family.strings.prefix,x.strings.suffix=this.family.strings.suffix),u&&this.given&&(u.strings.prefix=this.given.strings.prefix,u.strings.suffix=this.given.strings.suffix),x.strings.prefix&&(a[`comma-dropping-particle`]=``);var C=this.state.inheritOpt(this.name,`initialize-with`)&&this.state.inheritOpt(this.name,`initialize-with`).match(/[\u00a0\ufeff]/)&&l.initializationLevel===1?_:` `;v=this._join([u,x],a[`comma-dropping-particle`]+C)}return this.state.tmp.group_context.tip.variable_success=!0,this.state.tmp.can_substitute.replace(!1,n.LITERAL),this.state.tmp.term_predecessor=!0,this.state.tmp.name_node.children.push(v),v},n.NameOutput.prototype._normalizeNameInput=function(e){var t={literal:e.literal,family:e.family,isInstitution:e.isInstitution,given:e.given,suffix:e.suffix,"comma-suffix":e[`comma-suffix`],"non-dropping-particle":e[`non-dropping-particle`],"dropping-particle":e[`dropping-particle`],"static-ordering":e[`static-ordering`],"static-particles":e[`static-particles`],"reverse-ordering":e[`reverse-ordering`],"full-form-always":e[`full-form-always`],"parse-names":e[`parse-names`],"comma-dropping-particle":``,block_initialize:e.block_initialize,multi:e.multi};return this._parseName(t),t},n.NameOutput.prototype._stripPeriods=function(e,t){var n=this[e+`_decor`];if(t){if(this.state.tmp.strip_periods)t=t.replace(/\./g,``);else if(n){for(var r=0,i=n.decorations.length;r<i;r+=1)if(n.decorations[r][0]===`@strip-periods`&&n.decorations[r][1]===`true`){t=t.replace(/\./g,``);break}}}return t},n.NameOutput.prototype._nonDroppingParticle=function(e){var t=e[`non-dropping-particle`];t&&this.state.tmp.sort_key_flag&&(t=t.replace(/[\'\u2019]/,``));var n=this._stripPeriods(`family`,t);return this.state.output.append(n,this.family_decor,!0)?this.state.output.pop():!1},n.NameOutput.prototype._droppingParticle=function(e,t,n){var r=e[`dropping-particle`];r&&this.state.tmp.sort_key_flag&&(r=r.replace(/[\'\u2019]/,``));var i=this._stripPeriods(`given`,r);if(e[`dropping-particle`]&&e[`dropping-particle`].match(/^et.?al[^a-z]$/))this.state.inheritOpt(this.name,`et-al-use-last`)?n===void 0?this.etal_spec[t].freeters=2:this.etal_spec[t].persons=2:n===void 0?this.etal_spec[t].freeters=1:this.etal_spec[t].persons=1,e[`comma-dropping-particle`]=``;else if(this.state.output.append(i,this.given_decor,!0))return this.state.output.pop();return!1},n.NameOutput.prototype._familyName=function(e){var t=this._stripPeriods(`family`,e.family);return this.state.output.append(t,this.family_decor,!0)?this.state.output.pop():!1},n.NameOutput.prototype._givenName=function(e,t,r){var i,a=this.state.inheritOpt(this.name,`form`,`name-form`,`long`)!==`long`,o=this.state.inheritOpt(this.name,`initialize`)!==!1,s=typeof this.state.inheritOpt(this.name,`initialize-with`)==`string`&&!e.block_initialize,c,l;if(e[`full-form-always`])l=2;else{c=a?0:s?1:2;var u=this.state.tmp.disambig_settings.givens[t][r];l=u>c?u:c}var d=this.state.citation.opt[`givenname-disambiguation-rule`];if(d&&d.slice(-14)===`-with-initials`&&(s=!0),e.family&&l===1)if(s){var f=this.state.inheritOpt(this.name,`initialize-with`,!1,``);e.given=n.Util.Names.initializeWith(this.state,e.given,f,!o)}else e.given=n.Util.Names.unInitialize(this.state,e.given);else if(l===0)return{blob:!1};else l===2&&(e.given=n.Util.Names.unInitialize(this.state,e.given));var p=this._stripPeriods(`given`,e.given);return this.state.output.append(p,this.given_decor,!0)?(i=this.state.output.pop(),{blob:i,initializationLevel:l}):{blob:!1}},n.NameOutput.prototype._nameSuffix=function(e){var t=e.suffix,r;t&&typeof this.state.inheritOpt(this.name,`initialize-with`)==`string`&&(t=n.Util.Names.initializeWith(this.state,t,this.state.inheritOpt(this.name,`initialize-with`),!0)),t=this._stripPeriods(`family`,t);var i=``;return t&&t.slice(-1)===`.`&&(t=t.slice(0,-1),i=`.`),this.state.output.append(t,`empty`,!0)?(r=this.state.output.pop(),r.strings.suffix=i+r.strings.suffix,r):!1},n.NameOutput.prototype._getLongStyle=function(e){var t=e.short.length&&this.institutionpart[`long-with-short`]?this.institutionpart[`long-with-short`]:this.institutionpart.long;return t||(t=new n.Token),t},n.NameOutput.prototype._getShortStyle=function(){return this.institutionpart.short?this.institutionpart.short:new n.Token},n.NameOutput.prototype._parseName=function(e){if(!e[`parse-names`]&&e[`parse-names`]!==void 0)return e;e.family&&!e.given&&e.isInstitution&&(e.literal=e.family,e.family=void 0,e.isInstitution=void 0);var t;e.family&&e.family.slice(0,1)===`"`&&e.family.slice(-1)===`"`||!e[`parse-names`]&&e[`parse-names`]!==void 0?(e.family=e.family.slice(1,-1),t=!0,e[`parse-names`]=0):t=!1,this.state.opt.development_extensions.parse_names&&!e[`non-dropping-particle`]&&e.family&&!t&&e.given&&(e[`static-particles`]||n.parseParticles(e,!0))},n.NameOutput.prototype.getName=function(e,t,n,r){if(r&&t===`locale-orig`)return{name:!1,usedOrig:r};e.family||(e.family=``),e.given||(e.given=``);var i={};i[`static-ordering`]=this.getStaticOrder(e);var a=!0,o;if(t!==`locale-orig`&&(a=!1,e.multi)){for(var s=this.state.opt[t],c=0,l=s.length;c<l;c+=1)if(o=s[c],e.multi._key[o]){a=!0;var u=e.isInstitution;e=e.multi._key[o],e.isInstitution=u,i=this.getNameParams(o),i.transliterated=!0;break}}return a||(o=!1,e.multi&&e.multi.main?o=e.multi.main:this.Item.language&&(o=this.Item.language),o&&(i=this.getNameParams(o))),!n&&!a?{name:!1,usedOrig:r}:(e.family||(e.family=``),e.given||(e.given=``),e.literal&&(delete e.family,delete e.given),e={family:e.family,given:e.given,"non-dropping-particle":e[`non-dropping-particle`],"dropping-particle":e[`dropping-particle`],suffix:e.suffix,"static-ordering":i[`static-ordering`],"static-particles":e[`static-particles`],"reverse-ordering":i[`reverse-ordering`],"full-form-always":i[`full-form-always`],"parse-names":e[`parse-names`],"comma-suffix":e[`comma-suffix`],"comma-dropping-particle":e[`comma-dropping-particle`],transliterated:i.transliterated,block_initialize:i[`block-initialize`],literal:e.literal,isInstitution:e.isInstitution,multi:e.multi},!e.literal&&!e.given&&e.family&&e.isInstitution&&(e.literal=e.family),e.literal&&(delete e.family,delete e.given),e=this._normalizeNameInput(e),{name:e,usedOrig:r||!a})},n.NameOutput.prototype.getNameParams=function(e){var t={},r=n.localeResolve(this.Item.language,this.state.opt[`default-locale`][0]),i=this.state.locale[r.best]?r.best:this.state.opt[`default-locale`][0],a=this.state.locale[i].opts[`name-as-sort-order`],o=this.state.locale[i].opts[`name-as-reverse-order`],s=this.state.locale[i].opts[`name-never-short`],c=e.split(`-`)[0];return a&&a[c]&&(t[`static-ordering`]=!0,t[`reverse-ordering`]=!1),o&&o[c]&&(t[`reverse-ordering`]=!0,t[`static-ordering`]=!1),s&&s[c]&&(t[`full-form-always`]=!0),t[`static-ordering`]&&(t[`block-initialize`]=!0),t},n.NameOutput.prototype.setRenderedName=function(e){if(this.state.tmp.area===`bibliography`){for(var t=``,r=0,i=n.NAME_PARTS.length;r<i;r+=1)e[n.NAME_PARTS[r]]&&(t+=e[n.NAME_PARTS[r]]);this.state.tmp.rendered_name.push(t)}},n.NameOutput.prototype.fixupInstitution=function(e,t,n){!e.literal&&e.family&&(e.literal=e.family,delete e.family);var r=e.literal,i=r,a={long:r.split(/\s*\|\s*/),short:i.split(/\s*\|\s*/)};if(this.state.sys.getAbbreviation){if(this.institution.strings.form===`short`){let e=this.Item.jurisdiction;e=this.state.transform.loadAbbreviation(e,`institution-entire`,r,this.Item.language),this.state.transform.abbrevs[e][`institution-entire`][r]?r=this.state.transform.abbrevs[e][`institution-entire`][r]:(e=this.Item.jurisdiction,e=this.state.transform.loadAbbreviation(e,`institution-part`,r,this.Item.language),this.state.transform.abbrevs[e][`institution-part`][r]&&(r=this.state.transform.abbrevs[e][`institution-part`][r])),r=this._quashChecks(e,r)}if([`short`,`short-long`,`long-short`].indexOf(this.institution.strings[`institution-parts`])>-1){let e=this.Item.jurisdiction;e=this.state.transform.loadAbbreviation(e,`institution-part`,i,this.Item.language),this.state.transform.abbrevs[e][`institution-part`][i]&&(i=this.state.transform.abbrevs[e][`institution-part`][i]),i=this._quashChecks(e,i),[`short-long`,`long-short`].indexOf(this.institution.strings[`institution-parts`])>-1&&i===r&&(i=``)}if(a.long=r.split(/\s*\|\s*/),a.short=i.split(/\s*\|\s*/),[`short`,`short-long`,`long-short`].indexOf(this.institution.strings[`institution-parts`])>-1)for(var o=a.short.length-1;o>-1;o--){let e=this.Item.jurisdiction;var s=a.short[o];if(e=this.state.transform.loadAbbreviation(e,`institution-part`,s,this.Item.language),this.state.transform.abbrevs[e][`institution-part`][s]&&(a.short[o]=this.state.transform.abbrevs[e][`institution-part`][s]),a.short[o].indexOf(`|`)>-1){let e=a.short,t=e[o].split(/\s*\|\s*/);a.short=e.slice(0,o).concat(t).concat(e.slice(o+1))}}if(this.state.opt.development_extensions.legacy_institution_name_ordering&&a.short.reverse(),a.short=this._trimInstitution(a.short),this.institution.strings[`reverse-order`]&&a.short.reverse(),!this.state.tmp.just_looking&&this.Item.jurisdiction){let e=this.Item.jurisdiction;var c=this.state.tmp.abbrev_trimmer;if(c&&c[e]&&c[e][t])for(var l=0,u=a.short.length;l<u;l++){var d=a.short[l];a.short[l]=d.replace(c[e][t],``).trim()}}}return this.state.opt.development_extensions.legacy_institution_name_ordering&&a.long.reverse(),a.long=this._trimInstitution(a.long),this.institution.strings[`reverse-order`]&&a.long.reverse(),a},n.NameOutput.prototype.getStaticOrder=function(e,t){var r=!1;return(!t&&e[`static-ordering`]||this._isRomanesque(e)===0||(!e.multi||!e.multi.main)&&this.Item.language&&[`vi`,`hu`].indexOf(this.Item.language)>-1||e.multi&&e.multi.main&&[`vi`,`hu`].indexOf(e.multi.main.slice(0,2))>-1||this.state.opt[`auto-vietnamese-names`]&&n.VIETNAMESE_NAMES.exec(e.family+` `+e.given)&&n.VIETNAMESE_SPECIALS.exec(e.family+e.given))&&(r=!0),r},n.NameOutput.prototype._quashChecks=function(e,t){var t=this.state.transform.quashCheck(e,t),n=t.split(/>>[0-9]{4}>>/),r=t.match(/>>([0-9]{4})>>/);t=n.pop();var i=this.Item[`original-date`]?this.Item[`original-date`]:this.Item.issued;if(i&&(i=parseInt(i.year,10),i=isNaN(i)?!1:i),i){if(n.length>0)for(var a=r.length-1;a>0&&!(i>=parseInt(r[a],10));a--)t=n.pop();t=t.replace(/\s*\|\s*/g,`|`)}return t},n.NameOutput.prototype._trimInstitution=function(e){var t=!1,n=!1,r=!1,i=!1,a=e.slice();if(this.institution){if(this.institution.strings[`use-first`]!==void 0&&(t=this.institution.strings[`use-first`]),this.institution.strings[`use-last`]!==void 0&&(r=this.institution.strings[`use-last`]),this.institution.strings[`stop-first`]!==void 0&&(i=this.institution.strings[`stop-first`]),this.institution.strings[`stop-last`]!==void 0&&(n=this.institution.strings[`stop-last`]),t&&(n&&(a=a.slice(0,n*-1)),a=a.slice(0,t)),r){var o=e.slice();t?i=t:a=[],i&&(o=o.slice(i)),o=o.slice(r*-1),a=a.concat(o)}e=a}return e},n.PublisherOutput=function(e,t){this.state=e,this.group_tok=t,this.varlist=[]},n.PublisherOutput.prototype.render=function(){this.clearVars(),this.composeAndBlob(),this.composeElements(),this.composePublishers(),this.joinPublishers()},n.PublisherOutput.prototype.composeAndBlob=function(){this.and_blob={};var e=!1;this.group_tok.strings.and===`text`?e=this.state.getTerm(`and`):this.group_tok.strings.and===`symbol`&&(e=`&`);var t=new n.Token;t.strings.suffix=` `,t.strings.prefix=` `,this.state.output.append(e,t,!0);var r=this.state.output.pop();t.strings.prefix=this.group_tok.strings[`subgroup-delimiter`],this.state.output.append(e,t,!0);var i=this.state.output.pop();this.and_blob.single=!1,this.and_blob.multiple=!1,e&&(this.group_tok.strings[`subgroup-delimiter-precedes-last`]===`always`?this.and_blob.single=i:this.group_tok.strings[`subgroup-delimiter-precedes-last`]===`never`?(this.and_blob.single=r,this.and_blob.multiple=r):(this.and_blob.single=r,this.and_blob.multiple=i))},n.PublisherOutput.prototype.composeElements=function(){for(var e=0,t=2;e<t;e+=1)for(var n=[`publisher`,`publisher-place`][e],r=0,i=this[`publisher-list`].length;r<i;r+=1){var a=this[n+`-list`][r],o=this[n+`-token`];this.state.output.append(a,o,!0),this[n+`-list`][r]=this.state.output.pop()}},n.PublisherOutput.prototype.composePublishers=function(){for(var e,t=0,n=this[`publisher-list`].length;t<n;t+=1)e=[this[this.varlist[0]+`-list`][t],this[this.varlist[1]+`-list`][t]],this[`publisher-list`][t]=this._join(e,this.group_tok.strings.delimiter)},n.PublisherOutput.prototype.joinPublishers=function(){var e=this[`publisher-list`],t=this._join(e,this.group_tok.strings[`subgroup-delimiter`],this.and_blob.single,this.and_blob.multiple,this.group_tok);this.state.output.append(t,`literal`)},n.PublisherOutput.prototype._join=n.NameOutput.prototype._join,n.PublisherOutput.prototype._getToken=n.NameOutput.prototype._getToken,n.PublisherOutput.prototype.clearVars=function(){this.state.tmp[`publisher-list`]=!1,this.state.tmp[`publisher-place-list`]=!1,this.state.tmp[`publisher-group-token`]=!1,this.state.tmp[`publisher-token`]=!1,this.state.tmp[`publisher-place-token`]=!1},n.evaluateLabel=function(e,t,r,i){var a;e.strings.term===`locator`?(i&&i.label&&(a=i.label===`sub verbo`?`sub-verbo`:i.label),a||(a=`page`)):a=e.strings.term;var o=e.strings.plural;if(typeof o!=`number`){var s=i&&e.strings.term===`locator`?i:r;s[e.strings.term]&&(t.processNumber(!1,s,e.strings.term,r.type),o=t.tmp.shadow_numbers[e.strings.term].plural,!t.tmp.shadow_numbers[e.strings.term].labelForm&&!t.tmp.shadow_numbers[e.strings.term].labelDecorations&&(e.strings.form?t.tmp.shadow_numbers[e.strings.term].labelForm=e.strings.form:t.tmp.group_context.tip.label_form&&(t.tmp.shadow_numbers[e.strings.term].labelForm=t.tmp.group_context.tip.label_form),t.tmp.shadow_numbers[e.strings.term].labelCapitalizeIfFirst=e.strings.capitalize_if_first,t.tmp.shadow_numbers[e.strings.term].labelDecorations=e.decorations.slice()),[`locator`,`number`,`page`].indexOf(e.strings.term)>-1&&t.tmp.shadow_numbers[e.strings.term].label&&(a=t.tmp.shadow_numbers[e.strings.term].label),e.decorations&&t.opt.development_extensions.csl_reverse_lookup_support&&(e.decorations.reverse(),e.decorations.push([`@showid`,`true`,e.cslid]),e.decorations.reverse()))}return n.castLabel(t,e,a,o,n.TOLERANT)},n.castLabel=function(e,t,r,i,a){var o=t.strings.form,s=t.strings.capitalize_if_first;e.tmp.group_context.tip.label_form&&(o===`static`?e.tmp.group_context.tip.label_static=!0:o=e.tmp.group_context.tip.label_form),e.tmp.group_context.tip.label_capitalize_if_first&&(s=e.tmp.group_context.tip.label_capitalize_if_first);var c=e.getTerm(r,o,i,!1,a,t.default_locale);if(s&&(c=n.Output.Formatters[`capitalize-first`](e,c)),e.tmp.strip_periods)c=c.replace(/\./g,``);else for(var l=0,u=t.decorations.length;l<u;l+=1)if(t.decorations[l][0]===`@strip-periods`&&t.decorations[l][1]===`true`){c=c.replace(/\./g,``);break}return c},n.Node.name={build:function(e,t){var r;if([n.SINGLETON,n.START].indexOf(this.tokentype)>-1){var i;e.tmp.root===void 0?(i=void 0,e.tmp.root=`citation`):i=e.tmp.root,e.inheritOpt(this,`et-al-subsequent-min`)&&e.inheritOpt(this,`et-al-subsequent-min`)!==e.inheritOpt(this,`et-al-min`)&&(e.opt.update_mode=n.POSITION),e.inheritOpt(this,`et-al-subsequent-use-first`)&&e.inheritOpt(this,`et-al-subsequent-use-first`)!==e.inheritOpt(this,`et-al-use-first`)&&(e.opt.update_mode=n.POSITION),e.tmp.root=i,r=function(e){e.tmp.etal_term=`et-al`,e.tmp.name_delimiter=e.inheritOpt(this,`delimiter`,`name-delimiter`,`, `),e.tmp[`delimiter-precedes-et-al`]=e.inheritOpt(this,`delimiter-precedes-et-al`),e.inheritOpt(this,`and`)===`text`?this.and_term=e.getTerm(`and`,`long`,0):e.inheritOpt(this,`and`)===`symbol`&&(e.opt.development_extensions.expect_and_symbol_form?this.and_term=e.getTerm(`and`,`symbol`,0):this.and_term=`&`),e.tmp.and_term=this.and_term,n.STARTSWITH_ROMANESQUE_REGEXP.test(this.and_term)?(this.and_prefix_single=` `,this.and_prefix_multiple=`, `,typeof e.tmp.name_delimiter==`string`&&(this.and_prefix_multiple=e.tmp.name_delimiter),this.and_suffix=` `):(this.and_prefix_single=``,this.and_prefix_multiple=``,this.and_suffix=``),e.inheritOpt(this,`delimiter-precedes-last`)===`always`?this.and_prefix_single=e.tmp.name_delimiter:e.inheritOpt(this,`delimiter-precedes-last`)===`never`?this.and_prefix_multiple&&(this.and_prefix_multiple=` `):e.inheritOpt(this,`delimiter-precedes-last`)===`after-inverted-name`&&(this.and_prefix_single&&(this.and_prefix_single=e.tmp.name_delimiter),this.and_prefix_multiple&&(this.and_prefix_multiple=` `)),this.and={},e.inheritOpt(this,`and`)?(e.output.append(this.and_term,`empty`,!0),this.and.single=e.output.pop(),this.and.single.strings.prefix=this.and_prefix_single,this.and.single.strings.suffix=this.and_suffix,e.output.append(this.and_term,`empty`,!0),this.and.multiple=e.output.pop(),this.and.multiple.strings.prefix=this.and_prefix_multiple,this.and.multiple.strings.suffix=this.and_suffix):e.tmp.name_delimiter&&(this.and.single=new n.Blob(e.tmp.name_delimiter),this.and.single.strings.prefix=``,this.and.single.strings.suffix=``,this.and.multiple=new n.Blob(e.tmp.name_delimiter),this.and.multiple.strings.prefix=``,this.and.multiple.strings.suffix=``),this.ellipsis={},e.inheritOpt(this,`et-al-use-last`)&&(this.ellipsis_term=`…`,this.ellipsis_prefix_single=` `,this.ellipsis_prefix_multiple=e.inheritOpt(this,`delimiter`,`name-delimiter`,`, `),this.ellipsis_suffix=` `,this.ellipsis.single=new n.Blob(this.ellipsis_term),this.ellipsis.single.strings.prefix=this.ellipsis_prefix_single,this.ellipsis.single.strings.suffix=this.ellipsis_suffix,this.ellipsis.multiple=new n.Blob(this.ellipsis_term),this.ellipsis.multiple.strings.prefix=this.ellipsis_prefix_multiple,this.ellipsis.multiple.strings.suffix=this.ellipsis_suffix),e.tmp[`et-al-min`]===void 0&&(e.tmp[`et-al-min`]=e.inheritOpt(this,`et-al-min`)),e.tmp[`et-al-use-first`]===void 0&&(e.tmp[`et-al-use-first`]=e.inheritOpt(this,`et-al-use-first`)),e.tmp[`et-al-use-last`]===void 0&&(e.tmp[`et-al-use-last`]=e.inheritOpt(this,`et-al-use-last`)),e.nameOutput.name=this},e.build.name_flag=!0,this.execs.push(r)}t.push(this)}},n.Node[`name-part`]={build:function(e){e.build[this.strings.name]=this}},n.Node.names={build:function(e,t){var r;if((this.tokentype===n.START||this.tokentype===n.SINGLETON)&&(n.Util.substituteStart.call(this,e,t),e.build.substitute_level.push(1)),this.tokentype===n.SINGLETON){for(var i in e.build.names_variables[e.build.names_variables.length-1].concat(this.variables),this.variables){var a=this.variables[i],o=e.build.name_label[e.build.name_label.length-1];Object.keys(o).length&&(o[a]=o[Object.keys(o)[0]])}r=function(e){e.nameOutput.reinit(this,this.variables_real[0])},this.execs.push(r)}if(this.tokentype===n.START&&(e.build.names_flag=!0,e.build.name_flag=!1,e.build.names_level+=1,e.build.names_variables.push(this.variables),e.build.name_label.push({}),r=function(e){e.tmp.can_substitute.push(!0),e.tmp.name_node={},e.tmp.name_node.children=[],e.nameOutput.init(this)},this.execs.push(r)),this.tokentype===n.END){for(var i=0,s=3;i<s;i+=1){var c=[`family`,`given`,`et-al`][i];this[c]=e.build[c],e.build.names_level===1&&(e.build[c]=void 0)}this.label=e.build.name_label[e.build.name_label.length-1],e.build.names_level+=-1,e.build.names_variables.pop(),e.build.name_label.pop(),r=function(e){e.tmp.etal_node?this.etal_style=e.tmp.etal_node:this.etal_style=`empty`,this.etal_term=e.getTerm(e.tmp.etal_term,`long`,0),this.etal_prefix_single=` `,this.etal_prefix_multiple=e.tmp.name_delimiter,e.tmp[`delimiter-precedes-et-al`]===`always`?this.etal_prefix_single=e.tmp.name_delimiter:e.tmp[`delimiter-precedes-et-al`]===`never`?this.etal_prefix_multiple=` `:e.tmp[`delimiter-precedes-et-al`]===`after-inverted-name`&&(this.etal_prefix_single=e.tmp.name_delimiter,this.etal_prefix_multiple=` `),this.etal_suffix=``,n.STARTSWITH_ROMANESQUE_REGEXP.test(this.etal_term)||(this.etal_prefix_single===` `&&(this.etal_prefix_single=``),this.etal_prefix_multiple===` `&&(this.etal_prefix_multiple=``),this.etal_suffix===` `&&(this.etal_suffix=``));for(var t=0,r=3;t<r;t+=1){var i=[`family`,`given`][t];e.nameOutput[i]=this[i]}e.nameOutput.with=this.with;var a=`with`,o=``,s=``;n.STARTSWITH_ROMANESQUE_REGEXP.test(a)&&(o=` `,s=` `);var c={};c.single=new n.Blob(a),c.single.strings.suffix=s,c.multiple=new n.Blob(a),c.multiple.strings.suffix=s,e.inheritOpt(e.nameOutput.name,`delimiter-precedes-last`)===`always`?(c.single.strings.prefix=e.inheritOpt(this,`delimiter`,`names-delimiter`),c.multiple.strings.prefix=e.inheritOpt(this,`delimiter`,`names-delimiter`)):e.inheritOpt(e.nameOutput.name,`delimiter-precedes-last`)===`contextual`?(c.single.strings.prefix=o,c.multiple.strings.prefix=e.inheritOpt(this,`delimiter`,`names-delimiter`)):e.inheritOpt(e.nameOutput.name,`delimiter-precedes-last`)===`after-inverted-name`?(c.single.strings.prefix=e.inheritOpt(this,`delimiter`,`names-delimiter`),c.multiple.strings.prefix=o):(c.single.strings.prefix=o,c.multiple.strings.prefix=o),e.nameOutput.with=c,e.nameOutput.label=this.label,e.nameOutput.etal_style=this.etal_style,e.nameOutput.etal_term=this.etal_term,e.nameOutput.etal_prefix_single=this.etal_prefix_single,e.nameOutput.etal_prefix_multiple=this.etal_prefix_multiple,e.nameOutput.etal_suffix=this.etal_suffix,e.nameOutput.outputNames(),e.tmp[`et-al-use-first`]=void 0,e.tmp[`et-al-min`]=void 0,e.tmp[`et-al-use-last`]=void 0},this.execs.push(r),r=function(e){e.tmp.can_substitute.pop()||e.tmp.can_substitute.replace(!1,n.LITERAL),e.tmp.can_substitute.mystack.length===1&&(e.tmp.can_block_substitute=!1)},this.execs.push(r),e.build.name_flag=!1}t.push(this),(this.tokentype===n.END||this.tokentype===n.SINGLETON)&&(e.build.substitute_level.pop(),n.Util.substituteEnd.call(this,e,t))}},n.Node.number={build:function(e,t){var r;n.Util.substituteStart.call(this,e,t),this.strings.form===`roman`?this.formatter=e.fun.romanizer:this.strings.form===`ordinal`?this.formatter=e.fun.ordinalizer:this.strings.form===`long-ordinal`&&(this.formatter=e.fun.long_ordinalizer),this.successor_prefix===void 0&&(this.successor_prefix=e[e.build.area].opt.layout_delimiter),this.splice_prefix===void 0&&(this.splice_prefix=e[e.build.area].opt.layout_delimiter),r=function(e,t,r){if(this.variables.length!==0){var i=this.variables[0];if(r===void 0)var r={};if([`locator`,`locator-extra`].indexOf(i)>-1){if(e.tmp.just_looking||!r[i])return}else if(!t[i])return;i===`collection-number`&&t.type===`legal_case`&&(e.tmp.renders_collection_number=!0);var a=this;if(e.tmp.group_context.tip.force_suppress)return!1;if([`locator`,`locator-extra`].indexOf(i)>-1?e.processNumber.call(e,a,r,i,t.type):(!e.tmp.group_context.tip.condition&&t[i]&&(e.tmp.just_did_number=(``+t[i]).match(/[0-9]$/)),e.processNumber.call(e,a,t,i,t.type)),this.substring){var o=t[i].slice(this.substring);e.output.append(o,a)}else n.Util.outputNumericField(e,i,t.id);[`locator`,`locator-extra`].indexOf(this.variables_real[0])>-1&&!e.tmp.just_looking&&(e.tmp.done_vars.push(this.variables_real[0]),e.tmp.group_context.tip.done_vars.push(this.variables_real[0]))}},this.execs.push(r),t.push(this),n.Util.substituteEnd.call(this,e,t)}},n.Node.sort={build:function(e,t){if(t=e[e.build.root+`_sort`].tokens,this.tokentype===n.START){e.build.area===`citation`&&(e.opt.sort_citations=!0),e.build.area=e.build.root+`_sort`,e.build.extension=`_sort`;var r=function(e,t){if(e.opt.has_layout_locale){for(var r=n.localeResolve(t.language,e.opt[`default-locale`][0]),i=e[e.tmp.area.slice(0,-5)].opt.sort_locales,a,o=0,s=i.length;o<s&&(a=i[o][r.bare],a||(a=i[o][r.best]),!a);o+=1);a||(a=e.opt[`default-locale`][0]),e.tmp.lang_sort_hold=e.opt.lang,e.opt.lang=a}};this.execs.push(r)}if(this.tokentype===n.END){e.build.area=e.build.root,e.build.extension=``;var r=function(e){e.opt.has_layout_locale&&(e.opt.lang=e.tmp.lang_sort_hold,delete e.tmp.lang_sort_hold)};this.execs.push(r)}t.push(this)}},n.Node.substitute={build:function(e,t){var r;if(this.tokentype===n.START){var i=new n.Token(`choose`,n.START);n.Node.choose.build.call(i,e,t);var a=new n.Token(`if`,n.SINGLETON);r=function(){return!!(e.tmp.value.length&&!e.tmp.common_term_match_fail)},a.tests=[r],a.test=e.fun.match.any(a,e,a.tests),t.push(a),r=function(e){e.tmp.can_block_substitute=!0,e.tmp.value.length&&!e.tmp.common_term_match_fail&&e.tmp.can_substitute.replace(!1,n.LITERAL),e.tmp.common_term_match_fail=!1},this.execs.push(r),t.push(this)}if(this.tokentype===n.END){t.push(this);var o=new n.Token(`choose`,n.END);n.Node.choose.build.call(o,e,t)}}},n.Node.text={build:function(e,t){var r,i,a,o,s,c,l,u,d,f,p;if(this.postponed_macro){var m=n.Util.cloneToken(this);m.name=`group`,m.tokentype=n.START,n.Node.group.build.call(m,e,t),n.expandMacro.call(e,this,t);var h=n.Util.cloneToken(this);h.name=`group`,h.tokentype=n.END,this.postponed_macro===`juris-locator-label`&&(h.isJurisLocatorLabel=!0),n.Node.group.build.call(h,e,t)}else{if(n.Util.substituteStart.call(this,e,t),this.variables_real||(this.variables_real=[]),this.variables||(this.variables=[]),i=`long`,a=0,this.strings.form&&(i=this.strings.form),this.strings.plural&&(a=this.strings.plural),this.variables_real[0]===`citation-number`||this.variables_real[0]===`year-suffix`||this.variables_real[0]===`citation-label`)this.variables_real[0]===`citation-number`?(e.build.root===`citation`&&(e.opt.update_mode=n.NUMERIC),e.build.root===`bibliography`&&(e.opt.bib_mode=n.NUMERIC),e[e.tmp.area].opt.collapse===`citation-number`&&(this.range_prefix=e.getTerm(`citation-range-delimiter`)),this.successor_prefix=e[e.build.area].opt.layout_delimiter,this.splice_prefix=e[e.build.area].opt.layout_delimiter,r=function(e,t,r){if(o=``+t.id,!e.tmp.just_looking){if(e.tmp.area.slice(-5)===`_sort`&&this.variables[0]===`citation-number`){if(e.tmp.area===`bibliography_sort`&&e.tmp.group_context.tip.done_vars.push(`citation-number`),e.tmp.area===`citation_sort`&&e.bibliography_sort.tmp.citation_number_map)var i=e.bibliography_sort.tmp.citation_number_map[e.registry.registry[t.id].seq];else var i=e.registry.registry[t.id].seq;i&&(i=n.Util.padding(``+i)),e.output.append(i,this);return}r&&r[`author-only`]&&e.tmp.element_trace.replace(`suppress-me`),i=e.tmp.area!==`bibliography_sort`&&e.bibliography_sort.tmp.citation_number_map&&e.bibliography_sort.opt.citation_number_sort_direction===n.DESCENDING?e.bibliography_sort.tmp.citation_number_map[e.registry.registry[o].seq]:e.registry.registry[o].seq,e.opt.citation_number_slug?e.output.append(e.opt.citation_number_slug,this):(c=new n.NumericBlob(e,!1,i,this,t.id),e.tmp.in_cite_predecessor&&(c.suppress_splice_prefix=!0),e.output.append(c,`literal`))}},this.execs.push(r)):this.variables_real[0]===`year-suffix`?(e.opt.has_year_suffix=!0,e[e.tmp.area].opt.collapse===`year-suffix-ranged`&&(this.range_prefix=e.getTerm(`citation-range-delimiter`)),this.successor_prefix=e[e.build.area].opt.layout_delimiter,e[e.tmp.area].opt[`year-suffix-delimiter`]&&(this.successor_prefix=e[e.build.area].opt[`year-suffix-delimiter`]),r=function(e,t){if(e.registry.registry[t.id]&&e.registry.registry[t.id].disambig.year_suffix!==!1&&!e.tmp.just_looking){s=parseInt(e.registry.registry[t.id].disambig.year_suffix,10),e[e.tmp.area].opt.cite_group_delimiter&&(this.successor_prefix=e[e.tmp.area].opt.cite_group_delimiter),c=new n.NumericBlob(e,!1,s,this,t.id),l=new n.Util.Suffixator(n.SUFFIX_CHARS),c.setFormatter(l),e.output.append(c,`literal`),u=!1;for(var r=0,i=e.tmp.group_context.mystack.length;r<i;r++){var a=e.tmp.group_context.mystack[r];if(!a.variable_success&&(a.variable_attempt||!a.variable_attempt&&!a.term_intended)){u=!0;break}}d=e[e.tmp.area].opt[`year-suffix-delimiter`],u&&d&&!e.tmp.sort_key_flag&&(e.tmp.splice_delimiter=e[e.tmp.area].opt[`year-suffix-delimiter`])}},this.execs.push(r)):this.variables_real[0]===`citation-label`&&(e.build.root===`bibliography`&&(e.opt.bib_mode=n.TRIGRAPH),e.opt.has_year_suffix=!0,r=function(e,t){f=t[`citation-label`],f||(f=e.getCitationLabel(t)),e.tmp.just_looking||(p=``,e.registry.registry[t.id]&&e.registry.registry[t.id].disambig.year_suffix!==!1&&(s=parseInt(e.registry.registry[t.id].disambig.year_suffix,10),p=e.fun.suffixator.format(s)),f+=p),e.output.append(f,this)},this.execs.push(r));else if(this.strings.term)r=function(e,t){var r=e.opt.gender[t.type],o=this.strings.term;o=e.getTerm(o,i,a,r,n.TOLERANT,this.default_locale);var s;if(o!==``&&(e.tmp.group_context.tip.term_intended=!0),n.UPDATE_GROUP_CONTEXT_CONDITION(e,o,null,this),s=!e.tmp.term_predecessor&&!(e.opt.class===`in-text`&&e.tmp.area===`citation`)?n.Output.Formatters[`capitalize-first`](e,o):o,e.tmp.strip_periods)s=s.replace(/\./g,``);else for(var c=0,l=this.decorations.length;c<l;c+=1)if(this.decorations[c][0]===`@strip-periods`&&this.decorations[c][1]===`true`){s=s.replace(/\./g,``);break}e.output.append(s,this),e.tmp.can_block_substitute&&e.tmp.can_substitute.replace(!1,n.LITERAL)},this.execs.push(r),e.build.term=!1,e.build.form=!1,e.build.plural=!1;else if(this.variables_real.length){if(r=function(e,t){this.variables_real[0]!==`locator`&&(e.tmp.have_collapsed=!1),!e.tmp.group_context.tip.condition&&t[this.variables[0]]&&(e.tmp.just_did_number=!1);var n=t[this.variables[0]];n&&!e.tmp.group_context.tip.condition&&((``+n).slice(-1).match(/[0-9]/)?e.tmp.just_did_number=!0:e.tmp.just_did_number=!1)},this.execs.push(r),n.MULTI_FIELDS.indexOf(this.variables_real[0])>-1||this.variables_real[0].indexOf(`-main`)>-1||this.variables_real[0].indexOf(`-sub`)>-1||[`language-name`,`language-name-original`].indexOf(this.variables_real[0])>-1){var g=this.variables[0],_=!1,v=!1,y=!1;i===`short`?this.variables_real[0].slice(-6)!==`-short`&&(v=this.variables_real[0]+`-short`):g=!1,e.build.extension?y=!0:(y=!0,_=!0),r=e.transform.getOutputFunction(this.variables,g,_,v,y)}else r=n.CITE_FIELDS.indexOf(this.variables_real[0])>-1?function(e,t,r){r&&r[this.variables[0]]&&(e.processNumber(this,r,this.variables[0],t.type),n.Util.outputNumericField(e,this.variables[0],t.id),[`locator`,`locator-extra`].indexOf(this.variables_real[0])>-1&&!e.tmp.just_looking&&e.tmp.done_vars.push(this.variables_real[0]))}:[`page`,`page-first`,`chapter-number`,`collection-number`,`edition`,`issue`,`number`,`number-of-pages`,`number-of-volumes`,`volume`].indexOf(this.variables_real[0])>-1?function(e,t){e.processNumber(this,t,this.variables[0],t.type),n.Util.outputNumericField(e,this.variables[0],t.id)}:[`URL`,`DOI`].indexOf(this.variables_real[0])>-1?function(e,t){var r;if(this.variables[0]&&(r=e.getVariable(t,this.variables[0],i),r))if(this.variables[0]===`URL`&&i===`short`&&(r=r.replace(/(.*\.[^\/]+)\/.*/,`$1`),r.match(/\/\/www\./)&&(r=r.replace(/https?:\/\//,``))),e.opt.development_extensions.wrap_url_and_doi)if(!this.decorations.length||this.decorations[0][0]!==`@`+this.variables[0]){var a=n.Util.cloneToken(this),o=new n.Blob(null,null,`url-wrapper`);if(o.decorations.push([`@DOI`,`true`]),this.variables_real[0]===`DOI`){var s;this.strings.prefix&&this.strings.prefix.match(/^.*https:\/\/doi\.org\/$/)&&(r=r.replace(/^https?:\/\/doi\.org\//,``),s=r.match(/^https?:\/\//)?``:`https://doi.org/`,a.strings.prefix=this.strings.prefix.slice(0,a.strings.prefix.length-16));var c=new n.Blob(s),l=new n.Blob(r);o.push(c),o.push(l),e.output.append(o,a,!1,!1,!0)}else{var l=new n.Blob(r);o.push(l),e.output.append(o,a,!1,!1,!0)}}else e.output.append(r,this,!1,!1,!0);else{if(this.decorations.length)for(var u=this.decorations.length-1;u>-1;u--)this.decorations[u][0]===`@`+this.variables[0]&&(this.decorations=this.decorations.slice(0,u).concat(this.decorations.slice(u+1)));e.output.append(r,this,!1,!1,!0)}}:this.variables_real[0]===`section`?function(e,t){var n=e.getVariable(t,this.variables[0],i);n&&e.output.append(n,this)}:this.variables_real[0]===`hereinafter`?function(e,t){var n=e.transform.abbrevs.default.hereinafter[t.id];n&&(e.output.append(n,this),e.tmp.group_context.tip.variable_success=!0)}:function(e,t){var n;this.variables[0]&&(n=e.getVariable(t,this.variables[0],i),n&&(n=``+n,n=n.split(`\\`).join(``),e.output.append(n,this)))};this.execs.push(r)}else this.strings.value&&(r=function(e){e.tmp.group_context.tip.term_intended=!0,n.UPDATE_GROUP_CONTEXT_CONDITION(e,this.strings.value,!0,this),e.output.append(this.strings.value,this),e.tmp.can_block_substitute&&e.tmp.can_substitute.replace(!1,n.LITERAL)},this.execs.push(r));t.push(this),n.Util.substituteEnd.call(this,e,t)}}},n.Node.intext={build:function(e,t){this.tokentype===n.START&&(e.build.area=`intext`,e.build.root=`intext`,e.build.extension=``,this.execs.push(function(e,t){e.tmp.area=`intext`,e.tmp.root=`intext`,e.tmp.extension=``})),this.tokentype===n.END&&(e.intext_sort={opt:{sort_directions:e.citation_sort.opt.sort_directions}},e.intext.srt=e.citation.srt),t.push(this)}},n.Attributes={},n.Attributes[`@disambiguate`]=function(e,t){if(this.tests||(this.tests=[]),t===`true`){e.opt.has_disambiguate=!0;var n=function(t){if(e.tmp.area===`bibliography`){if(e.tmp.disambiguate_count<e.registry.registry[t.id].disambig.disambiguate)return e.tmp.disambiguate_count+=1,!0}else if(e.tmp.disambiguate_maxMax+=1,e.tmp.disambig_settings.disambiguate&&e.tmp.disambiguate_count<e.tmp.disambig_settings.disambiguate)return e.tmp.disambiguate_count+=1,!0;return!1};this.tests.push(n)}else if(t===`check-ambiguity-and-backreference`){var n=function(t){return!!(e.registry.registry[t.id].disambig.disambiguate&&e.registry.registry[t.id][`citation-count`]>1)};this.tests.push(n)}},n.Attributes[`@is-numeric`]=function(e,t){this.tests||(this.tests=[]);for(var r=t.split(/\s+/),i=function(t){return function(r,i){var a=r;if(i&&[`locator`,`locator-extra`].indexOf(t)>-1&&(a=i),!a[t])return!1;if(n.NUMERIC_VARIABLES.indexOf(t)>-1){if(e.tmp.shadow_numbers[t]||e.processNumber(!1,a,t,r.type),e.tmp.shadow_numbers[t].numeric)return!0}else if([`title`,`version`].indexOf(t)>-1&&a[t].slice(-1)===``+parseInt(a[t].slice(-1),10))return!0;return!1}},a=0;a<r.length;a+=1)this.tests.push(i(r[a]))},n.Attributes[`@is-uncertain-date`]=function(e,t){this.tests||(this.tests=[]);for(var n=t.split(/\s+/),r=function(e){return function(t){return!!(t[e]&&t[e].circa)}},i=0,a=n.length;i<a;i+=1)this.tests.push(r(n[i]))},n.Attributes[`@locator`]=function(e,t){this.tests||(this.tests=[]);var n=t.replace(`sub verbo`,`sub-verbo`);n=n.split(/\s+/);for(var r=function(t){return function(n,r){var i;return e.processNumber(!1,r,`locator`),i=e.tmp.shadow_numbers.locator.label,!!(i&&t===i)}},i=0,a=n.length;i<a;i+=1)this.tests.push(r(n[i]))},n.Attributes[`@position`]=function(e,t){this.tests||(this.tests=[]);var r;e.opt.update_mode=n.POSITION;for(var i=t.split(/\s+/),a=function(e,t){return!!(t&&n.POSITION_MAP[t.position]>=n.POSITION_MAP[n.POSITION_SUBSEQUENT]&&t[`near-note`])},o=function(e,t){return!!(t&&n.POSITION_MAP[t.position]==n.POSITION_MAP[n.POSITION_SUBSEQUENT]&&!t[`near-note`])},s=function(t){return function(r,i){if(e.tmp.area===`bibliography`)return!1;if(i&&i.position===void 0&&(i.position=0),i&&typeof i.position==`number`){if(i.position===0&&t===0||t>0&&n.POSITION_MAP[i.position]>=n.POSITION_MAP[t])return!0}else if(t===0)return!0;return!1}},c=0,l=i.length;c<l;c+=1){var r=i[c];r===`first`?r=n.POSITION_FIRST:r===`container-subsequent`?r=n.POSITION_CONTAINER_SUBSEQUENT:r===`subsequent`?r=n.POSITION_SUBSEQUENT:r===`ibid`?r=n.POSITION_IBID:r===`ibid-with-locator`&&(r=n.POSITION_IBID_WITH_LOCATOR),r===`near-note`?this.tests.push(a):r===`far-note`?this.tests.push(o):this.tests.push(s(r))}},n.Attributes[`@type`]=function(e,t){this.tests||(this.tests=[]);for(var n=t.split(/\s+/),r=function(e){return function(t){return t.type===e}},i=[],a=0,o=n.length;a<o;a+=1)i.push(r(n[a]));this.tests.push(e.fun.match.any(this,e,i))},n.Attributes[`@variable`]=function(e,t){this.tests||(this.tests=[]);var r;if(this.variables=t.split(/\s+/),this.variables_real=this.variables.slice(),this.name===`label`&&this.variables[0])this.strings.term=this.variables[0];else if([`names`,`date`,`text`,`number`].indexOf(this.name)>-1)r=function(e,t,n){for(var r=this.variables.length-1;r>-1;r+=-1)this.variables.pop();for(var r=0,i=this.variables_real.length;r<i;r++)e.tmp.done_vars.indexOf(this.variables_real[r])===-1&&this.variables.push(this.variables_real[r]),e.tmp.can_block_substitute&&e.tmp.done_vars.push(this.variables_real[r])},this.execs.push(r),r=function(e,t,r){for(var i=!1,a=0,o=this.variables.length;a<o;a++){var s=this.variables[a];if([`authority`,`committee`].indexOf(s)>-1&&typeof t[s]==`string`&&this.name===`names`){var c=!0,l=t[s].split(/\s*;\s*/),u={};if(t.multi&&t.multi._keys[s]){for(var d in t.multi._keys[s])if(u[d]=t.multi._keys[s][d].split(/\s*;\s*/),u[d].length!==l.length){c=!1;break}}c||(l=[t[s]],u=t.multi._keys[s]);for(var f=0,p=l.length;f<p;f++){var m={literal:l[f],multi:{_key:{}}};for(var d in u){var h={literal:u[d][f]};m.multi._key[d]=h}l[f]=m}t[s]=l}if(this.strings.form===`short`&&!t[s]&&(s===`title`?s=`title-short`:s===`container-title`&&(s=`container-title-short`)),s===`year-suffix`){i=!0;break}else if(n.DATE_VARIABLES.indexOf(s)>-1){if(e.opt.development_extensions.locator_date_and_revision&&s===`locator-date`){i=!0;break}if(t[s]){for(var g in t[s])if(!(this.dateparts.indexOf(g)===-1&&g!==`literal`)&&t[s][g]){i=!0;break}if(i)break}}else if(s===`locator`){r&&r.locator&&(i=!0);break}else if(s===`locator-extra`){r&&r[`locator-extra`]&&(i=!0);break}else if([`citation-number`,`citation-label`].indexOf(s)>-1){i=!0;break}else if(s===`first-reference-note-number`){r&&r[`first-reference-note-number`]&&(i=!0);break}else if(s===`first-container-reference-note-number`){r&&r[`first-container-reference-note-number`]&&(i=!0);break}else if(s===`hereinafter`){e.transform.abbrevs.default.hereinafter[t.id]&&e.sys.getAbbreviation&&t.id&&(i=!0);break}else if(typeof t[s]==`object`)break;else if(typeof t[s]==`string`&&t[s]){i=!0;break}else if(typeof t[s]==`number`){i=!0;break}if(i)break}if(i){for(var a=0,o=this.variables_real.length;a<o;a++){var s=this.variables_real[a];(s!==`citation-number`||e.tmp.area!==`bibliography`)&&(e.tmp.cite_renders_content=!0),e.tmp.group_context.tip.variable_success=!0,e.tmp.can_substitute.value()&&e.tmp.area===`bibliography`&&typeof t[s]==`string`&&(e.tmp.name_node.top=e.output.current.value(),e.tmp.rendered_name.push(t[s]))}e.tmp.can_substitute.replace(!1,n.LITERAL)}else e.tmp.group_context.tip.variable_attempt=!0},this.execs.push(r);else if([`if`,`else-if`,`condition`].indexOf(this.name)>-1)for(var i=function(t){return function(n,r){var i=n;if(r&&[`locator`,`locator-extra`,`first-reference-note-number`,`first-container-reference-note-number`,`locator-date`].indexOf(t)>-1&&(i=r),t===`hereinafter`&&e.sys.getAbbreviation&&i.id){if(e.transform.abbrevs.default.hereinafter[i.id])return!0}else if(i[t]){if(typeof i[t]==`number`||typeof i[t]==`string`)return!0;if(typeof i[t]==`object`){for(var a in i[t])if(i[t][a])return!0}}return!1}},a=0,o=this.variables.length;a<o;a+=1)this.tests.push(i(this.variables[a]))},n.Attributes[`@page`]=function(e,t){this.tests||(this.tests=[]);var n=t.replace(`sub verbo`,`sub-verbo`);n=n.split(/\s+/);for(var r=function(t){return function(n){var r;return e.processNumber(!1,n,`page`,n.type),r=e.tmp.shadow_numbers.page.label?e.tmp.shadow_numbers.page.label===`sub verbo`?`sub-verbo`:e.tmp.shadow_numbers.page.label:`page`,e.tmp.shadow_numbers.page.values.length>0&&e.tmp.shadow_numbers.page.values[0].gotosleepability&&(e.tmp.shadow_numbers.page.values[0].labelVisibility=!1),t===r}},i=0,a=n.length;i<a;i+=1)this.tests.push(r(n[i]))},n.Attributes[`@number`]=function(e,t){this.tests||(this.tests=[]);for(var n=t.split(/\s+/),r=function(t){return function(n){var r;return e.processNumber(!1,n,`number`,n.type),r=e.tmp.shadow_numbers.number.label?e.tmp.shadow_numbers.number.label:`number`,t===r}},i=0,a=n.length;i<a;i+=1)this.tests.push(r(n[i]))},n.Attributes[`@jurisdiction`]=function(e,t){this.tests||(this.tests=[]);var n=t.split(/\s+/);this.tests.push(function(e){return function(t){if(!t.jurisdiction)return!1;for(var n=t.jurisdiction,r=0,i=e.length;r<i;r++)if(n===e[r])return!0;return!1}}(n))},n.Attributes[`@country`]=function(e,t){this.tests||(this.tests=[]);var n=t.split(/\s+/);this.tests.push(function(e){return function(t){if(!t.country)return!1;for(var n=t.country,r=0,i=e.length;r<i;r++)if(n===e[r])return!0;return!1}}(n))},n.Attributes[`@context`]=function(e,t){this.tests||(this.tests=[]),this.tests.push(function(){if([`bibliography`,`citation`].indexOf(t)>-1)return e.tmp.area.slice(0,t.length)===t;if(t===`alternative`)return!!e.tmp.abort_alternative})},n.Attributes[`@has-year-only`]=function(e,t){this.tests||(this.tests=[]);for(var n=t.split(/\s+/),r=function(e){return function(t){var n=t[e];return!(!n||n.month||n.season)}},i=0,a=n.length;i<a;i+=1)this.tests.push(r(n[i]))},n.Attributes[`@has-to-month-or-season`]=function(e,t){this.tests||(this.tests=[]);for(var n=t.split(/\s+/),r=function(e){return function(t){var n=t[e];return!(!n||!n.month&&!n.season||n.day)}},i=0,a=n.length;i<a;i+=1)this.tests.push(r(n[i]))},n.Attributes[`@has-day`]=function(e,t){this.tests||(this.tests=[]);for(var n=t.split(/\s+/),r=function(e){return function(t){var n=t[e];return!(!n||!n.day)}},i=0,a=n.length;i<a;i+=1)this.tests.push(r(n[i]))},n.Attributes[`@is-plural`]=function(e,t){this.tests||(this.tests=[]),this.tests.push(function(n){var r=n[t];if(r&&r.length){for(var i=0,a=0,o=!1,s=0,c=r.length;s<c;s+=1)e.opt.development_extensions.spoof_institutional_affiliations&&(r[s].literal||r[s].isInstitution&&r[s].family&&!r[s].given)?(a+=1,o=!1):(i+=1,o=!0);if(i>1||a>1||a&&o)return!0}return!1})},n.Attributes[`@is-multiple`]=function(e,t){this.tests||(this.tests=[]),this.tests.push(function(e){return(``+e[t]).split(/(?:,\s|\s(?:tot\sen\smet|līdz|oraz|and|bis|έως|και|och|až|do|en|et|in|ir|ja|og|sa|to|un|und|és|și|i|u|y|à|e|a|и|-|–)\s|—|\&)/).length>1})},n.Attributes[`@locale`]=function(e,t){this.tests||(this.tests=[]);var r,i,a,o,s,c=e.opt[`default-locale`][0];if(this.name===`layout`){if(this.locale_raw=t,this.tokentype===n.START){e.opt.multi_layout||(e.opt.multi_layout=[]);var l=[],u=t.split(/\s+/),d={},f=n.localeResolve(u[0],c);l.push(f),f.generic?d[f.generic]=f.best:d[f.best]=f.best;for(var o=1,s=u.length;o<s;o+=1){var p=n.localeResolve(u[o],c);l.push(p),p.generic?d[p.generic]=f.best:d[p.best]=f.best}e[e.build.area].opt.sort_locales.push(d),e.opt.multi_layout.push(l)}e.opt.has_layout_locale=!0}else{a=t.split(/\s+/);var m=[];for(o=0,s=a.length;o<s;o+=1)i=a[o],r=n.localeResolve(i,c),a[o].length===2&&m.push(r.bare),e.localeConfigure(r,!0),a[o]=r;var h=a.slice();this.tests.push(function(t,r,i){return function(a){var c=!1,l=!1,u=a.language?a.language:r;for(l=n.localeResolve(u,r),o=0,s=t.length;o<s;o+=1)if(l.best===t[o].best){e.tmp.condition_lang_counter_arr.push(e.tmp.condition_counter),e.tmp.condition_lang_val_arr.push(e.opt.lang),e.opt.lang=t[0].best,c=!0;break}return!c&&i.indexOf(l.bare)>-1&&(e.tmp.condition_lang_counter_arr.push(e.tmp.condition_counter),e.tmp.condition_lang_val_arr.push(e.opt.lang),e.opt.lang=t[0].best,c=!0),c}}(h,c,m))}},n.Attributes[`@alternative-node-internal`]=function(e){this.tests||(this.tests=[]);var t=function(){return function(){return!e.tmp.abort_alternative}},n=this;this.tests.push(t(n))},n.Attributes[`@locale-internal`]=function(e,t){this.tests||(this.tests=[]);var r,i,a=t.split(/\s+/),o,s;for(this.locale_bares=[],o=0,s=a.length;o<s;o+=1)i=a[o],r=n.localeResolve(i,e.opt[`default-locale`][0]),a[o].length===2&&this.locale_bares.push(r.bare),e.localeConfigure(r),a[o]=r;this.locale_default=e.opt[`default-locale`][0],this.locale=a[0].best,this.locale_list=a.slice();var c=function(t){return function(r){var a=!1,c=!1;if(r.language&&(i=r.language,c=n.localeResolve(i,e.opt[`default-locale`][0]),c.best===e.opt[`default-locale`][0]&&(c=!1)),c){for(o=0,s=t.locale_list.length;o<s;o+=1)if(c.best===t.locale_list[o].best){e.opt.lang=t.locale,e.tmp.last_cite_locale=t.locale,e.output.openLevel(`empty`),e.output.current.value().new_locale=t.locale,a=!0;break}!a&&t.locale_bares.indexOf(c.bare)>-1&&(e.opt.lang=t.locale,e.tmp.last_cite_locale=t.locale,e.output.openLevel(`empty`),e.output.current.value().new_locale=t.locale,a=!0)}return a}},l=this;this.tests.push(c(l))},n.Attributes[`@court-class`]=function(e,t){this.tests||(this.tests=[]);for(var r=t.split(/\s+/),i=function(t){return function(r){return n.GET_COURT_CLASS(e,r)===t}},a=0,o=r.length;a<o;a++)this.tests.push(i(r[a]))},n.Attributes[`@container-multiple`]=function(e,t){this.tests||(this.tests=[]);var n=t===`true`;this.tests.push(function(t){return function(n){return e.tmp.container_item_count[n.container_id]&&e.tmp.container_item_count[n.container_id]>1?t:!t}}(n))},n.Attributes[`@container-subsequent`]=function(e,t){this.tests||(this.tests=[]);var n=t===`true`;this.tests.push(function(t){return function(n){return e.tmp.container_item_pos[n.container_id]>1?t:!t}}(n))},n.Attributes[`@has-subunit`]=function(e,t){this.tests||(this.tests=[]),this.tests.push(function(e){return function(t){var n=0;for(var r in t[e]){var i=t[e][r];if(!i.given){var a=(i.literal?i.literal:i.family).split(`|`).length;(n===0||a<n)&&(n=a)}}return n>1}}(t))},n.Attributes[`@cite-form`]=function(e,t){this.tests||(this.tests=[]),this.tests.push(function(e){return function(t){return t[`cite-form`]===e}}(t))},n.Attributes[`@disable-duplicate-year-suppression`]=function(e,t){e.opt.disable_duplicate_year_suppression=t.split(/\s+/)},n.Attributes[`@consolidate-containers`]=function(e,t){n.Attributes[`@track-containers`](e,t);var r=t.split(/\s+/);e.bibliography.opt.consolidate_containers=r},n.Attributes[`@track-containers`]=function(e,t){var n=t.split(/\s+/);e.bibliography.opt.track_container_items||(e.bibliography.opt.track_container_items=[]),e.bibliography.opt.consolidate_containers||(e.bibliography.opt.consolidate_containers=[]),e.bibliography.opt.track_container_items=e.bibliography.opt.track_container_items.concat(n)},n.Attributes[`@parallel-first`]=function(e,t){e.opt.parallel.enable=!0;var n=t.split(/\s+/);for(var r in e.opt.track_repeat||(e.opt.track_repeat={}),this.parallel_first={},n){var i=n[r];this.parallel_first[i]=!0,e.opt.track_repeat[i]=!0}},n.Attributes[`@parallel-last`]=function(e,t){e.opt.parallel.enable=!0;var n=t.split(/\s+/);for(var r in e.opt.track_repeat||(e.opt.track_repeat={}),this.parallel_last={},n){var i=n[r];this.parallel_last[i]=!0,e.opt.track_repeat[i]=!0}},n.Attributes[`@parallel-last-to-first`]=function(e,t){e.opt.parallel.enable=!0;var n=t.split(/\s+/);this.parallel_last_to_first={};for(var r=0,i=n.length;r<i;r++)this.parallel_last_to_first[n[r]]=!0},n.Attributes[`@parallel-delimiter-override`]=function(e,t){e.opt.parallel.enable=!0,this.strings.set_parallel_delimiter_override=t},n.Attributes[`@parallel-delimiter-override-on-suppress`]=function(e,t){e.opt.parallel.enable=!0,this.strings.set_parallel_delimiter_override_on_suppress=t},n.Attributes[`@no-repeat`]=function(e,t){e.opt.parallel.enable=!0;var n=t.split(/\s+/);for(var r in e.opt.track_repeat||(e.opt.track_repeat={}),this.non_parallel={},n){var i=n[r];this.non_parallel[i]=!0,e.opt.track_repeat[i]=!0}},n.Attributes[`@require`]=function(e,t){e.opt.use_context_condition=!0,this.strings.require=t},n.Attributes[`@reject`]=function(e,t){e.opt.use_context_condition=!0,this.strings.reject=t},n.Attributes[`@require-comma-on-symbol`]=function(e,t){e.opt.require_comma_on_symbol=t},n.Attributes[`@gender`]=function(e,t){this.gender=t},n.Attributes[`@cslid`]=function(e,t){this.cslid=parseInt(t,10)},n.Attributes[`@capitalize-if-first`]=function(e,t){this.strings.capitalize_if_first_override=t},n.Attributes[`@label-capitalize-if-first`]=function(e,t){this.strings.label_capitalize_if_first_override=t},n.Attributes[`@label-form`]=function(e,t){this.strings.label_form_override=t},n.Attributes[`@part-separator`]=function(e,t){this.strings[`part-separator`]=t},n.Attributes[`@leading-noise-words`]=function(e,t){this[`leading-noise-words`]=t},n.Attributes[`@name-never-short`]=function(e,t){this[`name-never-short`]=t},n.Attributes[`@class`]=function(e,t){e.opt.class=t},n.Attributes[`@version`]=function(e,t){e.opt.version=t},n.Attributes[`@value`]=function(e,t){this.strings.value=t},n.Attributes[`@name`]=function(e,t){this.strings.name=t},n.Attributes[`@form`]=function(e,t){this.strings.form=t},n.Attributes[`@date-parts`]=function(e,t){this.strings[`date-parts`]=t},n.Attributes[`@range-delimiter`]=function(e,t){this.strings[`range-delimiter`]=t},n.Attributes[`@macro`]=function(e,t){this.postponed_macro=t},n.Attributes[`@term`]=function(e,t){t===`sub verbo`?this.strings.term=`sub-verbo`:this.strings.term=t},n.Attributes[`@xmlns`]=function(){},n.Attributes[`@lang`]=function(e,t){t&&(e.build.lang=t)},n.Attributes[`@lingo`]=function(){},n.Attributes[`@macro-has-date`]=function(){this[`macro-has-date`]=!0},n.Attributes[`@suffix`]=function(e,t){this.strings.suffix=t},n.Attributes[`@prefix`]=function(e,t){this.strings.prefix=t},n.Attributes[`@delimiter`]=function(e,t){this.strings.delimiter=t},n.Attributes[`@match`]=function(e,t){this.match=t},n.Attributes[`@names-min`]=function(e,t){var n=parseInt(t,10);e[e.build.area].opt.max_number_of_names<n&&(e[e.build.area].opt.max_number_of_names=n),this.strings[`et-al-min`]=n},n.Attributes[`@names-use-first`]=function(e,t){this.strings[`et-al-use-first`]=parseInt(t,10)},n.Attributes[`@names-use-last`]=function(e,t){t===`true`?this.strings[`et-al-use-last`]=!0:this.strings[`et-al-use-last`]=!1},n.Attributes[`@sort`]=function(e,t){t===`descending`&&(this.strings.sort_direction=n.DESCENDING)},n.Attributes[`@plural`]=function(e,t){t===`always`||t===`true`?this.strings.plural=1:t===`never`||t===`false`?this.strings.plural=0:t===`contextual`&&(this.strings.plural=!1)},n.Attributes[`@has-publisher-and-publisher-place`]=function(){this.strings[`has-publisher-and-publisher-place`]=!0},n.Attributes[`@publisher-delimiter-precedes-last`]=function(e,t){this.strings[`publisher-delimiter-precedes-last`]=t},n.Attributes[`@publisher-delimiter`]=function(e,t){this.strings[`publisher-delimiter`]=t},n.Attributes[`@publisher-and`]=function(e,t){this.strings[`publisher-and`]=t},n.Attributes[`@givenname-disambiguation-rule`]=function(e,t){n.GIVENNAME_DISAMBIGUATION_RULES.indexOf(t)>-1&&(e.citation.opt[`givenname-disambiguation-rule`]=t)},n.Attributes[`@collapse`]=function(e,t){t&&(e[this.name].opt.collapse=t)},n.Attributes[`@cite-group-delimiter`]=function(e,t){t&&(e[e.tmp.area].opt.cite_group_delimiter=t)},n.Attributes[`@names-delimiter`]=function(e,t){e.setOpt(this,`names-delimiter`,t)},n.Attributes[`@name-form`]=function(e,t){e.setOpt(this,`name-form`,t)},n.Attributes[`@subgroup-delimiter`]=function(e,t){this.strings[`subgroup-delimiter`]=t},n.Attributes[`@subgroup-delimiter-precedes-last`]=function(e,t){this.strings[`subgroup-delimiter-precedes-last`]=t},n.Attributes[`@name-delimiter`]=function(e,t){e.setOpt(this,`name-delimiter`,t)},n.Attributes[`@et-al-min`]=function(e,t){var n=parseInt(t,10);e[e.build.area].opt.max_number_of_names<n&&(e[e.build.area].opt.max_number_of_names=n),e.setOpt(this,`et-al-min`,n)},n.Attributes[`@et-al-use-first`]=function(e,t){e.setOpt(this,`et-al-use-first`,parseInt(t,10))},n.Attributes[`@et-al-use-last`]=function(e,t){t===`true`?e.setOpt(this,`et-al-use-last`,!0):e.setOpt(this,`et-al-use-last`,!1)},n.Attributes[`@et-al-subsequent-min`]=function(e,t){var n=parseInt(t,10);e[e.build.area].opt.max_number_of_names<n&&(e[e.build.area].opt.max_number_of_names=n),e.setOpt(this,`et-al-subsequent-min`,n)},n.Attributes[`@et-al-subsequent-use-first`]=function(e,t){e.setOpt(this,`et-al-subsequent-use-first`,parseInt(t,10))},n.Attributes[`@suppress-min`]=function(e,t){this.strings[`suppress-min`]=parseInt(t,10)},n.Attributes[`@suppress-max`]=function(e,t){this.strings[`suppress-max`]=parseInt(t,10)},n.Attributes[`@and`]=function(e,t){e.setOpt(this,`and`,t)},n.Attributes[`@delimiter-precedes-last`]=function(e,t){e.setOpt(this,`delimiter-precedes-last`,t)},n.Attributes[`@delimiter-precedes-et-al`]=function(e,t){e.setOpt(this,`delimiter-precedes-et-al`,t)},n.Attributes[`@initialize-with`]=function(e,t){e.setOpt(this,`initialize-with`,t)},n.Attributes[`@initialize`]=function(e,t){t===`false`&&e.setOpt(this,`initialize`,!1)},n.Attributes[`@name-as-reverse-order`]=function(e,t){this[`name-as-reverse-order`]=t},n.Attributes[`@name-as-sort-order`]=function(e,t){this.name===`style-options`?this[`name-as-sort-order`]=t:e.setOpt(this,`name-as-sort-order`,t)},n.Attributes[`@sort-separator`]=function(e,t){e.setOpt(this,`sort-separator`,t)},n.Attributes[`@require-match`]=function(e,t){t===`true`&&(this.requireMatch=!0)},n.Attributes[`@exclude-types`]=function(e,t){e.bibliography.opt.exclude_types=t.split(/\s+/)},n.Attributes[`@exclude-with-fields`]=function(e,t){e.bibliography.opt.exclude_with_fields=t.split(/\s+/)},n.Attributes[`@year-suffix-delimiter`]=function(e,t){e[this.name].opt[`year-suffix-delimiter`]=t},n.Attributes[`@after-collapse-delimiter`]=function(e,t){e[this.name].opt[`after-collapse-delimiter`]=t},n.Attributes[`@subsequent-author-substitute`]=function(e,t){e[this.name].opt[`subsequent-author-substitute`]=t},n.Attributes[`@subsequent-author-substitute-rule`]=function(e,t){e[this.name].opt[`subsequent-author-substitute-rule`]=t},n.Attributes[`@disambiguate-add-names`]=function(e,t){t===`true`&&(e.opt[`disambiguate-add-names`]=!0)},n.Attributes[`@disambiguate-add-givenname`]=function(e,t){t===`true`&&(e.opt[`disambiguate-add-givenname`]=!0)},n.Attributes[`@disambiguate-add-year-suffix`]=function(e,t){t===`true`&&e.opt.xclass!==`numeric`&&(e.opt[`disambiguate-add-year-suffix`]=!0)},n.Attributes[`@second-field-align`]=function(e,t){(t===`flush`||t===`margin`)&&(e[this.name].opt[`second-field-align`]=t)},n.Attributes[`@hanging-indent`]=function(e,t){t===`true`&&(e.opt.development_extensions.hanging_indent_legacy_number?e[this.name].opt.hangingindent=2:e[this.name].opt.hangingindent=!0)},n.Attributes[`@line-spacing`]=function(e,t){t&&t.match(/^[.0-9]+$/)&&(e[this.name].opt[`line-spacing`]=parseFloat(t,10))},n.Attributes[`@entry-spacing`]=function(e,t){t&&t.match(/^[.0-9]+$/)&&(e[this.name].opt[`entry-spacing`]=parseFloat(t,10))},n.Attributes[`@near-note-distance`]=function(e,t){e[this.name].opt[`near-note-distance`]=parseInt(t,10)},n.Attributes[`@substring`]=function(e,t){this.substring=parseInt(t,10)},n.Attributes[`@text-case`]=function(e,t){this.execs.push(function(e,n){t===`normal`?this.text_case_normal=!0:(this.strings[`text-case`]=t,t===`title`&&n.jurisdiction&&(this.strings[`text-case`]=`passthrough`))})},n.Attributes[`@page-range-format`]=function(e,t){e.opt[`page-range-format`]=t},n.Attributes[`@year-range-format`]=function(e,t){e.opt[`year-range-format`]=t},n.Attributes[`@default-locale`]=function(e,t){if(this.name===`style`){var n,r,i,a,o,a=t.match(/-x-(sort|translit|translat)-/g);if(a)for(i=0,r=a.length;i<r;i+=1)a[i]=a[i].replace(/^-x-/,``).replace(/-$/,``);for(n=t.split(/-x-(?:sort|translit|translat)-/),o=[n[0]],i=1,r=n.length;i<r;i+=1)o.push(a[i-1]),o.push(n[i]);for(n=o.slice(),r=n.length,i=1;i<r;i+=2)e.opt[`locale-`+n[i]].push(n[i+1].replace(/^\s*/g,``).replace(/\s*$/g,``));n.length?e.opt[`default-locale`]=n.slice(0,1):e.opt[`default-locale`]=[`en`]}else t===`true`&&(this.default_locale=!0)},n.Attributes[`@default-locale-sort`]=function(e,t){e.opt[`default-locale-sort`]=t},n.Attributes[`@demote-non-dropping-particle`]=function(e,t){e.opt[`demote-non-dropping-particle`]=t},n.Attributes[`@initialize-with-hyphen`]=function(e,t){t===`false`&&(e.opt[`initialize-with-hyphen`]=!1)},n.Attributes[`@institution-parts`]=function(e,t){this.strings[`institution-parts`]=t},n.Attributes[`@if-short`]=function(e,t){t===`true`&&(this.strings[`if-short`]=!0)},n.Attributes[`@substitute-use-first`]=function(e,t){this.strings[`substitute-use-first`]=parseInt(t,10)},n.Attributes[`@use-first`]=function(e,t){this.strings[`use-first`]=parseInt(t,10)},n.Attributes[`@use-last`]=function(e,t){this.strings[`use-last`]=parseInt(t,10)},n.Attributes[`@stop-first`]=function(e,t){this.strings[`stop-first`]=parseInt(t,10)},n.Attributes[`@stop-last`]=function(e,t){this.strings[`stop-last`]=parseInt(t,10)*-1},n.Attributes[`@reverse-order`]=function(e,t){t===`true`&&(this.strings[`reverse-order`]=!0)},n.Attributes[`@display`]=function(e,t){e.bibliography.tokens.length===2&&(e.opt.using_display=!0),this.strings.cls=t},n.Stack=function(e,t){this.mystack=[],(t||e)&&this.mystack.push(e),this.tip=this.mystack[0]},n.Stack.prototype.push=function(e,t){t||e?this.mystack.push(e):this.mystack.push(``),this.tip=this.mystack[this.mystack.length-1]},n.Stack.prototype.clear=function(){this.mystack=[],this.tip={}},n.Stack.prototype.replace=function(e,t){this.mystack.length===0&&n.error(`Internal CSL processor error: attempt to replace nonexistent stack item with `+e),t||e?this.mystack[this.mystack.length-1]=e:this.mystack[this.mystack.length-1]=``,this.tip=this.mystack[this.mystack.length-1]},n.Stack.prototype.pop=function(){var e=this.mystack.pop();return this.mystack.length?this.tip=this.mystack[this.mystack.length-1]:this.tip={},e},n.Stack.prototype.value=function(){return this.mystack.slice(-1)[0]},n.Stack.prototype.length=function(){return this.mystack.length},n.Parallel=function(e){this.state=e},n.Parallel.prototype.StartCitation=function(e,t){if(this.state.tmp.suppress_repeats=[],!(e.length<2)){for(var n=0,r=!1,i=[],a=0,o=e.length-1;a<o;a++){var s=e[a][0],c=e[a+1][0],l=!1,u={};if(e[a][0].seeAlso&&e[a][0].seeAlso.length>0&&!r){l=!0,r=[e[a][0].id].concat(e[a][0].seeAlso);var d=r.slice(),f=e.slice(a);f[0][1].parallel=`first`;for(var p=0,m=f.length;p<m;p++){var h=f[p][0].id,g=d.indexOf(h);if(n=!1,g===-1?n=a+p-1:a+p===e.length-1&&(n=a+p),n){i.push([a,n]);break}else d=d.slice(0,g).concat(d.slice(g+1))}}for(var _ in a>0&&l&&(this.state.tmp.suppress_repeats[a-1].START=!0,l=!1),this.state.opt.track_repeat)if(!s[_]||!c[_])u[_]=!1;else if(typeof c[_]==`string`||typeof c[_]==`number`){if(_===`title`&&s[`title-short`]&&c[`title-short`])var v=s[`title-short`],y=c[`title-short`];else var v=s[_],y=c[_];v==y?u[_]=!0:u[_]=!1}else if(s[_].length===void 0){u[_]=!1;var b=s[_].year,x=c[_].year;b&&x&&b==x&&(u[_]=!0)}else{var v=JSON.stringify(s[_]),y=JSON.stringify(c[_]);v===y?u[_]=!0:u[_]=!1}r||(u.ORPHAN=!0),n===a&&(u.END=!0,r=!1),this.state.tmp.suppress_repeats.push(u)}for(var p=0,m=i.length;p<m;p++){var S=e[i[p][0]][0].id;this.state.registry.registry[S].master=!0,this.state.registry.registry[S].siblings=[];for(var C=i[p][0],w=i[p][1],T=C;T<w;T++){this.state.tmp.suppress_repeats[T].SIBLING=!0;var E=e[T+1][0].id;e[T+1][1].parallel=`other`,this.state.registry.registry[S].siblings.push(E)}}}},n.Parallel.prototype.checkRepeats=function(e){var t=this.state.tmp.cite_index;if(this.state.tmp.suppress_repeats){if(e.parallel_first&&Object.keys(e.parallel_first).length>0){var n=[{}].concat(this.state.tmp.suppress_repeats),r=!0;for(var i in e.parallel_first)(!n[t][i]||n[t].START)&&(r=!1);return r}if(e.parallel_last&&Object.keys(e.parallel_last).length>0){var n=this.state.tmp.suppress_repeats.concat([{}]),r=Object.keys(e.parallel_last).length>0;for(var i in e.parallel_last)(!n[t][i]||n[t].END)&&(r=!1);return r}if(e.non_parallel&&Object.keys(e.non_parallel).length>0){var n=[{}].concat(this.state.tmp.suppress_repeats),r=!0;for(var i in e.non_parallel)n[t][i]||(r=!1);return r}}return!1},n.Util={},n.Util.Match=function(){this.any=function(e,t,n){return function(e,t){for(var r=0,i=n.length;r<i;r+=1)if(n[r](e,t))return!0;return!1}},this.none=function(e,t,n){return function(e,t){for(var r=0,i=n.length;r<i;r+=1)if(n[r](e,t))return!1;return!0}},this.all=function(e,t,n){return function(e,t){for(var r=0,i=n.length;r<i;r+=1)if(!n[r](e,t))return!1;return!0}},this[void 0]=this.all,this.nand=function(e,t,n){return function(e,t){for(var r=0,i=n.length;r<i;r+=1)if(!n[r](e,t))return!0;return!1}}},n.Transform=function(e){this.abbrevs={},this.abbrevs.default=new e.sys.AbbreviationSegments;function t(t,n,r){var i=``;return e.sys.getHumanForm&&(t===`country`?(i=e.sys.getHumanForm(n.toLowerCase(),!1,!0),i=i.split(`|`)[0]):t===`jurisdiction`&&(i=e.sys.getHumanForm(n.toLowerCase(),!1,!0),i=r?``:i.split(`|`).slice(1).join(`, `))),i}function r(e,r,i,a,o,s,c){var l=``,u=n.FIELD_CATEGORY_REMAP[s],d;if(!u)return o;var f=s,p=o;e.sys.normalizeAbbrevsKey&&(p=e.sys.normalizeAbbrevsKey(s,o));var m=!1;if(f===`jurisdiction`&&p&&(m=p.indexOf(`:`)===-1),[`jurisdiction`,`country`].indexOf(s)>-1&&o===o.toLowerCase()&&(p=o.toUpperCase()),e.sys.getAbbreviation){d=[`jurisdiction`,`country`,`language-name`,`language-name-original`].indexOf(f)>-1?`default`:i.jurisdiction?i.jurisdiction:`default`;var h=e.transform.loadAbbreviation(d,u,p,i.language);if(e.transform.abbrevs[h][u]&&p){var g=e.transform.abbrevs[h][u][p];l=r.strings.form===`short`&&g?m?``:g:t(f,p,m)}}return!l&&(!e.opt.development_extensions.require_explicit_legal_case_title_short||i.type!==`legal_case`)&&a&&i[a]&&c&&(l=i[a]),!l&&!e.sys.getAbbreviation&&e.sys.getHumanForm&&(l=t(f,p,m)),!l&&!m&&(!e.sys.getHumanForm||f!==`jurisdiction`)&&(l=o),e.opt.development_extensions.force_title_abbrev_fallback&&f===`title`&&l===o&&i[`title-short`]&&(l=i[`title-short`]),l}function i(t,n){var r=e.opt[`default-locale`][0].slice(0,2),i=e.opt.development_extensions.strict_text_case_locales?RegExp(`^([a-zA-Z]{2})(?:$|-.*| .*)`):RegExp(`^([a-zA-Z]{2})(?:$|-.*|.*)`);if(t.language){var a=(``+t.language).match(i);r=a?a[1]:`tlh`}return t.multi&&t.multi&&t.multi.main&&t.multi.main[n]&&(r=t.multi.main[n]),(!e.opt.development_extensions.strict_text_case_locales||e.opt.development_extensions.normalize_lang_keys_to_lowercase)&&(r=r.toLowerCase()),r}function a(t,r,a,o,s,c){var l,u,d,f,p=s,m=!1;if(!t[r])return{name:``,usedOrig:s,token:n.Util.cloneToken(this)};var h=!1;n.VARIABLES_WITH_SHORT_FORM.indexOf(r)>-1&&c&&(r+=`-short`,h=!0);var g=!1,_=null,v=[];r.slice(-6)===`-short`?(v.push(r),v.push(r.slice(0,-6))):v.push(r);for(var y=0,b=v.length;y<b;y++){var x=!1,r=v[y];d={name:``,usedOrig:s,locale:i(t,r)},f=e.opt[a]?e.opt[a].slice():[];var S=!1;if(a===`locale-orig`?(s||(d.name=t[r],d.usedOrig=!1),S=!0,m=!0):o&&(f===void 0||f.length===0)&&(d.name=t[r],d.usedOrig=!0,S=!0,m=!0),!S){for(var C=0,w=f.length;C<w;C+=1)if(l=f[C],u=l.split(/[\-_]/)[0],l&&t.multi&&t.multi._keys[r]&&t.multi._keys[r][l]){d.name=t.multi._keys[r][l],d.locale=l,S=!0,x=!0,m=!1;break}else if(u&&t.multi&&t.multi._keys[r]&&t.multi._keys[r][u]){d.name=t.multi._keys[r][u],d.locale=u,S=!0,x=!0,m=!1;break}!d.name&&o&&(d={name:t[r],usedOrig:!0,locale:i(t,r)},m=!0)}if(d.token=n.Util.cloneToken(this),y===0?(x&&(d.found_variant_ok=!0),_=d,!h&&(f===void 0||f.length===0)&&(g=!0),x&&(g=!0)):!h&&!x&&_?(d=_,r=v[0]):x&&(d.found_variant_ok=!0),[`title`,`container-title`].indexOf(r)>-1&&!p&&(!d.token.strings[`text-case`]||d.token.strings[`text-case`]===`sentence`||d.token.strings[`text-case`]===`normal`)){e.opt.lang;var T=m?!1:d.locale,E=r.slice(0,-5),D=d.token.strings[`text-case`]===`sentence`;d.name=n.titlecaseSentenceOrNormal(e,t,E,T,D),delete d.token.strings[`text-case`]}if(g)break}return d}this.getTextSubField=a;function o(t,r,i,a){t||(t=`default`);var o=t.split(`:`)[0],s=n.getAbbrevsDomain(e,o,a);return s&&(t+=`@`+s),i?(e.sys.getAbbreviation&&(t=e.sys.getAbbreviation(e.opt.styleID,e.transform.abbrevs,t,r,i),t||(t=`default`,s&&(t+=`@`+s))),t):(e.transform.abbrevs[t]||(e.transform.abbrevs[t]=new e.sys.AbbreviationSegments),e.transform.abbrevs[t][r]||(e.transform.abbrevs[t][r]={}),t)}this.loadAbbreviation=o;function s(t,n,i,a){var o=t.variables[0];if(e.publisherOutput&&i){if([`publisher`,`publisher-place`].indexOf(o)===-1)return!1;e.publisherOutput[o+`-token`]=t,e.publisherOutput.varlist.push(o);var s=i.split(/;\s*/);s.length===e.publisherOutput[o+`-list`].length&&(e.publisherOutput[o+`-list`]=s);for(var c=0,l=s.length;c<l;c+=1)s[c]=r(e,t,n,!1,s[c],a,!0);return e.tmp[o+`-token`]=t,!0}return!1}function c(e,t){var n=t.match(/^#([0-9]+).*>>>/);n&&n[1]&&(e[`cite-form`]=n[1])}function l(t,n){var r=n.match(/^(?:#[0-9]+)*(?:!((?:[-_a-z]+(?:(?:.*)))(?:,(?:[-_a-z]+(?:(?:.*))))*))*>>>/);if(r&&(n=n.slice(r[0].length),r[1]))for(var i=r[1].split(`,`),a=0,o=i.length;a<o;a+=1){var s=i[a].match(/^([-_a-z]+)(?:\:(.*))*$/),c=s[1],l=e.tmp.abbrev_trimmer;s[2]?l&&t&&(l[t]||(l[t]={}),l[t][c]=s[2]):e.tmp.done_vars.indexOf(c)===-1&&(l&&t&&(l.QUASHES[t]||(l.QUASHES[t]={}),l.QUASHES[t][c]=!0),e.tmp.done_vars.push(c))}return n}this.quashCheck=l;function u(t,i,o,u){var d,f=n.LangPrefsMap[t[0]];return d=f?e.opt[`cite-lang-prefs`][f]:!1,function(e,o,p){var m,h,g,_,v,y,b;if(!t[0]||!o[t[0]]&&!o[u]||!e.tmp.just_looking&&p&&p[`suppress-author`]&&!e.tmp.probably_rendered_something&&e.tmp.can_substitute.length()>1)return null;var x={primary:!1,secondary:!1,tertiary:!1};if(e.tmp.area.slice(-5)===`_sort`)x.primary=`locale-sort`;else if(d&&d.length===1&&d[0]===`locale-orig`)x.primary=`locale-orig`,d=!1;else if(d&&!e.tmp.multi_layout)for(var S=[`primary`,`secondary`,`tertiary`],C=0,w=S.length;C<w&&!(d.length-1<C);C+=1)d[C]&&(x[S[C]]=`locale-`+d[C]);else x.primary=`locale-orig`;if((t[0]===`title-short`||e.tmp.area!==`bibliography`&&!(e.tmp.area===`citation`&&e.opt.xclass===`note`&&p&&!p.position))&&(x.secondary=!1,x.tertiary=!1),e.tmp.multi_layout&&(x.secondary=!1,x.tertiary=!1),e.tmp[`publisher-list`])return t[0]===`publisher`?e.tmp[`publisher-token`]=this:t[0]===`publisher-place`&&(e.tmp[`publisher-place-token`]=this),null;var T=e.tmp.lang_array.slice(),E=a.call(this,o,t[0],x.primary,!0,null,i);m=E.name,h=E.locale;var b=E.token,D=E.usedOrig;if(i&&!E.found_variant_ok&&(m=r(e,b,o,u,m,i,!0),m&&(c(o,m),e.tmp.just_looking||(m=l(o.jurisdiction,m)))),s(this,o,m,i))return e.tmp.lang_array=T,null;g=!1,v=!1;var O,k;x.secondary&&(E=a.call(this,o,t[0],x.secondary,!1,E.usedOrig,null,i),g=E.name,_=E.locale,O=E.token,i&&!E.found_variant_ok&&g&&(g=r(e,O,o,!1,g,i,!0))),x.tertiary&&(E=a.call(this,o,t[0],x.tertiary,!1,E.usedOrig,null,i),v=E.name,y=E.locale,k=E.token,i&&!E.found_variant_ok&&v&&(v=r(e,k,o,!1,v,i,!0)));var A;if(x.primary===`locale-translit`&&(A=e.opt.citeAffixes[f][x.primary].prefix),A===`<i>`&&t[0]===`title`&&!D){for(var j=!1,C=0,w=b.decorations.length;C<w;C+=1)b.decorations[C][0]===`@font-style`&&b.decorations[C][1]===`italic`&&(j=!0);j||b.decorations.push([`@font-style`,`italic`])}if(h!==`en`&&b.strings[`text-case`]===`title`&&(b.strings[`text-case`]=`passthrough`),t[0]===`title`&&(m=n.demoteNoiseWords(e,m,this[`leading-noise-words`])),g||v){if(e.output.openLevel(`empty`),b.strings.suffix=b.strings.suffix.replace(/[ .,]+$/,``),h&&(e.tmp.lang_array=[h].concat(T)),n.UPDATE_GROUP_CONTEXT_CONDITION(e,null,null,b,b.strings.prefix+m),e.output.append(m,b),e.tmp.probably_rendered_something=!0,m===g&&(g=!1),g){O.strings.prefix=e.opt.citeAffixes[f][x.secondary].prefix,O.strings.suffix=e.opt.citeAffixes[f][x.secondary].suffix,O.strings.prefix||(O.strings.prefix=` `);for(var C=O.decorations.length-1;C>-1;C+=-1)[`@quotes/true`,`@font-style/italic`,`@font-style/oblique`,`@font-weight/bold`].indexOf(O.decorations[C].join(`/`))>-1&&(O.decorations=O.decorations.slice(0,C).concat(O.decorations.slice(C+1)));_!==`en`&&O.strings[`text-case`]===`title`&&(O.strings[`text-case`]=`passthrough`),_&&(e.tmp.lang_array=[_].concat(T));var M=new n.Token;M.decorations.push([`@font-style`,`normal`]),M.decorations.push([`@font-weight`,`normal`]),e.output.openLevel(M),e.output.append(g,O),e.output.closeLevel(),e.output.current.value(),e.output.current.value().blobs.length-1}if(m===v&&(v=!1),v){k.strings.prefix=e.opt.citeAffixes[f][x.tertiary].prefix,k.strings.suffix=e.opt.citeAffixes[f][x.tertiary].suffix,k.strings.prefix||(k.strings.prefix=` `);for(var C=k.decorations.length-1;C>-1;C+=-1)[`@quotes/true`,`@font-style/italic`,`@font-style/oblique`,`@font-weight/bold`].indexOf(k.decorations[C].join(`/`))>-1&&(k.decorations=k.decorations.slice(0,C).concat(k.decorations.slice(C+1)));y!==`en`&&k.strings[`text-case`]===`title`&&(k.strings[`text-case`]=`passthrough`),y&&(e.tmp.lang_array=[y].concat(T));var N=new n.Token;N.decorations.push([`@font-style`,`normal`]),N.decorations.push([`@font-weight`,`normal`]),e.output.openLevel(N),e.output.append(v,k),e.output.closeLevel(),e.output.current.value(),e.output.current.value().blobs.length-1}e.output.closeLevel()}else h&&(e.tmp.lang_array=[h].concat(T)),n.UPDATE_GROUP_CONTEXT_CONDITION(e,null,null,b,b.strings.prefix+m),e.output.append(m,b),e.tmp.probably_rendered_something=!0;return e.tmp.lang_array=T,e.tmp.can_block_substitute&&e.tmp.name_node.children.push(e.output.current.value()),null}}this.getOutputFunction=u},n.Token=function(e,t,n){this.name=e,this.strings={},this.strings.delimiter=void 0,this.strings.prefix=``,this.strings.suffix=``,this.decorations=[],this.variables=[],this.execs=[],this.tokentype=t},n.Util.cloneToken=function(e){var t,r,i,a;if(typeof e==`string`)return e;for(var r in t=new n.Token(e.name,e.tokentype),e.strings)e.strings.hasOwnProperty(r)&&(t.strings[r]=e.strings[r]);if(e.decorations)for(t.decorations=[],i=0,a=e.decorations.length;i<a;i+=1)t.decorations.push(e.decorations[i].slice());return e.variables&&(t.variables=e.variables.slice()),e.execs&&(t.execs=e.execs.slice(),e.tests&&(t.tests=e.tests.slice())),t},n.AmbigConfig=function(){this.maxvals=[],this.minval=1,this.names=[],this.givens=[],this.year_suffix=!1,this.disambiguate=0},n.Blob=function(e,t,n){var r,i,a;if(this.levelname=n,t){for(var a in this.strings={prefix:``,suffix:``},t.strings)t.strings.hasOwnProperty(a)&&(this.strings[a]=t.strings[a]);for(this.decorations=[],r=t.decorations===void 0?0:t.decorations.length,i=0;i<r;i+=1)this.decorations.push(t.decorations[i].slice())}else this.strings={},this.strings.prefix=``,this.strings.suffix=``,this.strings.delimiter=``,this.decorations=[];typeof e==`string`?this.blobs=e:e?this.blobs=[e]:this.blobs=[],this.alldecor=[this.decorations]},n.Blob.prototype.push=function(e){typeof this.blobs==`string`?n.error(`Attempt to push blob onto string object`):!1!==e&&(e.alldecor=e.alldecor.concat(this.alldecor),this.blobs.push(e))},n.NumericBlob=function(e,t,r,i,a){if(this.id=a,this.alldecor=[],this.num=r,this.particle=t,this.blobs=r.toString(),this.status=n.START,this.strings={},i){if(i.strings[`text-case`]){var o=i.strings[`text-case`];this.particle=n.Output.Formatters[o](e,this.particle),this.blobs=n.Output.Formatters[o](e,this.blobs)}this.gender=i.gender,this.decorations=i.decorations,this.strings.prefix=i.strings.prefix,this.strings.suffix=i.strings.suffix,this.strings[`text-case`]=i.strings[`text-case`],this.successor_prefix=i.successor_prefix,this.range_prefix=i.range_prefix,this.splice_prefix=i.splice_prefix,this.formatter=i.formatter,this.formatter||(this.formatter=new n.Output.DefaultFormatter),this.formatter&&(this.type=this.formatter.format(1))}else this.decorations=[],this.strings.prefix=``,this.strings.suffix=``,this.successor_prefix=``,this.range_prefix=``,this.splice_prefix=``,this.formatter=new n.Output.DefaultFormatter},n.NumericBlob.prototype.setFormatter=function(e){this.formatter=e,this.type=this.formatter.format(1)},n.Output.DefaultFormatter=function(){},n.Output.DefaultFormatter.prototype.format=function(e){return e.toString()},n.NumericBlob.prototype.checkNext=function(e,t){t?(this.status=n.START,typeof e==`object`&&(e.num===this.num+1?e.status=n.SUCCESSOR:e.status=n.SEEN)):!e||!e.num||this.type!==e.type||e.num!==this.num+1?(this.status===n.SUCCESSOR_OF_SUCCESSOR&&(this.status=n.END),typeof e==`object`&&(e.status=n.SEEN)):this.status===n.START||this.status===n.SEEN?e.status=n.SUCCESSOR:(this.status===n.SUCCESSOR||this.status===n.SUCCESSOR_OF_SUCCESSOR)&&(this.range_prefix?(e.status=n.SUCCESSOR_OF_SUCCESSOR,this.status=n.SUPPRESS):e.status=n.SUCCESSOR)},n.NumericBlob.prototype.checkLast=function(e){return this.status===n.SEEN||e.num!==this.num-1&&this.status===n.SUCCESSOR?(this.status=n.SUCCESSOR,!0):!1},n.Util.fixDateNode=function(e,t,n){var r,i,a,o,s,c,l,u,d,f,p,m,h,g=this.cslXml.getAttributeValue(n,`lingo`),_=this.cslXml.getAttributeValue(n,`default-locale`);this.build.date_key=!0,r=this.cslXml.getAttributeValue(n,`form`);var g=_?this.opt[`default-locale`][0]:this.cslXml.getAttributeValue(n,`lingo`);if(!this.getDate(r,_))return e;var v=this.cslXml.getAttributeValue(n,`date-parts`);for(var y in i=this.cslXml.getAttributeValue(n,`variable`),u=this.cslXml.getAttributeValue(n,`prefix`),d=this.cslXml.getAttributeValue(n,`suffix`),m=this.cslXml.getAttributeValue(n,`display`),h=this.cslXml.getAttributeValue(n,`cslid`),a=this.cslXml.nodeCopy(this.getDate(r,_)),this.cslXml.setAttribute(a,`lingo`,this.opt.lang),this.cslXml.setAttribute(a,`form`,r),this.cslXml.setAttribute(a,`date-parts`,v),this.cslXml.setAttribute(a,`cslid`,h),this.cslXml.setAttribute(a,`variable`,i),this.cslXml.setAttribute(a,`default-locale`,_),u&&this.cslXml.setAttribute(a,`prefix`,u),d&&this.cslXml.setAttribute(a,`suffix`,d),m&&this.cslXml.setAttribute(a,`display`,m),f=this.cslXml.children(a),f)o=f[y],this.cslXml.nodename(o)===`date-part`&&(s=this.cslXml.getAttributeValue(o,`name`),_&&this.cslXml.setAttributeOnNodeIdentifiedByNameAttribute(a,`date-part`,s,`@default-locale`,`true`));for(var y in f=this.cslXml.children(n),f)if(o=f[y],this.cslXml.nodename(o)===`date-part`)for(c in s=this.cslXml.getAttributeValue(o,`name`),p=this.cslXml.attributes(o),p)c!==`@name`&&(g&&g!==this.opt.lang&&[`@suffix`,`@prefix`,`@form`].indexOf(c)>-1||(l=p[c],this.cslXml.setAttributeOnNodeIdentifiedByNameAttribute(a,`date-part`,s,c,l)));if(this.cslXml.getAttributeValue(n,`date-parts`)===`year`)this.cslXml.deleteNodeByNameAttribute(a,`month`),this.cslXml.deleteNodeByNameAttribute(a,`day`);else if(this.cslXml.getAttributeValue(n,`date-parts`)===`year-month`)this.cslXml.deleteNodeByNameAttribute(a,`day`);else if(this.cslXml.getAttributeValue(n,`date-parts`)===`month-day`){for(var b=this.cslXml.children(a),x=1,S=this.cslXml.numberofnodes(b);x<S;x++)if(this.cslXml.getAttributeValue(b[x],`name`)===`year`){this.cslXml.setAttribute(b[x-1],`suffix`,``);break}this.cslXml.deleteNodeByNameAttribute(a,`year`)}return this.cslXml.insertChildNodeAfter(e,n,t,a)},n.dateMacroAsSortKey=function(e,t){n.dateAsSortKey.call(this,e,t,!0)},n.dateAsSortKey=function(e,t,r){var i,a,o,s,c,l,u,d,f=this.variables[0],p=`empty`;if(r&&e.tmp.extension&&(p=`macro-with-date`),i=t[f],i===void 0&&(i={"date-parts":[[0]]}),this.dateparts===void 0&&(this.dateparts=[`year`,`month`,`day`]),i.raw?i=e.fun.dateparser.parseDateToArray(i.raw):i[`date-parts`]&&(i=e.dateParseArray(i)),i===void 0&&(i={}),i.year)for(u=0,d=n.DATE_PARTS_INTERNAL.length;u<d;u+=1)if(a=n.DATE_PARTS_INTERNAL[u],o=0,s=a,s.slice(-4)===`_end`&&(s=s.slice(0,-4)),i[a]&&this.dateparts.indexOf(s)>-1&&(o=i[a]),a.slice(0,4)===`year`){c=n.Util.Dates[s].numeric(e,o);var l=`1`;c[0]===`-`&&(l=`0`,c=c.slice(1),c=9999-parseInt(c,10)),e.output.append(n.Util.Dates[a.slice(0,4)].numeric(e,l+c),p)}else o=n.Util.Dates[s][`numeric-leading-zeros`](e,o),o||(o=`00`),e.output.append(o,p)},n.Engine.prototype.dateParseArray=function(e){var t={},r,i,a;for(r in e)if(r===`date-parts`){i=e[`date-parts`],i.length>1&&i[0].length!==i[1].length&&n.error(`CSL data error: element mismatch in date range input.`),a=[``,`_end`];for(var o=0,s=i.length;o<s;o+=1)for(var c=0,l=n.DATE_PARTS.length;c<l;c+=1)isNaN(parseInt(i[o][c],10))?t[n.DATE_PARTS[c]+a[o]]=void 0:t[n.DATE_PARTS[c]+a[o]]=parseInt(i[o][c],10)}else e.hasOwnProperty(r)&&(r===`literal`&&typeof e.literal==`object`&&typeof e.literal.part==`string`?(n.debug(`Warning: fixing up weird literal date value`),t.literal=e.literal.part):t[r]=e[r]);return t},n.Util.Names={},n.Util.Names.compareNamesets=n.NameOutput.prototype._compareNamesets,n.Util.Names.unInitialize=function(e,t){var n,r,i,a,o;if(!t)return``;for(i=t.split(/(?:\-|\s+)/),a=t.match(/(\-|\s+)/g),o=``,n=0,r=i.length;n<r;n+=1)o+=i[n],n<r-1&&(o+=a[n]);return o},n.Util.Names.initializeWith=function(e,t,r,i){var a,o,s;if(!t)return``;if(r||(r=``),[`Lord`,`Lady`].indexOf(t)>-1||!t.replace(/^(?:<[^>]+>)*/,``).match(n.STARTSWITH_ROMANESQUE_REGEXP)&&!r.match(`%s`))return t;e.opt[`initialize-with-hyphen`]===!1&&(t=t.replace(/\-/g,` `)),t=t.replace(/\s*\-\s*/g,`-`).replace(/\s+/g,` `),t=t.replace(/-([a-z])/g,`–$1`);for(var a=t.length-2;a>-1;a+=-1)t.slice(a,a+1)===`.`&&t.slice(a+1,a+2)!==` `&&(t=t.slice(0,a)+`. `+t.slice(a+1));var c=n.Output.Formatters.nameDoppel.split(t),l=[];if(l=[c.strings[0]],c.tags.length===0){var u=l[0].match(/[^\.]+$/);u&&u[0].length===1&&u[0]!==u[0].toLowerCase()&&(l[0]+=`.`)}for(a=1,o=c.strings.length;a<o;a+=1)l.push(c.tags[a-1]),l.push(c.strings[a]);return s=i?this.doNormalize(e,l,r):this.doInitialize(e,l,r),s=s.replace(/\u2013([a-z])/g,`-$1`),s},n.Util.Names.notag=function(e){return e.replace(/^(?:<[^>]+>)*/,``)},n.Util.Names.mergetag=function(e,t,n){var r=t.match(/(?:-*<[^>]+>-*)/g);if(r)t=r.join(``);else return n;return r=n.match(/^(.*[^\s])*(\s+)$/),r?(r[1]=r[1]?r[1]:``,n=r[1]+t+r[2]):n+=t,n},n.Util.Names.tagonly=function(e,t){var n=t.match(/(?:<[^>]+>)+/);return n?n.join(``):t},n.Util.Names.doNormalize=function(e,t,n){var r,i;n=n||``;var a=[];for(r=0,i=t.length;r<i;r+=1)this.notag(t[r]).length>1&&this.notag(t[r]).slice(-1)===`.`?(t[r]=t[r].replace(/^(.*)\.(.*)$/,`$1$2`),a.push(!0)):t[r].length===1&&t[r].toUpperCase()===t[r]?a.push(!0):a.push(!1);for(r=0,i=t.length;r<i;r+=2)a[r]&&(r<t.length-2&&(t[r+1]=this.tagonly(e,t[r+1]),a[r+2]||(t[r+1]=this.tagonly(e,t[r+1])+` `),t[r+2].length>1?t[r+1]=n.replace(/\ufeff$/,``)+t[r+1]:t[r+1]=this.mergetag(e,t[r+1],n)),r===t.length-1&&(t[r]=t[r]+n));return t.join(``).replace(/[\u0009\u000a\u000b\u000c\u000d\u0020\ufeff\u00a0]+$/,``).replace(/\s*\-\s*/g,`-`).replace(/[\u0009\u000a\u000b\u000c\u000d\u0020]+/g,` `)},n.Util.Names.doInitialize=function(e,t,r){var i,a,o,s,c,l,u;for(i=0,a=t.length;i<a;i+=2)if(u=t[i],u)if(o=u.match(n.NAME_INITIAL_REGEXP),!o&&!u.match(n.STARTSWITH_ROMANESQUE_REGEXP)&&u.length>1&&r.match(`%s`)&&(o=u.match(/(.)(.*)/)),o&&o[2]&&o[3]&&(o[1]+=o[2],o[2]=``),o&&o[1].slice(0,1)===o[1].slice(0,1).toUpperCase()){var d=``;if(o[2]){var f=``;for(l=o[2].split(``),s=0,c=l.length;s<c;s+=1){var p=l[s];if(p===p.toUpperCase())f+=p;else break}f.length<o[2].length&&(d=n.toLocaleLowerCase.call(e,f))}t[i]=o[1]+d,i<a-1?r.match(`%s`)?t[i]=r.replace(`%s`,t[i]):t[i+1].indexOf(`-`)>-1?t[i+1]=this.mergetag(e,t[i+1].replace(`-`,``),r)+`-`:t[i+1]=this.mergetag(e,t[i+1],r):r.match(`%s`)?t[i]=r.replace(`%s`,t[i]):t.push(r)}else u.match(n.ROMANESQUE_REGEXP)&&(!o||!o[3])&&(t[i]=` `+u);var m=t.join(``);return m=m.replace(/[\u0009\u000a\u000b\u000c\u000d\u0020\ufeff\u00a0]+$/,``).replace(/\s*\-\s*/g,`-`).replace(/[\u0009\u000a\u000b\u000c\u000d\u0020]+/g,` `),m},n.Util.Names.getRawName=function(e){var t=[];return e.literal?t.push(e.literal):(e.given&&t.push(e.given),e.family&&t.push(e.family)),t.join(` `)},n.Util.Dates={},n.Util.Dates.year={},n.Util.Dates.year.long=function(e,t){return t||(t=typeof t==`boolean`?``:0),t.toString()},n.Util.Dates.year.imperial=function(e,t,n){var r=``;t||(t=typeof t==`boolean`?``:0),n=n?`_end`:``;var i=e.tmp.date_object[`month`+n];for(i=i?``+i:`1`;i.length<2;)i=`0`+i;var a=e.tmp.date_object[`day`+n];for(a=a?``+a:`1`;a.length<2;)a=`0`+a;var o=parseInt(t+i+a,10),s,c;if(o>=18680908&&o<19120730?(s=`明治`,c=1867):o>=19120730&&o<19261225?(s=`大正`,c=1911):o>=19261225&&o<19890108?(s=`昭和`,c=1925):o>=19890108&&(s=`平成`,c=1988),s&&c){var l=s;e.sys.normalizeAbbrevsKey&&(l=e.sys.normalizeAbbrevsKey(`number`,s)),e.transform.abbrevs.default.number[l]||e.transform.loadAbbreviation(`default`,`number`,l,null),e.transform.abbrevs.default.number[l]&&(s=e.transform.abbrevs.default.number[l]),r=s+(t-c)}return r},n.Util.Dates.year.short=function(e,t){if(t=t.toString(),t&&t.length===4)return t.substr(2)},n.Util.Dates.year.numeric=function(e,t){var n,r;t=``+t;var n=t.match(/([0-9]*)$/);for(n?(r=t.slice(0,n[1].length*-1),t=n[1]):(r=t,t=``);t.length<4;)t=`0`+t;return r+t},n.Util.Dates.normalizeMonth=function(e,t){var n;if(e||(e=0),e=``+e,e.match(/^[0-9]+$/)||(e=0),e=parseInt(e,10),t){var r={stub:`month-`,num:e};if(r.num<1||r.num>24)r.num=0;else{for(;r.num>16;)r.num-=4;r.num>12&&(r.stub=`season-`,r.num-=12)}n=r}else (e<1||e>12)&&(e=0),n=e;return n},n.Util.Dates.month={},n.Util.Dates.month.numeric=function(e,t){var t=n.Util.Dates.normalizeMonth(t);return t||(t=``),t},n.Util.Dates.month[`numeric-leading-zeros`]=function(e,t){var t=n.Util.Dates.normalizeMonth(t);if(!t)t=``;else for(t=``+t;t.length<2;)t=`0`+t;return t},n.Util.Dates.month.long=function(e,t,r,i){var a=n.Util.Dates.normalizeMonth(t,!0),t=a.num;if(!t)t=``;else{for(t=``+t;t.length<2;)t=`0`+t;t=e.getTerm(a.stub+t,`long`,0,0,!1,i)}return t},n.Util.Dates.month.short=function(e,t,r,i){var a=n.Util.Dates.normalizeMonth(t,!0),t=a.num;if(!t)t=``;else{for(t=``+t;t.length<2;)t=`0`+t;t=e.getTerm(a.stub+t,`short`,0,0,!1,i)}return t},n.Util.Dates.day={},n.Util.Dates.day.numeric=function(e,t){return t.toString()},n.Util.Dates.day.long=n.Util.Dates.day.numeric,n.Util.Dates.day[`numeric-leading-zeros`]=function(e,t){for(t||(t=0),t=t.toString();t.length<2;)t=`0`+t;return t.toString()},n.Util.Dates.day.ordinal=function(e,t,n){return e.fun.ordinalizer.format(t,n)},n.Util.Sort={},n.Util.Sort.strip_prepositions=function(e){var t;return typeof e==`string`&&(t=e.match(/^(([aA]|[aA][nN]|[tT][hH][eE])\s+)/)),t&&(e=e.substr(t[1].length)),e},n.Util.substituteStart=function(e,t){var r,i,a,o=function(e,t,n){for(var r=0,i=this.decorations.length;r<i;r+=1)if(this.decorations[r][0]===`@strip-periods`&&this.decorations[r][1]===`true`){e.tmp.strip_periods+=1;break}},s,c,l;this.execs.push(o),this.decorations&&e.opt.development_extensions.csl_reverse_lookup_support&&(this.decorations.reverse(),this.decorations.push([`@showid`,`true`,this.cslid]),this.decorations.reverse()),l=[`number`,`date`,`names`],(this.name===`text`&&!this.postponed_macro||l.indexOf(this.name)>-1)&&(r=function(e,t,n){e.tmp.element_trace.value()===`author`||this.name===`names`?(!e.tmp.just_looking&&n&&n[`author-only`]&&e.tmp.area!==`intext`&&e.tmp.probably_rendered_something&&e.tmp.element_trace.push(`suppress-me`),!e.tmp.just_looking&&n&&n[`suppress-author`]&&(e.tmp.probably_rendered_something||e.tmp.element_trace.push(`suppress-me`))):this.name===`date`?!e.tmp.just_looking&&n&&n[`author-only`]&&e.tmp.area!==`intext`&&e.tmp.probably_rendered_something&&e.tmp.element_trace.push(`suppress-me`):!e.tmp.just_looking&&n&&n[`author-only`]&&e.tmp.area!==`intext`?!e.tmp.probably_rendered_something&&e.tmp.can_block_substitute||e.tmp.element_trace.push(`suppress-me`):n&&n[`suppress-author`]&&e.tmp.element_trace.push(`do-not-suppress-me`)},this.execs.push(r)),i=this.strings.cls,this.strings.cls=!1,e.build.render_nesting_level===0&&(e.build.area===`bibliography`&&e.bibliography.opt[`second-field-align`]?(a=new n.Token(`group`,n.START),a.decorations=[[`@display`,`left-margin`]],o=function(e,t){e.tmp.render_seen||(a.strings.first_blob=t.id,e.output.startTag(`bib_first`,a))},a.execs.push(o),t.push(a)):n.DISPLAY_CLASSES.indexOf(i)>-1&&(a=new n.Token(`group`,n.START),a.decorations=[[`@display`,i]],o=function(e,t){a.strings.first_blob=t.id,e.output.startTag(`bib_first`,a)},a.execs.push(o),t.push(a)),e.build.cls=i),e.build.render_nesting_level+=1,e.build.substitute_level.value()===1&&(s=new n.Token(`choose`,n.START),n.Node.choose.build.call(s,e,t),c=new n.Token(`if`,n.START),o=function(){return!!e.tmp.can_substitute.value()},c.tests||(c.tests=[]),c.tests.push(o),c.test=e.fun.match.any(this,e,c.tests),t.push(c)),e.sys.variableWrapper&&this.variables_real&&this.variables_real.length&&(o=function(e,t,r){if(!e.tmp.just_looking&&!e.tmp.suppress_decorations){var i=new n.Token(`text`,n.START);i.decorations=[[`@showid`,`true`]],e.output.startTag(`variable_entry`,i);var a=null;r&&(a=r.position),a||(a=0);var o=[`first`,`container-subsequent`,`subsequent`,`ibid`,`ibid-with-locator`],s=0;r&&r.noteIndex&&(s=r.noteIndex);var c=0;r&&r[`first-reference-note-number`]&&(c=r[`first-reference-note-number`]);var l=0;r&&r[`first-container-reference-note-number`]&&(l=r[`first-container-reference-note-number`]);var u=0;r&&r[`citation-number`]&&(u=r[`citation-number`]);var d=0;r&&r.index&&(d=r.index);var f={itemData:t,variableNames:this.variables,context:e.tmp.area,xclass:e.opt.xclass,position:o[a],"note-number":s,"first-reference-note-number":c,"first-container-reference-note-number":l,"citation-number":u,index:d,mode:e.opt.mode};e.output.current.value().params=f}},this.execs.push(o))},n.Util.substituteEnd=function(e,t){var r,i,a,o,s,c;if(e.sys.variableWrapper&&(this.hasVariable||this.variables_real&&this.variables_real.length)&&(r=function(e){!e.tmp.just_looking&&!e.tmp.suppress_decorations&&e.output.endTag(`variable_entry`)},this.execs.push(r)),r=function(e){for(var t=0,n=this.decorations.length;t<n;t+=1)if(this.decorations[t][0]===`@strip-periods`&&this.decorations[t][1]===`true`){e.tmp.strip_periods+=-1;break}},this.execs.push(r),e.build.render_nesting_level+=-1,e.build.render_nesting_level===0&&(e.build.cls?(r=function(e){e.output.endTag(`bib_first`)},this.execs.push(r),e.build.cls=!1):e.build.area===`bibliography`&&e.bibliography.opt[`second-field-align`]&&(i=new n.Token(`group`,n.END),r=function(e){e.tmp.render_seen||e.output.endTag(`bib_first`)},i.execs.push(r),t.push(i),a=new n.Token(`group`,n.START),a.decorations=[[`@display`,`right-inline`]],r=function(e){e.tmp.render_seen||(e.tmp.render_seen=!0,e.output.startTag(`bib_other`,a))},a.execs.push(r),t.push(a))),e.build.substitute_level.value()===1&&(o=new n.Token(`if`,n.END),t.push(o),s=new n.Token(`choose`,n.END),n.Node.choose.build.call(s,e,t)),this.name===`names`||this.name===`text`&&this.variables_real!==`title`){new n.Token(`text`,n.SINGLETON);var l=this.name;r=function(e,t){if(e.tmp.area===`bibliography`&&typeof e.bibliography.opt[`subsequent-author-substitute`]==`string`&&!(this.variables_real&&!t[this.variables_real])&&!(this.variables_real&&l===`names`)){var r=e.bibliography.opt[`subsequent-author-substitute-rule`],i,a;if(!e.tmp.suppress_decorations&&e.tmp.subsequent_author_substitute_ok&&e.tmp.rendered_name){if(r===`partial-each`||r===`partial-first`){var o=!0,s=[];for(i=0,a=e.tmp.name_node.children.length;i<a;i+=1){var u=e.tmp.rendered_name[i];o&&e.tmp.last_rendered_name&&e.tmp.last_rendered_name.length>i-1&&u&&!u.localeCompare(e.tmp.last_rendered_name[i])?(c=new n.Blob(e[e.tmp.area].opt[`subsequent-author-substitute`]),e.tmp.name_node.children[i].blobs=[c],r===`partial-first`&&(o=!1)):o=!1,s.push(u)}e.tmp.last_rendered_name=s}else if(r===`complete-each`){var s=e.tmp.rendered_name.join(`,`);if(s){if(e.tmp.last_rendered_name&&!s.localeCompare(e.tmp.last_rendered_name))for(i=0,a=e.tmp.name_node.children.length;i<a;i+=1)c=new n.Blob(e[e.tmp.area].opt[`subsequent-author-substitute`]),e.tmp.name_node.children[i].blobs=[c];e.tmp.last_rendered_name=s}}else{var s=e.tmp.rendered_name.join(`,`);s&&(e.tmp.last_rendered_name&&!s.localeCompare(e.tmp.last_rendered_name)&&(c=new n.Blob(e[e.tmp.area].opt[`subsequent-author-substitute`]),e.tmp.label_blob?e.tmp.name_node.top.blobs=[c,e.tmp.label_blob]:e.tmp.name_node.top.blobs.length?e.tmp.name_node.top.blobs[0].blobs=[c]:e.tmp.name_node.top.blobs=[c],e.tmp.substituted_variable=l),e.tmp.last_rendered_name=s)}e.tmp.subsequent_author_substitute_ok=!1}}},this.execs.push(r)}(this.name===`text`&&!this.postponed_macro||[`number`,`date`,`names`].indexOf(this.name)>-1)&&(r=function(e,t){e.tmp.element_trace.mystack.length>1&&e.tmp.element_trace.pop()},this.execs.push(r))},n.Util.padding=function(e){var t=e.match(/\s*(-{0,1}[0-9]+)/);if(t)for(e=parseInt(t[1],10),e<0&&(e=0x56bc75e2d63100000+e),e=``+e;e.length<20;)e=`0`+e;return e},n.Util.LongOrdinalizer=function(){},n.Util.LongOrdinalizer.prototype.init=function(e){this.state=e},n.Util.LongOrdinalizer.prototype.format=function(e,t){e<10&&(e=`0`+e);var r=n.Engine.getField(n.LOOSE,this.state.locale[this.state.opt.lang].terms,`long-ordinal-`+e,`long`,0,t);return r||(r=this.state.fun.ordinalizer.format(e,t)),this.state.tmp.cite_renders_content=!0,r},n.Util.Ordinalizer=function(e){this.state=e,this.suffixes={}},n.Util.Ordinalizer.prototype.init=function(){if(!this.suffixes[this.state.opt.lang]){this.suffixes[this.state.opt.lang]={};for(var e=0,t=3;e<t;e+=1){var n=[void 0,`masculine`,`feminine`][e];this.suffixes[this.state.opt.lang][n]=[];for(var r=1;r<5;r+=1){var i=this.state.getTerm(`ordinal-0`+r,`long`,!1,n);if(i===void 0){delete this.suffixes[this.state.opt.lang][n];break}this.suffixes[this.state.opt.lang][n].push(i)}}}},n.Util.Ordinalizer.prototype.format=function(e,t){var n;e=parseInt(e,10),n=``+e;var r=``,i=[];if(t&&i.push(t),i.push(`neuter`),this.state.locale[this.state.opt.lang].ord[`1.0.1`]){r=this.state.getTerm(`ordinal`,!1,0,t);for(var a,o=0,s=i.length;o<s;o+=1){a=i[o];var c=this.state.locale[this.state.opt.lang].ord[`1.0.1`];if(c[`whole-number`][n]&&c[`whole-number`][n][a]?r=this.state.getTerm(this.state.locale[this.state.opt.lang].ord[`1.0.1`][`whole-number`][n][a],!1,0,t):c[`last-two-digits`][n.slice(n.length-2)]&&c[`last-two-digits`][n.slice(n.length-2)][a]?r=this.state.getTerm(this.state.locale[this.state.opt.lang].ord[`1.0.1`][`last-two-digits`][n.slice(n.length-2)][a],!1,0,t):c[`last-digit`][n.slice(n.length-1)]&&c[`last-digit`][n.slice(n.length-1)][a]&&(r=this.state.getTerm(this.state.locale[this.state.opt.lang].ord[`1.0.1`][`last-digit`][n.slice(n.length-1)][a],!1,0,t)),r)break}}else t||(t=void 0),this.state.fun.ordinalizer.init(),r=e/10%10==1||e>10&&e<20?this.suffixes[this.state.opt.lang][t][3]:e%10==1&&e%100!=11?this.suffixes[this.state.opt.lang][t][0]:e%10==2&&e%100!=12?this.suffixes[this.state.opt.lang][t][1]:e%10==3&&e%100!=13?this.suffixes[this.state.opt.lang][t][2]:this.suffixes[this.state.opt.lang][t][3];return n=n+=r,n},n.Util.Romanizer=function(){},n.Util.Romanizer.prototype.format=function(e){var t=``,r,i,a,o;if(e<6e3)for(a=e.toString().split(``),a.reverse(),r=0,i=0,o=a.length,r=0;r<o;r+=1)i=parseInt(a[r],10),t=n.ROMAN_NUMERALS[r][i]+t;return t},n.Util.Suffixator=function(e){e||(e=n.SUFFIX_CHARS),this.slist=e.split(`,`)},n.Util.Suffixator.prototype.format=function(e){var t;e+=1;var n=``;do{t=e%26==0?26:e%26;var n=this.slist[t-1]+n;e=(e-t)/26}while(e!==0);return n},n.Engine.prototype.processNumber=function(e,t,r){var i,a=this,o=r;r=r===`page-first`?`page`:r;var s=`,\\s+and\\s+|\\s+and\\s+`;this.opt.lang.slice(0,2)!==`en`&&(s+=`|,\\s+`+this.getTerm(`and`)+`\\s+|\\s+`+this.getTerm(`and`)+`\\s+`);var c=`\\s*&\\s*`,l=RegExp(`^`+c+`$`),u=RegExp(`(`+c+`|`+s+`|;\\s+|,\\s+|\\s*\\\\*[\\-\\u2013]+\\s*)`,`g`),d=RegExp(`(?:`+c+`|`+s+`|;\\s+|,\\s+|\\s*\\\\*[\\-\\u2013]+\\s*)`),f=this.getTerm(`and`),p=this.getTerm(`and`,`symbol`);f===p&&(p=`&`);function m(e){e=e.trim();var i=e.match(/^([^ ]+)/);if(i&&!n.STATUTE_SUBDIV_STRINGS[i[1]]){var a=null;a=[`locator`,`locator-extra`,`page`].indexOf(r)>-1?t.label?n.STATUTE_SUBDIV_STRINGS_REVERSE[t.label]:`p.`:n.STATUTE_SUBDIV_STRINGS_REVERSE[r],a&&(e=a+` `+e)}return e}function h(e,t,i,a,s){a=a||``;var c={};if(!t&&!n.STATUTE_SUBDIV_STRINGS_REVERSE[r]&&(t=`var:`+r),t){var l=t.match(/(\s*)([^\s]+)(\s*)/);o===`page`&&s===0&&[`p.`,`pp.`].indexOf(l[2])===-1?(c.gotosleepability=!0,c.labelVisibility=!0):c.labelVisibility=!1,c.label=l[2],c.origLabel=e,c.labelSuffix=l[3]?l[3]:``,c.plural=0}var l=i.match(/^([0-9]*[a-zA-Z]+0*)?([0-9]+(?:[a-zA-Z]*|[-,a-zA-Z]+))$/);return l?(c.particle=l[1]?l[1]:``,c.value=l[2]):(c.particle=``,c.value=i),c.joiningSuffix=a.replace(/\s*-\s*/,`-`),c}function g(e){for(var t=e.length-2;t>-1;t-=2)e[t]===`-`&&e[t-1].match(/^(?:(?:[a-z]|[a-z][a-z]|[a-z][a-z][a-z]|[a-z][a-z][a-z][a-z])\.  *)*[0-9]+[,a-zA-Z]+$/)&&e[t+1].match(/^[,a-zA-Z]+$/)&&(e[t-1]=e.slice(t-1,t+2).join(``),e=e.slice(0,t).concat(e.slice(t+2)));return e}function _(e,t){t=t||``,e=m(e,t);var i,o,s;if(r===`page`&&e.indexOf(`–`)>-1&&(e=e.replace(/\u2013/g,`-`)),e.indexOf(`\\-`)>-1){i=new RegExp(u.source.replace(`\\-`,``)),o=new RegExp(d.source.replace(`\\-`,``));for(var c=e.split(`\\-`),f=0,_=c.length;f<_;f++)c[f]=c[f].replace(/\-/g,`–`);s=c.join(`\\-`),s=s.replace(/\\/g,``)}else i=u,o=d,s=e;var v=[],y=s.match(i);if(y){for(var c=s.split(o),f=0,_=y.length;f<_;f++)y[f].match(l)&&(c[f].match(/[a-zA-Z]$/)&&c[f].match(/^[a-zA-Z]/)?y[f]=p:y[f]=` `+p+` `);var b=!1;for(var f in c)if((``+c[f]).replace(/^[a-z]\.\s+/,``).match(/[^\s0-9ivxlcmIVXLCM]/))break;if(b)v=[s];else{for(var f=0,_=c.length-1;f<_;f++)v.push(c[f]),v.push(y[f]);v.push(c[c.length-1]),v=g(v)}}else var v=[s];for(var x=[],S=t,C=``,f=0,_=v.length;f<_;f+=2){var y=v[f].match(/((?:^| )(?:[a-z]|[a-z][a-z]|[a-z][a-z][a-z]|[a-z][a-z][a-z][a-z]|subpara|subch|amend|bibliog|annot|illus|princ|intro|sched|subdiv|subsec)(?:\.| ) *)/g);if(y){for(var c=v[f].split(/(?:(?:^| )(?:[a-z]|[a-z][a-z]|[a-z][a-z][a-z]|[a-z][a-z][a-z][a-z]|subpara|subch|amend|bibliog|annot|illus|princ|intro|sched|subdiv|subsec)(?:\.| ) *)/),w=c.length-1;w>0;w--)c[w-1]&&(!c[w].match(/^[0-9]+([-;,:a-zA-Z]*)$/)||!c[w-1].match(/^[0-9]+([-;,:a-zA-Z]*)$/))&&(c[w-1]=c[w-1]+y[w-1]+c[w],c=c.slice(0,w).concat(c.slice(w+1)),y=y.slice(0,w-1).concat(y.slice(w)));if(y.length>0){var T=y[0].trim();!n.STATUTE_SUBDIV_STRINGS[T]||a.getTerm(n.STATUTE_SUBDIV_STRINGS[T])===void 0||[`locator`,`number`,`locator-extra`,`page`].indexOf(r)===-1&&n.STATUTE_SUBDIV_STRINGS[T]!==r?f===0&&(y=y.slice(1),c[0]=c[0]+` `+T+` `+c[1],c=c.slice(0,1).concat(c.slice(2))):C=T}for(var w=0,E=c.length;w<E;w++)if(c[w]||w===c.length-1){var D;S=y[w-1]?y[w-1]:S,D=C===S.trim()?``:C,s=c[w]?c[w].trim():``,w===c.length-1?x.push(h(D,S,s,v[f+1],f)):x.push(h(D,S,s,null,f))}}else{var D=C===S.trim()?``:C;x.push(h(D,S,v[f],v[f+1]))}}return x}function v(e){for(var t=0,n=e.length-1;t<n;t++)!e[t].joiningSuffix&&e[t+1].label&&(e[t].joiningSuffix=` `)}function y(e,t,n){var r=e[n.pos],i=e[t].value,a=r.joiningSuffix===`\\-`;i.particle&&i.particle!==r.particle&&(n.collapsible=!1);var o=i.match(/^[0-9]+([-,:a-zA-Z]*)$/),s=r.value.match(/^(?:[0-9]+|[ixv]+)([-,:a-zA-Z]*|\-[\-0-9]+)$/);if((!i||!o||!s||a)&&(n.collapsible=!1,(!i||!s)&&(n.numeric=!1),a&&n.count--),(o&&o[1]||s&&s[1])&&(n.collapsible=!1),e[t].collapsible===void 0){for(var c=t,l=t+n.count;c<l;c++)isNaN(parseInt(e[c].value))&&!e[c].value.match(/^[ivxlcmIVXLCM]+$/)?e[c].collapsible=!1:e[c].collapsible=!0;n.collapsible=e[t].collapsible}for(var u=n.collapsible,c=n.pos,l=n.pos+n.count;c<l;c++)n.count>1&&u&&(e[c].plural=1),e[c].numeric=n.numeric,e[c].collapsible=n.collapsible}function b(e,t,i){i.label.slice(0,4)!==`var:`&&(i.pos===0?([`locator`,`number`,`locator-extra`,`page`].indexOf(r)>-1&&a.getTerm(n.STATUTE_SUBDIV_STRINGS[i.label])===void 0&&(e[i.pos].labelVisibility=!0),[`locator`,`number`,`locator-extra`,`page`].indexOf(r)===-1&&n.STATUTE_SUBDIV_STRINGS[i.label]!==r&&(e[0].labelVisibility=!0)):e[i.pos].labelVisibility=!0)}function x(e){if(e.length!==0){for(var n=0,i=1,a=1,s=e.length;a<s;a++){var c=e[a-1],l=e[a];if(c.label===l.label&&c.particle===c.particle)i++;else{var u=JSON.parse(JSON.stringify(e[n]));u.pos=n,u.count=i,u.numeric=!0,y(e,n,u),c.label!==l.label&&b(e,n,u),n=a,i=1}}var u=JSON.parse(JSON.stringify(e[n]));u.pos=n,u.count=i,u.numeric=!0,y(e,n,u),b(e,n,u),e.length&&e[0].numeric&&r.slice(0,10)===`number-of-`&&parseInt(t[o],10)>1&&(e[0].plural=1)}}function S(e){return e.replace(`\\-`,`-`)}function C(t){var r=n.Util.cloneToken(e),i=new n.Token;a.tmp.just_looking||(i.decorations=r.decorations,r.decorations=[],i.strings.prefix=r.strings.prefix,r.strings.prefix=``,i.strings.suffix=r.strings.suffix,r.strings.suffix=``);var o=t.length?t[0].label:null;if(t.length){for(var s=0,c=t.length;s<c;s++){var l=t[s],u=n.Util.cloneToken(r);u.gender=e.gender,o===l.label&&(u.formatter=e.formatter),l.numeric&&(u.successor_prefix=l.successor_prefix),u.strings.suffix=u.strings.suffix+S(l.joiningSuffix),l.styling=u}a.tmp.just_looking||t[0].value.slice(0,1)===`"`&&t[t.length-1].value.slice(-1)===`"`&&(t[0].value=t[0].value.slice(1),t[t.length-1].value=t[t.length-1].value.slice(0,-1),i.decorations.push([`@quotes`,!0]))}return i}function w(e,t){var r=!0;if([`locator`,`locator-extra`,`page`].indexOf(e)>-1){var i=t.origLabel?t.origLabel:t.label;r=!!a.getTerm(n.STATUTE_SUBDIV_STRINGS[i])}return r}function T(e,t){return e===`page`||[`locator`,`locator-extra`].indexOf(e)>-1&&([`p.`].indexOf(t.label)>-1||[`p.`].indexOf(t.origLabel)>-1)}function E(e,t,n,r){var i=T(e,t);return w(e,t)&&n===`-`&&r&&((i||[`locator`,`locator-extra`,`issue`,`volume`,`edition`,`number`].indexOf(e)>-1)&&(n=a.getTerm(`page-range-delimiter`),n||(n=`–`)),e===`collection-number`&&(n=a.getTerm(`year-range-delimiter`),n||(n=`–`))),n}function D(e,t,n){if(!(t<1)&&n.count===2&&e[t-1].particle===e[t].particle){if(e[t-1].joiningSuffix!==`-`){n.count=1;return}if(!a.opt[`page-range-format`]&&parseInt(e[t-1].value,10)>parseInt(e[t].value,10)){e[t-1].joiningSuffix=E(r,e[t],e[t-1].joiningSuffix,!0);return}var i=e[t],o=T(r,i),s;o&&!isNaN(parseInt(e[t-1].value))&&!isNaN(parseInt(e[t].value))?(s=e[t-1].particle+e[t-1].value+` - `+e[t].particle+e[t].value,s=a.fun.page_mangler(s)):((``+e[t-1].value).match(/^([0-9]+|[ivxlcmIVXLCM]+)$/)&&(``+e[t].value).match(/^([0-9]+|[ivxlcmIVXLCM]+)$/)&&(e[t-1].joiningSuffix=a.getTerm(`page-range-delimiter`)),s=e[t-1].value+S(e[t-1].joiningSuffix)+e[t].value);var c=s.match(/^((?:[0-9]*[a-zA-Z]+0*))?([0-9]+[a-z]*)(\s*[^0-9]+\s*)([-,a-zA-Z]?0*)([0-9]+[a-z]*)$/);if(c){var l=c[3];l=E(r,i,l,e[t].numeric),e[t-1].particle=c[1],e[t-1].value=c[2],e[t-1].joiningSuffix=l,e[t].particle=c[4],e[t].value=c[5]}n.count=0}}function O(t){if(e&&[`page`,`chapter-number`,`collection-number`,`edition`,`issue`,`number`,`number-of-pages`,`number-of-volumes`,`volume`,`locator`,`locator-extra`].indexOf(r)!==-1){for(var n={count:0,label:null,lastHadRangeDelimiter:!1},i=0,a=t.length;i<a;i++){var o=t[i];if(o.collapsible)n.label===o.label&&o.joiningSuffix===`-`?n.count=1:n.label===o.label&&o.joiningSuffix!==`-`?(n.count++,n.count===2&&D(t,i,n)):n.label===o.label?(n.count=1,n.label=o.label):(n.label=o.label,n.count=1);else{n.count=0,n.label=null;var s=o.numeric;o.joiningSuffix=E(r,o,o.joiningSuffix,s)}}n.count===2&&D(t,t.length-1,n)}}function k(e,t,i){var o=e[t];i.length&&(o.numeric=i[0].numeric,o.collapsible=i[0].collapsible,o.plural=i[0].plural,o.label=n.STATUTE_SUBDIV_STRINGS[i[0].label],r===`number`&&o.label===`issue`&&a.getTerm(`number`)&&(o.label=`number`))}if(e&&this.tmp.shadow_numbers[o]&&this.tmp.shadow_numbers[o].values.length){var A=this.tmp.shadow_numbers[o].values;O(A),this.tmp.shadow_numbers[o].masterStyling=C(A);return}if(this.tmp.shadow_numbers[o]||(this.tmp.shadow_numbers[o]={values:[]}),t){var j=n.LangPrefsMap[r];if(j){var M=this.opt[`cite-lang-prefs`][j][0];i=this.transform.getTextSubField(t,o,`locale-`+M,!0),i=i.name}else i=t[o];if(i&&o===`number`&&t.type===`legal_case`&&(i=i.replace(/[\\]*-/g,`\\-`)),i&&this.sys.getAbbreviation){if(this.sys.normalizeAbbrevsKey)var N=this.sys.normalizeAbbrevsKey(o,i);else var N=i;var P=this.transform.loadAbbreviation(t.jurisdiction,`number`,N,t.language);this.transform.abbrevs[P].number&&(this.transform.abbrevs[P].number[N]?i=this.transform.abbrevs[P].number[N]:this.transform.abbrevs[P].number[N]!==void 0&&delete this.transform.abbrevs[P].number[N])}if(i!==void 0&&(typeof i==`string`||typeof i==`number`)){typeof i==`number`&&(i=``+i);var F=n.STATUTE_SUBDIV_STRINGS_REVERSE[r];if(this.tmp.shadow_numbers[o].values.length===0){var A=_(i,F);v(A),x(A);for(var I of A)I.numeric||(I.plural=0);this.tmp.shadow_numbers[o].values=A,e&&(O(A),this.tmp.shadow_numbers[o].masterStyling=C(A)),k(this.tmp.shadow_numbers,o,A)}var L=this.tmp.shadow_numbers[o];r===`number`&&L.values.length===1&&L.values[0].value.indexOf(`|`)>-1&&(L.values[0].value=L.values[0].value.replace(/\|/g,`, `),L.values[0].numeric=!0,L.values[0].plural=1,L.values[0].collapsible=!1,L.numeric=!0,L.plural=1,L.collapsible=!1),L.values.length===1&&L.values[0].value.match(/^[0-9]+(?:\/[0-9]+)+$/)&&(L.values[0].numeric=!0,L.values[0].plural=0,L.values[0].collapsible=!1,L.numeric=!0,L.plural=0,L.collapsible=!1),r===`page`&&L.values.length>0&&L.values[0].gotosleepability&&(L.labelForm=`short`)}}},n.Util.outputNumericField=function(e,t,r){e.output.openLevel(e.tmp.shadow_numbers[t].masterStyling);for(var i=e.tmp.shadow_numbers[t].masterStyling,a=e.tmp.shadow_numbers[t].values,o=a.length?a[0].label:null,s=e.tmp.shadow_numbers[t].labelForm,c=e.tmp.group_context.tip.label_static,l=s||`short`,u=e.tmp.shadow_numbers[t].labelCapitalizeIfFirst,d=e.tmp.shadow_numbers[t].labelDecorations,f=null,p=0,m=a.length;p<m;p++){var h=a[p],g=``,_;h.label&&(_=h.label.slice(0,4)===`var:`?h.label.slice(4):n.STATUTE_SUBDIV_STRINGS[h.label],_&&(h.label===o?(c&&(g=e.getTerm(_,`static`,h.plural),g.indexOf(`%s`)===-1&&(g=``)),g||(g=e.getTerm(_,s,h.plural))):(c&&(g=e.getTerm(_,`static`,h.plural),g.indexOf(`%s`)===-1&&(g=``)),g||(g=e.getTerm(_,l,h.plural))),u&&(g=n.Output.Formatters[`capitalize-first`](e,g))));var v=-1;g&&(v=g.indexOf(`%s`));var y=n.Util.cloneToken(h.styling);if(y.formatter=h.styling.formatter,y.type=h.styling.type,y.num=h.styling.num,y.gender=h.styling.gender,v>0&&v<g.length-2)y.strings.prefix+=g.slice(0,v),y.strings.suffix=g.slice(v+2)+y.strings.suffix;else if(h.labelVisibility)if(g||(g=h.label,_=h.label),v>0){var b=new n.Token;b.decorations=d,e.output.append(g.slice(0,v),b)}else (v===g.length-2||v===-1)&&e.output.append(g+h.labelSuffix,`empty`);if(n.UPDATE_GROUP_CONTEXT_CONDITION(e,i.strings.prefix,null,i,`${h.particle}${h.value}`),h.collapsible){var x=h.value.match(/^[1-9][0-9]*$/)&&Number.isSafeInteger(parseInt(h.value,10))?new n.NumericBlob(e,h.particle,parseInt(h.value,10),y,r):new n.NumericBlob(e,h.particle,h.value,y,r);x.gender===void 0&&(x.gender=e.locale[e.opt.lang][`noun-genders`][t]),e.output.append(x,`literal`)}else e.output.append(h.particle+h.value,y);if(v===0&&v<g.length-2&&(f===null&&(f=_),_!==f||p===a.length-1)){var S=new n.Token;S.decorations=d,e.output.append(g.slice(v+2),S)}f=_,e.tmp.term_predecessor=!0}e.output.closeLevel()},n.Util.PageRangeMangler={},n.Util.PageRangeMangler.getFunction=function(e,t){var n,r,i,a,o,s,c,l,u,d,f,p,m,h,g,_,v,y,b=e.getTerm(t+`-range-delimiter`);n=/([0-9]*[a-zA-Z]+0*)?([0-9]+[a-z]*)\s*(?:\u2013|-)\s*([0-9]*[a-zA-Z]+0*)?([0-9]+[a-z]*)/,a=function(n){for(i=n.length,r=1;r<i;r+=2)typeof n[r]==`object`&&(n[r]=n[r].join(``));var a=n.join(``);return a=a.replace(/([^\\])\-/g,`$1`+e.getTerm(t+`-range-delimiter`)),a},o=function(e){var t,n,a,o=`\\s+\\-\\s+`,s=RegExp(`([^\\\\])[-`+(b===`-`?``:b)+`\\u2013]`,`g`);e=e.replace(s,`$1 - `).replace(/\s+-\s+/g,` - `);var c=RegExp(`((?:[0-9]*[a-zA-Z]+0*)?[0-9]+[a-z]*`+o+`(?:[0-9]*[a-zA-Z]+0*)?[0-9]+[a-z]*)`,`g`),l=RegExp(`(?:[0-9]*[a-zA-Z]+0*)?[0-9]+[a-z]*`+o+`(?:[0-9]*[a-zA-Z]+0*)?[0-9]+[a-z]*`);if(t=e.match(c),n=e.split(l),n.length===0)a=t;else for(a=[n[0]],r=1,i=n.length;r<i;r+=1)a.push(t[r-1].replace(/\s*\-\s*/g,`-`)),a.push(n[r]);return a},s=function(e){for(e=``+e,f=o(e),i=f.length,r=1;r<i;r+=2)p=f[r].match(n),p&&(!p[3]||p[1]===p[3])&&(p[4].length<p[2].length&&(p[4]=p[2].slice(0,p[2].length-p[4].length)+p[4]),parseInt(p[2],10)<parseInt(p[4],10)&&(p[3]=b+(p[1]?p[1]:``),f[r]=p.slice(1))),typeof f[r]==`string`&&(f[r]=f[r].replace(/\-/g,b));return f},c=function(e,t,n){i=e.length;for(var r=1,o=e.length;r<o;r+=2)typeof e[r]==`object`&&(e[r][3]=l(e[r][1],e[r][3],t,n),e[r][2].slice(1)===e[r][0]&&(e[r][2]=b));return a(e)},l=function(e,t,n,r){if(n||(n=0),m=(``+e).split(``),h=(``+t).split(``),g=h.slice(),g.reverse(),m.length===h.length)for(var i=0,a=m.length;i<a;i+=1)if(m[i]===h[i]&&g.length>n)g.pop();else{if(n&&r&&g.length===3){var o=m.slice(0,i);o.reverse(),g=g.concat(o)}break}return g.reverse(),g.join(``)},u=function(e){for(i=e.length,r=1;r<i;r+=2)typeof e[r]==`object`&&(p=e[r],_=parseInt(p[1],10),v=parseInt(p[3],10),_>100&&_%100&&parseInt(_/100,10)===parseInt(v/100,10)?p[3]=``+v%100:_>=1e4&&(p[3]=``+v%1e3)),p[2].slice(1)===p[0]&&(p[2]=b);return a(e)},d=function(e){for(i=e.length,r=1;r<i;r+=2){if(typeof e[r]==`object`&&(p=e[r],_=parseInt(p[1],10),v=parseInt(p[3],10),h=``+v,_>100&&_%100))for(var t=2;t<h.length;t++){var n=10**t;if(Math.floor(_/n)===Math.floor(v/n)){p[3]=``+v%n;break}}p[2].slice(1)===p[0]&&(p[2]=b)}return a(e)};var x=function(e,t,n,r){return e=``+e,t(s(e),n,r)};return e.opt[t+`-range-format`]?e.opt[t+`-range-format`]===`expanded`?y=function(e){return x(e,a)}:e.opt[t+`-range-format`]===`minimal`?y=function(e){return x(e,c)}:e.opt[t+`-range-format`]===`minimal-two`?y=function(e,t){return x(e,c,2,t)}:e.opt[t+`-range-format`]===`chicago`||e.opt[t+`-range-format`]===`chicago-15`?y=function(e){return x(e,u)}:e.opt[t+`-range-format`]===`chicago-16`&&(y=function(e){return x(e,d)}):y=function(e){return x(e,a)},y},n.Util.FlipFlopper=function(e){var t=[],r={'<span class="nocase">':{type:`nocase`,opener:`<span class="nocase">`,closer:`</span>`,attr:null,outer:null,flipflop:null},'<span class="nodecor">':{type:`nodecor`,opener:`<span class="nodecor">`,closer:`</span>`,attr:`@class`,outer:`nodecor`,flipflop:{nodecor:`nodecor`}},'<span style="font-variant:small-caps;">':{type:`tag`,opener:`<span style="font-variant:small-caps;">`,closer:`</span>`,attr:`@font-variant`,outer:`small-caps`,flipflop:{"small-caps":`normal`,normal:`small-caps`}},"<sc>":{type:`tag`,opener:`<sc>`,closer:`</sc>`,attr:`@font-variant`,outer:`small-caps`,flipflop:{"small-caps":`normal`,normal:`small-caps`}},"<i>":{type:`tag`,opener:`<i>`,closer:`</i>`,attr:`@font-style`,outer:`italic`,flipflop:{italic:`normal`,normal:`italic`}},"<b>":{type:`tag`,opener:`<b>`,closer:`</b>`,attr:`@font-weight`,outer:`bold`,flipflop:{bold:`normal`,normal:`bold`}},"<sup>":{type:`tag`,opener:`<sup>`,closer:`</sup>`,attr:`@vertical-align`,outer:`sup`,flipflop:{sub:`sup`,sup:`sup`}},"<sub>":{type:`tag`,opener:`<sub>`,closer:`</sub>`,attr:`@vertical-align`,outer:`sub`,flipflop:{sup:`sub`,sub:`sub`}},' "':{type:`quote`,opener:` "`,closer:`"`,attr:`@quotes`,outer:`true`,flipflop:{true:`inner`,inner:`true`,false:`true`}}," '":{type:`quote`,opener:` '`,closer:`'`,attr:`@quotes`,outer:`inner`,flipflop:{true:`inner`,inner:`true`,false:`true`}}};r[`("`]=r[` "`],r[`('`]=r[` '`];var i=e.getTerm(`open-quote`),a=e.getTerm(`close-quote`),o=e.getTerm(`open-inner-quote`),s=e.getTerm(`close-inner-quote`);i&&a&&[` "`,` '`,`"`,`'`].indexOf(i)===-1&&(r[i]=JSON.parse(JSON.stringify(r[` "`])),r[i].opener=i,r[i].closer=a),o&&s&&[` "`,` '`,`"`,`'`].indexOf(o)===-1&&(r[o]=JSON.parse(JSON.stringify(r[` '`])),r[o].opener=o,r[o].closer=s);function c(e){var t={" '":` "`,' "':` '`,'("':`('`,"('":`("`};r[e].outer=`true`,r[t[e]].outer=`inner`}function l(e){for(var t=[],n=Object.keys(r),i=0,a=n.length;i<a;i++){var o=n[i];(r[e].type!==`quote`||!r[e])&&t.push(o)}var s=r[e];return s.opener=RegExp(`^(?:`+t.map(function(e){return e.replace(`(`,`\\(`)}).join(`|`)+`)`),s}var u=function(){for(var e={},t=Object.keys(r),n=0,i=t.length;n<i;n++){var a=t[n];e[a]=l(a)}return e}(),d=function(){var e=[],t=[],n={};for(var r in u)e.push(r),n[u[r].closer]=!0;for(var i=Object.keys(n),a=0,o=i.length;a<o;a++){var s=i[a];t.push(s)}var c=e.concat(t).map(function(e){return e.replace(`(`,`\\(`)}).join(`|`);return{matchAll:RegExp(`((?:`+c+`))`,`g`),splitAll:RegExp(`(?:`+c+`)`,`g`),open:RegExp(`(^(?:`+e.map(function(e){return e.replace(`(`,`\\(`)}).join(`|`)+`)$)`),close:RegExp(`(^(?:`+t.join(`|`)+`)$)`)}}();function f(e,n){var r=t[t.length-1];return!r||e.match(r.opener)?(t.push({type:u[e].type,opener:u[e].opener,closer:u[e].closer,pos:n}),!1):(t.pop(),t.push({type:u[e].type,opener:u[e].opener,closer:u[e].closer,pos:n}),{fixtag:r.pos})}function p(e,n){var r=t[t.length-1];return r&&e===r.closer?(t.pop(),r.type===`nocase`?{nocase:{open:r.pos,close:n}}:!1):r?{fixtag:r.pos}:{fixtag:n}}function m(e,t){return e.match(d.open)?f(e,t):p(e,t)}function h(e){var t=[];e=e.replace(/(<span)\s+(style=\"font-variant:)\s*(small-caps);?\"[^>]*(>)/g,`$1 $2$3;"$4`),e=e.replace(/(<span)\s+(class=\"no(?:case|decor)\")[^>]*(>)/g,`$1 $2$3`);var n=e.match(d.matchAll);if(!n)return{tags:[],strings:[e],forcedSpaces:[]};for(var i=e.split(d.splitAll),a=0,o=n.length-1;a<o;a++)r[n[a]]&&(i[a+1]===``&&[`"`,`'`].indexOf(n[a+1])>-1?(n[a+1]=` `+n[a+1],t.push(!0)):t.push(!1));return{tags:n,strings:i,forcedSpaces:t}}var g=function(t){var n=[];this.set=function(i){for(var a=r[i].attr,o=null,s=n.length-1;s>-1;s--){var c=n[s];if(c[0]===a){o=c;break}}if(!o){var l=[e[e.tmp.area].opt.layout_decorations].concat(t.alldecor);outer:for(var s=l.length-1;s>-1;s--){var u=l[s];if(u)for(var d=u.length-1;d>-1;d--){var c=u[d];if(c[0]===a){o=c;break outer}}}}o=o?[a,r[i].flipflop[o[1]]]:[a,r[i].outer],n.push(o)},this.pair=function(){return n[n.length-1]},this.pop=function(){n.pop()}};function _(e,t){if(e===`'`){if(t&&t.match(/^[^\,\.\?\:\;\ ]/))return`’`}else if(e===` '`&&t&&t.match(/^[\ ]/))return` ’`;return!1}function v(t,r,i){var a=!0,o=new g(t);t.blobs=[];function s(t){this.stack=[t],this.latest=t,this.addStyling=function(t,r){if(a&&(t.slice(0,1)===` `&&(t=t.slice(1)),t.slice(0,1)===` `&&(t=t.slice(1)),a=!1),this.latest=this.stack[this.stack.length-1],r){if(typeof this.latest.blobs==`string`){var i=new n.Blob;i.blobs=this.latest.blobs,i.alldecor=this.latest.alldecor.slice(),this.latest.blobs=[i]}var o=new n.Token,s=new n.Blob(null,o);if(s.alldecor=this.latest.alldecor.slice(),r[0]===`@class`&&r[1]===`nodecor`){for(var c=[],l={},u=[e[e.tmp.area].opt.layout_decorations].concat(s.alldecor),d=u.length-1;d>-1;d--){var f=u[d];if(f)for(var p=f.length-1;p>-1;p--){var m=f[p];[`@font-weight`,`@font-style`,`@font-variant`].indexOf(m[0])>-1&&!l[m[0]]&&(r[1]!==`normal`&&(s.decorations.push([m[0],`normal`]),c.push([m[0],`normal`])),l[m[0]]=!0)}}s.alldecor.push(c)}else s.decorations.push(r),s.alldecor.push([r]);if(this.latest.blobs.push(s),this.stack.push(s),this.latest=s,t){var o=new n.Token,s=new n.Blob(null,o);s.blobs=t,s.alldecor=this.latest.alldecor.slice(),this.latest.blobs.push(s)}}else if(t){var i=new n.Blob;i.blobs=t,i.alldecor=this.latest.alldecor.slice(),this.latest.blobs.push(i)}},this.popStyling=function(){this.stack.pop()}}var c=new s(t);if(r.strings.length){var l=r.strings[0];i&&(l=` `+l),c.addStyling(l)}for(var u=0,f=r.tags.length;u<f;u++){var p=r.tags[u],l=r.strings[u+1];p.match(d.open)?(o.set(p),c.addStyling(l,o.pair())):(o.pop(),c.popStyling(),c.addStyling(l))}}this.processTags=function(e){var r=e.blobs,i=!1;r.slice(0,1)===` `&&!r.match(/^\s+[\'\"]/)&&(i=!0);var a=RegExp(`(`+n.ROMANESQUE_REGEXP.source+`)’(`+n.ROMANESQUE_REGEXP.source+`)`,`g`),r=` `+r.replace(a,`$1'$2`),o=h(r);if(o.tags.length!==0){for(var s=!1,l=0,u=o.tags.length;l<u;l++){var f=o.tags[l],r=o.strings[l+1],p=_(f,r);if(p)o.strings[l+1]=p+o.strings[l+1],o.tags[l]=``;else{for(var g;g=m(f,l),g;)if(Object.keys(g).indexOf(`fixtag`)>-1){if(f.match(d.close)&&f===`'`)o.strings[l+1]=`’`+o.strings[l+1],o.tags[l]=``;else{var y=o.tags[g.fixtag];o.forcedSpaces[g.fixtag-1]&&(y=y.slice(1)),o.strings[g.fixtag+1]=y+o.strings[g.fixtag+1],o.tags[g.fixtag]=``}if(t.length>0)if(f!==`'`)t.pop();else break;else break}else if(g.nocase){o.tags[g.nocase.open]=``,o.tags[g.nocase.close]=``;break}else break;g&&(g.fixtag||g.fixtag===0)&&(o.strings[l+1]=o.tags[l]+o.strings[l+1],o.tags[l]=``)}}for(var l=t.length-1;l>-1;l--){var b=t[l].pos,f=o.tags[b];f===` '`||f===`'`?o.strings[b+1]=` ’`+o.strings[b+1]:o.strings[b+1]=o.tags[b]+o.strings[b+1],o.tags[b]=``,t.pop()}for(var l=o.tags.length-1;l>-1;l--)o.tags[l]||(o.tags=o.tags.slice(0,l).concat(o.tags.slice(l+1)),o.strings[l]=o.strings[l]+o.strings[l+1],o.strings=o.strings.slice(0,l+1).concat(o.strings.slice(l+2)));for(var l=0,u=o.tags.length;l<u;l++){var f=o.tags[l],x=o.forcedSpaces[l-1];[` "`,` '`,`("`,`('`].indexOf(f)>-1&&(s||(c(f),s=!0),x||(o.strings[l]+=f.slice(0,1)))}v(e,o,i)}}},n.Output.Formatters=function(){var e=new n.Doppeler(`(?:‘|’|“|”| "| '|"|'|[-–—/.,;?!:]|\\[|\\]|\\(|\\)|<span style="font-variant: small-caps;">|<span class="no(?:case|decor)">|</span>|</?(?:i|sc|b|sub|sup)>)`,function(e){return e.replace(/(<span)\s+(class=\"no(?:case|decor)\")[^>]*(>)/g,`$1 $2$3`).replace(/(<span)\s+(style=\"font-variant:)\s*(small-caps);?(\")[^>]*(>)/g,`$1 $2 $3;$4$5`)}),t=new n.Doppeler(`(?:[-\\s]*<\\/*(?:spans+class="no(?:case|decor)"|i|sc|b|sub|sup)>[-\\s]*|[-\\s]+)`),r=new n.Doppeler(`(?:[\xA0 \xA0 -​ 　]+)`),i={'<span style="font-variant: small-caps;">':`</span>`,'<span class="nocase">':`</span>`,'<span class="nodecor">':`</span>`,"<sc>":`</sc>`,"<sub>":`</sub>`,"<sup>":`</sup>`};function a(e){var t=e.match(/(^\s*)((?:[\0-\t\x0B\f\x0E-\u2027\u202A-\uD7FF\uE000-\uFFFF]|[\uD800-\uDBFF][\uDC00-\uDFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF]))(.*)/);return t&&!(t[2].match(/^[\u0370-\u03FF]$/)&&!t[3])?t[1]+n.toLocaleUpperCase.call(this,t[2])+t[3]:e}function o(t,o){if(!o)return``;t.doppel=e.split(o);var s={' "':{opener:` '`,closer:`"`}," '":{opener:` "`,closer:`'`},"‘":{opener:`‘`,closer:`’`},"“":{opener:`“`,closer:`”`}};function c(e,n){if(t.quoteState.length===0||e===t.quoteState[t.quoteState.length-1].opener)return t.quoteState.push({opener:s[e].opener,closer:s[e].closer,pos:n}),!1;var r=t.quoteState[t.quoteState.length-1].pos;return t.quoteState.pop(),t.quoteState.push({opener:s[e].opener,closer:s[e].closer,positions:n}),r}function l(e,n){if(t.quoteState.length>0&&e===t.quoteState[t.quoteState.length-1].closer)t.quoteState.pop();else return n}function u(e,t){return[`“`,`‘`,` "`,` '`].indexOf(e)>-1?c(e,t):l(e,t)}function d(e,t){var n=e.match(/(^(?:\u2018|\u2019|\u201C|\u201D|\"|\')|(?: \"| \')$)/);if(n)return u(n[1],t)}t.doppel.strings.length&&t.doppel.strings[0].trim()&&(t.doppel.strings[0]=t.capitaliseWords(t.doppel.strings[0],0,t.doppel.tags[0]));for(var f=0,p=t.doppel.tags.length;f<p;f++){var m=t.doppel.tags[f],h=t.doppel.strings[f+1];if(t.tagState!==null&&(i[m]?t.tagState.push(i[m]):t.tagState.length&&m===t.tagState[t.tagState.length-1]&&t.tagState.pop()),t.afterPunct!==null&&m.match(/[\!\?\:]$/)&&(t.afterPunct=!0),t.tagState.length===0?t.doppel.strings[f+1]=t.capitaliseWords(h,f+1,t.doppel,t.doppel.tags[f+1]):t.doppel.strings[f+1].trim()&&(t.lastWordPos=null),t.quoteState!==null){var g=d(m,f);if(g||g===0){var _=t.doppel.origStrings[g+1].slice(0,1);t.doppel.strings[g+1]=_+t.doppel.strings[g+1].slice(1),t.lastWordPos=null}}t.isFirst&&h.trim()&&(t.isFirst=!1),t.afterPunct&&h.trim()&&(t.afterPunct=!1)}if(t.quoteState)for(var f=0,p=t.quoteState.length;f<p;f++){var g=t.quoteState[f].pos;if(g!==void 0){var _=t.doppel.origStrings[g+1].slice(0,1);t.doppel.strings[g+1]=_+t.doppel.strings[g+1].slice(1)}}if(t.lastWordPos){var v=r.split(t.doppel.strings[t.lastWordPos.strings]),y=v.strings[t.lastWordPos.words];y.length>1&&n.toLocaleLowerCase.call(this,y).match(t.skipWordsRex)&&(y=a.call(this,y),v.strings[t.lastWordPos.words]=y),t.doppel.strings[t.lastWordPos.strings]=r.join(v)}return e.join(t.doppel)}function s(e,t){return t}function c(e,t){return o.call(e,{quoteState:null,capitaliseWords:function(t){for(var r=t.split(` `),i=0,a=r.length;i<a;i++){var o=r[i];o&&(r[i]=n.toLocaleLowerCase.call(e,o))}return r.join(` `)},skipWordsRex:null,tagState:[],afterPunct:null,isFirst:null},t)}function l(e,t){return o.call(e,{quoteState:null,capitaliseWords:function(t){for(var r=t.split(` `),i=0,a=r.length;i<a;i++){var o=r[i];o&&(r[i]=n.toLocaleUpperCase.call(e,o))}return r.join(` `)},skipWordsRex:null,tagState:[],afterPunct:null,isFirst:null},t)}function u(e,t){var r={quoteState:[],capitaliseWords:function(t){for(var i=t.split(` `),o=0,s=i.length;o<s;o++){var c=i[o];c&&(r.isFirst?(i[o]=a.call(e,c),r.isFirst=!1):i[o]=n.toLocaleLowerCase.call(e,c))}return i.join(` `)},skipWordsRex:null,tagState:[],afterPunct:null,isFirst:!0};return o.call(e,r,t)}function d(e,t){var i={quoteState:[],capitaliseWords:function(t,o,s){if(t.trim()){for(var c=r.split(t),l=c.strings,u=0,d=l.length;u<d;u++){var f=l[u];if(!f)continue;let t=n.toLocaleLowerCase.call(e,f),r=!1;(f.length>1&&!t.match(i.skipWordsRex)||u===l.length-1&&s===`-`||i.isFirst||i.afterPunct)&&(r=!0),r&&f===t&&(l[u]=a.call(e,f)),i.afterPunct=!1,i.isFirst=!1,i.lastWordPos={strings:o,words:u}}t=r.join(c)}return t},skipWordsRex:e.locale[e.opt.lang].opts[`skip-words-regexp`],tagState:[],afterPunct:!1,isFirst:!0};return o.call(e,i,t)}function f(e,t){var i={quoteState:[],capitaliseWords:function(t){for(var o=r.split(t),s=o.strings,c=0,l=s.length;c<l;c++){var u=s[c];if(u&&i.isFirst){u===n.toLocaleLowerCase.call(e,u)&&(s[c]=a.call(e,u)),i.isFirst=!1;break}}return r.join(o)},skipWordsRex:null,tagState:[],afterPunct:null,isFirst:!0};return o.call(e,i,t)}function p(e,t){return o.call(e,{quoteState:[],capitaliseWords:function(t){for(var i=r.split(t),o=i.strings,s=0,c=o.length;s<c;s++){var l=o[s];l&&l===n.toLocaleLowerCase.call(e,l)&&(o[s]=a.call(e,l))}return r.join(i)},skipWordsRex:null,tagState:[],afterPunct:null,isFirst:null},t)}return{nameDoppel:t,passthrough:s,lowercase:c,uppercase:l,sentence:u,title:d,"capitalize-first":f,"capitalize-all":p}}(),n.Output.Formats=function(){},n.Output.Formats.prototype.html={text_escape:function(e){return e||(e=``),e.replace(/&/g,`&#38;`).replace(/</g,`&#60;`).replace(/>/g,`&#62;`).replace(/\s\s/g,`\xA0 `).replace(n.SUPERSCRIPTS_REGEXP,function(e){return`<sup>`+n.SUPERSCRIPTS[e]+`</sup>`})},bibstart:`<div class="csl-bib-body">
`,bibend:`</div>`,"@font-style/italic":`<i>%%STRING%%</i>`,"@font-style/oblique":`<em>%%STRING%%</em>`,"@font-style/normal":`<span style="font-style:normal;">%%STRING%%</span>`,"@font-variant/small-caps":`<span style="font-variant:small-caps;">%%STRING%%</span>`,"@passthrough/true":n.Output.Formatters.passthrough,"@font-variant/normal":`<span style="font-variant:normal;">%%STRING%%</span>`,"@font-weight/bold":`<b>%%STRING%%</b>`,"@font-weight/normal":`<span style="font-weight:normal;">%%STRING%%</span>`,"@font-weight/light":!1,"@text-decoration/none":`<span style="text-decoration:none;">%%STRING%%</span>`,"@text-decoration/underline":`<span style="text-decoration:underline;">%%STRING%%</span>`,"@vertical-align/sup":`<sup>%%STRING%%</sup>`,"@vertical-align/sub":`<sub>%%STRING%%</sub>`,"@vertical-align/baseline":`<span style="baseline">%%STRING%%</span>`,"@strip-periods/true":n.Output.Formatters.passthrough,"@strip-periods/false":n.Output.Formatters.passthrough,"@quotes/true":function(e,t){return t===void 0?e.getTerm(`open-quote`):e.getTerm(`open-quote`)+t+e.getTerm(`close-quote`)},"@quotes/inner":function(e,t){return t===void 0?`’`:e.getTerm(`open-inner-quote`)+t+e.getTerm(`close-inner-quote`)},"@quotes/false":!1,"@cite/entry":function(e,t){return e.sys.wrapCitationEntry(t,this.item_id,this.locator_txt,this.suffix_txt)},"@bibliography/entry":function(e,t){var n=``;return e.sys.embedBibliographyEntry&&(n=e.sys.embedBibliographyEntry(this.item_id)+`
`),`  <div class="csl-entry">`+t+`</div>
`+n},"@display/block":function(e,t){return`

    <div class="csl-block">`+t+`</div>
`},"@display/left-margin":function(e,t){return`
    <div class="csl-left-margin">`+t+`</div>`},"@display/right-inline":function(e,t){return`<div class="csl-right-inline">`+t+`</div>
  `},"@display/indent":function(e,t){return`<div class="csl-indent">`+t+`</div>
  `},"@showid/true":function(e,t,r){if(!e.tmp.just_looking&&!e.tmp.suppress_decorations){if(r)return`<span class="`+e.opt.nodenames[r]+`" cslid="`+r+`">`+t+`</span>`;if(this.params&&typeof t==`string`){var i=``;if(t){var a=t.match(n.VARIABLE_WRAPPER_PREPUNCT_REX);i=a[1],t=a[2]}var o=``;return t&&n.SWAPPING_PUNCTUATION.indexOf(t.slice(-1))>-1&&(o=t.slice(-1),t=t.slice(0,-1)),e.sys.variableWrapper(this.params,i,t,o)}else return t}else return t},"@URL/true":function(e,t){return`<a href="`+t+`">`+t+`</a>`},"@DOI/true":function(e,t){var n=t;return t.match(/^https?:\/\//)||(n=`https://doi.org/`+t),`<a href="`+n+`">`+t+`</a>`}},n.Output.Formats.prototype.text={text_escape:function(e){return e||(e=``),e},bibstart:``,bibend:``,"@font-style/italic":!1,"@font-style/oblique":!1,"@font-style/normal":!1,"@font-variant/small-caps":!1,"@passthrough/true":n.Output.Formatters.passthrough,"@font-variant/normal":!1,"@font-weight/bold":!1,"@font-weight/normal":!1,"@font-weight/light":!1,"@text-decoration/none":!1,"@text-decoration/underline":!1,"@vertical-align/baseline":!1,"@vertical-align/sup":!1,"@vertical-align/sub":!1,"@strip-periods/true":n.Output.Formatters.passthrough,"@strip-periods/false":n.Output.Formatters.passthrough,"@quotes/true":function(e,t){return t===void 0?e.getTerm(`open-quote`):e.getTerm(`open-quote`)+t+e.getTerm(`close-quote`)},"@quotes/inner":function(e,t){return t===void 0?`’`:e.getTerm(`open-inner-quote`)+t+e.getTerm(`close-inner-quote`)},"@quotes/false":!1,"@cite/entry":function(e,t){return e.sys.wrapCitationEntry(t,this.item_id,this.locator_txt,this.suffix_txt)},"@bibliography/entry":function(e,t){return t+`
`},"@display/block":function(e,t){return`
`+t},"@display/left-margin":function(e,t){return t+` `},"@display/right-inline":function(e,t){return t},"@display/indent":function(e,t){return`
    `+t},"@showid/true":function(e,t){return t},"@URL/true":function(e,t){return t},"@DOI/true":function(e,t){return t}},n.Output.Formats.prototype.rtf={text_escape:function(e){return e||(e=``),e.replace(/([\\{}])/g,`\\$1`).replace(n.SUPERSCRIPTS_REGEXP,function(e){return`\\super `+n.SUPERSCRIPTS[e]+`\\nosupersub{}`}).replace(/[\u007F-\uFFFF]/g,function(e){return`\\uc0\\u`+e.charCodeAt(0).toString()+`{}`}).split(`	`).join(`\\tab{}`)},"@passthrough/true":n.Output.Formatters.passthrough,"@font-style/italic":`{\\i{}%%STRING%%}`,"@font-style/normal":`{\\i0{}%%STRING%%}`,"@font-style/oblique":`{\\i{}%%STRING%%}`,"@font-variant/small-caps":`{\\scaps %%STRING%%}`,"@font-variant/normal":`{\\scaps0{}%%STRING%%}`,"@font-weight/bold":`{\\b{}%%STRING%%}`,"@font-weight/normal":`{\\b0{}%%STRING%%}`,"@font-weight/light":!1,"@text-decoration/none":!1,"@text-decoration/underline":`{\\ul{}%%STRING%%}`,"@vertical-align/baseline":!1,"@vertical-align/sup":`\\super %%STRING%%\\nosupersub{}`,"@vertical-align/sub":`\\sub %%STRING%%\\nosupersub{}`,"@strip-periods/true":n.Output.Formatters.passthrough,"@strip-periods/false":n.Output.Formatters.passthrough,"@quotes/true":function(e,t){return t===void 0?n.Output.Formats.rtf.text_escape(e.getTerm(`open-quote`)):n.Output.Formats.rtf.text_escape(e.getTerm(`open-quote`))+t+n.Output.Formats.rtf.text_escape(e.getTerm(`close-quote`))},"@quotes/inner":function(e,t){return t===void 0?n.Output.Formats.rtf.text_escape(`’`):n.Output.Formats.rtf.text_escape(e.getTerm(`open-inner-quote`))+t+n.Output.Formats.rtf.text_escape(e.getTerm(`close-inner-quote`))},"@quotes/false":!1,bibstart:`{\\rtf `,bibend:`}`,"@display/block":`\\line{}%%STRING%%\\line\r
`,"@cite/entry":function(e,t){return e.sys.wrapCitationEntry(t,this.item_id,this.locator_txt,this.suffix_txt)},"@bibliography/entry":function(e,t){return t},"@display/left-margin":function(e,t){return t+`\\tab `},"@display/right-inline":function(e,t){return t+`\r
`},"@display/indent":function(e,t){return`
\\tab `+t+`\\line\r
`},"@showid/true":function(e,t){if(!e.tmp.just_looking&&!e.tmp.suppress_decorations){var r=``;if(t){var i=t.match(n.VARIABLE_WRAPPER_PREPUNCT_REX);r=i[1],t=i[2]}var a=``;return t&&n.SWAPPING_PUNCTUATION.indexOf(t.slice(-1))>-1&&(a=t.slice(-1),t=t.slice(0,-1)),e.sys.variableWrapper(this.params,r,t,a)}else return t},"@URL/true":function(e,t){return t},"@DOI/true":function(e,t){return t}},n.Output.Formats.prototype.asciidoc={text_escape:function(e){return e||(e=``),e.replace(`*`,`pass:[*]`,`g`).replace(`_`,`pass:[_]`,`g`).replace(`#`,`pass:[#]`,`g`).replace(`^`,`pass:[^]`,`g`).replace(`~`,`pass:[~]`,`g`).replace(`[[`,`pass:[[[]`,`g`).replace(`  `,`&#160; `,`g`).replace(n.SUPERSCRIPTS_REGEXP,function(e){return`^`+n.SUPERSCRIPTS[e]+`^`})},bibstart:``,bibend:``,"@passthrough/true":n.Output.Formatters.passthrough,"@font-style/italic":`__%%STRING%%__`,"@font-style/oblique":`__%%STRING%%__`,"@font-style/normal":!1,"@font-variant/small-caps":`[small-caps]#%%STRING%%#`,"@font-variant/normal":!1,"@font-weight/bold":`**%%STRING%%**`,"@font-weight/normal":!1,"@font-weight/light":!1,"@text-decoration/none":!1,"@text-decoration/underline":`[underline]##%%STRING%%##`,"@vertical-align/sup":`^^%%STRING%%^^`,"@vertical-align/sub":`~~%%STRING%%~~`,"@vertical-align/baseline":!1,"@strip-periods/true":n.Output.Formatters.passthrough,"@strip-periods/false":n.Output.Formatters.passthrough,"@quotes/true":function(e,t){return t===void 0?"``":"``"+t+`''`},"@quotes/inner":function(e,t){return t===void 0?"`":"`"+t+`'`},"@quotes/false":!1,"@cite/entry":function(e,t){return e.sys.wrapCitationEntry(t,this.item_id,this.locator_txt,this.suffix_txt)},"@bibliography/entry":function(e,t){return t+`
`},"@display/block":function(e,t){return t},"@display/left-margin":function(e,t){return t},"@display/right-inline":function(e,t){return` `+t},"@display/indent":function(e,t){return` `+t},"@showid/true":function(e,t){if(!e.tmp.just_looking&&!e.tmp.suppress_decorations&&this.params&&typeof t==`string`){var r=``;if(t){var i=t.match(n.VARIABLE_WRAPPER_PREPUNCT_REX);r=i[1],t=i[2]}var a=``;return t&&n.SWAPPING_PUNCTUATION.indexOf(t.slice(-1))>-1&&(a=t.slice(-1),t=t.slice(0,-1)),e.sys.variableWrapper(this.params,r,t,a)}else return t},"@URL/true":function(e,t){return t},"@DOI/true":function(e,t){var n=t;return t.match(/^https?:\/\//)||(n=`https://doi.org/`+t),n+`[`+t+`]`}},n.Output.Formats.prototype.fo={text_escape:function(e){return e||(e=``),e.replace(/&/g,`&#38;`).replace(/</g,`&#60;`).replace(/>/g,`&#62;`).replace(`  `,`&#160; `,`g`).replace(n.SUPERSCRIPTS_REGEXP,function(e){return`<fo:inline vertical-align="super">`+n.SUPERSCRIPTS[e]+`</fo:inline>`})},bibstart:``,bibend:``,"@passthrough/true":n.Output.Formatters.passthrough,"@font-style/italic":`<fo:inline font-style="italic">%%STRING%%</fo:inline>`,"@font-style/oblique":`<fo:inline font-style="oblique">%%STRING%%</fo:inline>`,"@font-style/normal":`<fo:inline font-style="normal">%%STRING%%</fo:inline>`,"@font-variant/small-caps":`<fo:inline font-variant="small-caps">%%STRING%%</fo:inline>`,"@font-variant/normal":`<fo:inline font-variant="normal">%%STRING%%</fo:inline>`,"@font-weight/bold":`<fo:inline font-weight="bold">%%STRING%%</fo:inline>`,"@font-weight/normal":`<fo:inline font-weight="normal">%%STRING%%</fo:inline>`,"@font-weight/light":`<fo:inline font-weight="lighter">%%STRING%%</fo:inline>`,"@text-decoration/none":`<fo:inline text-decoration="none">%%STRING%%</fo:inline>`,"@text-decoration/underline":`<fo:inline text-decoration="underline">%%STRING%%</fo:inline>`,"@vertical-align/sup":`<fo:inline vertical-align="super">%%STRING%%</fo:inline>`,"@vertical-align/sub":`<fo:inline vertical-align="sub">%%STRING%%</fo:inline>`,"@vertical-align/baseline":`<fo:inline vertical-align="baseline">%%STRING%%</fo:inline>`,"@strip-periods/true":n.Output.Formatters.passthrough,"@strip-periods/false":n.Output.Formatters.passthrough,"@quotes/true":function(e,t){return t===void 0?e.getTerm(`open-quote`):e.getTerm(`open-quote`)+t+e.getTerm(`close-quote`)},"@quotes/inner":function(e,t){return t===void 0?`’`:e.getTerm(`open-inner-quote`)+t+e.getTerm(`close-inner-quote`)},"@quotes/false":!1,"@cite/entry":function(e,t){return e.sys.wrapCitationEntry(t,this.item_id,this.locator_txt,this.suffix_txt)},"@bibliography/entry":function(e,t){var n=``;if(e.bibliography&&e.bibliography.opt&&e.bibliography.opt.hangingindent){var r=e.bibliography.opt.hangingindent;n=` start-indent="`+r+`em" text-indent="-`+r+`em"`}var i=``;return e.sys.embedBibliographyEntry&&(i=e.sys.embedBibliographyEntry(this.item_id)+`
`),`<fo:block id="`+this.system_id+`"`+n+`>`+t+`</fo:block>
`+i},"@display/block":function(e,t){return`
  <fo:block>`+t+`</fo:block>
`},"@display/left-margin":function(e,t){return`
  <fo:table table-layout="fixed" width="100%">
    <fo:table-column column-number="1" column-width="$$$__COLUMN_WIDTH_1__$$$"/>
    <fo:table-column column-number="2" column-width="proportional-column-width(1)"/>
    <fo:table-body>
      <fo:table-row>
        <fo:table-cell>
          <fo:block>`+t+`</fo:block>
        </fo:table-cell>
        `},"@display/right-inline":function(e,t){return`<fo:table-cell>
          <fo:block>`+t+`</fo:block>
        </fo:table-cell>
      </fo:table-row>
    </fo:table-body>
  </fo:table>
`},"@display/indent":function(e,t){return`<fo:block margin-left="2em">`+t+`</fo:block>
`},"@showid/true":function(e,t){if(!e.tmp.just_looking&&!e.tmp.suppress_decorations&&this.params&&typeof t==`string`){var r=``;if(t){var i=t.match(n.VARIABLE_WRAPPER_PREPUNCT_REX);r=i[1],t=i[2]}var a=``;return t&&n.SWAPPING_PUNCTUATION.indexOf(t.slice(-1))>-1&&(a=t.slice(-1),t=t.slice(0,-1)),e.sys.variableWrapper(this.params,r,t,a)}else return t},"@URL/true":function(e,t){return`<fo:basic-link external-destination="url('`+t+`')">`+t+`</fo:basic-link>`},"@DOI/true":function(e,t){var n=t;return t.match(/^https?:\/\//)||(n=`https://doi.org/`+t),`<fo:basic-link external-destination="url('`+n+`')">`+t+`</fo:basic-link>`}},n.Output.Formats.prototype.latex={text_escape:function(e){return e||(e=``),e},bibstart:`\\begin{thebibliography}{4}`,bibend:`\\end{thebibliography}`,"@font-style/italic":`{\\em %%STRING%%}`,"@font-style/oblique":!1,"@font-style/normal":!1,"@font-variant/small-caps":!1,"@passthrough/true":n.Output.Formatters.passthrough,"@font-variant/normal":!1,"@font-weight/bold":`{\\bf %%STRING%%}`,"@font-weight/normal":!1,"@font-weight/light":!1,"@text-decoration/none":!1,"@text-decoration/underline":!1,"@vertical-align/baseline":!1,"@vertical-align/sup":!1,"@vertical-align/sub":!1,"@strip-periods/true":n.Output.Formatters.passthrough,"@strip-periods/false":n.Output.Formatters.passthrough,"@quotes/true":function(e,t){return t===void 0?e.getTerm(`open-quote`):e.getTerm(`open-quote`)+t+e.getTerm(`close-quote`)},"@quotes/inner":function(e,t){return t===void 0?`’`:e.getTerm(`open-inner-quote`)+t+e.getTerm(`close-inner-quote`)},"@quotes/false":!1,"@cite/entry":function(e,t){return e.sys.wrapCitationEntry(t,this.item_id,this.locator_txt,this.suffix_txt)},"@bibliography/entry":function(e,t){return`\\bibitem{`+e.sys.embedBibliographyEntry(this.item_id)+`}
`},"@display/block":function(e,t){return`
`+t},"@display/left-margin":function(e,t){return t},"@display/right-inline":function(e,t){return t},"@display/indent":function(e,t){return`
    `+t},"@showid/true":function(e,t,n){return t},"@URL/true":function(e,t){return t},"@DOI/true":function(e,t){return t}},n.Output.Formats=new n.Output.Formats,n.Registry=function(e){this.debug=!1,this.state=e,this.registry={},this.reflist=[],this.refhash={},this.namereg=new n.Registry.NameReg(e),this.citationreg=new n.Registry.CitationReg(e),this.authorstrings={},this.masterMap={},this.mylist=[],this.myhash={},this.deletes=[],this.inserts=[],this.uncited={},this.refreshes={},this.akeys={},this.oldseq={},this.return_data={},this.ambigcites={},this.ambigresets={},this.sorter=new n.Registry.Comparifier(e,`bibliography_sort`),this.getSortedIds=function(){for(var e=[],t=0,n=this.reflist.length;t<n;t+=1)e.push(``+this.reflist[t].id);return e},this.getSortedRegistryItems=function(){for(var e=[],t=0,n=this.reflist.length;t<n;t+=1)e.push(this.reflist[t]);return e}},n.Registry.prototype.init=function(e,t){var n,r;if(this.oldseq={},t){this.uncited={};for(var n=0,r=e.length;n<r;n+=1)this.myhash[e[n]]||this.mylist.push(``+e[n]),this.uncited[e[n]]=!0,this.myhash[e[n]]=!0}else{for(var i in this.uncited)e.push(i);var a={};for(n=e.length-1;n>-1;n+=-1)a[e[n]]?e=e.slice(0,n).concat(e.slice(n+1)):a[e[n]]=!0;this.mylist=e,this.myhash=a}this.refreshes={},this.touched={},this.ambigsTouched={},this.ambigresets={}},n.Registry.prototype.dopurge=function(e){for(var t=this.mylist.length-1;t>-1;t+=-1)this.citationreg.citationsByItemId&&(!this.citationreg.citationsByItemId||!this.citationreg.citationsByItemId[this.mylist[t]])&&!e[this.mylist[t]]&&(delete this.myhash[this.mylist[t]],delete this.uncited[this.mylist[t]],this.mylist=this.mylist.slice(0,t).concat(this.mylist.slice(t+1)));this.dodeletes(this.myhash)},n.Registry.prototype.dodeletes=function(e){var t,n,r,i,a,o,s,c,l;if(typeof e==`string`){var n=e;e={},e[n]=!0}for(var n in this.registry)if(!e[n]){if(this.uncited[n])continue;for(s in t=this.namereg.delitems(n),t)this.refreshes[s]=!0;for(r=this.registry[n].ambig,c=this.ambigcites[r].indexOf(n),c>-1&&(o=this.ambigcites[r].slice(),this.ambigcites[r]=o.slice(0,c).concat(o.slice(c+1,o.length)),this.ambigresets[r]=this.ambigcites[r].length),a=this.ambigcites[r].length,i=0;i<a;i+=1)l=``+this.ambigcites[r][i],this.refreshes[l]=!0;if(this.registry[n].siblings){if(this.registry[n].siblings.length==1){var u=this.registry[n].siblings[0];this.registry[u].siblings&&(this.registry[u].siblings.pop(),this.registry[u].master=!0)}else if(this.registry[n].siblings.length>1){var d=[n];if(this.registry[n].master){var f=this.registry[n].siblings[0],p=this.registry[f];p.master=!0,d.push(f)}for(var m=[],h=this.registry[n].siblings.length-1;h>-1;h+=-1){var g=this.registry[n].siblings.pop();d.indexOf(g)===-1&&m.push(g)}for(var h=m.length-1;h>-1;h+=-1)this.registry[n].siblings.push(m[h])}}for(var _=this.reflist.length-1;_>-1;_--)this.reflist[_].id===n&&(this.reflist=this.reflist.slice(0,_).concat(this.reflist.slice(_+1)));delete this.registry[n],delete this.refhash[n],this.return_data.bibchange=!0}},n.Registry.prototype.doinserts=function(e){var t,r,i,a,o,s,c;typeof e==`string`&&(e=[e]);for(var s=0,c=e.length;s<c;s+=1)t=e[s],this.registry[t]||(r=this.state.retrieveItem(t),i=n.getAmbiguousCite.call(this.state,r),this.ambigsTouched[i]=!0,r.legislation_id||(this.akeys[i]=!0),a={id:``+t,seq:0,offset:0,sortkeys:!1,ambig:!1,rendered:!1,disambig:!1,ref:r,newItem:!0},this.registry[t]=a,this.citationreg.citationsByItemId&&this.citationreg.citationsByItemId[t]&&(this.registry[t][`first-reference-note-number`]=this.citationreg.citationsByItemId[t][0].properties.noteIndex),o=n.getAmbigConfig.call(this.state),this.registerAmbigToken(i,t,o),this.touched[t]=!0,this.return_data.bibchange=!0)},n.Registry.prototype.rebuildlist=function(e){var t,n,r,i;if(e)for(this.reflist=[],t=this.mylist.length,n=0;n<t;n+=1)r=this.mylist[n],i=this.registry[r],this.reflist.push(i),this.oldseq[r]=this.registry[r].seq,this.registry[r].seq=n+1;else for(this.reflist_inserts=[],t=this.mylist.length,n=0;n<t;n+=1)r=this.mylist[n],i=this.registry[r],i.newItem&&this.reflist_inserts.push(i),this.oldseq[r]=this.registry[r].seq,this.registry[r].seq=n+1},n.Registry.prototype.dorefreshes=function(){var e,t,r,i,a;for(var e in this.refreshes)if(t=this.registry[e],t){t.sortkeys=void 0,r=this.state.refetchItem(e);var i=t.ambig;for(var o in i===void 0&&(this.state.tmp.disambig_settings=!1,i=n.getAmbiguousCite.call(this.state,r),a=n.getAmbigConfig.call(this.state),this.registerAmbigToken(i,e,a)),this.ambigresets)if(this.ambigresets[o]===1){var s=this.ambigcites[i][0],r=this.state.refetchItem(s);this.registry[s].disambig=new n.AmbigConfig,this.state.tmp.disambig_settings=!1;var i=n.getAmbiguousCite.call(this.state,r),a=n.getAmbigConfig.call(this.state);this.registerAmbigToken(i,s,a)}this.state.tmp.taintedItemIDs[e]=!0,this.ambigsTouched[i]=!0,r.legislation_id||(this.akeys[i]=!0),this.touched[e]=!0}},n.Registry.prototype.setdisambigs=function(){for(var e in this.ambigsTouched)this.state.disambiguate.run(e);this.ambigsTouched={},this.akeys={}},n.Registry.prototype.renumber=function(){var e,t,r;for(this.state.bibliography_sort.opt.citation_number_sort_direction===n.DESCENDING&&(this.state.bibliography_sort.tmp.citation_number_map={}),e=this.reflist.length,t=0;t<e;t+=1)r=this.reflist[t],r.seq=t+1,this.state.bibliography_sort.opt.citation_number_sort_direction===n.DESCENDING&&(this.state.bibliography_sort.tmp.citation_number_map[r.seq]=this.reflist.length-r.seq+1),this.state.opt.update_mode===n.NUMERIC&&r.seq!=this.oldseq[r.id]&&(this.state.tmp.taintedItemIDs[r.id]=!0),r.seq!=this.oldseq[r.id]&&(this.return_data.bibchange=!0)},n.Registry.prototype.setsortkeys=function(){for(var e,t=0,r=this.mylist.length;t<r;t+=1){var e=this.mylist[t];(this.touched[e]||this.state.tmp.taintedItemIDs[e]||!this.registry[e].sortkeys)&&(this.registry[e].sortkeys=n.getSortKeys.call(this.state,this.state.retrieveItem(e),`bibliography_sort`))}},n.Registry.prototype._insertItem=function(e,t){return t.splice(this._locationOf(e,t)+1,0,e),t},n.Registry.prototype._locationOf=function(e,t,n,r){if(t.length===0)return-1;n=n||0,r=r||t.length;var i=n+r>>1,a=this.sorter.compareKeys(e,t[i]);if(r-n<=1)return a==-1?i-1:i;switch(a){case-1:return this._locationOf(e,t,n,i);case 0:return i;case 1:return this._locationOf(e,t,i,r)}},n.Registry.prototype.sorttokens=function(e){var t,n,r,i;if(!e){for(this.reflist_inserts=[],t=this.mylist.length,i=0;i<t;i+=1)n=this.mylist[i],r=this.registry[n],r.newItem&&this.reflist_inserts.push(r);for(var a in this.state.tmp.taintedItemIDs)if(this.registry[a]&&!this.registry[a].newItem)for(var o=this.reflist.length-1;o>-1;o--)this.reflist[o].id===a&&(this.reflist_inserts.push(this.reflist[o]),this.reflist=this.reflist.slice(0,o).concat(this.reflist.slice(o+1)));for(var o=0,s=this.reflist_inserts.length;o<s;o++){var r=this.reflist_inserts[o];delete r.newItem,this.reflist=this._insertItem(r,this.reflist)}for(i=0;i<t;i+=1)n=this.mylist[i],r=this.registry[n],this.registry[n].seq=i+1}},n.Registry.Comparifier=function(e,t){var r,i,a,o,s=n.getSortCompare.call(e,e.opt[`default-locale-sort`]);r=e[t].opt.sort_directions,this.compareKeys=function(e,t){for(i=e.sortkeys?e.sortkeys.length:0,a=0;a<i;a+=1){var n=0;if(n=e.sortkeys[a]===t.sortkeys[a]?0:e.sortkeys[a]===void 0?r[a][1]:t.sortkeys[a]===void 0?r[a][0]:s(e.sortkeys[a],t.sortkeys[a]),0<n)return r[a][1];if(0>n)return r[a][0]}return e.seq>t.seq?1:e.seq<t.seq?-1:0},o=this.compareKeys,this.compareCompositeKeys=function(e,t){return o(e[1],t[1])}},n.Registry.prototype.compareRegistryTokens=function(e,t){return e.seq>t.seq?1:e.seq<t.seq?-1:0},n.Registry.prototype.registerAmbigToken=function(e,t,r){if(this.registry[t]||n.debug(`Warning: unregistered item: itemID=(`+t+`), akey=(`+e+`)`),this.registry[t]&&this.registry[t].disambig&&this.registry[t].disambig.names){for(var i=0,a=r.names.length;i<a;i+=1)if(r.names[i]!==this.registry[t].disambig.names[i])this.state.tmp.taintedItemIDs[t]=!0;else if(r.givens[i])for(var o=0,s=r.givens[i].length;o<s;o+=1)r.givens[i][o]!==this.registry[t].disambig.givens[i][o]&&(this.state.tmp.taintedItemIDs[t]=!0)}this.ambigcites[e]||(this.ambigcites[e]=[]),this.ambigcites[e].indexOf(``+t)===-1&&this.ambigcites[e].push(``+t),this.registry[t].ambig=e,this.registry[t].disambig=n.cloneAmbigConfig(r)},n.getSortKeys=function(e,t){var r=this.tmp.area,i=this.tmp.root,a=this.tmp.extension,o=n.Util.Sort.strip_prepositions,s,c;for(this.tmp.area=t,this.tmp.root=t.indexOf(`_`)>-1?t.slice(0,-5):t,this.tmp.extension=`_sort`,this.tmp.disambig_override=!0,this.tmp.disambig_request=!1,this.tmp.suppress_decorations=!0,n.getCite.call(this,e),this.tmp.suppress_decorations=!1,this.tmp.disambig_override=!1,s=this[t].keys.length,c=0;c<s;c+=1)this[t].keys[c]=o(this[t].keys[c]);return this.tmp.area=r,this.tmp.root=i,this.tmp.extension=a,this[t].keys},n.Registry.NameReg=function(e){var t,r,i,a,o,s,c,l,u,d,f,p;this.state=e,this.namereg={},this.nameind={},this.nameindpkeys={},this.itemkeyreg={},c=function(e){return e||(e=``),e.replace(/\./g,` `).replace(/\s+/g,` `).replace(/\s+$/,``)},l=function(e,a,o){t=c(o.family),e.opt[`demote-non-dropping-particle`]===`never`&&o[`non-dropping-particle`]&&o.family&&(t=`${t} ${o[`non-dropping-particle`]}`),i=c(o.given);var s=i.match(/[,\!]* ([^,]+)$/);s&&s[1]===s[1].toLowerCase()&&(i=i.replace(/[,\!]* [^,]+$/,``)),r=n.Util.Names.initializeWith(e,i,`%s`),e.citation.opt[`givenname-disambiguation-rule`]===`by-cite`&&(t=``+a+t)},u=function(n,i,s,c,u,d){var f;if(e.tmp.area.slice(0,12)===`bibliography`&&!u)return typeof d==`string`?1:2;i=e.nameOutput.getName(i,`locale-translit`,!0).name,l(this.state,``+n,i),f=2,a=e.opt[`disambiguate-add-givenname`],o=e.citation.opt[`givenname-disambiguation-rule`];var p=o;if(o===`by-cite`&&(o=`all-names`),u===`short`?f=0:typeof d==`string`&&(f=1),this.namereg[t]===void 0||this.namereg[t].ikey[r]===void 0)return f;if(p===`by-cite`&&f<=c)return c;if(!a||typeof o==`string`&&o.slice(0,12)===`primary-name`&&s>0||(!o||o===`all-names`||o===`primary-name`?(this.namereg[t].count>1&&(f=1),(this.namereg[t].ikey&&this.namereg[t].ikey[r].count>1||this.namereg[t].count>1&&typeof d!=`string`)&&(f=2)):(o===`all-names-with-initials`||o===`primary-name-with-initials`)&&(f=this.namereg[t].count>1?1:0),e.registry.registry[n]))return f;if(u==`short`)return 0;if(typeof d==`string`)return 1},d=function(n){var a,o,c,l,u;(typeof n==`string`||typeof n==`number`)&&(n=[``+n]);var d={};for(o=n.length,a=0;a<o;a+=1)if(l=``+n[a],this.nameind[l]){for(u in this.nameind[l])if(this.nameind[l].hasOwnProperty(u)){var f=u.split(`::`);if(t=f[0],r=f[1],i=f[2],this.namereg[t]===void 0)continue;if(s=this.namereg[t].items,i&&this.namereg[t].ikey[r]&&this.namereg[t].ikey[r].skey[i]&&(p=this.namereg[t].ikey[r].skey[i].items,c=p.indexOf(``+l),c>-1&&(this.namereg[t].ikey[r].skey[i].items=p.slice(0,c).concat(p.slice([c+1]))),this.namereg[t].ikey[r].skey[i].items.length===0&&(delete this.namereg[t].ikey[r].skey[i],this.namereg[t].ikey[r].count+=-1,this.namereg[t].ikey[r].count<2)))for(var m=0,h=this.namereg[t].ikey[r].items.length;m<h;m+=1)e.tmp.taintedItemIDs[this.namereg[t].ikey[r].items[m]]=!0;if(r&&this.namereg[t].ikey[r]&&(c=this.namereg[t].ikey[r].items.indexOf(``+l),c>-1&&(s=this.namereg[t].ikey[r].items.slice(),this.namereg[t].ikey[r].items=s.slice(0,c).concat(s.slice([c+1]))),this.namereg[t].ikey[r].items.length===0&&(delete this.namereg[t].ikey[r],this.namereg[t].count+=-1,this.namereg[t].count<2)))for(var m=0,h=this.namereg[t].items.length;m<h;m+=1)e.tmp.taintedItemIDs[this.namereg[t].items[m]]=!0;t&&(c=this.namereg[t].items.indexOf(``+l),c>-1&&(s=this.namereg[t].items.slice(),this.namereg[t].items=s.slice(0,c).concat(s.slice([c+1],s.length))),this.namereg[t].items.length<2&&delete this.namereg[t]),delete this.nameind[l][u]}delete this.nameind[l],delete this.nameindpkeys[l]}return d},f=function(n,a,o){var s,c;if(a=e.nameOutput.getName(a,`locale-translit`,!0).name,!(e.citation.opt[`givenname-disambiguation-rule`]&&e.citation.opt[`givenname-disambiguation-rule`].slice(0,8)===`primary-`&&o!==0)){if(l(this.state,``+n,a),t&&(this.namereg[t]===void 0?(this.namereg[t]={},this.namereg[t].count=0,this.namereg[t].ikey={},this.namereg[t].items=[n]):this.namereg[t].items.indexOf(n)===-1&&this.namereg[t].items.push(n)),t&&r)if(this.namereg[t].ikey[r]===void 0){if(this.namereg[t].ikey[r]={},this.namereg[t].ikey[r].count=0,this.namereg[t].ikey[r].skey={},this.namereg[t].ikey[r].items=[n],this.namereg[t].count+=1,this.namereg[t].count===2)for(var s=0,c=this.namereg[t].items.length;s<c;s+=1)e.tmp.taintedItemIDs[this.namereg[t].items[s]]=!0}else this.namereg[t].ikey[r].items.indexOf(n)===-1&&this.namereg[t].ikey[r].items.push(n);if(t&&r&&i)if(this.namereg[t].ikey[r].skey[i]===void 0){if(this.namereg[t].ikey[r].skey[i]={},this.namereg[t].ikey[r].skey[i].items=[n],this.namereg[t].ikey[r].count+=1,this.namereg[t].ikey[r].count===2)for(var s=0,c=this.namereg[t].ikey[r].items.length;s<c;s+=1)e.tmp.taintedItemIDs[this.namereg[t].ikey[r].items[s]]=!0}else this.namereg[t].ikey[r].skey[i].items.indexOf(n)===-1&&this.namereg[t].ikey[r].skey[i].items.push(n);this.nameind[n]===void 0&&(this.nameind[n]={},this.nameindpkeys[n]={}),t&&(this.nameind[n][t+`::`+r+`::`+i]=!0,this.nameindpkeys[n][t]=this.namereg[t])}},this.addname=f,this.delitems=d,this.evalname=u},n.Registry.CitationReg=function(){this.citationById={},this.citationByIndex=[]},n.Disambiguation=function(e){this.state=e,this.sys=this.state.sys,this.registry=e.registry.registry,this.ambigcites=e.registry.ambigcites,this.configModes(),this.debug=!1},n.Disambiguation.prototype.run=function(e){this.modes.length&&(this.debug&&this.state.sys.print(`[A] === RUN ===`),this.akey=e,this.initVars(e)&&this.runDisambig())},n.Disambiguation.prototype.runDisambig=function(){var e;for(this.debug&&this.state.sys.print(`[C] === runDisambig() ===`),this.initGivens=!0;this.lists.length;){for(this.gnameset=0,this.gname=0,this.clashes=[1,0];this.lists[0][1].length;)this.listpos=0,this.base||(this.base=this.lists[0][0]),e=this.incrementDisambig(),this.scanItems(this.lists[0]),this.evalScan(e);this.lists=this.lists.slice(1)}},n.Disambiguation.prototype.scanItems=function(e){var t,r,i;this.debug&&this.state.sys.print(`[2] === scanItems() ===`),this.Item=e[1][0],this.ItemCite=n.getAmbiguousCite.call(this.state,this.Item,this.base,!0),this.scanlist=e[1],this.partners=[],this.partners.push(this.Item),this.nonpartners=[];for(var a=0,t=1,r=e[1].length;t<r;t+=1){i=e[1][t];var o=n.getAmbiguousCite.call(this.state,i,this.base,!0);this.debug&&t>1&&this.state.sys.print(`  -----------`),this.ItemCite===o?(this.debug&&(this.state.sys.print(`  [CLASH]--> `+this.Item.id+`: `+this.ItemCite),this.state.sys.print(`             `+i.id+`: `+o)),a+=1,this.partners.push(i)):(this.debug&&(this.state.sys.print(`  [clear]--> `+this.Item.id+`: `+this.ItemCite),this.state.sys.print(`             `+i.id+`: `+o)),this.nonpartners.push(i))}this.clashes[0]=this.clashes[1],this.clashes[1]=a},n.Disambiguation.prototype.evalScan=function(e){this[this.modes[this.modeindex]](e),e&&(this.modeindex<this.modes.length-1?this.modeindex+=1:this.lists[this.listpos+1]=[this.base,[]])},n.Disambiguation.prototype.disNames=function(e){var t,n;if(this.debug&&this.state.sys.print(`[3] == disNames() ==`),this.clashes[1]===0&&this.nonpartners.length===1)this.captureStepToBase(),this.debug&&(this.state.sys.print(`  ** RESOLUTION [a]: lone partner, one nonpartner`),this.state.sys.print(`  registering `+this.partners[0].id+` and `+this.nonpartners[0].id)),this.state.registry.registerAmbigToken(this.akey,``+this.nonpartners[0].id,this.betterbase),this.state.registry.registerAmbigToken(this.akey,``+this.partners[0].id,this.betterbase),this.lists[this.listpos]=[this.betterbase,[]];else if(this.clashes[1]===0)this.captureStepToBase(),this.debug&&(this.state.sys.print(`  ** RESOLUTION [b]: lone partner, unknown number of remaining nonpartners`),this.state.sys.print(`  registering `+this.partners[0].id)),this.state.registry.registerAmbigToken(this.akey,``+this.partners[0].id,this.betterbase),this.lists[this.listpos]=[this.betterbase,this.nonpartners],this.nonpartners.length&&(this.initGivens=!0);else if(this.nonpartners.length===1)this.captureStepToBase(),this.debug&&(this.state.sys.print(`  ** RESOLUTION [c]: lone nonpartner, unknown number of partners remaining`),this.state.sys.print(`  registering `+this.nonpartners[0].id)),this.state.registry.registerAmbigToken(this.akey,``+this.nonpartners[0].id,this.betterbase),this.lists[this.listpos]=[this.betterbase,this.partners];else if(this.clashes[1]<this.clashes[0])this.captureStepToBase(),this.debug&&this.state.sys.print(`  ** RESOLUTION [d]: better result, but no entries safe to register`),this.lists[this.listpos]=[this.betterbase,this.partners],this.lists.push([this.betterbase,this.nonpartners]);else if(this.debug&&this.state.sys.print(`  ** RESOLUTION [e]: no improvement, and clashes remain`),e&&(this.lists[this.listpos]=[this.betterbase,this.nonpartners],this.lists.push([this.betterbase,this.partners]),this.modeindex===this.modes.length-1)){this.debug&&this.state.sys.print(`     (registering clashing entries because we've run out of options)`);for(var t=0,n=this.partners.length;t<n;t+=1)this.state.registry.registerAmbigToken(this.akey,``+this.partners[t].id,this.betterbase);this.lists[this.listpos]=[this.betterbase,[]]}},n.Disambiguation.prototype.disExtraText=function(){this.debug&&this.state.sys.print(`[3] === disExtraText ==`);var e=!1;if(this.clashes[1]===0&&this.nonpartners.length<2&&(e=!0),!e&&(!this.base.disambiguate||this.state.tmp.disambiguate_count!==this.state.tmp.disambiguate_maxMax))if(this.modeindex=0,this.base.disambiguate=this.state.tmp.disambiguate_count,this.betterbase.disambiguate=this.state.tmp.disambiguate_count,this.base.disambiguate)this.disNames();else{this.initGivens=!0,this.base.disambiguate=1;for(var t=0,n=this.lists[this.listpos][1].length;t<n;t+=1)this.state.tmp.taintedItemIDs[this.lists[this.listpos][1][t].id]=!0}else if(e||this.state.tmp.disambiguate_count===this.state.tmp.disambiguate_maxMax)if(e||this.modeindex===this.modes.length-1){for(var r=this.lists[this.listpos][0],t=0,n=this.lists[this.listpos][1].length;t<n;t+=1)this.state.tmp.taintedItemIDs[this.lists[this.listpos][1][t].id]=!0,this.state.registry.registerAmbigToken(this.akey,``+this.lists[this.listpos][1][t].id,r);this.lists[this.listpos]=[this.betterbase,[]]}else{this.modeindex=this.modes.length-1;var r=this.lists[this.listpos][0];r.disambiguate=!0;for(var t=0,n=this.lists[this.listpos][1].length;t<n;t+=1)this.state.tmp.taintedItemIDs[this.lists[this.listpos][1][t].id]=!0,this.state.registry.registerAmbigToken(this.akey,``+this.lists[this.listpos][1][t].id,r)}},n.Disambiguation.prototype.disYears=function(){var e,t,r,i;this.debug&&this.state.sys.print(`[3] === disYears ==`),r=[];var a=this.lists[this.listpos][0];if(this.clashes[1])for(var o=0,s=this.state.registry.mylist.length;o<s;o+=1)for(var c=this.state.registry.mylist[o],l=0,u=this.lists[this.listpos][1].length;l<u;l+=1){var i=this.lists[this.listpos][1][l];if(i.id==c){r.push(this.registry[i.id]);break}}r.sort(this.state.registry.sorter.compareKeys);for(var e=0,t=r.length;e<t;e+=1){a.year_suffix=``+e;var d=this.state.registry.registry[r[e].id].disambig;this.state.registry.registerAmbigToken(this.akey,``+r[e].id,a),n.ambigConfigDiff(d,a)&&(this.state.tmp.taintedItemIDs[r[e].id]=!0)}this.lists[this.listpos]=[this.betterbase,[]]},n.Disambiguation.prototype.incrementDisambig=function(){if(this.debug&&this.state.sys.print(`
[1] === incrementDisambig() ===`),this.initGivens)return this.initGivens=!1,!1;var e=!1,t=!0;if(this.modes[this.modeindex]===`disNames`){t=!1,typeof this.givensMax!=`number`&&(t=!0);var n=!1;typeof this.namesMax!=`number`&&(n=!0),typeof this.givensMax==`number`&&(this.base.givens.length&&this.base.givens[this.gnameset][this.gname]<this.givensMax?this.base.givens[this.gnameset][this.gname]+=1:t=!0),typeof this.namesMax==`number`&&t&&(this.state.opt[`disambiguate-add-names`]?(n=!1,this.gname<this.namesMax?(this.base.names[this.gnameset]+=1,this.gname+=1):n=!0):n=!0),typeof this.namesetsMax==`number`&&n&&this.gnameset<this.namesetsMax&&(this.gnameset+=1,this.base.names[this.gnameset]=1,this.gname=0),this.debug&&(this.state.sys.print(`    ------------------`),this.state.sys.print(`    incremented values`),this.state.sys.print(`    ------------------`),this.state.sys.print(`    | gnameset: `+this.gnameset),this.state.sys.print(`    | gname: `+this.gname),this.state.sys.print(`    | names value: `+this.base.names[this.gnameset]),this.base.givens.length?this.state.sys.print(`    | givens value: `+this.base.givens[this.gnameset][this.gname]):this.state.sys.print(`    | givens value: nil`),this.state.sys.print(`    | namesetsMax: `+this.namesetsMax),this.state.sys.print(`    | namesMax: `+this.namesMax),this.state.sys.print(`    | givensMax: `+this.givensMax)),(typeof this.namesetsMax!=`number`||this.namesetsMax===-1||this.gnameset===this.namesetsMax)&&(!this.state.opt[`disambiguate-add-names`]||typeof this.namesMax!=`number`||this.gname===this.namesMax)&&(typeof this.givensMax!=`number`||this.base.givens[this.gnameset]===void 0||this.base.givens[this.gnameset][this.gname]===void 0||this.base.givens[this.gnameset][this.gname]===this.givensMax)&&(e=!0,this.debug&&this.state.sys.print(`    MAXED`))}else this.modes[this.modeindex]===`disExtraText`&&(this.base.disambiguate+=1,this.betterbase.disambiguate+=1);return e},n.Disambiguation.prototype.initVars=function(e){var t,r,i,a,o;if(this.debug&&this.state.sys.print(`[B] === initVars() ===`),this.lists=[],this.base=!1,this.betterbase=!1,this.akey=e,this.maxNamesByItemId={},a=[],i=this.ambigcites[e],!i||!i.length)return!1;var s=this.state.refetchItem(``+i[0]);if(this.getCiteData(s),this.base=n.getAmbigConfig.call(this.state),i&&i.length>1){a.push([this.maxNamesByItemId[s.id],s]);for(var t=1,r=i.length;t<r;t+=1)s=this.state.refetchItem(``+i[t]),this.getCiteData(s,this.base),a.push([this.maxNamesByItemId[s.id],s]);a.sort(function(e,t){return e[0]>t[0]?1:e[0]<t[0]?-1:e[1].id>t[1].id?1:e[1].id<t[1].id?-1:0}),o=[];for(var t=0,r=a.length;t<r;t+=1)o.push(a[t][1]);this.lists.push([this.base,o]),this.Item=this.lists[0][1][0]}else this.Item=this.state.refetchItem(``+i[0]);if(this.modeindex=0,this.state.citation.opt[`disambiguate-add-names`]||!0)this.namesMax=this.maxNamesByItemId[this.Item.id][0];else var t,r;return this.padBase(this.base),this.padBase(this.betterbase),this.base.year_suffix=!1,this.base.disambiguate=!1,this.betterbase.year_suffix=!1,this.betterbase.disambiguate=!1,this.state.citation.opt[`givenname-disambiguation-rule`]===`by-cite`&&this.state.opt[`disambiguate-add-givenname`]&&(this.givensMax=2),!0},n.Disambiguation.prototype.padBase=function(e){for(var t=0,n=e.names.length;t<n;t+=1){e.givens[t]||(e.givens[t]=[]);for(var r=0,i=e.names[t];r<i;r+=1)e.givens[t][r]||(e.givens[t][r]=0)}},n.Disambiguation.prototype.configModes=function(){var e,t;this.modes=[],e=this.state.opt[`disambiguate-add-givenname`],t=this.state.citation.opt[`givenname-disambiguation-rule`],(this.state.opt[`disambiguate-add-names`]||e&&t===`by-cite`)&&this.modes.push(`disNames`),this.state.opt.development_extensions.prioritize_disambiguate_condition?(this.state.opt.has_disambiguate&&this.modes.push(`disExtraText`),this.state.opt[`disambiguate-add-year-suffix`]&&this.modes.push(`disYears`)):(this.state.opt[`disambiguate-add-year-suffix`]&&this.modes.push(`disYears`),this.state.opt.has_disambiguate&&this.modes.push(`disExtraText`))},n.Disambiguation.prototype.getCiteData=function(e,t){if(!this.maxNamesByItemId[e.id]){n.getAmbiguousCite.call(this.state,e,t),t=n.getAmbigConfig.call(this.state),this.maxNamesByItemId[e.id]=n.getMaxVals.call(this.state),this.state.registry.registry[e.id].disambig.givens=this.state.tmp.disambig_settings.givens.slice();for(var r=0,i=this.state.registry.registry[e.id].disambig.givens.length;r<i;r+=1)this.state.registry.registry[e.id].disambig.givens[r]=this.state.tmp.disambig_settings.givens[r].slice();this.namesetsMax=this.state.registry.registry[e.id].disambig.names.length-1,this.base||(this.base=t,this.betterbase=n.cloneAmbigConfig(t)),t.names.length<this.base.names.length&&(this.base=t);for(var r=0,i=t.names.length;r<i;r+=1)t.names[r]>this.base.names[r]&&(this.base.givens[r]=t.givens[r].slice(),this.base.names[r]=t.names[r],this.betterbase.names=this.base.names.slice(),this.betterbase.givens=this.base.givens.slice(),this.padBase(this.base),this.padBase(this.betterbase));this.betterbase.givens=this.base.givens.slice();for(var a=0,o=this.base.givens.length;a<o;a+=1)this.betterbase.givens[a]=this.base.givens[a].slice()}},n.Disambiguation.prototype.captureStepToBase=function(){this.state.citation.opt[`givenname-disambiguation-rule`]===`by-cite`&&this.base.givens&&this.base.givens.length&&this.base.givens[this.gnameset][this.gname]!==void 0&&(this.betterbase.givens.length<this.base.givens.length&&(this.betterbase.givens=JSON.parse(JSON.stringify(this.base.givens))),this.betterbase.givens[this.gnameset][this.gname]=this.base.givens[this.gnameset][this.gname]),this.betterbase.names[this.gnameset]=this.base.names[this.gnameset]},n.Engine.prototype.getJurisdictionList=function(e){for(var t=[],n=e.split(`:`),r=n.length;r>0;r--){var i=n.slice(0,r).join(`:`);if(t.push(i),this.opt.jurisdiction_fallbacks[i]){var a=this.opt.jurisdiction_fallbacks[i];t.push(a)}}return t.indexOf(`us`)===-1&&t.push(`us`),t},n.Engine.prototype.loadStyleModule=function(e,t,r){var i=null,a=0;this.juris[e]={};var o=n.setupXml(t);o.addMissingNameNodes(o.dataObj),o.addInstitutionNodes(o.dataObj),o.insertPublisherAndPlace(o.dataObj),o.flagDateMacros(o.dataObj);for(var s=o.getNodesByName(o.dataObj,`law-module`),c=0,l=s.length;c<l;c++){var u=o.getAttributeValue(s[c],`types`);if(u){this.juris[e].types={},u=u.split(/\s+/);for(var d=0,f=u.length;d<f;d++)this.juris[e].types[u[d]]=!0}r||(i=o.getAttributeValue(s[c],`fallback`),i&&e!==`us`&&(this.opt.jurisdiction_fallbacks[e]=i))}var p=this.opt.lang?this.opt.lang:this.opt[`default-locale`][0];n.SET_COURT_CLASSES(this,p,o,o.dataObj),this.juris[e].types||(this.juris[e].types=n.MODULE_TYPES);for(var s=o.getNodesByName(o.dataObj,`macro`),c=0,l=s.length;c<l;c++){var m=o.getAttributeValue(s[c],`name`);if(!n.MODULE_MACROS[m]){n.debug(`CSL: skipping non-modular macro name "`+m+`" in module context`);continue}a++,this.juris[e][m]=[],this.buildTokenLists(s[c],this.juris[e][m]),this.configureTokenList(this.juris[e][m])}return i},n.Engine.prototype.retrieveAllStyleModules=function(e){var t={},n=this.locale[this.opt.lang].opts[`jurisdiction-preference`];n=n||[],n=[``].concat(n);for(var r=n.length-1;r>-1;r--)for(var i=n[r],a=0,o=e.length;a<o;a++){var s=e[a];if(!this.opt.jurisdictions_seen[s]){var c=this.sys.retrieveStyleModule(s,i);(!c&&!i||c)&&(this.opt.jurisdictions_seen[s]=!0),c&&(t[s]=c)}}return t},n.ParticleList=function(){var e=[[[0,1],null]],t=[[[0,3],null]],n=[[null,[0,1]]],r=[[null,[0,2]]],i=[[null,[0,3]]],a=[[null,[0,1]],[[0,1],null]],o=[[null,[0,2]],[[0,2],null]],s=[[[0,1],null],[null,[0,1]]],c=[[[0,2],null],[null,[0,2]]],l=[[[0,3],null],[null,[0,3]]],u=[[null,[0,2]],[[0,1],[1,2]]];return[[`'s`,n],[`'s-`,n],[`'t`,n],[`a`,n],[`aan 't`,r],[`aan de`,r],[`aan den`,r],[`aan der`,r],[`aan het`,r],[`aan t`,r],[`aan`,n],[`ad-`,a],[`adh-`,a],[`af`,a],[`al`,a],[`al-`,a],[`am de`,r],[`am`,n],[`an-`,a],[`ar-`,a],[`as-`,a],[`ash-`,a],[`at-`,a],[`ath-`,a],[`auf dem`,c],[`auf den`,c],[`auf der`,c],[`auf ter`,r],[`auf`,s],[`aus 'm`,c],[`aus dem`,c],[`aus den`,c],[`aus der`,c],[`aus m`,c],[`aus`,s],[`aus'm`,c],[`az-`,a],[`aš-`,a],[`aḍ-`,a],[`aḏ-`,a],[`aṣ-`,a],[`aṭ-`,a],[`aṯ-`,a],[`aẓ-`,a],[`ben`,n],[`bij 't`,r],[`bij de`,r],[`bij den`,r],[`bij het`,r],[`bij t`,r],[`bij`,n],[`bin`,n],[`boven d`,r],[`boven d'`,r],[`d`,n],[`d'`,a],[`da`,a],[`dal`,n],[`dal'`,n],[`dall'`,n],[`dalla`,n],[`das`,a],[`de die le`,i],[`de die`,r],[`de l`,r],[`de l'`,r],[`de la`,u],[`de las`,u],[`de le`,r],[`de li`,o],[`de van der`,i],[`de`,a],[`de'`,a],[`deca`,n],[`degli`,a],[`dei`,a],[`del`,a],[`dela`,e],[`dell'`,a],[`della`,a],[`delle`,a],[`dello`,a],[`den`,a],[`der`,a],[`des`,a],[`di`,a],[`die le`,r],[`do`,n],[`don`,n],[`dos`,a],[`du`,a],[`ed-`,a],[`edh-`,a],[`el`,a],[`el-`,a],[`en-`,a],[`er-`,a],[`es-`,a],[`esh-`,a],[`et-`,a],[`eth-`,a],[`ez-`,a],[`eš-`,a],[`eḍ-`,a],[`eḏ-`,a],[`eṣ-`,a],[`eṭ-`,a],[`eṯ-`,a],[`eẓ-`,a],[`het`,n],[`i`,n],[`il`,e],[`im`,n],[`in 't`,r],[`in de`,r],[`in den`,r],[`in der`,o],[`in het`,r],[`in t`,r],[`in`,n],[`l`,n],[`l'`,n],[`la`,n],[`las`,n],[`le`,n],[`les`,a],[`lo`,a],[`los`,n],[`lou`,n],[`of`,n],[`onder 't`,r],[`onder de`,r],[`onder den`,r],[`onder het`,r],[`onder t`,r],[`onder`,n],[`op 't`,r],[`op de`,o],[`op den`,r],[`op der`,r],[`op gen`,r],[`op het`,r],[`op t`,r],[`op ten`,r],[`op`,n],[`over 't`,r],[`over de`,r],[`over den`,r],[`over het`,r],[`over t`,r],[`over`,n],[`s`,n],[`s'`,n],[`sen`,e],[`t`,n],[`te`,n],[`ten`,n],[`ter`,n],[`tho`,n],[`thoe`,n],[`thor`,n],[`to`,n],[`toe`,n],[`tot`,n],[`uijt 't`,r],[`uijt de`,r],[`uijt den`,r],[`uijt te de`,i],[`uijt ten`,r],[`uijt`,n],[`uit 't`,r],[`uit de`,r],[`uit den`,r],[`uit het`,r],[`uit t`,r],[`uit te de`,i],[`uit ten`,r],[`uit`,n],[`unter`,n],[`v`,n],[`v.`,n],[`v.d.`,n],[`van 't`,r],[`van de l`,i],[`van de l'`,i],[`van de`,r],[`van de`,r],[`van den`,r],[`van der`,r],[`van gen`,r],[`van het`,r],[`van la`,r],[`van t`,r],[`van ter`,r],[`van van de`,i],[`van`,a],[`vander`,n],[`vd`,n],[`ver`,n],[`vom und zum`,t],[`vom`,a],[`von 't`,r],[`von dem`,c],[`von den`,c],[`von der`,c],[`von t`,r],[`von und zu`,l],[`von zu`,c],[`von`,s],[`voor 't`,r],[`voor de`,r],[`voor den`,r],[`voor in 't`,i],[`voor in t`,i],[`voor`,n],[`vor der`,c],[`vor`,s],[`z`,e],[`ze`,e],[`zu`,s],[`zum`,a],[`zur`,a]]}(),n.parseParticles=function(){function e(e,t,r){var i=e;e=r?e.toLowerCase():e;var a=[],o,s;t?(e=e.split(``).reverse().join(``),o=n.PARTICLE_GIVEN_REGEXP):o=n.PARTICLE_FAMILY_REGEXP;for(var c=e.match(o);c;){var l=t?c[1].split(``).reverse().join(``):c[1],u=c?l:!1,u=u?l.replace(/^[-\'\u02bb\u2019\s]*(.).*$/,`$1`):!1;if(s=u?u.toUpperCase()!==u:!1,!s)break;t?(a.push(i.slice(l.length*-1)),i=i.slice(0,l.length*-1)):(a.push(i.slice(0,l.length)),i=i.slice(l.length)),e=c[2],c=e.match(o)}if(t){e=e.split(``).reverse().join(``),a.reverse();for(var d=1,f=a.length;d<f;d++)a[d].slice(0,1)==` `&&(a[d-1]+=` `);for(var d=0,f=a.length;d<f;d++)a[d].slice(0,1)==` `&&(a[d]=a[d].slice(1));e=i.slice(0,e.length)}else e=i.slice(e.length*-1);return[s,e,a]}function t(e){var t=e.slice(-1);return e=e.trim(),t===` `&&[`'`,`’`].indexOf(e.slice(-1))>-1&&(e+=` `),e}function r(e){if(!e.suffix&&e.given){var t=e.given.match(/(\s*,!*\s*)/);if(t){var n=e.given.indexOf(t[1]),r=e.given.slice(n+t[1].length),i=e.given.slice(n,n+t[1].length).replace(/\s*/g,``);r.replace(/\./g,``)===`et al`&&!e[`dropping-particle`]?(e[`dropping-particle`]=r,e[`comma-dropping-particle`]=`,`):(i.length===2&&(e[`comma-suffix`]=!0),e.suffix=r),e.given=e.given.slice(0,n)}}}return function(n){var i=e(n.family),a=i[1],o=i[2];n.family=a;var s=t(o.join(``));s&&(n[`non-dropping-particle`]=s),r(n);var i=e(n.given,!0),c=i[1],l=i[2];n.given=c;var u=l.join(``).trim();u&&(n[`dropping-particle`]=u)}}(),t.exports=n}))()),u=Symbol.for(`proxied`),d=function(e){let t=function(t,n){if(t.sys.wrapBibliographyEntry){let[e,r]=t.sys.wrapBibliographyEntry(this.system_id);n=[e,n,r].join(``)}return e.call(this,t,n)};return t[u]=!0,t};for(let e in l.default.Output.Formats){let t=l.default.Output.Formats[e][`@bibliography/entry`];!t||t[u]||(l.default.Output.Formats[e][`@bibliography/entry`]=d(t))}function f(e){if(o.has(e))return o.get(e);let t=e.replace(`-`,`_`);return o.has(t)?o.get(t):{}}var p={},m=function(e,t,n,r,i){let a=`${e}|${t}`,o;return p[a]instanceof l.default.Engine?(o=p[a],o.sys.retrieveItem=r,o.sys.wrapBibliographyEntry=void 0,o.updateItems([])):o=p[a]=new l.default.Engine({retrieveLocale:i,retrieveItem:r},n,t,!0),o},h=function(e,t,n,r){if(!l.default.Output.Formats[r]||!l.default.Output.Formats[r][`@bibliography/entry`])throw TypeError(`Cannot find format '${r}'`);let i=e.reduce((e,t)=>(e[t.id]=t,e),{}),a=c.get(c.has(t)?t:`apa`);n=o.has(n)?n:void 0;let s=m(t,n,a,function(e){if(Object.prototype.hasOwnProperty.call(i,e))return i[e];throw Error(`Cannot find entry with id '${e}'`)},f);return s.setOutputFormat(r),s.opt.development_extensions.wrap_url_and_doi=!1,s},g=(e,t,n)=>e.replace(/^\s*<[a-z]+/i,`$& data-${t}="${n}"`),_=(e,t)=>g(e,`csl-entry-id`,t);a();var v=(e,t)=>typeof t==`function`?t(e):t||``;function y(e,t={}){let{template:n=`apa`,lang:i,format:a=`text`,nosort:o=!1}=t,s=t.entry?[].concat(t.entry):e.map(({id:e})=>e);e=r(e);let c=h(e,n,i,a),l=c.updateItems(s,o);if(t.append||t.prepend){let n=e.reduce((e,t)=>(e[t.id]=t,e),{});c.sys.wrapBibliographyEntry=function(e){let r=n[e];return[v(r,t.prepend),v(r,t.append)]}}t.hyperlinks&&(c.opt.development_extensions.wrap_url_and_doi=!0);let[{bibstart:u,bibend:d},f]=c.makeBibliography(),p=f.map((e,t)=>_(e,l[t]));return t.asEntryArray?p.map((e,t)=>[l[t],e]):u+p.join(``)+d}a();function b(e){return typeof e==`object`?e:{id:e}}function x(e){return e.citationItems?e:{citationItems:[].concat(e).map(b),properties:{noteIndex:0}}}function S(e){return e?e.map(x):[]}function C(e,t={}){let{template:n=`apa`,lang:i,format:a=`text`}=t,o=e.map(({id:e})=>e),s=t.entry?t.entry:o;e=r(e);let c=h(e,n,i,a),l=S(t.citationsPre),u=x(s),d=S(t.citationsPost);return c.rebuildProcessorState([...l,u,...d],a,[])[l.length][2]}a(),i(`@csl`,{output:{bibliography:y,citation:C},config:{engine:h,locales:o,templates:c}});
//# sourceMappingURL=lib-mjs.Dp0CejwI.js.map